	; IntyBASIC compiler v1.2.4 Sep/19/2015
        ;
        ; Prologue for IntyBASIC programs
        ; by Oscar Toledo G.  http://nanochess.org/
        ;
        ; Revision: Jan/30/2014. Spacing adjustment and more comments.
        ; Revision: Apr/01/2014. It now sets the starting screen pos. for PRINT
	; Revision: Aug/26/2014. Added PAL detection code.
	; Revision: Dec/12/2014. Added optimized constant multiplication routines
	;                        by James Pujals.
	; Revision: Jan/25/2015. Added marker for automatic title replacement.
	;                        (option --title of IntyBASIC)
	; Revision: Aug/06/2015. Turns off ECS sound. Seed random generator using
	;                        trash in 16-bit RAM. Solved bugs and optimized
	;                        macro for constant multiplication.
	; 

        ROMW 16
        ORG $5000

        ; This macro will 'eat' SRCFILE directives if the assembler doesn't support the directive.
        IF ( DEFINED __FEATURE.SRCFILE ) = 0
            MACRO SRCFILE x, y
            ; macro must be non-empty, but a comment works fine.
            ENDM
        ENDI

        ;
        ; ROM header
        ;
        BIDECLE _ZERO           ; MOB picture base
        BIDECLE _ZERO           ; Process table
        BIDECLE _MAIN           ; Program start
        BIDECLE _ZERO           ; Background base image
        BIDECLE _ONES           ; GRAM
        BIDECLE _TITLE          ; Cartridge title and date
        DECLE   $03C0           ; No ECS title, jump to code after title,
                                ; ... no clicks
                                
_ZERO:  DECLE   $0000           ; Border control
        DECLE   $0000           ; 0 = color stack, 1 = f/b mode
        
_ONES:  DECLE   $0001, $0001    ; Initial color stack 0 and 1: Blue
        DECLE   $0001, $0001    ; Initial color stack 2 and 3: Blue
        DECLE   $0001           ; Initial border color: Blue

C_WHT:  EQU $0007

CLRSCR: MVII #$200,R4           ; Used also for CLS
        MVII #$F0,R1
FILLZERO:
        CLRR R0
MEMSET:
        MVO@ R0,R4
        DECR R1
        BNE MEMSET
        JR R5

        ;
        ; Title, Intellivision EXEC will jump over it and start
        ; execution directly in _MAIN
        ;
	; Note mark is for automatic replacement by IntyBASIC
_TITLE:
	BYTE 116,'Mermaid 0.8',0
        
        ;
        ; Main program
        ;
_MAIN:
        DIS
        MVII #STACK,R6

_MAIN0:
        ;
        ; Clean memory
        ;
        MVII #$00e,R1           ; 14 of sound (ECS)
        MVII #$0f0,R4           ; ECS PSG
        CALL FILLZERO
        MVII #$0fe,R1           ; 240 words of 8 bits plus 14 of sound
        MVII #$100,R4           ; 8-bit scratch RAM
        CALL FILLZERO

	; Seed random generator using 16 bit RAM (not cleared by EXEC)
	CLRR R0
	MVII #$02F0,R4
	MVII #$0110/4,R1        ; Includes phantom memory for extra randomness
_MAIN4:                         ; This loop is courtesy of GroovyBee
	ADD@ R4,R0
	ADD@ R4,R0
	ADD@ R4,R0
	ADD@ R4,R0
	DECR R1
	BNE _MAIN4
	MVO R0,_rand

        MVII #$058,R1           ; 88 words of 16 bits
        MVII #$308,R4           ; 16-bit scratch RAM
        CALL FILLZERO

        CALL CLRSCR             ; Clean up screen

        MVII #_pal1_vector,R0 ; Points to interrupt vector
        MVO R0,ISRVEC
        SWAP R0
        MVO R0,ISRVEC+1

        EIS

_MAIN1:	MVI _ntsc,R0
	CMPI #3,R0
	BNE _MAIN1
	CLRR R2
_MAIN2:	INCR R2
	MVI _ntsc,R0
	CMPI #4,R0
	BNE _MAIN2

        ; 387 for PAL in jzintv
        ; 444 for NTSC in jzintv
        CMPI #415,R2
        MVII #1,R0
        BGE _MAIN3
        CLRR R0
_MAIN3: MVO R0,_ntsc

        CALL _wait
	CALL _init_music
        MVII #1,R0
        MVO R0,_mode_select
        MVII #$038,R0
        MVO R0,$01F8            ; Configures sound
        MVO R0,$00F8            ; Configures sound (ECS)
        CALL _wait

;* ======================================================================== *;
;*  These routines are placed into the public domain by their author.  All  *;
;*  copyright rights are hereby relinquished on the routines and data in    *;
;*  this file.  -- James Pujals (DZ-Jay), 2014                              *;
;* ======================================================================== *;

; Modified by Oscar Toledo G. (nanochess), Aug/06/2015
; * Tested all multiplications with automated test.
; * Accelerated multiplication by 7,14,15,28,31,60,62,63,112,120,124
; * Solved bug in multiplication by 23,39,46,47,55,71,78,79,87,92,93,94,95,103,110,111,119
; * Improved sequence of instructions to be more interruptible.

;; ======================================================================== ;;
;;  MULT reg, tmp, const                                                    ;;
;;  Multiplies "reg" by constant "const" and using "tmp" for temporary      ;;
;;  calculations.  The result is placed in "reg."  The multiplication is    ;;
;;  performed by an optimal combination of shifts, additions, and           ;;
;;  subtractions.                                                           ;;
;;                                                                          ;;
;;  NOTE:   The resulting contents of the "tmp" are undefined.              ;;
;;                                                                          ;;
;;  ARGUMENTS                                                               ;;
;;      reg         A register containing the multiplicand.                 ;;
;;      tmp         A register for temporary calculations.                  ;;
;;      const       The constant multiplier.                                ;;
;;                                                                          ;;
;;  OUTPUT                                                                  ;;
;;      reg         Output value.                                           ;;
;;      tmp         Trashed.                                                ;;
;;      .ERR.Failed True if operation failed.                               ;;
;; ======================================================================== ;;
MACRO   MULT reg, tmp, const
;
    LISTING "code"

_mul.const      QSET    %const%
_mul.done       QSET    0

        IF (%const% > $7F)
_mul.const      QSET    (_mul.const SHR 1)
                SLL     %reg%,  1
        ENDI

        ; Multiply by $00 (0)
        IF (_mul.const = $00)
_mul.done       QSET    -1
                CLRR    %reg%
        ENDI

        ; Multiply by $01 (1)
        IF (_mul.const = $01)
_mul.done       QSET    -1
                ; Nothing to do
        ENDI

        ; Multiply by $02 (2)
        IF (_mul.const = $02)
_mul.done       QSET    -1
                SLL     %reg%,  1
        ENDI

        ; Multiply by $03 (3)
        IF (_mul.const = $03)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $04 (4)
        IF (_mul.const = $04)
_mul.done       QSET    -1
                SLL     %reg%,  2
        ENDI

        ; Multiply by $05 (5)
        IF (_mul.const = $05)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $06 (6)
        IF (_mul.const = $06)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $07 (7)
        IF (_mul.const = $07)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $08 (8)
        IF (_mul.const = $08)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  1
        ENDI

        ; Multiply by $09 (9)
        IF (_mul.const = $09)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $0A (10)
        IF (_mul.const = $0A)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $0B (11)
        IF (_mul.const = $0B)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $0C (12)
        IF (_mul.const = $0C)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $0D (13)
        IF (_mul.const = $0D)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $0E (14)
        IF (_mul.const = $0E)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $0F (15)
        IF (_mul.const = $0F)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $10 (16)
        IF (_mul.const = $10)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  2
        ENDI

        ; Multiply by $11 (17)
        IF (_mul.const = $11)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $12 (18)
        IF (_mul.const = $12)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $13 (19)
        IF (_mul.const = $13)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $14 (20)
        IF (_mul.const = $14)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $15 (21)
        IF (_mul.const = $15)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $16 (22)
        IF (_mul.const = $16)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $17 (23)
        IF (_mul.const = $17)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  1
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $18 (24)
        IF (_mul.const = $18)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $19 (25)
        IF (_mul.const = $19)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $1A (26)
        IF (_mul.const = $1A)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $1B (27)
        IF (_mul.const = $1B)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $1C (28)
        IF (_mul.const = $1C)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $1D (29)
        IF (_mul.const = $1D)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $1E (30)
        IF (_mul.const = $1E)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $1F (31)
        IF (_mul.const = $1F)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
		ADDR	%reg%,	%reg%
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $20 (32)
        IF (_mul.const = $20)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  2
		ADDR	%reg%,	%reg%
        ENDI

        ; Multiply by $21 (33)
        IF (_mul.const = $21)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
		ADDR	%reg%,	%reg%
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $22 (34)
        IF (_mul.const = $22)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $23 (35)
        IF (_mul.const = $23)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $24 (36)
        IF (_mul.const = $24)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $25 (37)
        IF (_mul.const = $25)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $26 (38)
        IF (_mul.const = $26)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $27 (39)
        IF (_mul.const = $27)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $28 (40)
        IF (_mul.const = $28)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $29 (41)
        IF (_mul.const = $29)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $2A (42)
        IF (_mul.const = $2A)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $2B (43)
        IF (_mul.const = $2B)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $2C (44)
        IF (_mul.const = $2C)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $2D (45)
        IF (_mul.const = $2D)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $2E (46)
        IF (_mul.const = $2E)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  1
		SUBR	%tmp%,  %reg%
        ENDI

        ; Multiply by $2F (47)
        IF (_mul.const = $2F)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  1
		SUBR	%tmp%,  %reg%
        ENDI

        ; Multiply by $30 (48)
        IF (_mul.const = $30)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $31 (49)
        IF (_mul.const = $31)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $32 (50)
        IF (_mul.const = $32)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $33 (51)
        IF (_mul.const = $33)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $34 (52)
        IF (_mul.const = $34)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $35 (53)
        IF (_mul.const = $35)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $36 (54)
        IF (_mul.const = $36)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $37 (55)
        IF (_mul.const = $37)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
		SLL	%reg%,	1
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $38 (56)
        IF (_mul.const = $38)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $39 (57)
        IF (_mul.const = $39)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $3A (58)
        IF (_mul.const = $3A)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $3B (59)
        IF (_mul.const = $3B)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $3C (60)
        IF (_mul.const = $3C)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $3D (61)
        IF (_mul.const = $3D)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $3E (62)
        IF (_mul.const = $3E)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
		ADDR	%reg%,	%reg%
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $3F (63)
        IF (_mul.const = $3F)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $40 (64)
        IF (_mul.const = $40)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  2
                SLL     %reg%,  2
        ENDI

        ; Multiply by $41 (65)
        IF (_mul.const = $41)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $42 (66)
        IF (_mul.const = $42)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
		ADDR	%reg%,	%reg%
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $43 (67)
        IF (_mul.const = $43)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
		ADDR	%reg%,	%reg%
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $44 (68)
        IF (_mul.const = $44)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $45 (69)
        IF (_mul.const = $45)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $46 (70)
        IF (_mul.const = $46)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $47 (71)
        IF (_mul.const = $47)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $48 (72)
        IF (_mul.const = $48)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $49 (73)
        IF (_mul.const = $49)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $4A (74)
        IF (_mul.const = $4A)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $4B (75)
        IF (_mul.const = $4B)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $4C (76)
        IF (_mul.const = $4C)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $4D (77)
        IF (_mul.const = $4D)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $4E (78)
        IF (_mul.const = $4E)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $4F (79)
        IF (_mul.const = $4F)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $50 (80)
        IF (_mul.const = $50)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $51 (81)
        IF (_mul.const = $51)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $52 (82)
        IF (_mul.const = $52)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $53 (83)
        IF (_mul.const = $53)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $54 (84)
        IF (_mul.const = $54)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $55 (85)
        IF (_mul.const = $55)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $56 (86)
        IF (_mul.const = $56)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $57 (87)
        IF (_mul.const = $57)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  1
		SUBR    %reg%,	%tmp%
                SLL     %reg%,  2
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $58 (88)
        IF (_mul.const = $58)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $59 (89)
        IF (_mul.const = $59)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $5A (90)
        IF (_mul.const = $5A)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $5B (91)
        IF (_mul.const = $5B)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $5C (92)
        IF (_mul.const = $5C)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  1
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $5D (93)
        IF (_mul.const = $5D)
_mul.done       QSET    -1
		MOVR	%reg%,	%tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  1
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $5E (94)
        IF (_mul.const = $5E)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  1
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $5F (95)
        IF (_mul.const = $5F)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                ADDR	%reg%,	%reg%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  1
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $60 (96)
        IF (_mul.const = $60)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  2
		ADDR	%reg%,	%reg%
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $61 (97)
        IF (_mul.const = $61)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $62 (98)
        IF (_mul.const = $62)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $63 (99)
        IF (_mul.const = $63)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $64 (100)
        IF (_mul.const = $64)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $65 (101)
        IF (_mul.const = $65)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $66 (102)
        IF (_mul.const = $66)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $67 (103)
        IF (_mul.const = $67)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  1
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $68 (104)
        IF (_mul.const = $68)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $69 (105)
        IF (_mul.const = $69)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $6A (106)
        IF (_mul.const = $6A)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $6B (107)
        IF (_mul.const = $6B)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $6C (108)
        IF (_mul.const = $6C)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $6D (109)
        IF (_mul.const = $6D)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $6E (110)
        IF (_mul.const = $6E)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $6F (111)
        IF (_mul.const = $6F)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
		SUBR	%tmp%,	%reg%
        ENDI

        ; Multiply by $70 (112)
        IF (_mul.const = $70)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $71 (113)
        IF (_mul.const = $71)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $72 (114)
        IF (_mul.const = $72)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $73 (115)
        IF (_mul.const = $73)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $74 (116)
        IF (_mul.const = $74)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $75 (117)
        IF (_mul.const = $75)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $76 (118)
        IF (_mul.const = $76)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $77 (119)
        IF (_mul.const = $77)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $78 (120)
        IF (_mul.const = $78)
_mul.done       QSET    -1
                SLL     %reg%,  2
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $79 (121)
        IF (_mul.const = $79)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  1
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $7A (122)
        IF (_mul.const = $7A)
_mul.done       QSET    -1
                SLL     %reg%,  1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $7B (123)
        IF (_mul.const = $7B)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  1
                ADDR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $7C (124)
        IF (_mul.const = $7C)
_mul.done       QSET    -1
                SLL     %reg%,  2
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
		ADDR	%reg%,	%reg%
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $7D (125)
        IF (_mul.const = $7D)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SLL     %reg%,  2
                SUBR    %reg%,  %tmp%
                SLL     %reg%,  2
                SLL     %reg%,  2
		ADDR	%reg%,	%reg%
                ADDR    %tmp%,  %reg%
        ENDI

        ; Multiply by $7E (126)
        IF (_mul.const = $7E)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SWAP    %reg%,  1
                SLR     %reg%,  1
		ADDR    %tmp%,  %tmp%
                SUBR    %tmp%,  %reg%
        ENDI

        ; Multiply by $7F (127)
        IF (_mul.const = $7F)
_mul.done       QSET    -1
                MOVR    %reg%,  %tmp%
                SWAP    %reg%, 1
                SLR     %reg%, 1
                SUBR    %tmp%,  %reg%
        ENDI

        IF  (_mul.done = 0)
            ERR $("Invalid multiplication constant \'%const%\', must be between 0 and ", $#($7F), ".")
        ENDI

    LISTING "prev"
ENDM

;; ======================================================================== ;;
;;  EOF: pm:mac:lang:mult                                                   ;;
;; ======================================================================== ;;

	;FILE mermaid008.bas
	;[1] REM Mermaid
	SRCFILE "mermaid008.bas",1
	;[2] REM (c) 2015 Tuatara Software
	SRCFILE "mermaid008.bas",2
	;[3] 
	SRCFILE "mermaid008.bas",3
	;[4] REM Concept and Artwork - R.C. Bain
	SRCFILE "mermaid008.bas",4
	;[5] REM Programming, Music, Sound Effects - Derek Bain
	SRCFILE "mermaid008.bas",5
	;[6] REM Castle Layout - R.C. Bain, B.K. Bain, M.L. Bain, Derek Bain
	SRCFILE "mermaid008.bas",6
	;[7] 
	SRCFILE "mermaid008.bas",7
	;[8] '       Increase the memory capacity!!
	SRCFILE "mermaid008.bas",8
	;[9]         GOTO Start
	SRCFILE "mermaid008.bas",9
	B Q3
	;[10]         ASM ORG $C040
	SRCFILE "mermaid008.bas",10
 ORG $C040
	;[11] Start:  WAIT
	SRCFILE "mermaid008.bas",11
	; START
Q3:		CALL _wait
	;[12] 
	SRCFILE "mermaid008.bas",12
	;[13] 
	SRCFILE "mermaid008.bas",13
	;[14] 'initialize
	SRCFILE "mermaid008.bas",14
	;[15] 
	SRCFILE "mermaid008.bas",15
	;[16] 	INCLUDE "constants.bas"
	SRCFILE "mermaid008.bas",16
	;FILE /Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas
	;[1] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",1
	;[2] REM HEADER - CONSTANTS.BAS
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",2
	;[3] REM 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",3
	;[4] REM Started by Mark Ball, July 2015
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",4
	;[5] REM
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",5
	;[6] REM Constants for use in IntyBASIC
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",6
	;[7] REM
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",7
	;[8] REM HISTORY
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",8
	;[9] REM -------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",9
	;[10] REM 1.00F 05/07/15 - First version.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",10
	;[11] REM 1.01F 07/07/15 - Added disc directions.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",11
	;[12] REM                - Added background modes.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",12
	;[13] REM                - Minor comment changes.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",13
	;[14] REM 1.02F 08/07/15 - Renamed constants.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",14
	;[15] REM                - Added background access information.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",15
	;[16] REM                - Adjustments to layout.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",16
	;[17] REM 1.03F 08/07/15 - Fixed comment delimiter.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",17
	;[18] REM 1.04F 11/07/15 - Added useful functions.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",18
	;[19] REM	               - Added controller movement mask.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",19
	;[20] REM 1.05F 11/07/15 - Added BACKGROUND constants.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",20
	;[21] REM 1.06F 11/07/15 - Changed Y, X order to X, Y in DEF FN functions.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",21
	;[22] REM 1.07F 11/07/15 - Added colour stack advance.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",22
	;[23] REM 1.08F 12/07/15 - Added functions for sprite position handling.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",23
	;[24] REM 1.09F 12/07/15 - Added a function for resetting a sprite.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",24
	;[25] REM 1.10F 13/07/15 - Added keypad constants.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",25
	;[26] REM 1.11F 13/07/15 - Added side button constants.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",26
	;[27] REM 1.12F 13/07/15 - Updated sprite functions.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",27
	;[28] REM 1.13F 19/07/15 - Added border masking constants.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",28
	;[29] REM 1.14F 20/07/15 - Added a combined border masking constant.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",29
	;[30] REM 1.15F 20/07/15 - Renamed border masking constants to BORDER_HIDE_xxxx.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",30
	;[31] REM 1.16F 28/09/15 - Fixed disc direction typos.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",31
	;[32] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",32
	;[33] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",33
	;[34] REM /////////////////////////////////////////////////////////////////////////
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",34
	;[35] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",35
	;[36] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",36
	;[37] REM Background information.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",37
	;[38] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",38
	;[39] CONST BACKTAB				= $0200		' Start of the background in RAM.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",39
	;[40] CONST BACKGROUND_ROWS		= 12		' Height of the background in cards.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",40
	;[41] CONST BACKGROUND_COLUMNS	= 20		' Width of the background in cards.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",41
	;[42] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",42
	;[43] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",43
	;[44] REM Background GRAM cards.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",44
	;[45] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",45
	;[46] CONST BG00 					= $0800
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",46
	;[47] CONST BG01 					= $0808
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",47
	;[48] CONST BG02 					= $0810
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",48
	;[49] CONST BG03 					= $0818
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",49
	;[50] CONST BG04 					= $0820
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",50
	;[51] CONST BG05 					= $0828
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",51
	;[52] CONST BG06 					= $0830
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",52
	;[53] CONST BG07 					= $0838
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",53
	;[54] CONST BG08 					= $0840
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",54
	;[55] CONST BG09 					= $0848
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",55
	;[56] CONST BG10 					= $0850
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",56
	;[57] CONST BG11 					= $0858
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",57
	;[58] CONST BG12 					= $0860
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",58
	;[59] CONST BG13 					= $0868
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",59
	;[60] CONST BG14 					= $0870
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",60
	;[61] CONST BG15 					= $0878
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",61
	;[62] CONST BG16 					= $0880
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",62
	;[63] CONST BG17 					= $0888
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",63
	;[64] CONST BG18 					= $0890
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",64
	;[65] CONST BG19 					= $0898
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",65
	;[66] CONST BG20 					= $08A0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",66
	;[67] CONST BG21 					= $08A8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",67
	;[68] CONST BG22 					= $08B0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",68
	;[69] CONST BG23 					= $08B8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",69
	;[70] CONST BG24 					= $08C0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",70
	;[71] CONST BG25 					= $08C8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",71
	;[72] CONST BG26 					= $08D0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",72
	;[73] CONST BG27 					= $08D8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",73
	;[74] CONST BG28 					= $08E0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",74
	;[75] CONST BG29 					= $08E8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",75
	;[76] CONST BG30 					= $08F0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",76
	;[77] CONST BG31 					= $08F8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",77
	;[78] CONST BG32 					= $0900
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",78
	;[79] CONST BG33 					= $0908
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",79
	;[80] CONST BG34 					= $0910
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",80
	;[81] CONST BG35 					= $0918
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",81
	;[82] CONST BG36 					= $0920
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",82
	;[83] CONST BG37 					= $0928
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",83
	;[84] CONST BG38 					= $0930
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",84
	;[85] CONST BG39 					= $0938
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",85
	;[86] CONST BG40 					= $0940
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",86
	;[87] CONST BG41 					= $0948
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",87
	;[88] CONST BG42 					= $0950
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",88
	;[89] CONST BG43 					= $0958
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",89
	;[90] CONST BG44 					= $0960
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",90
	;[91] CONST BG45 					= $0968
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",91
	;[92] CONST BG46 					= $0970
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",92
	;[93] CONST BG47 					= $0978
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",93
	;[94] CONST BG48 					= $0980
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",94
	;[95] CONST BG49 					= $0988
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",95
	;[96] CONST BG50 					= $0990
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",96
	;[97] CONST BG51 					= $0998
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",97
	;[98] CONST BG52 					= $09A0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",98
	;[99] CONST BG53 					= $09A8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",99
	;[100] CONST BG54 					= $09B0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",100
	;[101] CONST BG55 					= $09B8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",101
	;[102] CONST BG56 					= $09C0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",102
	;[103] CONST BG57 					= $09C8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",103
	;[104] CONST BG58 					= $09D0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",104
	;[105] CONST BG59 					= $09D8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",105
	;[106] CONST BG60 					= $09E0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",106
	;[107] CONST BG61 					= $09E8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",107
	;[108] CONST BG62 					= $09F0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",108
	;[109] CONST BG63 					= $09F8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",109
	;[110] 	
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",110
	;[111] REM /////////////////////////////////////////////////////////////////////////
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",111
	;[112] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",112
	;[113] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",113
	;[114] REM GRAM card index numbers.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",114
	;[115] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",115
	;[116] REM Note: For use with the "define" command.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",116
	;[117] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",117
	;[118] CONST DEF00 				= $0000
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",118
	;[119] CONST DEF01 				= $0001
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",119
	;[120] CONST DEF02 				= $0002
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",120
	;[121] CONST DEF03 				= $0003
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",121
	;[122] CONST DEF04 				= $0004
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",122
	;[123] CONST DEF05 				= $0005
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",123
	;[124] CONST DEF06 				= $0006
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",124
	;[125] CONST DEF07 				= $0007
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",125
	;[126] CONST DEF08 				= $0008
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",126
	;[127] CONST DEF09 				= $0009
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",127
	;[128] CONST DEF10 				= $000A
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",128
	;[129] CONST DEF11 				= $000B
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",129
	;[130] CONST DEF12 				= $000C
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",130
	;[131] CONST DEF13 				= $000D
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",131
	;[132] CONST DEF14 				= $000E
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",132
	;[133] CONST DEF15 				= $000F
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",133
	;[134] CONST DEF16 				= $0010
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",134
	;[135] CONST DEF17 				= $0011
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",135
	;[136] CONST DEF18 				= $0012
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",136
	;[137] CONST DEF19 				= $0013
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",137
	;[138] CONST DEF20 				= $0014
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",138
	;[139] CONST DEF21 				= $0015
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",139
	;[140] CONST DEF22 				= $0016
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",140
	;[141] CONST DEF23 				= $0017
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",141
	;[142] CONST DEF24 				= $0018
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",142
	;[143] CONST DEF25 				= $0019
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",143
	;[144] CONST DEF26 				= $001A
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",144
	;[145] CONST DEF27 				= $001B
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",145
	;[146] CONST DEF28 				= $001C
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",146
	;[147] CONST DEF29 				= $001D
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",147
	;[148] CONST DEF30 				= $001E
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",148
	;[149] CONST DEF31 				= $001F
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",149
	;[150] CONST DEF32 				= $0020
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",150
	;[151] CONST DEF33 				= $0021
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",151
	;[152] CONST DEF34 				= $0022
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",152
	;[153] CONST DEF35 				= $0023
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",153
	;[154] CONST DEF36 				= $0024
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",154
	;[155] CONST DEF37 				= $0025
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",155
	;[156] CONST DEF38 				= $0026
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",156
	;[157] CONST DEF39 				= $0027
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",157
	;[158] CONST DEF40 				= $0028
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",158
	;[159] CONST DEF41 				= $0029
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",159
	;[160] CONST DEF42 				= $002A
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",160
	;[161] CONST DEF43 				= $002B
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",161
	;[162] CONST DEF44 				= $002C
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",162
	;[163] CONST DEF45 				= $002D
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",163
	;[164] CONST DEF46 				= $002E
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",164
	;[165] CONST DEF47 				= $002F
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",165
	;[166] CONST DEF48 				= $0030
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",166
	;[167] CONST DEF49 				= $0031
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",167
	;[168] CONST DEF50 				= $0032
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",168
	;[169] CONST DEF51 				= $0033
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",169
	;[170] CONST DEF52 				= $0034
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",170
	;[171] CONST DEF53 				= $0035
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",171
	;[172] CONST DEF54 				= $0036
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",172
	;[173] CONST DEF55 				= $0037
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",173
	;[174] CONST DEF56 				= $0038
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",174
	;[175] CONST DEF57 				= $0039
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",175
	;[176] CONST DEF58 				= $003A
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",176
	;[177] CONST DEF59 				= $003B
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",177
	;[178] CONST DEF60 				= $003C
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",178
	;[179] CONST DEF61 				= $003D
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",179
	;[180] CONST DEF62 				= $003E
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",180
	;[181] CONST DEF63 				= $003F
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",181
	;[182] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",182
	;[183] REM /////////////////////////////////////////////////////////////////////////
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",183
	;[184] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",184
	;[185] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",185
	;[186] REM Screen modes.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",186
	;[187] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",187
	;[188] REM Note: For use with the "mode" command.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",188
	;[189] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",189
	;[190] CONST SCREEN_COLOR_STACK			= $0000
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",190
	;[191] CONST SCREEN_FOREGROUND_BACKGROUND	= $0001
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",191
	;[192] REM Abbreviated versions.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",192
	;[193] CONST SCREEN_CS						= $0000
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",193
	;[194] CONST SCREEN_FB						= $0001
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",194
	;[195] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",195
	;[196] REM /////////////////////////////////////////////////////////////////////////
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",196
	;[197] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",197
	;[198] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",198
	;[199] REM COLORS - Border.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",199
	;[200] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",200
	;[201] REM Notes:
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",201
	;[202] REM - For use with the commands "mode 0" and "mode 1".
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",202
	;[203] REM - For use with the "border" command.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",203
	;[204] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",204
	;[205] CONST BORDER_BLACK			= $0000
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",205
	;[206] CONST BORDER_BLUE			= $0001
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",206
	;[207] CONST BORDER_RED			= $0002
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",207
	;[208] CONST BORDER_TAN			= $0003
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",208
	;[209] CONST BORDER_DARKGREEN		= $0004
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",209
	;[210] CONST BORDER_GREEN			= $0005
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",210
	;[211] CONST BORDER_YELLOW			= $0006
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",211
	;[212] CONST BORDER_WHITE			= $0007
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",212
	;[213] CONST BORDER_GREY			= $0008
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",213
	;[214] CONST BORDER_CYAN			= $0009
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",214
	;[215] CONST BORDER_ORANGE			= $000A
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",215
	;[216] CONST BORDER_BROWN			= $000B
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",216
	;[217] CONST BORDER_PINK			= $000C
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",217
	;[218] CONST BORDER_LIGHTBLUE		= $000D
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",218
	;[219] CONST BORDER_YELLOWGREEN	= $000E
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",219
	;[220] CONST BORDER_PURPLE			= $000F
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",220
	;[221] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",221
	;[222] REM /////////////////////////////////////////////////////////////////////////
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",222
	;[223] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",223
	;[224] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",224
	;[225] REM BORDER - Edge masks.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",225
	;[226] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",226
	;[227] REM Note: For use with the "border color, edge" command.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",227
	;[228] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",228
	;[229] CONST BORDER_HIDE_LEFT_EDGE		= $0001		' Hide the leftmost column of the background.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",229
	;[230] CONST BORDER_HIDE_TOP_EDGE		= $0002		' Hide the topmost row of the background.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",230
	;[231] CONST BORDER_HIDE_TOP_LEFT_EDGE	= $0003		' Hide both the topmost row and leftmost column of the background.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",231
	;[232] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",232
	;[233] REM /////////////////////////////////////////////////////////////////////////
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",233
	;[234] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",234
	;[235] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",235
	;[236] REM COLORS - Mode 0 (Color Stack).
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",236
	;[237] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",237
	;[238] REM Stack
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",238
	;[239] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",239
	;[240] REM Note: For use as the last 4 parameters used in the "mode 1" command.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",240
	;[241] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",241
	;[242] CONST STACK_BLACK			= $0000
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",242
	;[243] CONST STACK_BLUE			= $0001
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",243
	;[244] CONST STACK_RED				= $0002
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",244
	;[245] CONST STACK_TAN				= $0003
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",245
	;[246] CONST STACK_DARKGREEN		= $0004
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",246
	;[247] CONST STACK_GREEN			= $0005
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",247
	;[248] CONST STACK_YELLOW			= $0006
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",248
	;[249] CONST STACK_WHITE			= $0007
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",249
	;[250] CONST STACK_GREY			= $0008
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",250
	;[251] CONST STACK_CYAN			= $0009
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",251
	;[252] CONST STACK_ORANGE			= $000A
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",252
	;[253] CONST STACK_BROWN			= $000B
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",253
	;[254] CONST STACK_PINK			= $000C
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",254
	;[255] CONST STACK_LIGHTBLUE		= $000D
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",255
	;[256] CONST STACK_YELLOWGREEN		= $000E
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",256
	;[257] CONST STACK_PURPLE			= $000F
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",257
	;[258] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",258
	;[259] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",259
	;[260] REM Foreground.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",260
	;[261] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",261
	;[262] REM Notes:
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",262
	;[263] REM - For use with "peek/poke" commands that access BACKTAB.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",263
	;[264] REM - Only one foreground colour permitted per background card.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",264
	;[265] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",265
	;[266] CONST CS_BLACK				= $0000
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",266
	;[267] CONST CS_BLUE				= $0001
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",267
	;[268] CONST CS_RED				= $0002
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",268
	;[269] CONST CS_TAN				= $0003
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",269
	;[270] CONST CS_DARKGREEN			= $0004
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",270
	;[271] CONST CS_GREEN				= $0005
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",271
	;[272] CONST CS_YELLOW				= $0006
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",272
	;[273] CONST CS_WHITE				= $0007
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",273
	;[274] CONST CS_GREY				= $1000
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",274
	;[275] CONST CS_CYAN				= $1001
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",275
	;[276] CONST CS_ORANGE				= $1002
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",276
	;[277] CONST CS_BROWN				= $1003
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",277
	;[278] CONST CS_PINK				= $1004
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",278
	;[279] CONST CS_LIGHTBLUE			= $1005
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",279
	;[280] CONST CS_YELLOWGREEN		= $1006
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",280
	;[281] CONST CS_PURPLE				= $1007
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",281
	;[282] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",282
	;[283] CONST CS_CARD_DATA_MASK		= $07F8		' Mask to get the background card's data.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",283
	;[284] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",284
	;[285] CONST CS_ADVANCE			= $2000		' Advance the colour stack by one position.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",285
	;[286] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",286
	;[287] REM /////////////////////////////////////////////////////////////////////////
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",287
	;[288] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",288
	;[289] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",289
	;[290] REM COLORS - Mode 1 (Foreground Background)
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",290
	;[291] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",291
	;[292] REM Foreground.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",292
	;[293] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",293
	;[294] REM Notes:
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",294
	;[295] REM - For use with "peek/poke" commands that access BACKTAB.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",295
	;[296] REM - Only one foreground colour permitted per background card.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",296
	;[297] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",297
	;[298] CONST FG_BLACK				= $0000
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",298
	;[299] CONST FG_BLUE				= $0001
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",299
	;[300] CONST FG_RED				= $0002
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",300
	;[301] CONST FG_TAN				= $0003
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",301
	;[302] CONST FG_DARKGREEN			= $0004
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",302
	;[303] CONST FG_GREEN				= $0005
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",303
	;[304] CONST FG_YELLOW				= $0006
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",304
	;[305] CONST FG_WHITE				= $0007
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",305
	;[306] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",306
	;[307] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",307
	;[308] REM Background.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",308
	;[309] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",309
	;[310] REM Notes:
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",310
	;[311] REM - For use with "peek/poke" commands that access BACKTAB.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",311
	;[312] REM - Only one background colour permitted per background card.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",312
	;[313] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",313
	;[314] CONST BG_BLACK				= $0000
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",314
	;[315] CONST BG_BLUE				= $0200
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",315
	;[316] CONST BG_RED				= $0400
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",316
	;[317] CONST BG_TAN				= $0600
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",317
	;[318] CONST BG_DARKGREEN			= $0800
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",318
	;[319] CONST BG_GREEN				= $0A00
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",319
	;[320] CONST BG_YELLOW				= $0C00
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",320
	;[321] CONST BG_WHITE				= $0E00
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",321
	;[322] CONST BG_GREY				= $1000
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",322
	;[323] CONST BG_CYAN				= $1200
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",323
	;[324] CONST BG_ORANGE				= $1400
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",324
	;[325] CONST BG_BROWN				= $1600
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",325
	;[326] CONST BG_PINK				= $1800
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",326
	;[327] CONST BG_LIGHTBLUE			= $1A00
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",327
	;[328] CONST BG_YELLOWGREEN		= $1C00
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",328
	;[329] CONST BG_PURPLE				= $1E00
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",329
	;[330] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",330
	;[331] CONST FGBG_CARD_DATA_MASK	= $01F8		' Mask to get the background card's data.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",331
	;[332] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",332
	;[333] REM /////////////////////////////////////////////////////////////////////////
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",333
	;[334] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",334
	;[335] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",335
	;[336] REM Sprites.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",336
	;[337] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",337
	;[338] REM Note: For use with "sprite" command.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",338
	;[339] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",339
	;[340] REM X
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",340
	;[341] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",341
	;[342] REM Note: Add these constants to the sprite command's X parameter.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",342
	;[343] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",343
	;[344] CONST HIT					= $0100		' Enable the sprite's collision detection.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",344
	;[345] CONST VISIBLE				= $0200		' Make the sprite visible.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",345
	;[346] CONST ZOOMX2				= $0400		' Make the sprite twice the width.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",346
	;[347] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",347
	;[348] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",348
	;[349] REM Y
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",349
	;[350] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",350
	;[351] REM Note: Add these constants to the sprite command's Y parameter.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",351
	;[352] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",352
	;[353] CONST DOUBLEY				= $0080		' Make a double height sprite (with 2 GRAM cards).
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",353
	;[354] CONST ZOOMY2				= $0100		' Make the sprite twice (x2) the normal height.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",354
	;[355] CONST ZOOMY4				= $0200		' Make the sprite quadruple (x4) the normal height.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",355
	;[356] CONST ZOOMY8				= $0300		' Make the sprite octuple (x8) the normal height.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",356
	;[357] CONST FLIPX					= $0400		' Flip/mirror the sprite in X.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",357
	;[358] CONST FLIPY					= $0800		' Flip/mirror the sprite in Y.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",358
	;[359] CONST MIRROR				= $0C00		' Flip/mirror the sprite in both X and Y.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",359
	;[360] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",360
	;[361] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",361
	;[362] REM A
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",362
	;[363] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",363
	;[364] REM Notes:
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",364
	;[365] REM - Combine to create the sprite command's A parameter.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",365
	;[366] REM - Only one colour per sprite.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",366
	;[367] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",367
	;[368] CONST GRAM					= $0800		' Sprite's data is located in GRAM.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",368
	;[369] CONST BEHIND				= $2000		' Sprite is behind the background.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",369
	;[370] CONST SPR_BLACK				= $0000
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",370
	;[371] CONST SPR_BLUE				= $0001
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",371
	;[372] CONST SPR_RED				= $0002
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",372
	;[373] CONST SPR_TAN				= $0003
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",373
	;[374] CONST SPR_DARKGREEN			= $0004
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",374
	;[375] CONST SPR_GREEN				= $0005
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",375
	;[376] CONST SPR_YELLOW			= $0006
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",376
	;[377] CONST SPR_WHITE				= $0007
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",377
	;[378] CONST SPR_GREY				= $1000
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",378
	;[379] CONST SPR_CYAN				= $1001
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",379
	;[380] CONST SPR_ORANGE			= $1002
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",380
	;[381] CONST SPR_BROWN				= $1003
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",381
	;[382] CONST SPR_PINK				= $1004
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",382
	;[383] CONST SPR_LIGHTBLUE			= $1005
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",383
	;[384] CONST SPR_YELLOWGREEN		= $1006
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",384
	;[385] CONST SPR_PURPLE			= $1007
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",385
	;[386] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",386
	;[387] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",387
	;[388] REM GRAM numbers.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",388
	;[389] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",389
	;[390] REM Note: For use in the sprite command's parameter A.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",390
	;[391] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",391
	;[392] CONST SPR00 				= $0800
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",392
	;[393] CONST SPR01 				= $0808
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",393
	;[394] CONST SPR02 				= $0810
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",394
	;[395] CONST SPR03 				= $0818
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",395
	;[396] CONST SPR04 				= $0820
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",396
	;[397] CONST SPR05 				= $0828
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",397
	;[398] CONST SPR06 				= $0830
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",398
	;[399] CONST SPR07 				= $0838
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",399
	;[400] CONST SPR08 				= $0840
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",400
	;[401] CONST SPR09 				= $0848
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",401
	;[402] CONST SPR10 				= $0850
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",402
	;[403] CONST SPR11 				= $0858
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",403
	;[404] CONST SPR12 				= $0860
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",404
	;[405] CONST SPR13 				= $0868
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",405
	;[406] CONST SPR14 				= $0870
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",406
	;[407] CONST SPR15 				= $0878
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",407
	;[408] CONST SPR16 				= $0880
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",408
	;[409] CONST SPR17 				= $0888
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",409
	;[410] CONST SPR18 				= $0890
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",410
	;[411] CONST SPR19 				= $0898
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",411
	;[412] CONST SPR20 				= $08A0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",412
	;[413] CONST SPR21 				= $08A8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",413
	;[414] CONST SPR22 				= $08B0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",414
	;[415] CONST SPR23 				= $08B8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",415
	;[416] CONST SPR24 				= $08C0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",416
	;[417] CONST SPR25 				= $08C8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",417
	;[418] CONST SPR26 				= $08D0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",418
	;[419] CONST SPR27 				= $08D8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",419
	;[420] CONST SPR28 				= $08E0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",420
	;[421] CONST SPR29 				= $08E8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",421
	;[422] CONST SPR30 				= $08F0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",422
	;[423] CONST SPR31 				= $08F8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",423
	;[424] CONST SPR32 				= $0900
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",424
	;[425] CONST SPR33 				= $0908
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",425
	;[426] CONST SPR34 				= $0910
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",426
	;[427] CONST SPR35 				= $0918
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",427
	;[428] CONST SPR36 				= $0920
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",428
	;[429] CONST SPR37 				= $0928
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",429
	;[430] CONST SPR38 				= $0930
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",430
	;[431] CONST SPR39 				= $0938
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",431
	;[432] CONST SPR40 				= $0940
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",432
	;[433] CONST SPR41 				= $0948
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",433
	;[434] CONST SPR42 				= $0950
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",434
	;[435] CONST SPR43 				= $0958
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",435
	;[436] CONST SPR44 				= $0960
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",436
	;[437] CONST SPR45 				= $0968
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",437
	;[438] CONST SPR46 				= $0970
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",438
	;[439] CONST SPR47 				= $0978
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",439
	;[440] CONST SPR48 				= $0980
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",440
	;[441] CONST SPR49 				= $0988
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",441
	;[442] CONST SPR50 				= $0990
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",442
	;[443] CONST SPR51 				= $0998
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",443
	;[444] CONST SPR52 				= $09A0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",444
	;[445] CONST SPR53 				= $09A8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",445
	;[446] CONST SPR54 				= $09B0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",446
	;[447] CONST SPR55 				= $09B8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",447
	;[448] CONST SPR56 				= $09C0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",448
	;[449] CONST SPR57 				= $09C8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",449
	;[450] CONST SPR58 				= $09D0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",450
	;[451] CONST SPR59 				= $09D8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",451
	;[452] CONST SPR60 				= $09E0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",452
	;[453] CONST SPR61 				= $09E8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",453
	;[454] CONST SPR62 				= $09F0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",454
	;[455] CONST SPR63 				= $09F8
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",455
	;[456] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",456
	;[457] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",457
	;[458] REM Sprite collision.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",458
	;[459] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",459
	;[460] REM Notes:
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",460
	;[461] REM - For use with variables COL0, COL1, COL2, COL3, COL4, COL5, COL6 and COL7.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",461
	;[462] REM - More than one collision can occur simultaneously.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",462
	;[463] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",463
	;[464] CONST HIT_SPRITE0			= $0001		' Sprite collided with sprite 0.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",464
	;[465] CONST HIT_SPRITE1			= $0002		' Sprite collided with sprite 1.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",465
	;[466] CONST HIT_SPRITE2			= $0004		' Sprite collided with sprite 2.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",466
	;[467] CONST HIT_SPRITE3			= $0008		' Sprite collided with sprite 3.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",467
	;[468] CONST HIT_SPRITE4			= $0010		' Sprite collided with sprite 4.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",468
	;[469] CONST HIT_SPRITE5			= $0020		' Sprite collided with sprite 5.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",469
	;[470] CONST HIT_SPRITE6			= $0040		' Sprite collided with sprite 6.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",470
	;[471] CONST HIT_SPRITE7			= $0080		' Sprite collided with sprite 7.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",471
	;[472] CONST HIT_BACKGROUND		= $0100		' Sprite collided with a background pixel.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",472
	;[473] CONST HIT_BORDER			= $0200		' Sprite collided with the top/bottom/left/right border.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",473
	;[474] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",474
	;[475] REM /////////////////////////////////////////////////////////////////////////
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",475
	;[476] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",476
	;[477] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",477
	;[478] REM DISC - Compass.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",478
	;[479] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",479
	;[480] REM   NW         N         NE
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",480
	;[481] REM     \   NNW  |  NNE   /
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",481
	;[482] REM       \      |      /
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",482
	;[483] REM         \    |    /
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",483
	;[484] REM    WNW    \  |  /    ENE
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",484
	;[485] REM             \|/
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",485
	;[486] REM  W ----------+---------- E
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",486
	;[487] REM             /|\ 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",487
	;[488] REM    WSW    /  |  \    ESE
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",488
	;[489] REM         /    |    \
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",489
	;[490] REM       /      |      \
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",490
	;[491] REM     /   SSW  |  SSE   \
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",491
	;[492] REM   SW         S         SE
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",492
	;[493] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",493
	;[494] REM Notes:
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",494
	;[495] REM - North points upwards on the hand controller.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",495
	;[496] REM - Directions are listed in a clockwise manner.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",496
	;[497] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",497
	;[498] CONST DISC_NORTH			= $0004
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",498
	;[499] CONST DISC_NORTH_NORTH_EAST = $0014
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",499
	;[500] CONST DISC_NORTH_EAST		= $0016
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",500
	;[501] CONST DISC_EAST_NORTH_EAST	= $0006
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",501
	;[502] CONST DISC_EAST				= $0002
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",502
	;[503] CONST DISC_EAST_SOUTH_EAST	= $0012
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",503
	;[504] CONST DISC_SOUTH_EAST		= $0013
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",504
	;[505] CONST DISC_SOUTH_SOUTH_EAST	= $0003
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",505
	;[506] CONST DISC_SOUTH			= $0001
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",506
	;[507] CONST DISC_SOUTH_SOUTH_WEST	= $0011
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",507
	;[508] CONST DISC_SOUTH_WEST		= $0025
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",508
	;[509] CONST DISC_WEST_SOUTH_WEST	= $0009
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",509
	;[510] CONST DISC_WEST				= $0008
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",510
	;[511] CONST DISC_WEST_NORTH_WEST	= $0018
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",511
	;[512] CONST DISC_NORTH_WEST		= $001C
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",512
	;[513] CONST DISC_NORTH_NORTH_WEST	= $000C
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",513
	;[514] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",514
	;[515] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",515
	;[516] REM DISC - Compass abbreviated versions.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",516
	;[517] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",517
	;[518] CONST DISC_N				= $0004
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",518
	;[519] CONST DISC_NNE 				= $0014
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",519
	;[520] CONST DISC_NE				= $0016
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",520
	;[521] CONST DISC_ENE				= $0006
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",521
	;[522] CONST DISC_E				= $0002
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",522
	;[523] CONST DISC_ESE				= $0012
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",523
	;[524] CONST DISC_SE				= $0013
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",524
	;[525] CONST DISC_SSE				= $0003
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",525
	;[526] CONST DISC_S				= $0001
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",526
	;[527] CONST DISC_SSW				= $0011
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",527
	;[528] CONST DISC_SW				= $0019
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",528
	;[529] CONST DISC_WSW				= $0009
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",529
	;[530] CONST DISC_W				= $0008
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",530
	;[531] CONST DISC_WNW				= $0018
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",531
	;[532] CONST DISC_NW				= $001C
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",532
	;[533] CONST DISC_NNW				= $000C
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",533
	;[534] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",534
	;[535] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",535
	;[536] REM DISC - Directions.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",536
	;[537] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",537
	;[538] CONST DISC_UP				= $0004
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",538
	;[539] CONST DISC_UP_RIGHT			= $0016		' Up and right diagonal.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",539
	;[540] CONST DISC_RIGHT			= $0002
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",540
	;[541] CONST DISC_DOWN_RIGHT		= $0013		' Down  and right diagonal.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",541
	;[542] CONST DISC_DOWN				= $0001
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",542
	;[543] CONST DISC_DOWN_LEFT		= $0019		' Down and left diagonal.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",543
	;[544] CONST DISC_LEFT				= $0008
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",544
	;[545] CONST DISC_UP_LEFT			= $001C		' Up and left diagonal.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",545
	;[546] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",546
	;[547] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",547
	;[548] REM DISK - Mask.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",548
	;[549] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",549
	;[550] CONST DISK_MASK				= $001F
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",550
	;[551] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",551
	;[552] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",552
	;[553] REM Controller - Keypad.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",553
	;[554] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",554
	;[555] CONST KEYPAD_0				= 72
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",555
	;[556] CONST KEYPAD_1				= 129
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",556
	;[557] CONST KEYPAD_2				= 65
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",557
	;[558] CONST KEYPAD_3				= 33
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",558
	;[559] CONST KEYPAD_4				= 130
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",559
	;[560] CONST KEYPAD_5				= 66
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",560
	;[561] CONST KEYPAD_6				= 34
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",561
	;[562] CONST KEYPAD_7				= 132
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",562
	;[563] CONST KEYPAD_8				= 68
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",563
	;[564] CONST KEYPAD_9				= 36
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",564
	;[565] CONST KEYPAD_CLEAR			= 136
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",565
	;[566] CONST KEYPAD_ENTER			= 40
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",566
	;[567] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",567
	;[568] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",568
	;[569] REM Controller - Side buttons.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",569
	;[570] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",570
	;[571] CONST BUTTON_TOP_LEFT		= $A0		' Top left and top right are the same button.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",571
	;[572] CONST BUTTON_TOP_RIGHT		= $A0		' Note: Bit 6 is low. 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",572
	;[573] CONST BUTTON_BOTTOM_LEFT	= $60		' Note: Bit 7 is low.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",573
	;[574] CONST BUTTON_BOTTOM_RIGHT	= $C0		' Note: Bit 5 is low
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",574
	;[575] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",575
	;[576] REM Abbreviated versions.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",576
	;[577] CONST BUTTON_1				= $A0		' Top left or top right.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",577
	;[578] CONST BUTTON_2				= $60		' Bottom left.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",578
	;[579] CONST BUTTON_3				= $C0		' Bottom right.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",579
	;[580] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",580
	;[581] REM Mask.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",581
	;[582] CONST BUTTON_MASK			= $E0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",582
	;[583] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",583
	;[584] REM /////////////////////////////////////////////////////////////////////////
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",584
	;[585] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",585
	;[586] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",586
	;[587] REM Useful functions.
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",587
	;[588] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",588
	;[589] DEF FN screenpos(aColumn, aRow)		= (((aRow)*BACKGROUND_COLUMNS)+(aColumn))
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",589
	;[590] DEF FN screenaddr(aColumn, aRow)	= (BACKTAB+(((aRow)*BACKGROUND_COLUMNS)+(aColumn)))
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",590
	;[591] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",591
	;[592] DEF FN setspritex(aSpriteNo,anXPosition)	= #mobshadow(aSpriteNo)=(#mobshadow(aSpriteNo) and $ff00)+anXPosition
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",592
	;[593] DEF FN setspritey(aSpriteNo,aYPosition)		= #mobshadow(aSpriteNo+8)=(#mobshadow(aSpriteNo+8) and $ff80)+aYPosition
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",593
	;[594] DEF FN resetsprite(aSpriteNo)				= sprite aSpriteNo, 0, 0, 0
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",594
	;[595] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",595
	;[596] REM /////////////////////////////////////////////////////////////////////////
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",596
	;[597] 
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",597
	;[598] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",598
	;[599] REM END
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",599
	;[600] REM -------------------------------------------------------------------------
	SRCFILE "/Users/dz/Documents/Development/Intellivision/IntyBASIC Contest - 2015/intybasic-version/v1.2.4/constants.bas",600
	;ENDFILE
	;FILE mermaid008.bas
	;[17] 	'foreground/background mode
	SRCFILE "mermaid008.bas",17
	;[18] 	MODE SCREEN_FOREGROUND_BACKGROUND
	SRCFILE "mermaid008.bas",18
	MVII #2,R0
	MVO R0,_mode_select
	;[19] 	WAIT
	SRCFILE "mermaid008.bas",19
	CALL _wait
	;[20] 	DEFINE 0,15,screen_bitmaps_0
	SRCFILE "mermaid008.bas",20
	CLRR R0
	MVO R0,_gram_target
	MVII #15,R0
	MVO R0,_gram_total
	MVII #Q5,R0
	MVO R0,_gram_bitmap
	;[21] 	WAIT
	SRCFILE "mermaid008.bas",21
	CALL _wait
	;[22] 	SCREEN screen_title
	SRCFILE "mermaid008.bas",22
	MVII #Q6,R3
	MVII #512,R2
	MVII #20,R1
	MVII #12,R0
	CALL CPYBLK
	;[23] 	
	SRCFILE "mermaid008.bas",23
	;[24] 	gosub WAITALOT
	SRCFILE "mermaid008.bas",24
	CALL Q7
	;[25] 
	SRCFILE "mermaid008.bas",25
	;[26] Rem Setup arrays for holding 8 sprites x,y locations and color
	SRCFILE "mermaid008.bas",26
	;[27] Dim Spritex (8)
	SRCFILE "mermaid008.bas",27
	;[28] Dim Spritey (8)
	SRCFILE "mermaid008.bas",28
	;[29] Dim #SpriteC (8)
	SRCFILE "mermaid008.bas",29
	;[30] 
	SRCFILE "mermaid008.bas",30
	;[31] Rem Setup array for castle layout (10x10 grid)
	SRCFILE "mermaid008.bas",31
	;[32] Dim castleLayout (100)
	SRCFILE "mermaid008.bas",32
	;[33] 
	SRCFILE "mermaid008.bas",33
	;[34] Rem Setup array for music notes
	SRCFILE "mermaid008.bas",34
	;[35] Dim note(3)
	SRCFILE "mermaid008.bas",35
	;[36] 
	SRCFILE "mermaid008.bas",36
	;[37] Rem Castle layout  (room numbers)
	SRCFILE "mermaid008.bas",37
	;[38] Rem 1	2	3	4	5	6	7	8	9	10
	SRCFILE "mermaid008.bas",38
	;[39] Rem 11	12	13	14	15	16	17	18	19	20
	SRCFILE "mermaid008.bas",39
	;[40] Rem 21	22	23	24	25	26	27	28	29	30
	SRCFILE "mermaid008.bas",40
	;[41] Rem 31	32	33	34	35	36	37	38	39	40
	SRCFILE "mermaid008.bas",41
	;[42] Rem 41	42	43	44	45	46	47	48	49	50
	SRCFILE "mermaid008.bas",42
	;[43] Rem 51	52	53	54	55	56	57	58	59	60
	SRCFILE "mermaid008.bas",43
	;[44] Rem 61	62	63	64	65	66	67	68	69	70
	SRCFILE "mermaid008.bas",44
	;[45] Rem 71	72	73	74	75	76	77	78	79	80
	SRCFILE "mermaid008.bas",45
	;[46] Rem 81	82	83	84	85	86	87	88	89	90
	SRCFILE "mermaid008.bas",46
	;[47] Rem 91	92	93	94	95	96	97	98	99	100
	SRCFILE "mermaid008.bas",47
	;[48] 
	SRCFILE "mermaid008.bas",48
	;[49] 	
	SRCFILE "mermaid008.bas",49
	;[50] reset:
	SRCFILE "mermaid008.bas",50
	; RESET
Q13:	;[51] 
	SRCFILE "mermaid008.bas",51
	;[52] #score = 0
	SRCFILE "mermaid008.bas",52
	CLRR R0
	MVO R0,V1
	;[53] level = 0
	SRCFILE "mermaid008.bas",53
	MVO R0,V2
	;[54] #bubble_counter = 45
	SRCFILE "mermaid008.bas",54
	MVII #45,R0
	MVO R0,V3
	;[55] #boost_counter = 144
	SRCFILE "mermaid008.bas",55
	MVII #144,R0
	MVO R0,V4
	;[56] #merChange_counter = 24
	SRCFILE "mermaid008.bas",56
	MVII #24,R0
	MVO R0,V5
	;[57] #countdownTimer = 9600
	SRCFILE "mermaid008.bas",57
	MVII #9600,R0
	MVO R0,V6
	;[58] diffLevel = 0
	SRCFILE "mermaid008.bas",58
	CLRR R0
	MVO R0,V7
	;[59] mermaid = 0
	SRCFILE "mermaid008.bas",59
	MVO R0,V8
	;[60] levelSelect = 0
	SRCFILE "mermaid008.bas",60
	NOP
	MVO R0,V9
	;[61] mermaidSelect = 0
	SRCFILE "mermaid008.bas",61
	MVO R0,V10
	;[62] 'mermaidFacing keeps track of her direction 0-Left 1-Right
	SRCFILE "mermaid008.bas",62
	;[63] mermaidFacing = 0
	SRCFILE "mermaid008.bas",63
	NOP
	MVO R0,V11
	;[64] #mermaid_color = SPR_GREEN
	SRCFILE "mermaid008.bas",64
	MVII #5,R0
	MVO R0,V12
	;[65] 'startIntroMusic = 0
	SRCFILE "mermaid008.bas",65
	;[66] lives = 5
	SRCFILE "mermaid008.bas",66
	MVO R0,V13
	;[67] waitkeypress = 0
	SRCFILE "mermaid008.bas",67
	CLRR R0
	MVO R0,V14
	;[68] mermaid_speed = 2
	SRCFILE "mermaid008.bas",68
	MVII #2,R0
	MVO R0,V15
	;[69] trace = 0
	SRCFILE "mermaid008.bas",69
	CLRR R0
	MVO R0,V16
	;[70] starting_point = 8
	SRCFILE "mermaid008.bas",70
	MVII #8,R0
	MVO R0,V17
	;[71] REM  mermaidLocation (0 = ocean, 1 = castle)
	SRCFILE "mermaid008.bas",71
	;[72] mermaidLocation = 0
	SRCFILE "mermaid008.bas",72
	CLRR R0
	MVO R0,V18
	;[73] REM  nextScreen (0 = no change, 1 = advance north, 2 = advance east 3 = advance south, 4 = advance west)
	SRCFILE "mermaid008.bas",73
	;[74] nextScreen = 0     
	SRCFILE "mermaid008.bas",74
	MVO R0,V19
	;[75] inventory_key = 0
	SRCFILE "mermaid008.bas",75
	NOP
	MVO R0,V20
	;[76] inventory_crown = 0
	SRCFILE "mermaid008.bas",76
	MVO R0,V21
	;[77] inventory_gold = 0
	SRCFILE "mermaid008.bas",77
	NOP
	MVO R0,V22
	;[78] inventory_silver = 0
	SRCFILE "mermaid008.bas",78
	MVO R0,V23
	;[79] key_visible = 0
	SRCFILE "mermaid008.bas",79
	NOP
	MVO R0,V24
	;[80] crown_visible = 0
	SRCFILE "mermaid008.bas",80
	MVO R0,V25
	;[81] gold_position = 0
	SRCFILE "mermaid008.bas",81
	NOP
	MVO R0,V26
	;[82] silver_position = 0
	SRCFILE "mermaid008.bas",82
	MVO R0,V27
	;[83] treasure = 0
	SRCFILE "mermaid008.bas",83
	NOP
	MVO R0,V28
	;[84] soundFlag = 0
	SRCFILE "mermaid008.bas",84
	MVO R0,V29
	;[85] sound_duration=0
	SRCFILE "mermaid008.bas",85
	NOP
	MVO R0,V30
	;[86] creature=0
	SRCFILE "mermaid008.bas",86
	MVO R0,V31
	;[87] creature1_Facing=0
	SRCFILE "mermaid008.bas",87
	NOP
	MVO R0,V32
	;[88] creature1_Frame=0
	SRCFILE "mermaid008.bas",88
	MVO R0,V33
	;[89] creature1_Timer=0
	SRCFILE "mermaid008.bas",89
	NOP
	MVO R0,V34
	;[90] creature1_Speed=0
	SRCFILE "mermaid008.bas",90
	MVO R0,V35
	;[91] queen_visible = 0
	SRCFILE "mermaid008.bas",91
	NOP
	MVO R0,V36
	;[92] lives1UPFlag = 0
	SRCFILE "mermaid008.bas",92
	MVO R0,V37
	;[93] 
	SRCFILE "mermaid008.bas",93
	;[94] Rem sprite#0 is Mermaid1
	SRCFILE "mermaid008.bas",94
	;[95] Spritex(0)=160
	SRCFILE "mermaid008.bas",95
	MVII #160,R0
	MVO R0,Q8
	;[96] Spritey(0)=60
	SRCFILE "mermaid008.bas",96
	MVII #60,R0
	MVO R0,Q9
	;[97] #SpriteC(0)=SPR_YELLOW
	SRCFILE "mermaid008.bas",97
	MVII #6,R0
	MVO R0,Q10
	;[98] 
	SRCFILE "mermaid008.bas",98
	;[99] Rem sprite#1 is Mermaid2
	SRCFILE "mermaid008.bas",99
	;[100] Spritex(1)=160
	SRCFILE "mermaid008.bas",100
	MVII #160,R0
	MVO R0,Q8+1
	;[101] Spritey(1)=60
	SRCFILE "mermaid008.bas",101
	MVII #60,R0
	MVO R0,Q9+1
	;[102] #SpriteC(1)=#mermaid_color
	SRCFILE "mermaid008.bas",102
	MVI V12,R0
	MVO R0,Q10+1
	;[103] 
	SRCFILE "mermaid008.bas",103
	;[104] Rem sprite#2 is Bubble
	SRCFILE "mermaid008.bas",104
	;[105] Spritex(2)=160
	SRCFILE "mermaid008.bas",105
	MVII #160,R0
	MVO R0,Q8+2
	;[106] Spritey(2)=60
	SRCFILE "mermaid008.bas",106
	MVII #60,R0
	MVO R0,Q9+2
	;[107] #SpriteC(2)=SPR_CYAN
	SRCFILE "mermaid008.bas",107
	MVII #4097,R0
	MVO R0,Q10+2
	;[108] 
	SRCFILE "mermaid008.bas",108
	;[109] title_screen:
	SRCFILE "mermaid008.bas",109
	; TITLE_SCREEN
Q14:	;[110] 'cls
	SRCFILE "mermaid008.bas",110
	;[111] wait
	SRCFILE "mermaid008.bas",111
	CALL _wait
	;[112] 
	SRCFILE "mermaid008.bas",112
	;[113] Rem Define sprites
	SRCFILE "mermaid008.bas",113
	;[114] DEFINE DEF32,16,sprites
	SRCFILE "mermaid008.bas",114
	MVII #32,R0
	MVO R0,_gram_target
	MVII #16,R0
	MVO R0,_gram_total
	MVII #Q15,R0
	MVO R0,_gram_bitmap
	;[115] wait
	SRCFILE "mermaid008.bas",115
	CALL _wait
	;[116] DEFINE DEF48,16,moreSprites
	SRCFILE "mermaid008.bas",116
	MVII #48,R0
	MVO R0,_gram_target
	MVII #16,R0
	MVO R0,_gram_total
	MVII #Q16,R0
	MVO R0,_gram_bitmap
	;[117] 
	SRCFILE "mermaid008.bas",117
	;[118] PRINT AT 22 COLOR FG_GREEN+BG_BLUE,"TUATARA SOFTWARE"
	SRCFILE "mermaid008.bas",118
	MVII #534,R0
	MVO R0,_screen
	MVII #517,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #416,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #8,R0
	MVO@ R0,R4
	XORI #160,R0
	MVO@ R0,R4
	XORI #168,R0
	MVO@ R0,R4
	XORI #168,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	XORI #264,R0
	MVO@ R0,R4
	XORI #408,R0
	MVO@ R0,R4
	XORI #224,R0
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	XORI #144,R0
	MVO@ R0,R4
	XORI #24,R0
	MVO@ R0,R4
	XORI #176,R0
	MVO@ R0,R4
	XORI #152,R0
	MVO@ R0,R4
	XORI #184,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[119] PRINT AT 46 COLOR FG_YELLOW+BG_BLUE,"PRESENTS"
	SRCFILE "mermaid008.bas",119
	MVII #558,R0
	MVO R0,_screen
	MVII #518,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #384,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #16,R0
	MVO@ R0,R4
	XORI #184,R0
	MVO@ R0,R4
	XORI #176,R0
	MVO@ R0,R4
	XORI #176,R0
	MVO@ R0,R4
	XORI #88,R0
	MVO@ R0,R4
	XORI #208,R0
	MVO@ R0,R4
	XORI #56,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[120] PRINT AT 84 COLOR FG_WHITE+BG_BLUE,"MERMAID V0.08"
	SRCFILE "mermaid008.bas",120
	MVII #596,R0
	MVO R0,_screen
	MVII #519,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #360,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #64,R0
	MVO@ R0,R4
	XORI #184,R0
	MVO@ R0,R4
	XORI #248,R0
	MVO@ R0,R4
	XORI #96,R0
	MVO@ R0,R4
	XORI #64,R0
	MVO@ R0,R4
	XORI #104,R0
	MVO@ R0,R4
	XORI #288,R0
	MVO@ R0,R4
	XORI #432,R0
	MVO@ R0,R4
	XORI #304,R0
	MVO@ R0,R4
	XORI #240,R0
	MVO@ R0,R4
	XORI #240,R0
	MVO@ R0,R4
	XORI #64,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[121] 
	SRCFILE "mermaid008.bas",121
	;[122] PRINT AT SCREENPOS(1, 9) COLOR FG_TAN+BG_BLUE,"DIFFICULTY (1-4) ?"
	SRCFILE "mermaid008.bas",122
	MVII #693,R0
	MVO R0,_screen
	MVII #515,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #288,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #104,R0
	MVO@ R0,R4
	XORI #120,R0
	MVO@ R0,R4
	MVO@ R0,R4
	XORI #120,R0
	MVO@ R0,R4
	XORI #80,R0
	MVO@ R0,R4
	XORI #176,R0
	MVO@ R0,R4
	XORI #200,R0
	MVO@ R0,R4
	XORI #192,R0
	MVO@ R0,R4
	XORI #104,R0
	MVO@ R0,R4
	XORI #456,R0
	MVO@ R0,R4
	XORI #64,R0
	MVO@ R0,R4
	XORI #200,R0
	MVO@ R0,R4
	XORI #224,R0
	MVO@ R0,R4
	XORI #200,R0
	MVO@ R0,R4
	XORI #232,R0
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	XORI #248,R0
	MVO@ R0,R4
	MVO R4,_screen
	;[123] 
	SRCFILE "mermaid008.bas",123
	;[124] VOICE INIT
	SRCFILE "mermaid008.bas",124
	CALL IV_INIT
	;[125] VOICE PLAY tuatara
	SRCFILE "mermaid008.bas",125
	MVII #Q17,R0
	CALL IV_PLAY.1
	;[126] VOICE PLAY software
	SRCFILE "mermaid008.bas",126
	MVII #Q18,R0
	CALL IV_PLAY.1
	;[127] VOICE PLAY presents
	SRCFILE "mermaid008.bas",127
	MVII #Q19,R0
	CALL IV_PLAY.1
	;[128] GOSUB waitabit
	SRCFILE "mermaid008.bas",128
	CALL Q20
	;[129] VOICE PLAY mermaid
	SRCFILE "mermaid008.bas",129
	MVII #Q21,R0
	CALL IV_PLAY.1
	;[130] Play Simple
	SRCFILE "mermaid008.bas",130
	MVII #1,R3
	MVO R3,_music_mode
	;[131] ''Play Intro_Tune
	SRCFILE "mermaid008.bas",131
	;[132] GOSUB introSwimBy	
	SRCFILE "mermaid008.bas",132
	CALL Q22
	;[133] PLAY NONE
	SRCFILE "mermaid008.bas",133
	CLRR R3
	MVO R3,_music_mode
	;[134] 
	SRCFILE "mermaid008.bas",134
	;[135] nextLevel:
	SRCFILE "mermaid008.bas",135
	; NEXTLEVEL
Q23:	;[136] 
	SRCFILE "mermaid008.bas",136
	;[137] level = level + 1
	SRCFILE "mermaid008.bas",137
	MVI V2,R0
	INCR R0
	MVO R0,V2
	;[138] 
	SRCFILE "mermaid008.bas",138
	;[139] 'castle will be on random screen each level based on current level # and user-selected difficulty level
	SRCFILE "mermaid008.bas",139
	;[140] 
	SRCFILE "mermaid008.bas",140
	;[141] GOSUB levelRandomizer
	SRCFILE "mermaid008.bas",141
	CALL Q24
	;[142] 
	SRCFILE "mermaid008.bas",142
	;[143] GOSUB merColor
	SRCFILE "mermaid008.bas",143
	CALL Q25
	;[144] 
	SRCFILE "mermaid008.bas",144
	;[145] 
	SRCFILE "mermaid008.bas",145
	;[146] main:
	SRCFILE "mermaid008.bas",146
	; MAIN
Q26:	;[147] cls
	SRCFILE "mermaid008.bas",147
	CALL CLRSCR
	MVII #512,R0
	MVO R0,_screen
	;[148] resetsprite(0):resetsprite(1):resetsprite(2):resetsprite(3):resetsprite(4):resetsprite(5):resetsprite(6):resetsprite(7)
	SRCFILE "mermaid008.bas",148
	CLRR R0
	MVO R0,_mobs
	MVO R0,_mobs+8
	NOP
	MVO R0,_mobs+16
	MVO R0,_mobs+1
	NOP
	MVO R0,_mobs+9
	MVO R0,_mobs+17
	NOP
	MVO R0,_mobs+2
	MVO R0,_mobs+10
	NOP
	MVO R0,_mobs+18
	MVO R0,_mobs+3
	NOP
	MVO R0,_mobs+11
	MVO R0,_mobs+19
	NOP
	MVO R0,_mobs+4
	MVO R0,_mobs+12
	NOP
	MVO R0,_mobs+20
	MVO R0,_mobs+5
	NOP
	MVO R0,_mobs+13
	MVO R0,_mobs+21
	NOP
	MVO R0,_mobs+6
	MVO R0,_mobs+14
	NOP
	MVO R0,_mobs+22
	MVO R0,_mobs+7
	NOP
	MVO R0,_mobs+15
	MVO R0,_mobs+23
	;[149] Rem first sprite is Mermaid1
	SRCFILE "mermaid008.bas",149
	;[150] Spritex(0)=80
	SRCFILE "mermaid008.bas",150
	MVII #80,R0
	MVO R0,Q8
	;[151] Spritey(0)=60
	SRCFILE "mermaid008.bas",151
	MVII #60,R0
	MVO R0,Q9
	;[152] #SpriteC(0)=SPR_YELLOW
	SRCFILE "mermaid008.bas",152
	MVII #6,R0
	MVO R0,Q10
	;[153] 
	SRCFILE "mermaid008.bas",153
	;[154] Rem second sprite is Mermaid2  
	SRCFILE "mermaid008.bas",154
	;[155] Spritex(1)=80
	SRCFILE "mermaid008.bas",155
	MVII #80,R0
	MVO R0,Q8+1
	;[156] Spritey(1)=60
	SRCFILE "mermaid008.bas",156
	MVII #60,R0
	MVO R0,Q9+1
	;[157] #SpriteC(1)=#mermaid_color
	SRCFILE "mermaid008.bas",157
	MVI V12,R0
	MVO R0,Q10+1
	;[158] 
	SRCFILE "mermaid008.bas",158
	;[159] ''Rem sprite#3 is creature-left
	SRCFILE "mermaid008.bas",159
	;[160] Spritex(3)=80
	SRCFILE "mermaid008.bas",160
	MVII #80,R0
	MVO R0,Q8+3
	;[161] Spritey(3)=20
	SRCFILE "mermaid008.bas",161
	MVII #20,R0
	MVO R0,Q9+3
	;[162] #SpriteC(3)=SPR_GREY
	SRCFILE "mermaid008.bas",162
	MVII #4096,R0
	MVO R0,Q10+3
	;[163] 
	SRCFILE "mermaid008.bas",163
	;[164] ''Rem sprite#4 is creature-right
	SRCFILE "mermaid008.bas",164
	;[165] Spritex(4)=88
	SRCFILE "mermaid008.bas",165
	MVII #88,R0
	MVO R0,Q8+4
	;[166] Spritey(4)=20
	SRCFILE "mermaid008.bas",166
	MVII #20,R0
	MVO R0,Q9+4
	;[167] #SpriteC(4)=SPR_GREY
	SRCFILE "mermaid008.bas",167
	MVII #4096,R0
	MVO R0,Q10+4
	;[168] 
	SRCFILE "mermaid008.bas",168
	;[169] ''Rem sprite#5 is queen
	SRCFILE "mermaid008.bas",169
	;[170] Spritex(5)=70
	SRCFILE "mermaid008.bas",170
	MVII #70,R0
	MVO R0,Q8+5
	;[171] Spritey(5)=48
	SRCFILE "mermaid008.bas",171
	MVII #48,R0
	MVO R0,Q9+5
	;[172] #SpriteC(5)=SPR_PINK
	SRCFILE "mermaid008.bas",172
	MVII #4100,R0
	MVO R0,Q10+5
	;[173] 
	SRCFILE "mermaid008.bas",173
	;[174] ''Rem sprite#6 is queen2
	SRCFILE "mermaid008.bas",174
	;[175] Spritex(6)=70
	SRCFILE "mermaid008.bas",175
	MVII #70,R0
	MVO R0,Q8+6
	;[176] Spritey(6)=48
	SRCFILE "mermaid008.bas",176
	MVII #48,R0
	MVO R0,Q9+6
	;[177] #SpriteC(6)=SPR_YELLOW
	SRCFILE "mermaid008.bas",177
	MVII #6,R0
	MVO R0,Q10+6
	;[178] 
	SRCFILE "mermaid008.bas",178
	;[179] ''Rem sprite#7 is queen's sceptre
	SRCFILE "mermaid008.bas",179
	;[180] Spritex(7)=54
	SRCFILE "mermaid008.bas",180
	MVII #54,R0
	MVO R0,Q8+7
	;[181] Spritey(7)=48
	SRCFILE "mermaid008.bas",181
	MVII #48,R0
	MVO R0,Q9+7
	;[182] #SpriteC(7)=SPR_TAN
	SRCFILE "mermaid008.bas",182
	MVII #3,R0
	MVO R0,Q10+7
	;[183] 
	SRCFILE "mermaid008.bas",183
	;[184] 'reset bubbles and boost to 3
	SRCFILE "mermaid008.bas",184
	;[185] bubbles = 3: boost = 3 : merChange = 1
	SRCFILE "mermaid008.bas",185
	MVO R0,V38
	NOP
	MVO R0,V39
	MVII #1,R0
	MVO R0,V40
	;[186] GOSUB update_bubble_counter:GOSUB update_boost_counter:GOSUB update_merChange_counter
	SRCFILE "mermaid008.bas",186
	CALL Q27
	CALL Q28
	CALL Q29
	;[187] 
	SRCFILE "mermaid008.bas",187
	;[188] #countdownTimer = ((5-level)*2400)/diffLevel 
	SRCFILE "mermaid008.bas",188
	MVII #5,R0
	SUB V2,R0
	MVII #2400,R5
	CLRR R4
	CLRC
	RRC R0,1
	BEQ T2
T1:
	BNC $+3
	ADDR R5,R4
	ADDR R5,R5
	SARC R0,1
	BNE T1
T2:
	BNC $+3
	ADDR R5,R4
	MOVR R4,R0
	MVI V7,R4
	MOVR R0,R5
	TSTR R4
	BEQ T3
	MVII #-1,R0
T4:
	INCR R0
	SUBR R4,R5
	BC T4
T3:
	MVO R0,V6
	;[189] inventory_crown = 0
	SRCFILE "mermaid008.bas",189
	CLRR R0
	MVO R0,V21
	;[190] inventory_key = 0
	SRCFILE "mermaid008.bas",190
	MVO R0,V20
	;[191] queen_visible = 0
	SRCFILE "mermaid008.bas",191
	NOP
	MVO R0,V36
	;[192] queen_counter=0
	SRCFILE "mermaid008.bas",192
	MVO R0,V41
	;[193] queen_frame=0
	SRCFILE "mermaid008.bas",193
	NOP
	MVO R0,V42
	;[194] 
	SRCFILE "mermaid008.bas",194
	;[195] mermaidLocation=0
	SRCFILE "mermaid008.bas",195
	MVO R0,V18
	;[196] 
	SRCFILE "mermaid008.bas",196
	;[197] SCREEN screen_level
	SRCFILE "mermaid008.bas",197
	MVII #Q30,R3
	MVII #512,R2
	MVII #20,R1
	MVII #12,R0
	CALL CPYBLK
	;[198] GOSUB update_score
	SRCFILE "mermaid008.bas",198
	CALL Q31
	;[199] PLAY Simple
	SRCFILE "mermaid008.bas",199
	MVII #1,R3
	MVO R3,_music_mode
	;[200] PLAY Game_Tune
	SRCFILE "mermaid008.bas",200
	MVII #Q32,R0
	CALL _play_music
	;[201] 
	SRCFILE "mermaid008.bas",201
	;[202] game_loop:
	SRCFILE "mermaid008.bas",202
	; GAME_LOOP
Q33:	;[203] 
	SRCFILE "mermaid008.bas",203
	;[204] 
	SRCFILE "mermaid008.bas",204
	;[205] ''if mermaidFacing=0 then Sprite 0,Spritex(0)+VISIBLE+ZOOMX2,Spritey(0)+ZOOMY2, SPR32+ (8*spriteframe) +#SpriteC(0) else Sprite 0,Spritex(0)+VISIBLE+ZOOMX2,Spritey(0)+ZOOMY2+FLIPX, SPR32+ (8*spriteframe) +#SpriteC(0)
	SRCFILE "mermaid008.bas",205
	;[206] if mermaidFacing=0 then Sprite 0,Spritex(0)+VISIBLE+HIT+ZOOMX2,Spritey(0)+ZOOMY2, SPR32+ (8*spriteframe) +#SpriteC(0) else Sprite 0,Spritex(0)+VISIBLE+HIT+ZOOMX2,Spritey(0)+ZOOMY2+FLIPX, SPR32+ (8*spriteframe) +#SpriteC(0)
	SRCFILE "mermaid008.bas",206
	MVI V11,R0
	TSTR R0
	BNE T5
	MVI Q8,R0
	ADDI #1792,R0
	MVO R0,_mobs
	MVI Q9,R0
	ADDI #256,R0
	MVO R0,_mobs+8
	MVI V43,R0
	SLL R0,2
	ADDR R0,R0
	ADDI #2304,R0
	MVI Q10,R1
	ADDR R1,R0
	MVO R0,_mobs+16
	B T6
T5:
	MVI Q8,R0
	ADDI #1792,R0
	MVO R0,_mobs
	MVI Q9,R0
	ADDI #1280,R0
	MVO R0,_mobs+8
	MVI V43,R0
	SLL R0,2
	ADDR R0,R0
	ADDI #2304,R0
	MVI Q10,R1
	ADDR R1,R0
	MVO R0,_mobs+16
T6:
	;[207] if mermaidFacing=0 then Sprite 1,Spritex(1)+VISIBLE+ZOOMX2,Spritey(1)+ZOOMY2, SPR36+ (8*spriteframe) +#SpriteC(1) else Sprite 1,Spritex(1)+VISIBLE+ZOOMX2,Spritey(1)+ZOOMY2+FLIPX, SPR36+ (8*spriteframe) +#SpriteC(1)
	SRCFILE "mermaid008.bas",207
	MVI V11,R0
	TSTR R0
	BNE T7
	MVI Q8+1,R0
	ADDI #1536,R0
	MVO R0,_mobs+1
	MVI Q9+1,R0
	ADDI #256,R0
	MVO R0,_mobs+9
	MVI V43,R0
	SLL R0,2
	ADDR R0,R0
	ADDI #2336,R0
	MVI Q10+1,R1
	ADDR R1,R0
	MVO R0,_mobs+17
	B T8
T7:
	MVI Q8+1,R0
	ADDI #1536,R0
	MVO R0,_mobs+1
	MVI Q9+1,R0
	ADDI #1280,R0
	MVO R0,_mobs+9
	MVI V43,R0
	SLL R0,2
	ADDR R0,R0
	ADDI #2336,R0
	MVI Q10+1,R1
	ADDR R1,R0
	MVO R0,_mobs+17
T8:
	;[208] 
	SRCFILE "mermaid008.bas",208
	;[209] 'reposition creature
	SRCFILE "mermaid008.bas",209
	;[210] IF creature>0 AND creature<7 THEN GOSUB moveCreature
	SRCFILE "mermaid008.bas",210
	MVI V31,R0
	CMPI #0,R0
	MVII #-1,R0
	BGT $+3
	INCR R0
	MVI V31,R1
	CMPI #7,R1
	MVII #-1,R1
	BLT $+3
	INCR R1
	ANDR R1,R0
	BEQ T9
	CALL Q34
T9:
	;[211] IF creature>0 AND creature<7 THEN GOSUB display_creature
	SRCFILE "mermaid008.bas",211
	MVI V31,R0
	CMPI #0,R0
	MVII #-1,R0
	BGT $+3
	INCR R0
	MVI V31,R1
	CMPI #7,R1
	MVII #-1,R1
	BLT $+3
	INCR R1
	ANDR R1,R0
	BEQ T10
	CALL Q35
T10:
	;[212] 
	SRCFILE "mermaid008.bas",212
	;[213] IF creature>0 AND creature<7 THEN GOSUB moveCreature:GOSUB display_creature
	SRCFILE "mermaid008.bas",213
	MVI V31,R0
	CMPI #0,R0
	MVII #-1,R0
	BGT $+3
	INCR R0
	MVI V31,R1
	CMPI #7,R1
	MVII #-1,R1
	BLT $+3
	INCR R1
	ANDR R1,R0
	BEQ T11
	CALL Q34
	CALL Q35
T11:
	;[214] 
	SRCFILE "mermaid008.bas",214
	;[215] IF queen_visible = 1 THEN GOSUB displayQueen
	SRCFILE "mermaid008.bas",215
	MVI V36,R0
	CMPI #1,R0
	BNE T12
	CALL Q36
T12:
	;[216] 
	SRCFILE "mermaid008.bas",216
	;[217] gosub waitalittle
	SRCFILE "mermaid008.bas",217
	CALL Q37
	;[218] Spriteframe=Spriteframe+1:If SpriteFrame>3 then SpriteFrame=0
	SRCFILE "mermaid008.bas",218
	MVI V43,R0
	INCR R0
	MVO R0,V43
	MVI V43,R0
	CMPI #3,R0
	BLE T13
	CLRR R0
	MVO R0,V43
T13:
	;[219] if creature>0 AND creature<7 THEN creature1_timer=creature1_Timer+1:If creature1_timer<4 THEN creature1_frame=0 ELSE creature1_frame=1
	SRCFILE "mermaid008.bas",219
	MVI V31,R0
	CMPI #0,R0
	MVII #-1,R0
	BGT $+3
	INCR R0
	MVI V31,R1
	CMPI #7,R1
	MVII #-1,R1
	BLT $+3
	INCR R1
	ANDR R1,R0
	BEQ T14
	MVI V34,R0
	INCR R0
	MVO R0,V34
	MVI V34,R0
	CMPI #4,R0
	BGE T15
	CLRR R0
	MVO R0,V33
	B T16
T15:
	MVII #1,R0
	MVO R0,V33
T16:
T14:
	;[220] if creature1_timer>10 THEN creature1_timer=0
	SRCFILE "mermaid008.bas",220
	MVI V34,R0
	CMPI #10,R0
	BLE T17
	CLRR R0
	MVO R0,V34
T17:
	;[221] 
	SRCFILE "mermaid008.bas",221
	;[222] 'print gold bar, silver coin or crown
	SRCFILE "mermaid008.bas",222
	;[223] 'gold bar = $2C39
	SRCFILE "mermaid008.bas",223
	;[224] IF mermaidLocation = 0 AND inventory_gold = 0 AND gold_position > 0 THEN PRINT AT 180+gold_position, $2C39:gold_visible=1 ELSE PRINT AT 180+gold_position, $0200
	SRCFILE "mermaid008.bas",224
	MVI V18,R0
	TSTR R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V22,R1
	TSTR R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	ANDR R1,R0
	MVI V26,R1
	CMPI #0,R1
	MVII #-1,R1
	BGT $+3
	INCR R1
	ANDR R1,R0
	BEQ T18
	MVI V26,R0
	ADDI #692,R0
	MVO R0,_screen
	MVII #11321,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	MVII #1,R0
	MVO R0,V44
	B T19
T18:
	MVI V26,R0
	ADDI #692,R0
	MVO R0,_screen
	MVII #512,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
T19:
	;[225] 'silver coin = $1841
	SRCFILE "mermaid008.bas",225
	;[226] IF mermaidLocation = 0 AND inventory_silver = 0 AND silver_position > 0 THEN PRINT AT 180+silver_position, $1841:silver_visible=1 ELSE PRINT AT 180+silver_position, $0200
	SRCFILE "mermaid008.bas",226
	MVI V18,R0
	TSTR R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V23,R1
	TSTR R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	ANDR R1,R0
	MVI V27,R1
	CMPI #0,R1
	MVII #-1,R1
	BGT $+3
	INCR R1
	ANDR R1,R0
	BEQ T20
	MVI V27,R0
	ADDI #692,R0
	MVO R0,_screen
	MVII #6209,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	MVII #1,R0
	MVO R0,V45
	B T21
T20:
	MVI V27,R0
	ADDI #692,R0
	MVO R0,_screen
	MVII #512,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
T21:
	;[227] 'crown = $3849
	SRCFILE "mermaid008.bas",227
	;[228] IF mermaidLocation = 0 AND mermaid_oceanLocation = crownLocation AND inventory_crown = 0 THEN PRINT AT 180+crownPosition, $3849:crown_visible=1 ELSE PRINT AT 180+crownPosition, $0200
	SRCFILE "mermaid008.bas",228
	MVI V18,R0
	TSTR R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V46,R1
	CMP V47,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	ANDR R1,R0
	MVI V21,R1
	TSTR R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	ANDR R1,R0
	BEQ T22
	MVI V48,R0
	ADDI #692,R0
	MVO R0,_screen
	MVII #14409,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	MVII #1,R0
	MVO R0,V25
	B T23
T22:
	MVI V48,R0
	ADDI #692,R0
	MVO R0,_screen
	MVII #512,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
T23:
	;[229] 'key = $2E51
	SRCFILE "mermaid008.bas",229
	;[230] IF mermaidLocation = 0 AND mermaid_oceanLocation = keyLocation AND inventory_key = 0 THEN PRINT AT 180+keyPosition, $2E51:key_visible=1 ELSE PRINT AT 180+keyPosition, $0200
	SRCFILE "mermaid008.bas",230
	MVI V18,R0
	TSTR R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V46,R1
	CMP V49,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	ANDR R1,R0
	MVI V20,R1
	TSTR R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	ANDR R1,R0
	BEQ T24
	MVI V50,R0
	ADDI #692,R0
	MVO R0,_screen
	MVII #11857,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	MVII #1,R0
	MVO R0,V24
	B T25
T24:
	MVI V50,R0
	ADDI #692,R0
	MVO R0,_screen
	MVII #512,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
T25:
	;[231] 'place the castle
	SRCFILE "mermaid008.bas",231
	;[232] IF mermaidLocation = 0 AND mermaid_oceanLocation = castleLocation THEN GOSUB castle_Placement
	SRCFILE "mermaid008.bas",232
	MVI V18,R0
	TSTR R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V46,R1
	CMP V51,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	ANDR R1,R0
	BEQ T26
	CALL Q38
T26:
	;[233] 'place the queen's throne
	SRCFILE "mermaid008.bas",233
	;[234] IF mermaidLocation = 1 AND mermaid_CastleLocation = queenLocation AND queen_visible = 0 THEN queen_visible = 1
	SRCFILE "mermaid008.bas",234
	MVI V18,R0
	CMPI #1,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V52,R1
	CMP V53,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	ANDR R1,R0
	MVI V36,R1
	TSTR R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	ANDR R1,R0
	BEQ T27
	MVII #1,R0
	MVO R0,V36
T27:
	;[235] 
	SRCFILE "mermaid008.bas",235
	;[236] IF queen_visible = 1 THEN GOSUB displayQueen
	SRCFILE "mermaid008.bas",236
	MVI V36,R0
	CMPI #1,R0
	BNE T28
	CALL Q36
T28:
	;[237] 
	SRCFILE "mermaid008.bas",237
	;[238] 'check for controller movement, reposition mermaid
	SRCFILE "mermaid008.bas",238
	;[239] IF cont.left THEN 
	SRCFILE "mermaid008.bas",239
	MVI 510,R0
	XOR 511,R0
	ANDI #8,R0
	BEQ T29
	;[240] 	IF mermaidLocation=0 THEN 
	SRCFILE "mermaid008.bas",240
	MVI V18,R0
	TSTR R0
	BNE T30
	;[241] 		IF Spritex(0) > 4 THEN GOSUB mermaid_moveLeft ELSE nextScreen = 4: GOSUB mermaid_moveLeft
	SRCFILE "mermaid008.bas",241
	MVI Q8,R0
	CMPI #4,R0
	BLE T31
	CALL Q39
	B T32
T31:
	MVII #4,R0
	MVO R0,V19
	CALL Q39
T32:
	;[242] 	ELSE
	SRCFILE "mermaid008.bas",242
	B T33
T30:
	;[243] 		IF Spritex(0) > 14 THEN	
	SRCFILE "mermaid008.bas",243
	MVI Q8,R0
	CMPI #14,R0
	BLE T34
	;[244] 			GOSUB mermaid_moveLeft
	SRCFILE "mermaid008.bas",244
	CALL Q39
	;[245] 		ELSE 
	SRCFILE "mermaid008.bas",245
	B T35
T34:
	;[246] 			''IF Spritex(0) > 12 AND Spritex(0) <= 14 THEN nextScreen = 4: GOSUB mermaid_moveLeft
	SRCFILE "mermaid008.bas",246
	;[247] 			IF Spritex(0) >= 12 AND Spritex(0) <= 16 THEN nextScreen = 4: GOSUB mermaid_moveLeft
	SRCFILE "mermaid008.bas",247
	MVI Q8,R0
	CMPI #12,R0
	MVII #-1,R0
	BGE $+3
	INCR R0
	MVI Q8,R1
	CMPI #16,R1
	MVII #-1,R1
	BLE $+3
	INCR R1
	ANDR R1,R0
	BEQ T36
	MVII #4,R0
	MVO R0,V19
	CALL Q39
T36:
	;[248] 		END IF
	SRCFILE "mermaid008.bas",248
T35:
	;[249] 	END IF
	SRCFILE "mermaid008.bas",249
T33:
	;[250] END IF
	SRCFILE "mermaid008.bas",250
T29:
	;[251] 
	SRCFILE "mermaid008.bas",251
	;[252] IF cont.right THEN 
	SRCFILE "mermaid008.bas",252
	MVI 510,R0
	XOR 511,R0
	ANDI #2,R0
	BEQ T37
	;[253] 	IF mermaidLocation=0 THEN 
	SRCFILE "mermaid008.bas",253
	MVI V18,R0
	TSTR R0
	BNE T38
	;[254] 		IF Spritex(0) < 156 THEN GOSUB mermaid_moveRight ELSE nextScreen = 2: GOSUB mermaid_moveRight
	SRCFILE "mermaid008.bas",254
	MVI Q8,R0
	CMPI #156,R0
	BGE T39
	CALL Q40
	B T40
T39:
	MVII #2,R0
	MVO R0,V19
	CALL Q40
T40:
	;[255] 	ELSE
	SRCFILE "mermaid008.bas",255
	B T41
T38:
	;[256] 		IF Spritex(0) < 146 THEN 
	SRCFILE "mermaid008.bas",256
	MVI Q8,R0
	CMPI #146,R0
	BGE T42
	;[257] 			GOSUB mermaid_moveRight
	SRCFILE "mermaid008.bas",257
	CALL Q40
	;[258] 		ELSE
	SRCFILE "mermaid008.bas",258
	B T43
T42:
	;[259] 			''IF Spritex(0) >= 146 and Spritex(0) < 148 THEN nextScreen = 2: GOSUB mermaid_moveRight
	SRCFILE "mermaid008.bas",259
	;[260] 			IF Spritex(0) >= 144 and Spritex(0) <= 148 THEN nextScreen = 2: GOSUB mermaid_moveRight
	SRCFILE "mermaid008.bas",260
	MVI Q8,R0
	CMPI #144,R0
	MVII #-1,R0
	BGE $+3
	INCR R0
	MVI Q8,R1
	CMPI #148,R1
	MVII #-1,R1
	BLE $+3
	INCR R1
	ANDR R1,R0
	BEQ T44
	MVII #2,R0
	MVO R0,V19
	CALL Q40
T44:
	;[261] 		END IF
	SRCFILE "mermaid008.bas",261
T43:
	;[262] 	END IF
	SRCFILE "mermaid008.bas",262
T41:
	;[263] END IF
	SRCFILE "mermaid008.bas",263
T37:
	;[264] 
	SRCFILE "mermaid008.bas",264
	;[265] IF cont.up THEN 
	SRCFILE "mermaid008.bas",265
	MVI 510,R0
	XOR 511,R0
	ANDI #4,R0
	BEQ T45
	;[266] 	IF mermaidLocation=0 THEN 
	SRCFILE "mermaid008.bas",266
	MVI V18,R0
	TSTR R0
	BNE T46
	;[267] 		IF Spritey(0) > 8 THEN GOSUB mermaid_moveUp 
	SRCFILE "mermaid008.bas",267
	MVI Q9,R0
	CMPI #8,R0
	BLE T47
	CALL Q41
T47:
	;[268] 	ELSE
	SRCFILE "mermaid008.bas",268
	B T48
T46:
	;[269] 		IF Spritey(0) > 14 THEN
	SRCFILE "mermaid008.bas",269
	MVI Q9,R0
	CMPI #14,R0
	BLE T49
	;[270] 			GOSUB mermaid_moveUp
	SRCFILE "mermaid008.bas",270
	CALL Q41
	;[271] 		ELSE
	SRCFILE "mermaid008.bas",271
	B T50
T49:
	;[272] 			''IF Spritey(0) > 12 and Spritey(0) <= 14 THEN nextScreen = 1: GOSUB mermaid_moveUp 
	SRCFILE "mermaid008.bas",272
	;[273] 			IF Spritey(0) >= 12 and Spritey(0) <= 16 THEN nextScreen = 1: GOSUB mermaid_moveUp 
	SRCFILE "mermaid008.bas",273
	MVI Q9,R0
	CMPI #12,R0
	MVII #-1,R0
	BGE $+3
	INCR R0
	MVI Q9,R1
	CMPI #16,R1
	MVII #-1,R1
	BLE $+3
	INCR R1
	ANDR R1,R0
	BEQ T51
	MVII #1,R0
	MVO R0,V19
	CALL Q41
T51:
	;[274] 		END IF
	SRCFILE "mermaid008.bas",274
T50:
	;[275] 	END IF
	SRCFILE "mermaid008.bas",275
T48:
	;[276] END IF
	SRCFILE "mermaid008.bas",276
T45:
	;[277] 
	SRCFILE "mermaid008.bas",277
	;[278] IF cont.down THEN 
	SRCFILE "mermaid008.bas",278
	MVI 510,R0
	XOR 511,R0
	ANDI #1,R0
	BEQ T52
	;[279] 	IF mermaidLocation=0 THEN 
	SRCFILE "mermaid008.bas",279
	MVI V18,R0
	TSTR R0
	BNE T53
	;[280] 		IF Spritey(0) < 86 THEN GOSUB mermaid_moveDown
	SRCFILE "mermaid008.bas",280
	MVI Q9,R0
	CMPI #86,R0
	BGE T54
	CALL Q42
T54:
	;[281] 	ELSE
	SRCFILE "mermaid008.bas",281
	B T55
T53:
	;[282] 		IF Spritey(0) < 88 THEN 
	SRCFILE "mermaid008.bas",282
	MVI Q9,R0
	CMPI #88,R0
	BGE T56
	;[283] 			GOSUB mermaid_moveDown
	SRCFILE "mermaid008.bas",283
	CALL Q42
	;[284] 		ELSE
	SRCFILE "mermaid008.bas",284
	B T57
T56:
	;[285] 			''IF Spritey(0) >=88 and Spritey(0) < 90 THEN nextScreen = 3: GOSUB mermaid_moveDown
	SRCFILE "mermaid008.bas",285
	;[286] 			IF Spritey(0) >=88 and Spritey(0) <= 92 THEN nextScreen = 3: GOSUB mermaid_moveDown
	SRCFILE "mermaid008.bas",286
	MVI Q9,R0
	CMPI #88,R0
	MVII #-1,R0
	BGE $+3
	INCR R0
	MVI Q9,R1
	CMPI #92,R1
	MVII #-1,R1
	BLE $+3
	INCR R1
	ANDR R1,R0
	BEQ T58
	MVII #3,R0
	MVO R0,V19
	CALL Q42
T58:
	;[287] 		END IF
	SRCFILE "mermaid008.bas",287
T57:
	;[288] 	END IF
	SRCFILE "mermaid008.bas",288
T55:
	;[289] END IF	
	SRCFILE "mermaid008.bas",289
T52:
	;[290] 
	SRCFILE "mermaid008.bas",290
	;[291] IF bubbles > 0 AND bubble_active = 0 THEN IF cont.B0 THEN bubble_active = 1:bubbles=bubbles-1:Spritex(2)=Spritex(0):Spritey(2)=Spritey(0):soundFlag=5 : GOSUB loadSound
	SRCFILE "mermaid008.bas",291
	MVI V38,R0
	CMPI #0,R0
	MVII #-1,R0
	BGT $+3
	INCR R0
	MVI V54,R1
	TSTR R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	ANDR R1,R0
	BEQ T59
	MVI 510,R0
	XOR 511,R0
	ANDI #224,R0
	CMPI #160,R0
	BNE T60
	MVII #1,R0
	MVO R0,V54
	MVI V38,R0
	DECR R0
	MVO R0,V38
	MVI Q8,R0
	MVO R0,Q8+2
	MVI Q9,R0
	MVO R0,Q9+2
	MVII #5,R0
	MVO R0,V29
	CALL Q43
T60:
T59:
	;[292] IF bubble_active = 1 THEN #bubble_counter=#bubble_counter-1:Sprite 2,Spritex(2)+VISIBLE+ZOOMX2,Spritey(2)+ZOOMY2, SPR40+#SpriteC(2)
	SRCFILE "mermaid008.bas",292
	MVI V54,R0
	CMPI #1,R0
	BNE T61
	MVI V3,R0
	DECR R0
	MVO R0,V3
	MVI Q8+2,R0
	ADDI #1536,R0
	MVO R0,_mobs+2
	MVI Q9+2,R0
	ADDI #256,R0
	MVO R0,_mobs+10
	MVI Q10+2,R0
	ADDI #2368,R0
	MVO R0,_mobs+18
T61:
	;[293] ''IF #bubble_counter = 0 then bubble_active = 0:GOSUB update_bubble_counter:Sprite 2,Spritex(2)+ZOOMX2,Spritey(2)+ZOOMY2, SPR40+#SpriteC(2)
	SRCFILE "mermaid008.bas",293
	;[294] IF #bubble_counter = 0 then bubble_active = 0:GOSUB update_bubble_counter:resetsprite(2)
	SRCFILE "mermaid008.bas",294
	MVI V3,R0
	TSTR R0
	BNE T62
	MVO R0,V54
	CALL Q27
	CLRR R0
	MVO R0,_mobs+2
	MVO R0,_mobs+10
	NOP
	MVO R0,_mobs+18
T62:
	;[295] 
	SRCFILE "mermaid008.bas",295
	;[296] IF boost > 0 AND boost_active = 0 THEN 
	SRCFILE "mermaid008.bas",296
	MVI V39,R0
	CMPI #0,R0
	MVII #-1,R0
	BGT $+3
	INCR R0
	MVI V55,R1
	TSTR R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	ANDR R1,R0
	BEQ T63
	;[297] 	IF cont.B2 THEN 
	SRCFILE "mermaid008.bas",297
	MVI 510,R0
	XOR 511,R0
	ANDI #224,R0
	CMPI #192,R0
	BNE T64
	;[298] 		boost_active = 1:boost=boost-1
	SRCFILE "mermaid008.bas",298
	MVII #1,R0
	MVO R0,V55
	MVI V39,R0
	DECR R0
	MVO R0,V39
	;[299] 		IF merChange_active = 0 THEN mermaid_speed=mermaid_speed*2
	SRCFILE "mermaid008.bas",299
	MVI V56,R0
	TSTR R0
	BNE T65
	MVI V15,R0
	SLL R0,1
	MVO R0,V15
T65:
	;[300] 		soundFlag=7 
	SRCFILE "mermaid008.bas",300
	MVII #7,R0
	MVO R0,V29
	;[301] 		GOSUB loadSound
	SRCFILE "mermaid008.bas",301
	CALL Q43
	;[302] 	END IF
	SRCFILE "mermaid008.bas",302
T64:
	;[303] END IF
	SRCFILE "mermaid008.bas",303
T63:
	;[304] IF boost_active = 1 THEN #boost_counter=#boost_counter-1
	SRCFILE "mermaid008.bas",304
	MVI V55,R0
	CMPI #1,R0
	BNE T66
	MVI V4,R0
	DECR R0
	MVO R0,V4
T66:
	;[305] IF #boost_counter = 0 then boost_active = 0:mermaid_speed=mermaid_speed/2:GOSUB update_boost_counter
	SRCFILE "mermaid008.bas",305
	MVI V4,R0
	TSTR R0
	BNE T67
	MVO R0,V55
	MVI V15,R0
	SLR R0,1
	MVO R0,V15
	CALL Q28
T67:
	;[306] 
	SRCFILE "mermaid008.bas",306
	;[307] IF merChange > 0 AND merChange_active = 0 THEN 
	SRCFILE "mermaid008.bas",307
	MVI V40,R0
	CMPI #0,R0
	MVII #-1,R0
	BGT $+3
	INCR R0
	MVI V56,R1
	TSTR R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	ANDR R1,R0
	BEQ T68
	;[308] 	IF cont.B1 THEN 
	SRCFILE "mermaid008.bas",308
	MVI 510,R0
	XOR 511,R0
	ANDI #224,R0
	CMPI #96,R0
	BNE T69
	;[309] 		merChange_active = mermaid
	SRCFILE "mermaid008.bas",309
	MVI V8,R0
	MVO R0,V56
	;[310] 		perform_merChange:
	SRCFILE "mermaid008.bas",310
	; PERFORM_MERCHANGE
Q44:	;[311] 		mermaid=RANDOM(5)+1 : IF mermaid = merChange_active GOTO perform_merChange 
	SRCFILE "mermaid008.bas",311
	MVII #5,R1
	CALL _next_random
	CALL qs_mpy8
	SWAP R0
	ANDI #255,R0
	INCR R0
	MVO R0,V8
	MVI V8,R0
	CMP V56,R0
	BEQ Q44
	;[312] 		GOSUB merColor
	SRCFILE "mermaid008.bas",312
	CALL Q25
	;[313] 		merChange=merChange-1
	SRCFILE "mermaid008.bas",313
	MVI V40,R0
	DECR R0
	MVO R0,V40
	;[314] 		if boost_active = 0 THEN mermaid_speed=mermaid_speed*2
	SRCFILE "mermaid008.bas",314
	MVI V55,R0
	TSTR R0
	BNE T71
	MVI V15,R0
	SLL R0,1
	MVO R0,V15
T71:
	;[315] 		Spritex(2)=Spritex(0):Spritey(2)=Spritey(0)
	SRCFILE "mermaid008.bas",315
	MVI Q8,R0
	MVO R0,Q8+2
	MVI Q9,R0
	MVO R0,Q9+2
	;[316] 		bubble_active=1:boost_active=1
	SRCFILE "mermaid008.bas",316
	MVII #1,R0
	MVO R0,V54
	MVO R0,V55
	;[317] 		soundFlag=7
	SRCFILE "mermaid008.bas",317
	MVII #7,R0
	MVO R0,V29
	;[318] 		GOSUB loadSound
	SRCFILE "mermaid008.bas",318
	CALL Q43
	;[319] 	END IF
	SRCFILE "mermaid008.bas",319
T69:
	;[320] END IF
	SRCFILE "mermaid008.bas",320
T68:
	;[321] IF merChange_active > 0 THEN #merChange_counter=#merChange_counter-1
	SRCFILE "mermaid008.bas",321
	MVI V56,R0
	CMPI #0,R0
	BLE T72
	MVI V5,R0
	DECR R0
	MVO R0,V5
T72:
	;[322] IF #merChange_counter = 0 then mermaid = merChange_active : merChange_active = 0 : GOSUB merColor: mermaid_speed=mermaid_speed/2: boost_active = 0 : bubble_active = 0: resetsprite(2): GOSUB update_merChange_counter
	SRCFILE "mermaid008.bas",322
	MVI V5,R0
	TSTR R0
	BNE T73
	MVI V56,R0
	MVO R0,V8
	CLRR R0
	MVO R0,V56
	CALL Q25
	MVI V15,R0
	SLR R0,1
	MVO R0,V15
	CLRR R0
	MVO R0,V55
	MVO R0,V54
	NOP
	MVO R0,_mobs+2
	MVO R0,_mobs+10
	NOP
	MVO R0,_mobs+18
	CALL Q29
T73:
	;[323] 
	SRCFILE "mermaid008.bas",323
	;[324] 'if bubble_active=1 do not enforce collisions with sea creatures!
	SRCFILE "mermaid008.bas",324
	;[325] IF bubble_active=1 GOTO avoid_creature_collision
	SRCFILE "mermaid008.bas",325
	MVI V54,R0
	CMPI #1,R0
	BEQ Q45
	;[326] 
	SRCFILE "mermaid008.bas",326
	;[327] 'check for collisions with sea creatures
	SRCFILE "mermaid008.bas",327
	;[328] IF COL0 AND HIT_SPRITE3 THEN 
	SRCFILE "mermaid008.bas",328
	MVI _col0,R0
	ANDI #8,R0
	BEQ T75
	;[329] 	playerHit=creature:soundFlag=8:GOSUB loadSound
	SRCFILE "mermaid008.bas",329
	MVI V31,R0
	MVO R0,V57
	MVII #8,R0
	MVO R0,V29
	CALL Q43
	;[330] 	'if shark hits player, move mermaid back to ocean starting position
	SRCFILE "mermaid008.bas",330
	;[331] 	'if any other sea creature hits player, move back to starting position in current location (ocean or castle)
	SRCFILE "mermaid008.bas",331
	;[332] 	IF creature=1 THEN mermaidLocation = 0 : GOSUB creatureCollisionOcean: GOTO avoid_creature_collision
	SRCFILE "mermaid008.bas",332
	MVI V31,R0
	CMPI #1,R0
	BNE T76
	CLRR R0
	MVO R0,V18
	CALL Q46
	B Q45
T76:
	;[333] 	IF mermaidLocation = 0 THEN GOSUB creatureCollisionOcean ELSE GOSUB creatureCollisionCastle
	SRCFILE "mermaid008.bas",333
	MVI V18,R0
	TSTR R0
	BNE T77
	CALL Q46
	B T78
T77:
	CALL Q47
T78:
	;[334] END IF
	SRCFILE "mermaid008.bas",334
T75:
	;[335] 
	SRCFILE "mermaid008.bas",335
	;[336] 'check for collisions with treasure, key, crown
	SRCFILE "mermaid008.bas",336
	;[337] avoid_creature_collision:
	SRCFILE "mermaid008.bas",337
	; AVOID_CREATURE_COLLISION
Q45:	;[338] 
	SRCFILE "mermaid008.bas",338
	;[339] ON crown_visible GOTO skip_crown, detect_crown_collision
	SRCFILE "mermaid008.bas",339
	MVI V25,R0
	CMPI #2,R0
	BC T80
	ADDI #T79,R0
	MOVR R0,R1
	MVI@ R1,PC
T79:
	DECLE Q49
	DECLE Q50
T80:
	;[340] 
	SRCFILE "mermaid008.bas",340
	;[341] detect_crown_collision:
	SRCFILE "mermaid008.bas",341
	; DETECT_CROWN_COLLISION
Q50:	;[342] 'if spriteY(0) >=78 AND spriteY(0) <=86 AND spriteX(0) >= (crownPosition*8)-6 AND spriteX(0) <= (crownPosition*8)+14 AND inventory_crown = 0 THEN inventory_crown = 1: soundFlag=1: #score=#score+250 : GOSUB loadSound : GOSUB check1up
	SRCFILE "mermaid008.bas",342
	;[343] if spriteY(0) > 78 AND spriteY(0) < 86 AND spriteX(0) > (crownPosition*8)-6 AND spriteX(0) < (crownPosition*8)+14 AND inventory_crown = 0 THEN inventory_crown = 1: soundFlag=1: #score=#score+250 : GOSUB loadSound : GOSUB check1up
	SRCFILE "mermaid008.bas",343
	MVI Q9,R0
	CMPI #78,R0
	MVII #-1,R0
	BGT $+3
	INCR R0
	MVI Q9,R1
	CMPI #86,R1
	MVII #-1,R1
	BLT $+3
	INCR R1
	ANDR R1,R0
	MVI Q8,R1
	MVI V48,R2
	SLL R2,2
	ADDR R2,R2
	SUBI #6,R2
	CMPR R2,R1
	MVII #-1,R1
	BGT $+3
	INCR R1
	ANDR R1,R0
	MVI Q8,R1
	MVI V48,R2
	SLL R2,2
	ADDR R2,R2
	ADDI #14,R2
	CMPR R2,R1
	MVII #-1,R1
	BLT $+3
	INCR R1
	ANDR R1,R0
	MVI V21,R1
	TSTR R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	ANDR R1,R0
	BEQ T81
	MVII #1,R0
	MVO R0,V21
	MVO R0,V29
	MVI V1,R0
	ADDI #250,R0
	MVO R0,V1
	CALL Q43
	CALL Q52
T81:
	;[344] 
	SRCFILE "mermaid008.bas",344
	;[345] skip_crown:
	SRCFILE "mermaid008.bas",345
	; SKIP_CROWN
Q49:	;[346] 
	SRCFILE "mermaid008.bas",346
	;[347] ON key_visible GOTO skip_key, detect_key_collision
	SRCFILE "mermaid008.bas",347
	MVI V24,R0
	CMPI #2,R0
	BC T83
	ADDI #T82,R0
	MOVR R0,R1
	MVI@ R1,PC
T82:
	DECLE Q54
	DECLE Q55
T83:
	;[348] detect_key_collision:
	SRCFILE "mermaid008.bas",348
	; DETECT_KEY_COLLISION
Q55:	;[349] 'if spriteY(0) >=78 AND spriteY(0) <=86 AND spriteX(0) >= (keyPosition*8)-6 AND spriteX(0) <= (keyPosition*8)+14 AND inventory_key = 0 THEN inventory_key = 1: soundFlag=2: #score=#score+100 : GOSUB loadSound : GOSUB check1up
	SRCFILE "mermaid008.bas",349
	;[350] if spriteY(0) > 78 AND spriteY(0) < 86 AND spriteX(0) > (keyPosition*8)-6 AND spriteX(0) < (keyPosition*8)+14 AND inventory_key = 0 THEN inventory_key = 1: soundFlag=2: #score=#score+100 : GOSUB loadSound : GOSUB check1up
	SRCFILE "mermaid008.bas",350
	MVI Q9,R0
	CMPI #78,R0
	MVII #-1,R0
	BGT $+3
	INCR R0
	MVI Q9,R1
	CMPI #86,R1
	MVII #-1,R1
	BLT $+3
	INCR R1
	ANDR R1,R0
	MVI Q8,R1
	MVI V50,R2
	SLL R2,2
	ADDR R2,R2
	SUBI #6,R2
	CMPR R2,R1
	MVII #-1,R1
	BGT $+3
	INCR R1
	ANDR R1,R0
	MVI Q8,R1
	MVI V50,R2
	SLL R2,2
	ADDR R2,R2
	ADDI #14,R2
	CMPR R2,R1
	MVII #-1,R1
	BLT $+3
	INCR R1
	ANDR R1,R0
	MVI V20,R1
	TSTR R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	ANDR R1,R0
	BEQ T84
	MVII #1,R0
	MVO R0,V20
	MVII #2,R0
	MVO R0,V29
	MVI V1,R0
	ADDI #100,R0
	MVO R0,V1
	CALL Q43
	CALL Q52
T84:
	;[351] 
	SRCFILE "mermaid008.bas",351
	;[352] skip_key:
	SRCFILE "mermaid008.bas",352
	; SKIP_KEY
Q54:	;[353] 
	SRCFILE "mermaid008.bas",353
	;[354] ON gold_visible GOTO skip_gold, detect_gold_collision
	SRCFILE "mermaid008.bas",354
	MVI V44,R0
	CMPI #2,R0
	BC T86
	ADDI #T85,R0
	MOVR R0,R1
	MVI@ R1,PC
T85:
	DECLE Q58
	DECLE Q59
T86:
	;[355] detect_gold_collision:
	SRCFILE "mermaid008.bas",355
	; DETECT_GOLD_COLLISION
Q59:	;[356] 'if spriteY(0) >=78 AND spriteY(0) <=86 AND spriteX(0) >= (gold_position*8)-6 AND spriteX(0) <= (gold_position*8)+14 AND inventory_gold = 0 THEN inventory_gold = 1: soundFlag=3: #score=#score+50 : GOSUB loadSound : GOSUB check1up
	SRCFILE "mermaid008.bas",356
	;[357] if spriteY(0) > 78 AND spriteY(0) < 86 AND spriteX(0) > (gold_position*8)-6 AND spriteX(0) < (gold_position*8)+14 AND inventory_gold = 0 THEN inventory_gold = 1: soundFlag=3: #score=#score+50 : GOSUB loadSound : GOSUB check1up
	SRCFILE "mermaid008.bas",357
	MVI Q9,R0
	CMPI #78,R0
	MVII #-1,R0
	BGT $+3
	INCR R0
	MVI Q9,R1
	CMPI #86,R1
	MVII #-1,R1
	BLT $+3
	INCR R1
	ANDR R1,R0
	MVI Q8,R1
	MVI V26,R2
	SLL R2,2
	ADDR R2,R2
	SUBI #6,R2
	CMPR R2,R1
	MVII #-1,R1
	BGT $+3
	INCR R1
	ANDR R1,R0
	MVI Q8,R1
	MVI V26,R2
	SLL R2,2
	ADDR R2,R2
	ADDI #14,R2
	CMPR R2,R1
	MVII #-1,R1
	BLT $+3
	INCR R1
	ANDR R1,R0
	MVI V22,R1
	TSTR R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	ANDR R1,R0
	BEQ T87
	MVII #1,R0
	MVO R0,V22
	MVII #3,R0
	MVO R0,V29
	MVI V1,R0
	ADDI #50,R0
	MVO R0,V1
	CALL Q43
	CALL Q52
T87:
	;[358] 
	SRCFILE "mermaid008.bas",358
	;[359] skip_gold:
	SRCFILE "mermaid008.bas",359
	; SKIP_GOLD
Q58:	;[360] 
	SRCFILE "mermaid008.bas",360
	;[361] ON silver_visible GOTO skip_silver, detect_silver_collision
	SRCFILE "mermaid008.bas",361
	MVI V45,R0
	CMPI #2,R0
	BC T89
	ADDI #T88,R0
	MOVR R0,R1
	MVI@ R1,PC
T88:
	DECLE Q62
	DECLE Q63
T89:
	;[362] detect_silver_collision:
	SRCFILE "mermaid008.bas",362
	; DETECT_SILVER_COLLISION
Q63:	;[363] 'if spriteY(0) >=78 AND spriteY(0) <=86 AND spriteX(0) >= (silver_position*8)-6 AND spriteX(0) <= (silver_position*8)+14 AND inventory_silver = 0 THEN inventory_silver = 1: soundFlag=4: #score=#score+10 : GOSUB loadSound : GOSUB check1up
	SRCFILE "mermaid008.bas",363
	;[364] if spriteY(0) > 78 AND spriteY(0) < 86 AND spriteX(0) > (silver_position*8)-6 AND spriteX(0) < (silver_position*8)+14 AND inventory_silver = 0 THEN inventory_silver = 1: soundFlag=4: #score=#score+10 : GOSUB loadSound : GOSUB check1up
	SRCFILE "mermaid008.bas",364
	MVI Q9,R0
	CMPI #78,R0
	MVII #-1,R0
	BGT $+3
	INCR R0
	MVI Q9,R1
	CMPI #86,R1
	MVII #-1,R1
	BLT $+3
	INCR R1
	ANDR R1,R0
	MVI Q8,R1
	MVI V27,R2
	SLL R2,2
	ADDR R2,R2
	SUBI #6,R2
	CMPR R2,R1
	MVII #-1,R1
	BGT $+3
	INCR R1
	ANDR R1,R0
	MVI Q8,R1
	MVI V27,R2
	SLL R2,2
	ADDR R2,R2
	ADDI #14,R2
	CMPR R2,R1
	MVII #-1,R1
	BLT $+3
	INCR R1
	ANDR R1,R0
	MVI V23,R1
	TSTR R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	ANDR R1,R0
	BEQ T90
	MVII #1,R0
	MVO R0,V23
	MVII #4,R0
	MVO R0,V29
	MVI V1,R0
	ADDI #10,R0
	MVO R0,V1
	CALL Q43
	CALL Q52
T90:
	;[365] 
	SRCFILE "mermaid008.bas",365
	;[366] skip_silver:
	SRCFILE "mermaid008.bas",366
	; SKIP_SILVER
Q62:	;[367] 
	SRCFILE "mermaid008.bas",367
	;[368] 'check for castle collision if mermaid has the key and crown
	SRCFILE "mermaid008.bas",368
	;[369] IF mermaidLocation = 0 AND mermaid_oceanLocation = castleLocation AND soundFlag<> 6 THEN
	SRCFILE "mermaid008.bas",369
	MVI V18,R0
	TSTR R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V46,R1
	CMP V51,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	ANDR R1,R0
	MVI V29,R1
	CMPI #6,R1
	MVII #-1,R1
	BNE $+3
	INCR R1
	ANDR R1,R0
	BEQ T91
	;[370] 	IF spriteY(0) > 56 AND spriteY(0) < 90 AND spriteX(0) > 72 AND spriteX(0) < 103 AND inventory_key = 1 AND inventory_crown = 1 THEN soundFlag=6: GOSUB loadSound : GOSUB check1up
	SRCFILE "mermaid008.bas",370
	MVI Q9,R0
	CMPI #56,R0
	MVII #-1,R0
	BGT $+3
	INCR R0
	MVI Q9,R1
	CMPI #90,R1
	MVII #-1,R1
	BLT $+3
	INCR R1
	ANDR R1,R0
	MVI Q8,R1
	CMPI #72,R1
	MVII #-1,R1
	BGT $+3
	INCR R1
	ANDR R1,R0
	MVI Q8,R1
	CMPI #103,R1
	MVII #-1,R1
	BLT $+3
	INCR R1
	ANDR R1,R0
	MVI V20,R1
	CMPI #1,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	ANDR R1,R0
	MVI V21,R1
	CMPI #1,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	ANDR R1,R0
	BEQ T92
	MVII #6,R0
	MVO R0,V29
	CALL Q43
	CALL Q52
T92:
	;[371] END IF
	SRCFILE "mermaid008.bas",371
T91:
	;[372] 
	SRCFILE "mermaid008.bas",372
	;[373] ON queen_visible GOTO skip_queen, detect_queen_collision
	SRCFILE "mermaid008.bas",373
	MVI V36,R0
	CMPI #2,R0
	BC T94
	ADDI #T93,R0
	MOVR R0,R1
	MVI@ R1,PC
T93:
	DECLE Q66
	DECLE Q67
T94:
	;[374] detect_queen_collision:
	SRCFILE "mermaid008.bas",374
	; DETECT_QUEEN_COLLISION
Q67:	;[375] IF spriteY(0) > 30 AND spriteY(0) < 66 AND spriteX(0) > 72 AND spriteX(0) < 88 THEN GOTO level_complete
	SRCFILE "mermaid008.bas",375
	MVI Q9,R0
	CMPI #30,R0
	MVII #-1,R0
	BGT $+3
	INCR R0
	MVI Q9,R1
	CMPI #66,R1
	MVII #-1,R1
	BLT $+3
	INCR R1
	ANDR R1,R0
	MVI Q8,R1
	CMPI #72,R1
	MVII #-1,R1
	BGT $+3
	INCR R1
	ANDR R1,R0
	MVI Q8,R1
	CMPI #88,R1
	MVII #-1,R1
	BLT $+3
	INCR R1
	ANDR R1,R0
	BNE Q69
	;[376] 
	SRCFILE "mermaid008.bas",376
	;[377] skip_queen:
	SRCFILE "mermaid008.bas",377
	; SKIP_QUEEN
Q66:	;[378] 
	SRCFILE "mermaid008.bas",378
	;[379] IF sound_duration > 0 AND sound_duration < 3 then sound_duration=sound_duration+1:SOUND 2,note(1),15-(sound_duration*2)/16:SOUND 4,note(1),$18:spritex(0)=spritex(1)
	SRCFILE "mermaid008.bas",379
	MVI V30,R0
	CMPI #0,R0
	MVII #-1,R0
	BGT $+3
	INCR R0
	MVI V30,R1
	CMPI #3,R1
	MVII #-1,R1
	BLT $+3
	INCR R1
	ANDR R1,R0
	BEQ T96
	MVI V30,R0
	INCR R0
	MVO R0,V30
	MVI Q12+1,R0
	MVO R0,498
	SWAP R0
	MVO R0,502
	MVII #15,R0
	MVI V30,R1
	SLL R1,1
	SLR R1,2
	SLR R1,2
	SUBR R1,R0
	NOP
	MVO R0,509
	MVI Q12+1,R0
	MVO R0,505
	MVII #24,R0
	MVO R0,504
	MVI Q8+1,R0
	MVO R0,Q8
T96:
	;[380] IF sound_duration > 2 AND sound_duration < 6 then sound_duration=sound_duration+1:SOUND 2,note(2),15-(sound_duration*2)/16:SOUND 4,note(2),$18:spritex(0)=spritex(1)
	SRCFILE "mermaid008.bas",380
	MVI V30,R0
	CMPI #2,R0
	MVII #-1,R0
	BGT $+3
	INCR R0
	MVI V30,R1
	CMPI #6,R1
	MVII #-1,R1
	BLT $+3
	INCR R1
	ANDR R1,R0
	BEQ T97
	MVI V30,R0
	INCR R0
	MVO R0,V30
	MVI Q12+2,R0
	MVO R0,498
	SWAP R0
	MVO R0,502
	MVII #15,R0
	MVI V30,R1
	SLL R1,1
	SLR R1,2
	SLR R1,2
	SUBR R1,R0
	NOP
	MVO R0,509
	MVI Q12+2,R0
	MVO R0,505
	MVII #24,R0
	MVO R0,504
	MVI Q8+1,R0
	MVO R0,Q8
T97:
	;[381] IF sound_duration > 5 AND sound_duration < 9 then sound_duration=sound_duration+1:SOUND 2,note(3),15-(sound_duration*2)/16:SOUND 4,note(3),$18:spritex(0)=spritex(1)
	SRCFILE "mermaid008.bas",381
	MVI V30,R0
	CMPI #5,R0
	MVII #-1,R0
	BGT $+3
	INCR R0
	MVI V30,R1
	CMPI #9,R1
	MVII #-1,R1
	BLT $+3
	INCR R1
	ANDR R1,R0
	BEQ T98
	MVI V30,R0
	INCR R0
	MVO R0,V30
	MVI Q12+3,R0
	MVO R0,498
	SWAP R0
	MVO R0,502
	MVII #15,R0
	MVI V30,R1
	SLL R1,1
	SLR R1,2
	SLR R1,2
	SUBR R1,R0
	NOP
	MVO R0,509
	MVI Q12+3,R0
	MVO R0,505
	MVII #24,R0
	MVO R0,504
	MVI Q8+1,R0
	MVO R0,Q8
T98:
	;[382] IF sound_duration > 8 THEN GOSUB noSound
	SRCFILE "mermaid008.bas",382
	MVI V30,R0
	CMPI #8,R0
	BLE T99
	CALL Q71
T99:
	;[383] 
	SRCFILE "mermaid008.bas",383
	;[384] #countdownTimer = #countdownTimer - 1 
	SRCFILE "mermaid008.bas",384
	MVI V6,R0
	DECR R0
	MVO R0,V6
	;[385] if #countdownTimer = 0 THEN gosub lose_life: GOTO main
	SRCFILE "mermaid008.bas",385
	TSTR R0
	BNE T100
	CALL Q72
	B Q26
T100:
	;[386] 
	SRCFILE "mermaid008.bas",386
	;[387] 'check for trace enable/disable   (press 'CLEAR' on the keypad)
	SRCFILE "mermaid008.bas",387
	;[388] 'IF cont.key <> 12 GOTO skip_check_trace
	SRCFILE "mermaid008.bas",388
	;[389] 'WAIT
	SRCFILE "mermaid008.bas",389
	;[390] IF cont.key = 10 THEN trace=trace+1
	SRCFILE "mermaid008.bas",390
	MVI _cnt1_key,R0
	CMPI #12,R0
	BNE $+4
	MVI _cnt2_key,R0
	CMPI #10,R0
	BNE T101
	MVI V16,R0
	INCR R0
	MVO R0,V16
T101:
	;[391] 'remove trace information from screen when trace mode is disabled
	SRCFILE "mermaid008.bas",391
	;[392] IF trace>1 THEN trace=0: IF mermaidLocation = 0 THEN SCREEN screen_level ELSE SCREEN castle_level: GOSUB display_castle_walls 
	SRCFILE "mermaid008.bas",392
	MVI V16,R0
	CMPI #1,R0
	BLE T102
	CLRR R0
	MVO R0,V16
	MVI V18,R0
	TSTR R0
	BNE T103
	MVII #Q30,R3
	MVII #512,R2
	MVII #20,R1
	MVII #12,R0
	CALL CPYBLK
	B T104
T103:
	MVII #Q73,R3
	MVII #512,R2
	MVII #20,R1
	MVII #12,R0
	CALL CPYBLK
	CALL Q74
T104:
T102:
	;[393] 
	SRCFILE "mermaid008.bas",393
	;[394] ''crown&key - cheat_mode
	SRCFILE "mermaid008.bas",394
	;[395] ''IF cont.key = 8 THEN inventory_crown = 1: inventory_key = 1
	SRCFILE "mermaid008.bas",395
	;[396] 
	SRCFILE "mermaid008.bas",396
	;[397] 'skip_check_trace:
	SRCFILE "mermaid008.bas",397
	;[398] 
	SRCFILE "mermaid008.bas",398
	;[399] GOSUB update_score
	SRCFILE "mermaid008.bas",399
	CALL Q31
	;[400] 	GOTO game_loop
	SRCFILE "mermaid008.bas",400
	B Q33
	;[401] 
	SRCFILE "mermaid008.bas",401
	;[402] 	
	SRCFILE "mermaid008.bas",402
	;[403] crownSound:
	SRCFILE "mermaid008.bas",403
	; CROWNSOUND
Q75:	;[404] DATA $03F9,$00FE,$0040
	SRCFILE "mermaid008.bas",404
	DECLE 1017
	DECLE 254
	DECLE 64
	;[405] keySound:
	SRCFILE "mermaid008.bas",405
	; KEYSOUND
Q76:	;[406] DATA $0039,$0040,$0047
	SRCFILE "mermaid008.bas",406
	DECLE 57
	DECLE 64
	DECLE 71
	;[407] goldSound:
	SRCFILE "mermaid008.bas",407
	; GOLDSOUND
Q77:	;[408] DATA $006B,$0065,$005A
	SRCFILE "mermaid008.bas",408
	DECLE 107
	DECLE 101
	DECLE 90
	;[409] silverSound:
	SRCFILE "mermaid008.bas",409
	; SILVERSOUND
Q78:	;[410] DATA $04B9,$0435,$03C0
	SRCFILE "mermaid008.bas",410
	DECLE 1209
	DECLE 1077
	DECLE 960
	;[411] bubbleSound:
	SRCFILE "mermaid008.bas",411
	; BUBBLESOUND
Q79:	;[412] DATA $0357,$02A7,$023B
	SRCFILE "mermaid008.bas",412
	DECLE 855
	DECLE 679
	DECLE 571
	;[413] castleSound:
	SRCFILE "mermaid008.bas",413
	; CASTLESOUND
Q80:	;[414] DATA $01FC,$01C5,$01AC
	SRCFILE "mermaid008.bas",414
	DECLE 508
	DECLE 453
	DECLE 428
	;[415] boostSound:
	SRCFILE "mermaid008.bas",415
	; BOOSTSOUND
Q81:	;[416] DATA $00AA,$00E2,$0030
	SRCFILE "mermaid008.bas",416
	DECLE 170
	DECLE 226
	DECLE 48
	;[417] creatureCollisionSound:
	SRCFILE "mermaid008.bas",417
	; CREATURECOLLISIONSOUND
Q82:	;[418] DATA $0780,$0973,$0C9D
	SRCFILE "mermaid008.bas",418
	DECLE 1920
	DECLE 2419
	DECLE 3229
	;[419] lives1UPSound:
	SRCFILE "mermaid008.bas",419
	; LIVES1UPSOUND
Q83:	;[420] DATA $0026,$0022,$001E
	SRCFILE "mermaid008.bas",420
	DECLE 38
	DECLE 34
	DECLE 30
	;[421] 
	SRCFILE "mermaid008.bas",421
	;[422] thump_Sound:   Procedure
	SRCFILE "mermaid008.bas",422
	; THUMP_SOUND
Q84:	PROC
	BEGIN
	;[423] SOUND 2,$08EB,8:SOUND 4,$08EB,$18
	SRCFILE "mermaid008.bas",423
	MVII #2283,R0
	MVO R0,498
	SWAP R0
	MVO R0,502
	MVII #8,R0
	MVO R0,509
	MVII #2283,R0
	MVO R0,505
	MVII #24,R0
	MVO R0,504
	;[424] SOUND 2,1,0:SOUND 4,1,$38:WAIT
	SRCFILE "mermaid008.bas",424
	MVII #1,R0
	MVO R0,498
	SWAP R0
	MVO R0,502
	CLRR R0
	MVO R0,509
	MVII #1,R0
	MVO R0,505
	MVII #56,R0
	MVO R0,504
	CALL _wait
	;[425] END
	SRCFILE "mermaid008.bas",425
	RETURN
	ENDP
	;[426] 
	SRCFILE "mermaid008.bas",426
	;[427] 
	SRCFILE "mermaid008.bas",427
	;[428] loadSound:   Procedure
	SRCFILE "mermaid008.bas",428
	; LOADSOUND
Q43:	PROC
	BEGIN
	;[429] REM soundFlag (1=crown, 2=key, 3=gold, 4=silver, 5=bubble, 6=castle, 7=boost, 9=1UP)
	SRCFILE "mermaid008.bas",429
	;[430] IF soundFlag = 1 THEN RESTORE crownSound: READ note(1),note(2),note(3):sound_duration=1
	SRCFILE "mermaid008.bas",430
	MVI V29,R0
	CMPI #1,R0
	BNE T105
	MVII #Q75,R4
	MVO R4,_read
	MVI _read,R4
	MVI@ R4,R0
	MVO R4,_read
	MVO R0,Q12+1
	MVI _read,R4
	MVI@ R4,R0
	MVO R4,_read
	MVO R0,Q12+2
	MVI _read,R4
	MVI@ R4,R0
	MVO R4,_read
	MVO R0,Q12+3
	MVII #1,R0
	MVO R0,V30
T105:
	;[431] IF soundFlag = 2 THEN RESTORE keySound: READ note(1),note(2),note(3):sound_duration=1
	SRCFILE "mermaid008.bas",431
	MVI V29,R0
	CMPI #2,R0
	BNE T106
	MVII #Q76,R4
	MVO R4,_read
	MVI _read,R4
	MVI@ R4,R0
	MVO R4,_read
	MVO R0,Q12+1
	MVI _read,R4
	MVI@ R4,R0
	MVO R4,_read
	MVO R0,Q12+2
	MVI _read,R4
	MVI@ R4,R0
	MVO R4,_read
	MVO R0,Q12+3
	MVII #1,R0
	MVO R0,V30
T106:
	;[432] IF soundFlag = 3 THEN RESTORE goldSound: READ note(1),note(2),note(3):sound_duration=1
	SRCFILE "mermaid008.bas",432
	MVI V29,R0
	CMPI #3,R0
	BNE T107
	MVII #Q77,R4
	MVO R4,_read
	MVI _read,R4
	MVI@ R4,R0
	MVO R4,_read
	MVO R0,Q12+1
	MVI _read,R4
	MVI@ R4,R0
	MVO R4,_read
	MVO R0,Q12+2
	MVI _read,R4
	MVI@ R4,R0
	MVO R4,_read
	MVO R0,Q12+3
	MVII #1,R0
	MVO R0,V30
T107:
	;[433] IF soundFlag = 4 THEN RESTORE silverSound: READ note(1),note(2),note(3):sound_duration=1
	SRCFILE "mermaid008.bas",433
	MVI V29,R0
	CMPI #4,R0
	BNE T108
	MVII #Q78,R4
	MVO R4,_read
	MVI _read,R4
	MVI@ R4,R0
	MVO R4,_read
	MVO R0,Q12+1
	MVI _read,R4
	MVI@ R4,R0
	MVO R4,_read
	MVO R0,Q12+2
	MVI _read,R4
	MVI@ R4,R0
	MVO R4,_read
	MVO R0,Q12+3
	MVII #1,R0
	MVO R0,V30
T108:
	;[434] IF soundFlag = 5 THEN RESTORE bubbleSound: READ note(1),note(2),note(3):sound_duration=1
	SRCFILE "mermaid008.bas",434
	MVI V29,R0
	CMPI #5,R0
	BNE T109
	MVII #Q79,R4
	MVO R4,_read
	MVI _read,R4
	MVI@ R4,R0
	MVO R4,_read
	MVO R0,Q12+1
	MVI _read,R4
	MVI@ R4,R0
	MVO R4,_read
	MVO R0,Q12+2
	MVI _read,R4
	MVI@ R4,R0
	MVO R4,_read
	MVO R0,Q12+3
	MVII #1,R0
	MVO R0,V30
T109:
	;[435] IF soundFlag = 6 THEN RESTORE castleSound: READ note(1),note(2),note(3):sound_duration=1
	SRCFILE "mermaid008.bas",435
	MVI V29,R0
	CMPI #6,R0
	BNE T110
	MVII #Q80,R4
	MVO R4,_read
	MVI _read,R4
	MVI@ R4,R0
	MVO R4,_read
	MVO R0,Q12+1
	MVI _read,R4
	MVI@ R4,R0
	MVO R4,_read
	MVO R0,Q12+2
	MVI _read,R4
	MVI@ R4,R0
	MVO R4,_read
	MVO R0,Q12+3
	MVII #1,R0
	MVO R0,V30
T110:
	;[436] IF soundFlag = 7 THEN RESTORE boostSound: READ note(1),note(2),note(3):sound_duration=1
	SRCFILE "mermaid008.bas",436
	MVI V29,R0
	CMPI #7,R0
	BNE T111
	MVII #Q81,R4
	MVO R4,_read
	MVI _read,R4
	MVI@ R4,R0
	MVO R4,_read
	MVO R0,Q12+1
	MVI _read,R4
	MVI@ R4,R0
	MVO R4,_read
	MVO R0,Q12+2
	MVI _read,R4
	MVI@ R4,R0
	MVO R4,_read
	MVO R0,Q12+3
	MVII #1,R0
	MVO R0,V30
T111:
	;[437] IF soundFlag = 8 THEN RESTORE creatureCollisionSound: READ note(1),note(2),note(3):sound_duration=1
	SRCFILE "mermaid008.bas",437
	MVI V29,R0
	CMPI #8,R0
	BNE T112
	MVII #Q82,R4
	MVO R4,_read
	MVI _read,R4
	MVI@ R4,R0
	MVO R4,_read
	MVO R0,Q12+1
	MVI _read,R4
	MVI@ R4,R0
	MVO R4,_read
	MVO R0,Q12+2
	MVI _read,R4
	MVI@ R4,R0
	MVO R4,_read
	MVO R0,Q12+3
	MVII #1,R0
	MVO R0,V30
T112:
	;[438] IF soundFlag = 9 THEN RESTORE lives1UPSound: READ note(1),note(2),note(3):sound_duration=1
	SRCFILE "mermaid008.bas",438
	MVI V29,R0
	CMPI #9,R0
	BNE T113
	MVII #Q83,R4
	MVO R4,_read
	MVI _read,R4
	MVI@ R4,R0
	MVO R4,_read
	MVO R0,Q12+1
	MVI _read,R4
	MVI@ R4,R0
	MVO R4,_read
	MVO R0,Q12+2
	MVI _read,R4
	MVI@ R4,R0
	MVO R4,_read
	MVO R0,Q12+3
	MVII #1,R0
	MVO R0,V30
T113:
	;[439] spritex(0)=spritex(1)
	SRCFILE "mermaid008.bas",439
	MVI Q8+1,R0
	MVO R0,Q8
	;[440] END
	SRCFILE "mermaid008.bas",440
	RETURN
	ENDP
	;[441] 
	SRCFILE "mermaid008.bas",441
	;[442] noSound:   Procedure
	SRCFILE "mermaid008.bas",442
	; NOSOUND
Q71:	PROC
	BEGIN
	;[443] SOUND 2,1,0:SOUND 4,1,$38:WAIT
	SRCFILE "mermaid008.bas",443
	MVII #1,R0
	MVO R0,498
	SWAP R0
	MVO R0,502
	CLRR R0
	MVO R0,509
	MVII #1,R0
	MVO R0,505
	MVII #56,R0
	MVO R0,504
	CALL _wait
	;[444] IF soundFlag = 1 THEN crown_visible=0
	SRCFILE "mermaid008.bas",444
	MVI V29,R0
	CMPI #1,R0
	BNE T114
	CLRR R0
	MVO R0,V25
T114:
	;[445] IF soundFlag = 2 THEN key_visible=0
	SRCFILE "mermaid008.bas",445
	MVI V29,R0
	CMPI #2,R0
	BNE T115
	CLRR R0
	MVO R0,V24
T115:
	;[446] IF soundFlag = 3 THEN gold_visible=0
	SRCFILE "mermaid008.bas",446
	MVI V29,R0
	CMPI #3,R0
	BNE T116
	CLRR R0
	MVO R0,V44
T116:
	;[447] IF soundFlag = 4 THEN silver_visible=0
	SRCFILE "mermaid008.bas",447
	MVI V29,R0
	CMPI #4,R0
	BNE T117
	CLRR R0
	MVO R0,V45
T117:
	;[448] IF soundFlag = 6 THEN mermaidLocation=1:#score=#score+500:GOSUB check1up:GOSUB waitabit:gosub castle_walls
	SRCFILE "mermaid008.bas",448
	MVI V29,R0
	CMPI #6,R0
	BNE T118
	MVII #1,R0
	MVO R0,V18
	MVI V1,R0
	ADDI #500,R0
	MVO R0,V1
	CALL Q52
	CALL Q20
	CALL Q87
T118:
	;[449] soundFlag = 0:sound_duration=0:spritex(0)=spritex(1)
	SRCFILE "mermaid008.bas",449
	CLRR R0
	MVO R0,V29
	MVO R0,V30
	MVI Q8+1,R0
	MVO R0,Q8
	;[450] END
	SRCFILE "mermaid008.bas",450
	RETURN
	ENDP
	;[451] 
	SRCFILE "mermaid008.bas",451
	;[452] 	' 13 bitmaps
	SRCFILE "mermaid008.bas",452
	;[453] screen_bitmaps_0:
	SRCFILE "mermaid008.bas",453
	; SCREEN_BITMAPS_0
Q5:	;[454] 	DATA $FFFF,$FFFF,$13BF,$0000
	SRCFILE "mermaid008.bas",454
	DECLE 65535
	DECLE 65535
	DECLE 5055
	DECLE 0
	;[455] 	DATA $FFFF,$FFFF,$8CFF,$0000
	SRCFILE "mermaid008.bas",455
	DECLE 65535
	DECLE 65535
	DECLE 36095
	DECLE 0
	;[456] 	DATA $FFFF,$FFFF,$038F,$0001
	SRCFILE "mermaid008.bas",456
	DECLE 65535
	DECLE 65535
	DECLE 911
	DECLE 1
	;[457] 	DATA $EBFF,$EFF7,$FBF7,$EBE7
	SRCFILE "mermaid008.bas",457
	DECLE 60415
	DECLE 61431
	DECLE 64503
	DECLE 60391
	;[458] 	DATA $EBFF,$FBD7,$E5D5,$F5EB
	SRCFILE "mermaid008.bas",458
	DECLE 60415
	DECLE 64471
	DECLE 58837
	DECLE 62955
	;[459] 	DATA $6666,$0000,$0000,$0000
	SRCFILE "mermaid008.bas",459
	DECLE 26214
	DECLE 0
	DECLE 0
	DECLE 0
	;[460] 	DATA $0000,$8100,$0081,$0000
	SRCFILE "mermaid008.bas",460
	DECLE 0
	DECLE 33024
	DECLE 129
	DECLE 0
	;[461] 	DATA $FFFF,$FFFF,$8181,$FF81
	SRCFILE "mermaid008.bas",461
	DECLE 65535
	DECLE 65535
	DECLE 33153
	DECLE 65409
	;[462] 	DATA $FFFF,$FFFF,$C3E7,$FFE7
	SRCFILE "mermaid008.bas",462
	DECLE 65535
	DECLE 65535
	DECLE 50151
	DECLE 65511
	;[463] 	DATA $FFFF,$A5FF,$8181,$FFC3
	SRCFILE "mermaid008.bas",463
	DECLE 65535
	DECLE 42495
	DECLE 33153
	DECLE 65475
	;[464] 	DATA $FFFF,$FFFF,$41BF,$FFB5
	SRCFILE "mermaid008.bas",464
	DECLE 65535
	DECLE 65535
	DECLE 16831
	DECLE 65461
	;[465] 	DATA $1818,$C324,$24C3,$1818
	SRCFILE "mermaid008.bas",465
	DECLE 6168
	DECLE 49956
	DECLE 9411
	DECLE 6168
	;[466] 	DATA $81C3,$1800,$0018,$C381
	SRCFILE "mermaid008.bas",466
	DECLE 33219
	DECLE 6144
	DECLE 24
	DECLE 50049
	;[467] 	DATA $7E42,$7E7E,$7E7E,$7E7E
	SRCFILE "mermaid008.bas",467
	DECLE 32322
	DECLE 32382
	DECLE 32382
	DECLE 32382
	;[468] 	DATA $8142,$8181,$81FF,$8181
	SRCFILE "mermaid008.bas",468
	DECLE 33090
	DECLE 33153
	DECLE 33279
	DECLE 33153
	;[469] 	
	SRCFILE "mermaid008.bas",469
	;[470] 	REM 20x12 cards
	SRCFILE "mermaid008.bas",470
	;[471] screen_title:
	SRCFILE "mermaid008.bas",471
	; SCREEN_TITLE
Q6:	;[472] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "mermaid008.bas",472
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[473] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "mermaid008.bas",473
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[474] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "mermaid008.bas",474
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[475] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "mermaid008.bas",475
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[476] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "mermaid008.bas",476
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[477] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "mermaid008.bas",477
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[478] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "mermaid008.bas",478
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[479] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "mermaid008.bas",479
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[480] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "mermaid008.bas",480
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[481] 	DATA $0200,$0200,$0200,$0200,$2A21,$0200,$0200,$0200,$2A21,$0200,$0200,$0200,$0200,$0200,$2A19,$0200,$0200,$0200,$0200,$0200
	SRCFILE "mermaid008.bas",481
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 10785
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 10785
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 10777
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[482] 	DATA $2C01,$2C09,$2C11,$0200,$2A19,$0200,$2C01,$2C09,$2C11,$0200,$2A19,$0200,$2C01,$2C09,$2C11,$0200,$2A21,$2C01,$2C09,$2C11
	SRCFILE "mermaid008.bas",482
	DECLE 11265
	DECLE 11273
	DECLE 11281
	DECLE 512
	DECLE 10777
	DECLE 512
	DECLE 11265
	DECLE 11273
	DECLE 11281
	DECLE 512
	DECLE 10777
	DECLE 512
	DECLE 11265
	DECLE 11273
	DECLE 11281
	DECLE 512
	DECLE 10785
	DECLE 11265
	DECLE 11273
	DECLE 11281
	;[483] 	DATA $2400,$2400,$2400,$2400,$2400,$2400,$2400,$2400,$2400,$2400,$2400,$2400,$2400,$2400,$2400,$2400,$2400,$2400,$2400,$2400
	SRCFILE "mermaid008.bas",483
	DECLE 9216
	DECLE 9216
	DECLE 9216
	DECLE 9216
	DECLE 9216
	DECLE 9216
	DECLE 9216
	DECLE 9216
	DECLE 9216
	DECLE 9216
	DECLE 9216
	DECLE 9216
	DECLE 9216
	DECLE 9216
	DECLE 9216
	DECLE 9216
	DECLE 9216
	DECLE 9216
	DECLE 9216
	DECLE 9216
	;[484] 
	SRCFILE "mermaid008.bas",484
	;[485] screen_level:
	SRCFILE "mermaid008.bas",485
	; SCREEN_LEVEL
Q30:	;[486] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "mermaid008.bas",486
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[487] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "mermaid008.bas",487
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[488] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "mermaid008.bas",488
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[489] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "mermaid008.bas",489
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[490] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "mermaid008.bas",490
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[491] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "mermaid008.bas",491
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[492] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "mermaid008.bas",492
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[493] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "mermaid008.bas",493
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[494] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "mermaid008.bas",494
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[495] 	DATA $0200,$0200,$0200,$0200,$2A21,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$2A19,$0200,$0200,$0200,$0200,$0200
	SRCFILE "mermaid008.bas",495
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 10785
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 10777
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[496] 	DATA $2C01,$2C09,$2C11,$0200,$2A19,$0200,$2C01,$2C09,$0200,$2C01,$2C09,$0200,$2C01,$2C09,$2C11,$0200,$2A21,$2C01,$2C09,$2C11
	SRCFILE "mermaid008.bas",496
	DECLE 11265
	DECLE 11273
	DECLE 11281
	DECLE 512
	DECLE 10777
	DECLE 512
	DECLE 11265
	DECLE 11273
	DECLE 512
	DECLE 11265
	DECLE 11273
	DECLE 512
	DECLE 11265
	DECLE 11273
	DECLE 11281
	DECLE 512
	DECLE 10785
	DECLE 11265
	DECLE 11273
	DECLE 11281
	;[497] 	DATA $2400,$2400,$2400,$2400,$2400,$2400,$2400,$2400,$2400,$2400,$2400,$2400,$2400,$2400,$2400,$2400,$2400,$2400,$2400,$2400
	SRCFILE "mermaid008.bas",497
	DECLE 9216
	DECLE 9216
	DECLE 9216
	DECLE 9216
	DECLE 9216
	DECLE 9216
	DECLE 9216
	DECLE 9216
	DECLE 9216
	DECLE 9216
	DECLE 9216
	DECLE 9216
	DECLE 9216
	DECLE 9216
	DECLE 9216
	DECLE 9216
	DECLE 9216
	DECLE 9216
	DECLE 9216
	DECLE 9216
	;[498] 
	SRCFILE "mermaid008.bas",498
	;[499] castle_level:
	SRCFILE "mermaid008.bas",499
	; CASTLE_LEVEL
Q73:	;[500] 	DATA $1858,$1858,$1858,$1858,$1858,$1858,$1858,$1858,$1858,$0200,$0200,$1858,$1858,$1858,$1858,$1858,$1858,$1858,$1858,$1858
	SRCFILE "mermaid008.bas",500
	DECLE 6232
	DECLE 6232
	DECLE 6232
	DECLE 6232
	DECLE 6232
	DECLE 6232
	DECLE 6232
	DECLE 6232
	DECLE 6232
	DECLE 512
	DECLE 512
	DECLE 6232
	DECLE 6232
	DECLE 6232
	DECLE 6232
	DECLE 6232
	DECLE 6232
	DECLE 6232
	DECLE 6232
	DECLE 6232
	;[501] 	DATA $1860,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$1860
	SRCFILE "mermaid008.bas",501
	DECLE 6240
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6240
	;[502] 	DATA $1860,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$1860
	SRCFILE "mermaid008.bas",502
	DECLE 6240
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6240
	;[503] 	DATA $1860,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$1860
	SRCFILE "mermaid008.bas",503
	DECLE 6240
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6240
	;[504] 	DATA $1860,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$1860
	SRCFILE "mermaid008.bas",504
	DECLE 6240
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6240
	;[505] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "mermaid008.bas",505
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[506] 	DATA $0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200
	SRCFILE "mermaid008.bas",506
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	;[507] 	DATA $1860,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$1860
	SRCFILE "mermaid008.bas",507
	DECLE 6240
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6240
	;[508] 	DATA $1860,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$1860
	SRCFILE "mermaid008.bas",508
	DECLE 6240
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6240
	;[509] 	DATA $1860,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$1860
	SRCFILE "mermaid008.bas",509
	DECLE 6240
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6240
	;[510] 	DATA $1860,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$0200,$1860
	SRCFILE "mermaid008.bas",510
	DECLE 6240
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 512
	DECLE 6240
	;[511] 	DATA $1858,$1858,$1858,$1858,$1858,$1858,$1858,$1858,$1858,$0200,$0200,$1858,$1858,$1858,$1858,$1858,$1858,$1858,$1858,$1858
	SRCFILE "mermaid008.bas",511
	DECLE 6232
	DECLE 6232
	DECLE 6232
	DECLE 6232
	DECLE 6232
	DECLE 6232
	DECLE 6232
	DECLE 6232
	DECLE 6232
	DECLE 512
	DECLE 512
	DECLE 6232
	DECLE 6232
	DECLE 6232
	DECLE 6232
	DECLE 6232
	DECLE 6232
	DECLE 6232
	DECLE 6232
	DECLE 6232
	;[512] 
	SRCFILE "mermaid008.bas",512
	;[513] REM castle_placement displays the castle in the ocean when the mermaid is on the appropriate screen
	SRCFILE "mermaid008.bas",513
	;[514] 	
	SRCFILE "mermaid008.bas",514
	;[515] castle_placement:   Procedure
	SRCFILE "mermaid008.bas",515
	; CASTLE_PLACEMENT
Q38:	PROC
	BEGIN
	;[516] PRINT AT 108,$1829
	SRCFILE "mermaid008.bas",516
	MVII #620,R0
	MVO R0,_screen
	MVII #6185,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	;[517] PRINT AT 111,$1829
	SRCFILE "mermaid008.bas",517
	MVII #623,R0
	MVO R0,_screen
	MVII #6185,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	;[518] PRINT AT 128,$1831
	SRCFILE "mermaid008.bas",518
	MVII #640,R0
	MVO R0,_screen
	MVII #6193,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	;[519] PRINT AT 129,$1829
	SRCFILE "mermaid008.bas",519
	MVII #641,R0
	MVO R0,_screen
	MVII #6185,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	;[520] PRINT AT 130,$1829
	SRCFILE "mermaid008.bas",520
	MVII #642,R0
	MVO R0,_screen
	MVII #6185,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	;[521] PRINT AT 131,$1831
	SRCFILE "mermaid008.bas",521
	MVII #643,R0
	MVO R0,_screen
	MVII #6193,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	;[522] 
	SRCFILE "mermaid008.bas",522
	;[523] FOR a = 148 TO 208 STEP 20
	SRCFILE "mermaid008.bas",523
	MVII #148,R0
	MVO R0,V58
T119:
	;[524] 	FOR b = 0 TO 3
	SRCFILE "mermaid008.bas",524
	CLRR R0
	MVO R0,V59
T120:
	;[525] 		PRINT AT a+b,$1831
	SRCFILE "mermaid008.bas",525
	MVI V58,R0
	ADD V59,R0
	ADDI #512,R0
	MVO R0,_screen
	MVII #6193,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	;[526] 	NEXT b
	SRCFILE "mermaid008.bas",526
	MVI V59,R0
	INCR R0
	MVO R0,V59
	CMPI #3,R0
	BLE T120
	;[527] NEXT a
	SRCFILE "mermaid008.bas",527
	MVI V58,R0
	ADDI #20,R0
	MVO R0,V58
	CMPI #208,R0
	BLE T119
	;[528] 
	SRCFILE "mermaid008.bas",528
	;[529] END	
	SRCFILE "mermaid008.bas",529
	RETURN
	ENDP
	;[530] 	
	SRCFILE "mermaid008.bas",530
	;[531] tuatara:     VOICE TT1,UW2,PA1,UH,PA1,TT1,AR,PA1,UH,PA2,0
	SRCFILE "mermaid008.bas",531
	; TUATARA
Q17:		DECLE _TT1
	DECLE _UW2
	DECLE 5
	DECLE _UH
	DECLE 5
	DECLE _TT1
	DECLE _AR
	DECLE 5
	DECLE _UH
	DECLE 4
	DECLE 0
	;[532] software:    VOICE SS,UH,FF,TT1,WH,ER2,PA2,0
	SRCFILE "mermaid008.bas",532
	; SOFTWARE
Q18:		DECLE _SS
	DECLE _UH
	DECLE _FF
	DECLE _TT1
	DECLE _WH
	DECLE _ER2
	DECLE 4
	DECLE 0
	;[533] presents:    VOICE PP,RR1,IY,ZZ,EH,NN1,TT1,SS,PA2,0
	SRCFILE "mermaid008.bas",533
	; PRESENTS
Q19:		DECLE _PP
	DECLE _RR1
	DECLE _IY
	DECLE _ZZ
	DECLE _EH
	DECLE _NN1
	DECLE _TT1
	DECLE _SS
	DECLE 4
	DECLE 0
	;[534] mermaid:     VOICE MM,ER1,MM,EY,DD1,PA1,0
	SRCFILE "mermaid008.bas",534
	; MERMAID
Q21:		DECLE _MM
	DECLE _ER1
	DECLE _MM
	DECLE _EY
	DECLE _DD1
	DECLE 5
	DECLE 0
	;[535] 
	SRCFILE "mermaid008.bas",535
	;[536] WaitTitleDiffSelect:Procedure
	SRCFILE "mermaid008.bas",536
	; WAITTITLEDIFFSELECT
Q97:	PROC
	BEGIN
	;[537] 	For a=0 to 5
	SRCFILE "mermaid008.bas",537
	CLRR R0
	MVO R0,V58
T121:
	;[538] 		wait
	SRCFILE "mermaid008.bas",538
	CALL _wait
	;[539] 		'check for key press on either controller
	SRCFILE "mermaid008.bas",539
	;[540]     	'set difficulty level based on user input
	SRCFILE "mermaid008.bas",540
	;[541] 		'IF levelSelect = 0 then IF cont.key >= 1 AND cont.key <= 4 THEN levelSelect=1:diffLevel = cont.key:EXIT FOR
	SRCFILE "mermaid008.bas",541
	;[542] 		IF cont.key >= 1 AND cont.key <= 4 THEN levelSelect=1:diffLevel = cont.key:waitkeypress = 1:PRINT AT SCREENPOS(1, 10) COLOR FG_WHITE+BG_BLUE,"MERMAID (1-5) ?":EXIT FOR
	SRCFILE "mermaid008.bas",542
	MVI _cnt1_key,R0
	CMPI #12,R0
	BNE $+4
	MVI _cnt2_key,R0
	CMPI #1,R0
	MVII #-1,R0
	BGE $+3
	INCR R0
	MVI _cnt1_key,R1
	CMPI #12,R1
	BNE $+4
	MVI _cnt2_key,R1
	CMPI #4,R1
	MVII #-1,R1
	BLE $+3
	INCR R1
	ANDR R1,R0
	BEQ T122
	MVII #1,R0
	MVO R0,V9
	MVI _cnt1_key,R0
	CMPI #12,R0
	BNE $+4
	MVI _cnt2_key,R0
	MVO R0,V7
	MVII #1,R0
	MVO R0,V14
	MVII #713,R0
	MVO R0,_screen
	MVII #519,R0
	MVO R0,_color
	MVI _screen,R4
	MVII #360,R0
	XOR _color,R0
	MVO@ R0,R4
	XORI #64,R0
	MVO@ R0,R4
	XORI #184,R0
	MVO@ R0,R4
	XORI #248,R0
	MVO@ R0,R4
	XORI #96,R0
	MVO@ R0,R4
	XORI #64,R0
	MVO@ R0,R4
	XORI #104,R0
	MVO@ R0,R4
	XORI #288,R0
	MVO@ R0,R4
	XORI #64,R0
	MVO@ R0,R4
	XORI #200,R0
	MVO@ R0,R4
	XORI #224,R0
	MVO@ R0,R4
	XORI #192,R0
	MVO@ R0,R4
	XORI #224,R0
	MVO@ R0,R4
	XORI #72,R0
	MVO@ R0,R4
	XORI #248,R0
	MVO@ R0,R4
	MVO R4,_screen
	B T123
T122:
	;[543] 	Next a
	SRCFILE "mermaid008.bas",543
	MVI V58,R0
	INCR R0
	MVO R0,V58
	CMPI #5,R0
	BLE T121
T123:
	;[544] End
	SRCFILE "mermaid008.bas",544
	RETURN
	ENDP
	;[545] 
	SRCFILE "mermaid008.bas",545
	;[546] WaitTitleMermaidSelect:Procedure
	SRCFILE "mermaid008.bas",546
	; WAITTITLEMERMAIDSELECT
Q98:	PROC
	BEGIN
	;[547] 	For a=0 to 5
	SRCFILE "mermaid008.bas",547
	CLRR R0
	MVO R0,V58
T124:
	;[548] 		wait
	SRCFILE "mermaid008.bas",548
	CALL _wait
	;[549] 		'check for key press on either controller
	SRCFILE "mermaid008.bas",549
	;[550]     	'select mermaid based on user input
	SRCFILE "mermaid008.bas",550
	;[551] 		'IF mermaidSelect = 0 then IF cont.key >= 1 AND cont.key <= 5 THEN mermaidSelect=1:mermaid = cont.key:EXIT FOR	
	SRCFILE "mermaid008.bas",551
	;[552] 		if waitkeypress > 10 then IF cont.key >= 1 AND cont.key <= 5 THEN mermaidSelect=1:mermaid = cont.key:waitkeypress = 0:EXIT FOR	
	SRCFILE "mermaid008.bas",552
	MVI V14,R0
	CMPI #10,R0
	BLE T125
	MVI _cnt1_key,R0
	CMPI #12,R0
	BNE $+4
	MVI _cnt2_key,R0
	CMPI #1,R0
	MVII #-1,R0
	BGE $+3
	INCR R0
	MVI _cnt1_key,R1
	CMPI #12,R1
	BNE $+4
	MVI _cnt2_key,R1
	CMPI #5,R1
	MVII #-1,R1
	BLE $+3
	INCR R1
	ANDR R1,R0
	BEQ T126
	MVII #1,R0
	MVO R0,V10
	MVI _cnt1_key,R0
	CMPI #12,R0
	BNE $+4
	MVI _cnt2_key,R0
	MVO R0,V8
	CLRR R0
	MVO R0,V14
	B T127
T126:
T125:
	;[553] 		'IF cont.key >= 1 AND cont.key <= 5 THEN mermaidSelect=1:mermaid = cont.key:EXIT FOR	
	SRCFILE "mermaid008.bas",553
	;[554] 	Next a
	SRCFILE "mermaid008.bas",554
	MVI V58,R0
	INCR R0
	MVO R0,V58
	CMPI #5,R0
	BLE T124
T127:
	;[555] End
	SRCFILE "mermaid008.bas",555
	RETURN
	ENDP
	;[556] 
	SRCFILE "mermaid008.bas",556
	;[557] WaitaLittle:Procedure
	SRCFILE "mermaid008.bas",557
	; WAITALITTLE
Q37:	PROC
	BEGIN
	;[558] 	For a=0 to 5
	SRCFILE "mermaid008.bas",558
	CLRR R0
	MVO R0,V58
T128:
	;[559] 		wait
	SRCFILE "mermaid008.bas",559
	CALL _wait
	;[560] 	Next a
	SRCFILE "mermaid008.bas",560
	MVI V58,R0
	INCR R0
	MVO R0,V58
	CMPI #5,R0
	BLE T128
	;[561] End
	SRCFILE "mermaid008.bas",561
	RETURN
	ENDP
	;[562] 
	SRCFILE "mermaid008.bas",562
	;[563] WaitaBit:Procedure
	SRCFILE "mermaid008.bas",563
	; WAITABIT
Q20:	PROC
	BEGIN
	;[564] 	For a=0 to 10
	SRCFILE "mermaid008.bas",564
	CLRR R0
	MVO R0,V58
T129:
	;[565] 		Wait
	SRCFILE "mermaid008.bas",565
	CALL _wait
	;[566] 	Next a
	SRCFILE "mermaid008.bas",566
	MVI V58,R0
	INCR R0
	MVO R0,V58
	CMPI #10,R0
	BLE T129
	;[567] End
	SRCFILE "mermaid008.bas",567
	RETURN
	ENDP
	;[568] 
	SRCFILE "mermaid008.bas",568
	;[569] WaitaLot:Procedure
	SRCFILE "mermaid008.bas",569
	; WAITALOT
Q7:	PROC
	BEGIN
	;[570] 	For a=0 to 8
	SRCFILE "mermaid008.bas",570
	CLRR R0
	MVO R0,V58
T130:
	;[571] 		gosub waitabit
	SRCFILE "mermaid008.bas",571
	CALL Q20
	;[572] 	next a
	SRCFILE "mermaid008.bas",572
	MVI V58,R0
	INCR R0
	MVO R0,V58
	CMPI #8,R0
	BLE T130
	;[573] End
	SRCFILE "mermaid008.bas",573
	RETURN
	ENDP
	;[574] 
	SRCFILE "mermaid008.bas",574
	;[575] introSwimBy: Procedure
	SRCFILE "mermaid008.bas",575
	; INTROSWIMBY
Q22:	PROC
	BEGIN
	;[576] 	Spriteframe=0
	SRCFILE "mermaid008.bas",576
	CLRR R0
	MVO R0,V43
	;[577]         For cnt1=160 to 20 step -2
	SRCFILE "mermaid008.bas",577
	MVII #160,R0
	MVO R0,V60
T131:
	;[578] 			'large mermaid
	SRCFILE "mermaid008.bas",578
	;[579] 			Sprite 0,Spritex(0)+VISIBLE+ZOOMX2,Spritey(0)+ZOOMY2, SPR32+ (8*spriteframe) +#SpriteC(0)
	SRCFILE "mermaid008.bas",579
	MVI Q8,R0
	ADDI #1536,R0
	MVO R0,_mobs
	MVI Q9,R0
	ADDI #256,R0
	MVO R0,_mobs+8
	MVI V43,R0
	SLL R0,2
	ADDR R0,R0
	ADDI #2304,R0
	MVI Q10,R1
	ADDR R1,R0
	MVO R0,_mobs+16
	;[580] 			Sprite 1,Spritex(1)+VISIBLE+ZOOMX2,Spritey(1)+ZOOMY2, SPR36+ (8*spriteframe) +#SpriteC(1)
	SRCFILE "mermaid008.bas",580
	MVI Q8+1,R0
	ADDI #1536,R0
	MVO R0,_mobs+1
	MVI Q9+1,R0
	ADDI #256,R0
	MVO R0,_mobs+9
	MVI V43,R0
	SLL R0,2
	ADDR R0,R0
	ADDI #2336,R0
	MVI Q10+1,R1
	ADDR R1,R0
	MVO R0,_mobs+17
	;[581] 			if levelSelect=0 then gosub waitTitleDiffSelect else gosub waitTitleMermaidSelect
	SRCFILE "mermaid008.bas",581
	MVI V9,R0
	TSTR R0
	BNE T132
	CALL Q97
	B T133
T132:
	CALL Q98
T133:
	;[582] 			if levelSelect=1 and mermaidSelect=1 GOTO introDone
	SRCFILE "mermaid008.bas",582
	MVI V9,R0
	CMPI #1,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V10,R1
	CMPI #1,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	ANDR R1,R0
	BNE Q103
	;[583] 			if waitkeypress > 0 then waitkeypress = waitkeypress + 1
	SRCFILE "mermaid008.bas",583
	MVI V14,R0
	CMPI #0,R0
	BLE T135
	INCR R0
	MVO R0,V14
T135:
	;[584] 			Spriteframe=Spriteframe+1:If SpriteFrame>3 then SpriteFrame=0
	SRCFILE "mermaid008.bas",584
	MVI V43,R0
	INCR R0
	MVO R0,V43
	MVI V43,R0
	CMPI #3,R0
	BLE T136
	CLRR R0
	MVO R0,V43
T136:
	;[585] 			Spritex(0)=Spritex(0)-2: Spritex(1)=Spritex(1)-2
	SRCFILE "mermaid008.bas",585
	MVI Q8,R0
	SUBI #2,R0
	MVO R0,Q8
	MVI Q8+1,R0
	SUBI #2,R0
	MVO R0,Q8+1
	;[586] 			If Spritex(0)<20 then Spritex(0)=160:Spritex(1)=160
	SRCFILE "mermaid008.bas",586
	MVI Q8,R0
	CMPI #20,R0
	BGE T137
	MVII #160,R0
	MVO R0,Q8
	MVO R0,Q8+1
T137:
	;[587] 			'If Spritex(1)<20 then Spritex(1)=160
	SRCFILE "mermaid008.bas",587
	;[588] 		next cnt1
	SRCFILE "mermaid008.bas",588
	MVI V60,R0
	SUBI #2,R0
	MVO R0,V60
	CMPI #20,R0
	BGE T131
	;[589] 	startIntroMusic=startIntroMusic+1
	SRCFILE "mermaid008.bas",589
	MVI V61,R0
	INCR R0
	MVO R0,V61
	;[590] 	if startIntroMusic=1 then Play Intro_Tune
	SRCFILE "mermaid008.bas",590
	MVI V61,R0
	CMPI #1,R0
	BNE T138
	MVII #Q104,R0
	CALL _play_music
T138:
	;[591] 	goto introSwimBy
	SRCFILE "mermaid008.bas",591
	B Q22
	;[592] 	'exiting subroutine, set levelSelect back to zero
	SRCFILE "mermaid008.bas",592
	;[593] 	introDone:
	SRCFILE "mermaid008.bas",593
	; INTRODONE
Q103:	;[594] End
	SRCFILE "mermaid008.bas",594
	RETURN
	ENDP
	;[595] 
	SRCFILE "mermaid008.bas",595
	;[596] update_score:	Procedure
	SRCFILE "mermaid008.bas",596
	; UPDATE_SCORE
Q31:	PROC
	BEGIN
	;[597] ON mermaidLocation GOTO update_score_ocean, update_score_castle
	SRCFILE "mermaid008.bas",597
	MVI V18,R0
	CMPI #2,R0
	BC T140
	ADDI #T139,R0
	MOVR R0,R1
	MVI@ R1,PC
T139:
	DECLE Q107
	DECLE Q108
T140:
	;[598] update_score_ocean:
	SRCFILE "mermaid008.bas",598
	; UPDATE_SCORE_OCEAN
Q107:	;[599] 
	SRCFILE "mermaid008.bas",599
	;[600] 	PRINT AT SCREENPOS(1, 0) COLOR FG_WHITE+BG_BLUE,<>#score
	SRCFILE "mermaid008.bas",600
	MVII #513,R0
	MVO R0,_screen
	MVII #519,R0
	MVO R0,_color
	MVI V1,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[601] 	PRINT AT SCREENPOS(7, 0) COLOR FG_WHITE+BG_BLUE,<>level
	SRCFILE "mermaid008.bas",601
	MVII #519,R0
	MVO R0,_screen
	MVO R0,_color
	MVI V2,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[602] 	PRINT AT SCREENPOS(1, 11) COLOR FG_GREEN+BG_BLUE,<>mermaid_oceanLocation
	SRCFILE "mermaid008.bas",602
	MVII #733,R0
	MVO R0,_screen
	MVII #517,R0
	MVO R0,_color
	MVI V46,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[603] 	PRINT AT SCREENPOS(4, 11) COLOR FG_GREEN+BG_BLUE,<>ocean_level_width
	SRCFILE "mermaid008.bas",603
	MVII #736,R0
	MVO R0,_screen
	MVII #517,R0
	MVO R0,_color
	MVI V62,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[604] 	PRINT AT SCREENPOS(15, 11) COLOR FG_YELLOW+BG_BLUE,<>lives
	SRCFILE "mermaid008.bas",604
	MVII #747,R0
	MVO R0,_screen
	MVII #518,R0
	MVO R0,_color
	MVI V13,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[605] 	PRINT AT SCREENPOS(17, 11) COLOR FG_TAN+BG_BLUE,<>bubbles
	SRCFILE "mermaid008.bas",605
	MVII #749,R0
	MVO R0,_screen
	MVII #515,R0
	MVO R0,_color
	MVI V38,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[606] 	PRINT AT SCREENPOS(19, 11) COLOR FG_RED+BG_BLUE,<>boost
	SRCFILE "mermaid008.bas",606
	MVII #751,R0
	MVO R0,_screen
	MVII #514,R0
	MVO R0,_color
	MVI V39,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[607] 	'print ocean tiles as countdown timer decreases
	SRCFILE "mermaid008.bas",607
	;[608]     FOR a = 0 TO 3
	SRCFILE "mermaid008.bas",608
	CLRR R0
	MVO R0,V58
T141:
	;[609] 		PRINT AT 16+a,$0200
	SRCFILE "mermaid008.bas",609
	MVI V58,R0
	ADDI #528,R0
	MVO R0,_screen
	MVII #512,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	;[610] 	NEXT a
	SRCFILE "mermaid008.bas",610
	MVI V58,R0
	INCR R0
	MVO R0,V58
	CMPI #3,R0
	BLE T141
	;[611] 	IF #countdownTimer > 999 THEN 
	SRCFILE "mermaid008.bas",611
	MVI V6,R0
	CMPI #999,R0
	BLE T142
	;[612] 		PRINT AT SCREENPOS(16, 0) COLOR FG_WHITE+BG_BLUE,<>#countdownTimer
	SRCFILE "mermaid008.bas",612
	MVII #528,R0
	MVO R0,_screen
	MVII #519,R0
	MVO R0,_color
	MVI V6,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[613] 	ELSEIF #countdownTimer > 99 THEN
	SRCFILE "mermaid008.bas",613
	B T143
T142:
	MVI V6,R0
	CMPI #99,R0
	BLE T144
	;[614] 		PRINT AT SCREENPOS(17, 0) COLOR FG_WHITE+BG_BLUE,<>#countdownTimer 
	SRCFILE "mermaid008.bas",614
	MVII #529,R0
	MVO R0,_screen
	MVII #519,R0
	MVO R0,_color
	MVI V6,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[615] 	ELSE 
	SRCFILE "mermaid008.bas",615
	B T143
T144:
	;[616] 		IF #countdownTimer > 9 THEN PRINT AT SCREENPOS(18, 0) COLOR FG_WHITE+BG_BLUE,<>#countdownTimer ELSE PRINT AT SCREENPOS(19, 0) COLOR FG_WHITE+BG_BLUE,<>#countdownTimer
	SRCFILE "mermaid008.bas",616
	MVI V6,R0
	CMPI #9,R0
	BLE T145
	MVII #530,R0
	MVO R0,_screen
	MVII #519,R0
	MVO R0,_color
	MVI V6,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	B T146
T145:
	MVII #531,R0
	MVO R0,_screen
	MVII #519,R0
	MVO R0,_color
	MVI V6,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
T146:
	;[617] 	END IF
	SRCFILE "mermaid008.bas",617
T143:
	;[618] 	GOTO update_score_trace
	SRCFILE "mermaid008.bas",618
	B Q110
	;[619] 
	SRCFILE "mermaid008.bas",619
	;[620] update_score_castle:
	SRCFILE "mermaid008.bas",620
	; UPDATE_SCORE_CASTLE
Q108:	;[621] 
	SRCFILE "mermaid008.bas",621
	;[622] 	PRINT AT SCREENPOS(1, 0) COLOR FG_WHITE+BG_GREY,<>#score
	SRCFILE "mermaid008.bas",622
	MVII #513,R0
	MVO R0,_screen
	MVII #4103,R0
	MVO R0,_color
	MVI V1,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[623] 	PRINT AT SCREENPOS(7, 0) COLOR FG_WHITE+BG_GREY,<>level
	SRCFILE "mermaid008.bas",623
	MVII #519,R0
	MVO R0,_screen
	MVII #4103,R0
	MVO R0,_color
	MVI V2,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[624] 	PRINT AT SCREENPOS(1, 11) COLOR FG_WHITE+BG_GREY,<>mermaid_castleLocationX
	SRCFILE "mermaid008.bas",624
	MVII #733,R0
	MVO R0,_screen
	MVII #4103,R0
	MVO R0,_color
	MVI V63,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[625] 	PRINT AT SCREENPOS(4, 11) COLOR FG_WHITE+BG_GREY,<>mermaid_castleLocationY
	SRCFILE "mermaid008.bas",625
	MVII #736,R0
	MVO R0,_screen
	MVII #4103,R0
	MVO R0,_color
	MVI V64,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[626] 	PRINT AT SCREENPOS(15, 11) COLOR FG_YELLOW+BG_GREY,<>lives
	SRCFILE "mermaid008.bas",626
	MVII #747,R0
	MVO R0,_screen
	MVII #4102,R0
	MVO R0,_color
	MVI V13,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[627] 	PRINT AT SCREENPOS(17, 11) COLOR FG_TAN+BG_GREY,<>bubbles
	SRCFILE "mermaid008.bas",627
	MVII #749,R0
	MVO R0,_screen
	MVII #4099,R0
	MVO R0,_color
	MVI V38,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[628] 	PRINT AT SCREENPOS(19, 11) COLOR FG_RED+BG_GREY,<>boost
	SRCFILE "mermaid008.bas",628
	MVII #751,R0
	MVO R0,_screen
	MVII #4098,R0
	MVO R0,_color
	MVI V39,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[629] 	'print ocean tiles as countdown timer decreases
	SRCFILE "mermaid008.bas",629
	;[630]     FOR a = 0 TO 3
	SRCFILE "mermaid008.bas",630
	CLRR R0
	MVO R0,V58
T147:
	;[631] 		PRINT AT 16+a,$0200
	SRCFILE "mermaid008.bas",631
	MVI V58,R0
	ADDI #528,R0
	MVO R0,_screen
	MVII #512,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	;[632] 	NEXT a
	SRCFILE "mermaid008.bas",632
	MVI V58,R0
	INCR R0
	MVO R0,V58
	CMPI #3,R0
	BLE T147
	;[633] 	IF #countdownTimer > 999 THEN 
	SRCFILE "mermaid008.bas",633
	MVI V6,R0
	CMPI #999,R0
	BLE T148
	;[634] 		PRINT AT SCREENPOS(16, 0) COLOR FG_WHITE+BG_GREY,<>#countdownTimer
	SRCFILE "mermaid008.bas",634
	MVII #528,R0
	MVO R0,_screen
	MVII #4103,R0
	MVO R0,_color
	MVI V6,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[635] 	ELSEIF #countdownTimer > 99 THEN
	SRCFILE "mermaid008.bas",635
	B T149
T148:
	MVI V6,R0
	CMPI #99,R0
	BLE T150
	;[636] 		PRINT AT SCREENPOS(17, 0) COLOR FG_WHITE+BG_GREY,<>#countdownTimer 
	SRCFILE "mermaid008.bas",636
	MVII #529,R0
	MVO R0,_screen
	MVII #4103,R0
	MVO R0,_color
	MVI V6,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[637] 	ELSE 
	SRCFILE "mermaid008.bas",637
	B T149
T150:
	;[638] 		IF #countdownTimer > 9 THEN PRINT AT SCREENPOS(18, 0) COLOR FG_WHITE+BG_GREY,<>#countdownTimer ELSE PRINT AT SCREENPOS(19, 0) COLOR FG_WHITE+BG_GREY,<>#countdownTimer
	SRCFILE "mermaid008.bas",638
	MVI V6,R0
	CMPI #9,R0
	BLE T151
	MVII #530,R0
	MVO R0,_screen
	MVII #4103,R0
	MVO R0,_color
	MVI V6,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	B T152
T151:
	MVII #531,R0
	MVO R0,_screen
	MVII #4103,R0
	MVO R0,_color
	MVI V6,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
T152:
	;[639] 	END IF
	SRCFILE "mermaid008.bas",639
T149:
	;[640] 	
	SRCFILE "mermaid008.bas",640
	;[641] 	
	SRCFILE "mermaid008.bas",641
	;[642] update_score_trace:	
	SRCFILE "mermaid008.bas",642
	; UPDATE_SCORE_TRACE
Q110:	;[643] 'only display trace information when TRACE = 1
	SRCFILE "mermaid008.bas",643
	;[644] 	IF trace = 1 then
	SRCFILE "mermaid008.bas",644
	MVI V16,R0
	CMPI #1,R0
	BNE T153
	;[645] 		PRINT AT SCREENPOS(6, 1) COLOR FG_TAN+BG_BLUE,<>#bubble_counter
	SRCFILE "mermaid008.bas",645
	MVII #538,R0
	MVO R0,_screen
	MVII #515,R0
	MVO R0,_color
	MVI V3,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[646] 		PRINT AT SCREENPOS(16, 1) COLOR FG_TAN+BG_BLUE,<>level
	SRCFILE "mermaid008.bas",646
	MVII #548,R0
	MVO R0,_screen
	MVII #515,R0
	MVO R0,_color
	MVI V2,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[647] 		PRINT AT SCREENPOS(18, 1) COLOR FG_TAN+BG_BLUE,<>diffLevel
	SRCFILE "mermaid008.bas",647
	MVII #550,R0
	MVO R0,_screen
	MVII #515,R0
	MVO R0,_color
	MVI V7,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[648] 		PRINT AT SCREENPOS(2, 2) COLOR FG_RED+BG_BLUE,<>Spritex(0)
	SRCFILE "mermaid008.bas",648
	MVII #554,R0
	MVO R0,_screen
	MVII #514,R0
	MVO R0,_color
	MVI Q8,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[649] 		PRINT AT SCREENPOS(6, 2) COLOR FG_RED+BG_BLUE,<>Spritey(0)
	SRCFILE "mermaid008.bas",649
	MVII #558,R0
	MVO R0,_screen
	MVII #514,R0
	MVO R0,_color
	MVI Q9,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[650] 		PRINT AT SCREENPOS(10, 2) COLOR FG_TAN+BG_BLUE,<>#boost_counter
	SRCFILE "mermaid008.bas",650
	MVII #562,R0
	MVO R0,_screen
	MVII #515,R0
	MVO R0,_color
	MVI V4,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[651] 		PRINT AT SCREENPOS(15, 2) COLOR FG_WHITE+BG_BLUE,<>inventory_key
	SRCFILE "mermaid008.bas",651
	MVII #567,R0
	MVO R0,_screen
	MVII #519,R0
	MVO R0,_color
	MVI V20,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[652] 		PRINT AT SCREENPOS(17, 2) COLOR FG_RED+BG_BLUE,<>inventory_crown
	SRCFILE "mermaid008.bas",652
	MVII #569,R0
	MVO R0,_screen
	MVII #514,R0
	MVO R0,_color
	MVI V21,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[653] 		PRINT AT SCREENPOS(2, 3) COLOR FG_RED+BG_BLUE,<>Spritex(1)
	SRCFILE "mermaid008.bas",653
	MVII #574,R0
	MVO R0,_screen
	MVII #514,R0
	MVO R0,_color
	MVI Q8+1,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[654] 		PRINT AT SCREENPOS(6, 3) COLOR FG_RED+BG_BLUE,<>Spritey(1)
	SRCFILE "mermaid008.bas",654
	MVII #578,R0
	MVO R0,_screen
	MVII #514,R0
	MVO R0,_color
	MVI Q9+1,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[655] 		PRINT AT SCREENPOS(15, 3) COLOR FG_WHITE+BG_BLUE,<>keyPosition
	SRCFILE "mermaid008.bas",655
	MVII #587,R0
	MVO R0,_screen
	MVII #519,R0
	MVO R0,_color
	MVI V50,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[656] 		PRINT AT SCREENPOS(17, 3) COLOR FG_RED+BG_BLUE,<>crownPosition
	SRCFILE "mermaid008.bas",656
	MVII #589,R0
	MVO R0,_screen
	MVII #514,R0
	MVO R0,_color
	MVI V48,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[657] 		junk = (crownPosition*8)-6:PRINT AT SCREENPOS(1, 4) COLOR FG_RED+BG_BLUE,<>junk 
	SRCFILE "mermaid008.bas",657
	MVI V48,R0
	SLL R0,2
	ADDR R0,R0
	SUBI #6,R0
	MVO R0,V65
	MVII #593,R0
	MVO R0,_screen
	MVII #514,R0
	MVO R0,_color
	MVI V65,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[658] 		junk = (crownPosition*8)+14:PRINT AT SCREENPOS(5, 4) COLOR FG_RED+BG_BLUE,<>junk 
	SRCFILE "mermaid008.bas",658
	MVI V48,R0
	SLL R0,2
	ADDR R0,R0
	ADDI #14,R0
	MVO R0,V65
	MVII #597,R0
	MVO R0,_screen
	MVII #514,R0
	MVO R0,_color
	MVI V65,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[659] 		PRINT AT SCREENPOS(8, 4) COLOR FG_GREEN+BG_BLUE,<>treasure
	SRCFILE "mermaid008.bas",659
	MVII #600,R0
	MVO R0,_screen
	MVII #517,R0
	MVO R0,_color
	MVI V28,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[660] 		PRINT AT SCREENPOS(10, 4) COLOR FG_YELLOW+BG_BLUE,<>gold_position
	SRCFILE "mermaid008.bas",660
	MVII #602,R0
	MVO R0,_screen
	MVII #518,R0
	MVO R0,_color
	MVI V26,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[661] 		PRINT AT SCREENPOS(12, 4) COLOR FG_TAN+BG_BLUE,<>silver_position
	SRCFILE "mermaid008.bas",661
	MVII #604,R0
	MVO R0,_screen
	MVII #515,R0
	MVO R0,_color
	MVI V27,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[662] 		PRINT AT SCREENPOS(15, 4) COLOR FG_WHITE+BG_BLUE,<>key_visible
	SRCFILE "mermaid008.bas",662
	MVII #607,R0
	MVO R0,_screen
	MVII #519,R0
	MVO R0,_color
	MVI V24,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[663] 		PRINT AT SCREENPOS(17, 4) COLOR FG_RED+BG_BLUE,<>crown_visible
	SRCFILE "mermaid008.bas",663
	MVII #609,R0
	MVO R0,_screen
	MVII #514,R0
	MVO R0,_color
	MVI V25,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[664] 		junk = (keyPosition*8)-6:PRINT AT SCREENPOS(1, 5) COLOR FG_WHITE+BG_BLUE,<>junk 
	SRCFILE "mermaid008.bas",664
	MVI V50,R0
	SLL R0,2
	ADDR R0,R0
	SUBI #6,R0
	MVO R0,V65
	MVII #613,R0
	MVO R0,_screen
	MVII #519,R0
	MVO R0,_color
	MVI V65,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[665] 		junk = (keyPosition*8)+14:PRINT AT SCREENPOS(4, 5) COLOR FG_WHITE+BG_BLUE,<>junk 
	SRCFILE "mermaid008.bas",665
	MVI V50,R0
	SLL R0,2
	ADDR R0,R0
	ADDI #14,R0
	MVO R0,V65
	MVII #616,R0
	MVO R0,_screen
	MVII #519,R0
	MVO R0,_color
	MVI V65,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[666] 		PRINT AT SCREENPOS(9, 5) COLOR FG_TAN+BG_BLUE,<>Spritex(3)
	SRCFILE "mermaid008.bas",666
	MVII #621,R0
	MVO R0,_screen
	MVII #515,R0
	MVO R0,_color
	MVI Q8+3,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[667] 		PRINT AT SCREENPOS(12, 5) COLOR FG_TAN+BG_BLUE,<>Spritey(3)
	SRCFILE "mermaid008.bas",667
	MVII #624,R0
	MVO R0,_screen
	MVII #515,R0
	MVO R0,_color
	MVI Q9+3,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[668] 		PRINT AT SCREENPOS(7, 6) COLOR FG_GREEN+BG_BLUE,<>spawnPoint
	SRCFILE "mermaid008.bas",668
	MVII #639,R0
	MVO R0,_screen
	MVII #517,R0
	MVO R0,_color
	MVI V66,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[669] 		PRINT AT SCREENPOS(9, 6) COLOR FG_TAN+BG_BLUE,<>Spritex(4)
	SRCFILE "mermaid008.bas",669
	MVII #641,R0
	MVO R0,_screen
	MVII #515,R0
	MVO R0,_color
	MVI Q8+4,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[670] 		PRINT AT SCREENPOS(12, 6) COLOR FG_TAN+BG_BLUE,<>Spritey(4)			
	SRCFILE "mermaid008.bas",670
	MVII #644,R0
	MVO R0,_screen
	MVII #515,R0
	MVO R0,_color
	MVI Q9+4,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[671] 		PRINT AT SCREENPOS(1, 7) COLOR FG_TAN+BG_BLUE,<>creature
	SRCFILE "mermaid008.bas",671
	MVII #653,R0
	MVO R0,_screen
	MVII #515,R0
	MVO R0,_color
	MVI V31,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[672] 		PRINT AT SCREENPOS(4, 7) COLOR FG_YELLOW+BG_BLUE,<>creature1_Speed
	SRCFILE "mermaid008.bas",672
	MVII #656,R0
	MVO R0,_screen
	MVII #518,R0
	MVO R0,_color
	MVI V35,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[673] 		PRINT AT SCREENPOS(7, 7) COLOR FG_YELLOW+BG_BLUE,<>creature1_Speed
	SRCFILE "mermaid008.bas",673
	MVII #659,R0
	MVO R0,_screen
	MVII #518,R0
	MVO R0,_color
	MVI V35,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[674] 		PRINT AT SCREENPOS(10, 7) COLOR FG_WHITE+BG_BLUE,<>castleLayout(mermaid_CastleLocation)
	SRCFILE "mermaid008.bas",674
	MVII #662,R0
	MVO R0,_screen
	MVII #519,R0
	MVO R0,_color
	MVII #Q11,R3
	ADD V52,R3
	MVI@ R3,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[675] 		PRINT AT SCREENPOS(13, 7) COLOR FG_GREEN+BG_BLUE,<>nextScreen
	SRCFILE "mermaid008.bas",675
	MVII #665,R0
	MVO R0,_screen
	MVII #517,R0
	MVO R0,_color
	MVI V19,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[676] 		'PRINT AT SCREENPOS(15, 7) COLOR FG_GREEN+BG_BLUE,<>dir
	SRCFILE "mermaid008.bas",676
	;[677] 		PRINT AT SCREENPOS(15, 7) COLOR FG_GREEN+BG_BLUE,<>queenLocation
	SRCFILE "mermaid008.bas",677
	MVII #667,R0
	MVO R0,_screen
	MVII #517,R0
	MVO R0,_color
	MVI V53,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[678] 		PRINT AT SCREENPOS(1, 8) COLOR FG_TAN+BG_BLUE,<>creature1_UpDown
	SRCFILE "mermaid008.bas",678
	MVII #673,R0
	MVO R0,_screen
	MVII #515,R0
	MVO R0,_color
	MVI V67,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[679] 		PRINT AT SCREENPOS(3, 8) COLOR FG_TAN+BG_BLUE,<>creature1_UpDown_Speed		
	SRCFILE "mermaid008.bas",679
	MVII #675,R0
	MVO R0,_screen
	MVII #515,R0
	MVO R0,_color
	MVI V68,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[680] 		PRINT AT SCREENPOS(5, 8) COLOR FG_RED+BG_BLUE,<>playerHit	
	SRCFILE "mermaid008.bas",680
	MVII #677,R0
	MVO R0,_screen
	MVII #514,R0
	MVO R0,_color
	MVI V57,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[681] 		PRINT AT SCREENPOS(7, 8) COLOR FG_RED+BG_BLUE,<>mermaid
	SRCFILE "mermaid008.bas",681
	MVII #679,R0
	MVO R0,_screen
	MVII #514,R0
	MVO R0,_color
	MVI V8,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[682] 		PRINT AT SCREENPOS(15, 8) COLOR FG_RED+BG_BLUE,<>mermaid_CastleLocation
	SRCFILE "mermaid008.bas",682
	MVII #687,R0
	MVO R0,_screen
	MVII #514,R0
	MVO R0,_color
	MVI V52,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[683] 		PRINT AT SCREENPOS(7, 10) COLOR FG_WHITE+BG_BLUE,<>castleLocation
	SRCFILE "mermaid008.bas",683
	MVII #719,R0
	MVO R0,_screen
	MVII #519,R0
	MVO R0,_color
	MVI V51,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[684] 		PRINT AT SCREENPOS(15, 10) COLOR FG_WHITE+BG_BLUE,<>keyLocation
	SRCFILE "mermaid008.bas",684
	MVII #727,R0
	MVO R0,_screen
	MVII #519,R0
	MVO R0,_color
	MVI V49,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[685] 		PRINT AT SCREENPOS(17, 10) COLOR FG_RED+BG_BLUE,<>crownLocation
	SRCFILE "mermaid008.bas",685
	MVII #729,R0
	MVO R0,_screen
	MVII #514,R0
	MVO R0,_color
	MVI V47,R0
	MVI _color,R3
	MVI _screen,R4
	CALL PRNUM16.l
	MVO R4,_screen
	;[686] 	END IF 
	SRCFILE "mermaid008.bas",686
T153:
	;[687] END
	SRCFILE "mermaid008.bas",687
	RETURN
	ENDP
	;[688] 
	SRCFILE "mermaid008.bas",688
	;[689] update_bubble_counter:    Procedure
	SRCFILE "mermaid008.bas",689
	; UPDATE_BUBBLE_COUNTER
Q27:	PROC
	BEGIN
	;[690] if level > 0 and level < 5 then #bubble_counter = ((5-level)*72)/diffLevel 
	SRCFILE "mermaid008.bas",690
	MVI V2,R0
	CMPI #0,R0
	MVII #-1,R0
	BGT $+3
	INCR R0
	MVI V2,R1
	CMPI #5,R1
	MVII #-1,R1
	BLT $+3
	INCR R1
	ANDR R1,R0
	BEQ T154
	MVII #5,R0
	SUB V2,R0
	MULT R0,R4,72
	MVI V7,R4
	MOVR R0,R5
	TSTR R4
	BEQ T155
	MVII #-1,R0
T156:
	INCR R0
	SUBR R4,R5
	BC T156
T155:
	MVO R0,V3
T154:
	;[691] if #bubble_counter < 36 then #bubble_counter = 36
	SRCFILE "mermaid008.bas",691
	MVI V3,R0
	CMPI #36,R0
	BGE T157
	MVII #36,R0
	MVO R0,V3
T157:
	;[692] END 
	SRCFILE "mermaid008.bas",692
	RETURN
	ENDP
	;[693] 
	SRCFILE "mermaid008.bas",693
	;[694] update_boost_counter:    Procedure
	SRCFILE "mermaid008.bas",694
	; UPDATE_BOOST_COUNTER
Q28:	PROC
	BEGIN
	;[695] if level > 0 and level < 5 then #boost_counter = ((5-level)*36)/diffLevel 
	SRCFILE "mermaid008.bas",695
	MVI V2,R0
	CMPI #0,R0
	MVII #-1,R0
	BGT $+3
	INCR R0
	MVI V2,R1
	CMPI #5,R1
	MVII #-1,R1
	BLT $+3
	INCR R1
	ANDR R1,R0
	BEQ T158
	MVII #5,R0
	SUB V2,R0
	MULT R0,R4,36
	MVI V7,R4
	MOVR R0,R5
	TSTR R4
	BEQ T159
	MVII #-1,R0
T160:
	INCR R0
	SUBR R4,R5
	BC T160
T159:
	MVO R0,V4
T158:
	;[696] if #boost_counter < 18 then #boost_counter = 18
	SRCFILE "mermaid008.bas",696
	MVI V4,R0
	CMPI #18,R0
	BGE T161
	MVII #18,R0
	MVO R0,V4
T161:
	;[697] END 
	SRCFILE "mermaid008.bas",697
	RETURN
	ENDP
	;[698] 
	SRCFILE "mermaid008.bas",698
	;[699] update_merChange_counter:    Procedure
	SRCFILE "mermaid008.bas",699
	; UPDATE_MERCHANGE_COUNTER
Q29:	PROC
	BEGIN
	;[700] if level > 0 and level < 5 then #merChange_counter = ((5-level)*24)/diffLevel 
	SRCFILE "mermaid008.bas",700
	MVI V2,R0
	CMPI #0,R0
	MVII #-1,R0
	BGT $+3
	INCR R0
	MVI V2,R1
	CMPI #5,R1
	MVII #-1,R1
	BLT $+3
	INCR R1
	ANDR R1,R0
	BEQ T162
	MVII #5,R0
	SUB V2,R0
	MULT R0,R4,24
	MVI V7,R4
	MOVR R0,R5
	TSTR R4
	BEQ T163
	MVII #-1,R0
T164:
	INCR R0
	SUBR R4,R5
	BC T164
T163:
	MVO R0,V5
T162:
	;[701] if #boost_counter < 12 then #boost_counter = 12
	SRCFILE "mermaid008.bas",701
	MVI V4,R0
	CMPI #12,R0
	BGE T165
	MVII #12,R0
	MVO R0,V4
T165:
	;[702] END 
	SRCFILE "mermaid008.bas",702
	RETURN
	ENDP
	;[703] 
	SRCFILE "mermaid008.bas",703
	;[704] levelRandomizer:    Procedure
	SRCFILE "mermaid008.bas",704
	; LEVELRANDOMIZER
Q24:	PROC
	BEGIN
	;[705] REM      Ocean screens are 15 to 90 screens wide  (screen wraps from 90 to 1 and vice versa)
	SRCFILE "mermaid008.bas",705
	;[706] REM 	 ocean_level_width = diffLevel*level*15
	SRCFILE "mermaid008.bas",706
	;[707] REM      Mermaid always begins in the center location 
	SRCFILE "mermaid008.bas",707
	;[708] REM           starting_point = (ocean_level_width+1)/2
	SRCFILE "mermaid008.bas",708
	;[709] REM      Castles are 10x10 grids
	SRCFILE "mermaid008.bas",709
	;[710] 
	SRCFILE "mermaid008.bas",710
	;[711] ocean_level_width = diffLevel*level*15
	SRCFILE "mermaid008.bas",711
	MVI V7,R0
	MVI V2,R1
	CALL qs_mpy16
	MOVR R1,R0
	MULT R0,R4,15
	MVO R0,V62
	;[712] if ocean_level_width > 90 then ocean_level_width = 90
	SRCFILE "mermaid008.bas",712
	MVI V62,R0
	CMPI #90,R0
	BLE T166
	MVII #90,R0
	MVO R0,V62
T166:
	;[713] starting_point = (ocean_level_width+1)/2
	SRCFILE "mermaid008.bas",713
	MVI V62,R0
	INCR R0
	SLR R0,1
	MVO R0,V17
	;[714] mermaid_castleLocationX = 0
	SRCFILE "mermaid008.bas",714
	CLRR R0
	MVO R0,V63
	;[715] mermaid_castleLocationY = 0
	SRCFILE "mermaid008.bas",715
	MVO R0,V64
	;[716] mermaid_oceanLocation = starting_point
	SRCFILE "mermaid008.bas",716
	MVI V17,R0
	MVO R0,V46
	;[717] castleLocation = RANDOM(ocean_level_width)+1
	SRCFILE "mermaid008.bas",717
	MVI V62,R1
	CALL _next_random
	CALL qs_mpy8
	SWAP R0
	ANDI #255,R0
	INCR R0
	MVO R0,V51
	;[718] keyLocation = RANDOM(ocean_level_width)+1
	SRCFILE "mermaid008.bas",718
	MVI V62,R1
	CALL _next_random
	CALL qs_mpy8
	SWAP R0
	ANDI #255,R0
	INCR R0
	MVO R0,V49
	;[719] keyPosition = RANDOM(18)+2
	SRCFILE "mermaid008.bas",719
	MVII #18,R1
	CALL _next_random
	CALL qs_mpy8
	SWAP R0
	ANDI #255,R0
	ADDI #2,R0
	MVO R0,V50
	;[720] crownLocation = RANDOM(ocean_level_width)+1
	SRCFILE "mermaid008.bas",720
	MVI V62,R1
	CALL _next_random
	CALL qs_mpy8
	SWAP R0
	ANDI #255,R0
	INCR R0
	MVO R0,V47
	;[721] crownPosition = RANDOM(18)+2
	SRCFILE "mermaid008.bas",721
	MVII #18,R1
	CALL _next_random
	CALL qs_mpy8
	SWAP R0
	ANDI #255,R0
	ADDI #2,R0
	MVO R0,V48
	;[722] 'avoid placing queen in the castle entrance
	SRCFILE "mermaid008.bas",722
	;[723] queenRandomizer:
	SRCFILE "mermaid008.bas",723
	; QUEENRANDOMIZER
Q117:	;[724] queenLocation = RANDOM(100)+1: IF queenLocation = 95 GOTO queenRandomizer
	SRCFILE "mermaid008.bas",724
	MVII #100,R1
	CALL _next_random
	CALL qs_mpy8
	SWAP R0
	ANDI #255,R0
	INCR R0
	MVO R0,V53
	MVI V53,R0
	CMPI #95,R0
	BEQ Q117
	;[725] 
	SRCFILE "mermaid008.bas",725
	;[726] 'avoid placing key and crown in a castle tile
	SRCFILE "mermaid008.bas",726
	;[727] if keyPosition >= 9 and keyPosition <= 12 and castleLocation = keyLocation then keyPosition = 15
	SRCFILE "mermaid008.bas",727
	MVI V50,R0
	CMPI #9,R0
	MVII #-1,R0
	BGE $+3
	INCR R0
	MVI V50,R1
	CMPI #12,R1
	MVII #-1,R1
	BLE $+3
	INCR R1
	ANDR R1,R0
	MVI V51,R1
	CMP V49,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	ANDR R1,R0
	BEQ T168
	MVII #15,R0
	MVO R0,V50
T168:
	;[728] if crownPosition >= 9 and crownPosition <= 12 and castleLocation = crownLocation then crownPosition = 5
	SRCFILE "mermaid008.bas",728
	MVI V48,R0
	CMPI #9,R0
	MVII #-1,R0
	BGE $+3
	INCR R0
	MVI V48,R1
	CMPI #12,R1
	MVII #-1,R1
	BLE $+3
	INCR R1
	ANDR R1,R0
	MVI V51,R1
	CMP V47,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	ANDR R1,R0
	BEQ T169
	MVII #5,R0
	MVO R0,V48
T169:
	;[729] 
	SRCFILE "mermaid008.bas",729
	;[730] 'avoid placing key and crown on the same tile
	SRCFILE "mermaid008.bas",730
	;[731] if keyPosition = crownPosition AND keyLocation = crownLocation THEN keyPosition = 5: crownPosition = 15
	SRCFILE "mermaid008.bas",731
	MVI V50,R0
	CMP V48,R0
	MVII #-1,R0
	BEQ $+3
	INCR R0
	MVI V49,R1
	CMP V47,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	ANDR R1,R0
	BEQ T170
	MVII #5,R0
	MVO R0,V50
	MVII #15,R0
	MVO R0,V48
T170:
	;[732] 
	SRCFILE "mermaid008.bas",732
	;[733] END
	SRCFILE "mermaid008.bas",733
	RETURN
	ENDP
	;[734] 
	SRCFILE "mermaid008.bas",734
	;[735] mermaid_moveLeft:    Procedure
	SRCFILE "mermaid008.bas",735
	; MERMAID_MOVELEFT
Q39:	PROC
	BEGIN
	;[736] IF nextScreen = 0 THEN 
	SRCFILE "mermaid008.bas",736
	MVI V19,R0
	TSTR R0
	BNE T171
	;[737] 	GOTO all_left 
	SRCFILE "mermaid008.bas",737
	B Q119
	;[738] ELSE 
	SRCFILE "mermaid008.bas",738
	B T172
T171:
	;[739] 	ON mermaidLocation GOTO ocean_left, castle_left
	SRCFILE "mermaid008.bas",739
	MVI V18,R0
	CMPI #2,R0
	BC T174
	ADDI #T173,R0
	MOVR R0,R1
	MVI@ R1,PC
T173:
	DECLE Q120
	DECLE Q121
T174:
	;[740] END IF
	SRCFILE "mermaid008.bas",740
T172:
	;[741] 
	SRCFILE "mermaid008.bas",741
	;[742] ocean_left:
	SRCFILE "mermaid008.bas",742
	; OCEAN_LEFT
Q120:	;[743] nextScreen = 0
	SRCFILE "mermaid008.bas",743
	CLRR R0
	MVO R0,V19
	;[744] SCREEN screen_level
	SRCFILE "mermaid008.bas",744
	MVII #Q30,R3
	MVII #512,R2
	MVII #20,R1
	MVII #12,R0
	CALL CPYBLK
	;[745] GOSUB treasure_placement:GOSUB creature_placement
	SRCFILE "mermaid008.bas",745
	CALL Q123
	CALL Q124
	;[746] mermaid_oceanLocation = mermaid_oceanLocation-1
	SRCFILE "mermaid008.bas",746
	MVI V46,R0
	DECR R0
	MVO R0,V46
	;[747] IF mermaid_oceanLocation < 1 THEN mermaid_oceanLocation = ocean_level_width
	SRCFILE "mermaid008.bas",747
	MVI V46,R0
	CMPI #1,R0
	BGE T175
	MVI V62,R0
	MVO R0,V46
T175:
	;[748] Spritex(0) = 150: Spritex(1) = 150: Spritex(2) = 150
	SRCFILE "mermaid008.bas",748
	MVII #150,R0
	MVO R0,Q8
	MVO R0,Q8+1
	NOP
	MVO R0,Q8+2
	;[749] 'display new scene
	SRCFILE "mermaid008.bas",749
	;[750] 
	SRCFILE "mermaid008.bas",750
	;[751] GOTO all_left
	SRCFILE "mermaid008.bas",751
	B Q119
	;[752] 
	SRCFILE "mermaid008.bas",752
	;[753] castle_left:
	SRCFILE "mermaid008.bas",753
	; CASTLE_LEFT
Q121:	;[754] 'determine if castle room permits movement to the west 
	SRCFILE "mermaid008.bas",754
	;[755] ON castleLayout(mermaid_CastleLocation) GOTO ,room_west,,room_west,,room_west,,room_west,,,,room_west,,room_west,room_west,room_west
	SRCFILE "mermaid008.bas",755
	MVII #Q11,R3
	ADD V52,R3
	MVI@ R3,R0
	CMPI #16,R0
	BC T177
	ADDI #T176,R0
	MOVR R0,R1
	MVI@ R1,PC
T176:
	DECLE T177
	DECLE Q126
	DECLE T177
	DECLE Q126
	DECLE T177
	DECLE Q126
	DECLE T177
	DECLE Q126
	DECLE T177
	DECLE T177
	DECLE T177
	DECLE Q126
	DECLE T177
	DECLE Q126
	DECLE Q126
	DECLE Q126
T177:
	;[756] 'if west wall is blocked, skip ahead to all_left 
	SRCFILE "mermaid008.bas",756
	;[757] dir=0
	SRCFILE "mermaid008.bas",757
	CLRR R0
	MVO R0,V69
	;[758] GOTO all_left
	SRCFILE "mermaid008.bas",758
	B Q119
	;[759] 
	SRCFILE "mermaid008.bas",759
	;[760] room_west:
	SRCFILE "mermaid008.bas",760
	; ROOM_WEST
Q126:	;[761] 'determine if mermaid is properly aligned with opening
	SRCFILE "mermaid008.bas",761
	;[762] 'IF Spritey(0) > 40 and Spritey(0) < 56 and nextScreen > 0 and spriteX(0)<=14 THEN 
	SRCFILE "mermaid008.bas",762
	;[763] IF Spritey(0) > 40 and Spritey(0) < 56 and nextScreen > 0 and spriteX(0)<=16 THEN 
	SRCFILE "mermaid008.bas",763
	MVI Q9,R0
	CMPI #40,R0
	MVII #-1,R0
	BGT $+3
	INCR R0
	MVI Q9,R1
	CMPI #56,R1
	MVII #-1,R1
	BLT $+3
	INCR R1
	ANDR R1,R0
	MVI V19,R1
	CMPI #0,R1
	MVII #-1,R1
	BGT $+3
	INCR R1
	ANDR R1,R0
	MVI Q8,R1
	CMPI #16,R1
	MVII #-1,R1
	BLE $+3
	INCR R1
	ANDR R1,R0
	BEQ T178
	;[764] 	IF mermaid_castleLocationX > 1 THEN 
	SRCFILE "mermaid008.bas",764
	MVI V63,R0
	CMPI #1,R0
	BLE T179
	;[765] 		mermaid_castleLocationX = mermaid_castleLocationX - 1: mermaid_CastleLocation = mermaid_CastleLocation - 1 
	SRCFILE "mermaid008.bas",765
	DECR R0
	MVO R0,V63
	MVI V52,R0
	DECR R0
	MVO R0,V52
	;[766] 		Spritex(0) = 150: Spritex(1) = 150: Spritex(2) = 150 : dir = 1
	SRCFILE "mermaid008.bas",766
	MVII #150,R0
	MVO R0,Q8
	MVO R0,Q8+1
	NOP
	MVO R0,Q8+2
	MVII #1,R0
	MVO R0,V69
	;[767] 		'display new scene
	SRCFILE "mermaid008.bas",767
	;[768] 		SCREEN castle_level : GOSUB display_castle_walls : GOSUB treasure_placement : GOSUB creature_placement : GOTO finish_mermaid_left
	SRCFILE "mermaid008.bas",768
	MVII #Q73,R3
	MVII #512,R2
	MVII #20,R1
	MVII #12,R0
	CALL CPYBLK
	CALL Q74
	CALL Q123
	CALL Q124
	B Q128
	;[769] 	ELSE
	SRCFILE "mermaid008.bas",769
	B T180
T179:
	;[770] 		'bumped into castle wall, play bump sound
	SRCFILE "mermaid008.bas",770
	;[771] 		if spriteX(0)<14 THEN dir = 2 : GOSUB thump_sound : GOTO finish_mermaid_left
	SRCFILE "mermaid008.bas",771
	MVI Q8,R0
	CMPI #14,R0
	BGE T181
	MVII #2,R0
	MVO R0,V69
	CALL Q84
	B Q128
T181:
	;[772] 	END IF
	SRCFILE "mermaid008.bas",772
T180:
	;[773] ELSE
	SRCFILE "mermaid008.bas",773
	B T182
T178:
	;[774] 	GOTO all_left
	SRCFILE "mermaid008.bas",774
	B Q119
	;[775] END IF
	SRCFILE "mermaid008.bas",775
T182:
	;[776] 
	SRCFILE "mermaid008.bas",776
	;[777] all_left:
	SRCFILE "mermaid008.bas",777
	; ALL_LEFT
Q119:	;[778] Spritex(0) = Spritex(0) - mermaid_speed
	SRCFILE "mermaid008.bas",778
	MVI Q8,R0
	SUB V15,R0
	MVO R0,Q8
	;[779] Spritex(1) = Spritex(1) - mermaid_speed
	SRCFILE "mermaid008.bas",779
	MVI Q8+1,R0
	SUB V15,R0
	MVO R0,Q8+1
	;[780] Spritex(2) = Spritex(2) - mermaid_speed
	SRCFILE "mermaid008.bas",780
	MVI Q8+2,R0
	SUB V15,R0
	MVO R0,Q8+2
	;[781] if mermaidFacing=1 then mermaidFacing=0
	SRCFILE "mermaid008.bas",781
	MVI V11,R0
	CMPI #1,R0
	BNE T183
	CLRR R0
	MVO R0,V11
T183:
	;[782] 
	SRCFILE "mermaid008.bas",782
	;[783] finish_mermaid_left:
	SRCFILE "mermaid008.bas",783
	; FINISH_MERMAID_LEFT
Q128:	;[784] nextScreen = 0
	SRCFILE "mermaid008.bas",784
	CLRR R0
	MVO R0,V19
	;[785] 
	SRCFILE "mermaid008.bas",785
	;[786] END
	SRCFILE "mermaid008.bas",786
	RETURN
	ENDP
	;[787] 
	SRCFILE "mermaid008.bas",787
	;[788] mermaid_moveRight:    Procedure
	SRCFILE "mermaid008.bas",788
	; MERMAID_MOVERIGHT
Q40:	PROC
	BEGIN
	;[789] IF nextScreen = 0 THEN 
	SRCFILE "mermaid008.bas",789
	MVI V19,R0
	TSTR R0
	BNE T184
	;[790] 	GOTO all_right 
	SRCFILE "mermaid008.bas",790
	B Q132
	;[791] ELSE 
	SRCFILE "mermaid008.bas",791
	B T185
T184:
	;[792] 	ON mermaidLocation GOTO ocean_right, castle_right
	SRCFILE "mermaid008.bas",792
	MVI V18,R0
	CMPI #2,R0
	BC T187
	ADDI #T186,R0
	MOVR R0,R1
	MVI@ R1,PC
T186:
	DECLE Q133
	DECLE Q134
T187:
	;[793] END IF
	SRCFILE "mermaid008.bas",793
T185:
	;[794] 
	SRCFILE "mermaid008.bas",794
	;[795] ocean_right:
	SRCFILE "mermaid008.bas",795
	; OCEAN_RIGHT
Q133:	;[796] nextScreen = 0
	SRCFILE "mermaid008.bas",796
	CLRR R0
	MVO R0,V19
	;[797] SCREEN screen_level
	SRCFILE "mermaid008.bas",797
	MVII #Q30,R3
	MVII #512,R2
	MVII #20,R1
	MVII #12,R0
	CALL CPYBLK
	;[798] GOSUB treasure_placement:GOSUB creature_placement
	SRCFILE "mermaid008.bas",798
	CALL Q123
	CALL Q124
	;[799] mermaid_oceanLocation = mermaid_oceanLocation+1
	SRCFILE "mermaid008.bas",799
	MVI V46,R0
	INCR R0
	MVO R0,V46
	;[800] IF mermaid_oceanLocation > ocean_level_width THEN mermaid_oceanLocation = 1
	SRCFILE "mermaid008.bas",800
	MVI V46,R0
	CMP V62,R0
	BLE T188
	MVII #1,R0
	MVO R0,V46
T188:
	;[801] Spritex(0) = 10: Spritex(1) = 10: Spritex(2) = 10
	SRCFILE "mermaid008.bas",801
	MVII #10,R0
	MVO R0,Q8
	MVO R0,Q8+1
	NOP
	MVO R0,Q8+2
	;[802] 'display new scene
	SRCFILE "mermaid008.bas",802
	;[803] 
	SRCFILE "mermaid008.bas",803
	;[804] GOTO all_right
	SRCFILE "mermaid008.bas",804
	B Q132
	;[805] 
	SRCFILE "mermaid008.bas",805
	;[806] castle_right:
	SRCFILE "mermaid008.bas",806
	; CASTLE_RIGHT
Q134:	;[807] 'determine if castle room permits movement to the east 
	SRCFILE "mermaid008.bas",807
	;[808] ON castleLayout(mermaid_CastleLocation) GOTO ,room_east,,room_east,room_east,,room_east,,,,room_east,,room_east,,room_east,room_east
	SRCFILE "mermaid008.bas",808
	MVII #Q11,R3
	ADD V52,R3
	MVI@ R3,R0
	CMPI #16,R0
	BC T190
	ADDI #T189,R0
	MOVR R0,R1
	MVI@ R1,PC
T189:
	DECLE T190
	DECLE Q137
	DECLE T190
	DECLE Q137
	DECLE Q137
	DECLE T190
	DECLE Q137
	DECLE T190
	DECLE T190
	DECLE T190
	DECLE Q137
	DECLE T190
	DECLE Q137
	DECLE T190
	DECLE Q137
	DECLE Q137
T190:
	;[809] 'if east wall is blocked, skip ahead to all_right
	SRCFILE "mermaid008.bas",809
	;[810] dir = 0
	SRCFILE "mermaid008.bas",810
	CLRR R0
	MVO R0,V69
	;[811] GOTO all_right
	SRCFILE "mermaid008.bas",811
	B Q132
	;[812] 
	SRCFILE "mermaid008.bas",812
	;[813] room_east:
	SRCFILE "mermaid008.bas",813
	; ROOM_EAST
Q137:	;[814] 'determine if mermaid is properly aligned with opening
	SRCFILE "mermaid008.bas",814
	;[815] 'IF Spritey(0) > 40 and Spritey(0) < 56 and nextScreen > 0 and spriteX(0)>=146 THEN 
	SRCFILE "mermaid008.bas",815
	;[816] IF Spritey(0) > 40 and Spritey(0) < 56 and nextScreen > 0 and spriteX(0)>=144 THEN 
	SRCFILE "mermaid008.bas",816
	MVI Q9,R0
	CMPI #40,R0
	MVII #-1,R0
	BGT $+3
	INCR R0
	MVI Q9,R1
	CMPI #56,R1
	MVII #-1,R1
	BLT $+3
	INCR R1
	ANDR R1,R0
	MVI V19,R1
	CMPI #0,R1
	MVII #-1,R1
	BGT $+3
	INCR R1
	ANDR R1,R0
	MVI Q8,R1
	CMPI #144,R1
	MVII #-1,R1
	BGE $+3
	INCR R1
	ANDR R1,R0
	BEQ T191
	;[817] 	IF mermaid_castleLocationX < 10 THEN 
	SRCFILE "mermaid008.bas",817
	MVI V63,R0
	CMPI #10,R0
	BGE T192
	;[818] 		mermaid_castleLocationX = mermaid_castleLocationX + 1: mermaid_CastleLocation = mermaid_CastleLocation + 1 : nextScreen = 0
	SRCFILE "mermaid008.bas",818
	INCR R0
	MVO R0,V63
	MVI V52,R0
	INCR R0
	MVO R0,V52
	CLRR R0
	MVO R0,V19
	;[819] 		Spritex(0) = 10: Spritex(1) = 10: Spritex(2) = 10 : dir = 1
	SRCFILE "mermaid008.bas",819
	MVII #10,R0
	MVO R0,Q8
	MVO R0,Q8+1
	NOP
	MVO R0,Q8+2
	MVII #1,R0
	MVO R0,V69
	;[820] 		'display new scene
	SRCFILE "mermaid008.bas",820
	;[821] 		SCREEN castle_level: GOSUB display_castle_walls : GOSUB treasure_placement : GOSUB creature_placement :GOTO finish_mermaid_right
	SRCFILE "mermaid008.bas",821
	MVII #Q73,R3
	MVII #512,R2
	MVII #20,R1
	MVII #12,R0
	CALL CPYBLK
	CALL Q74
	CALL Q123
	CALL Q124
	B Q139
	;[822] 	ELSE
	SRCFILE "mermaid008.bas",822
	B T193
T192:
	;[823] 		'bumped into castle wall, play bump sound
	SRCFILE "mermaid008.bas",823
	;[824] 		if spriteX(0)>146 THEN dir = 2 : GOSUB thump_sound : GOTO finish_mermaid_right
	SRCFILE "mermaid008.bas",824
	MVI Q8,R0
	CMPI #146,R0
	BLE T194
	MVII #2,R0
	MVO R0,V69
	CALL Q84
	B Q139
T194:
	;[825] 	END IF
	SRCFILE "mermaid008.bas",825
T193:
	;[826] ELSE
	SRCFILE "mermaid008.bas",826
	B T195
T191:
	;[827] 	GOTO all_right	
	SRCFILE "mermaid008.bas",827
	B Q132
	;[828] END IF
	SRCFILE "mermaid008.bas",828
T195:
	;[829] 
	SRCFILE "mermaid008.bas",829
	;[830] all_right:
	SRCFILE "mermaid008.bas",830
	; ALL_RIGHT
Q132:	;[831] 
	SRCFILE "mermaid008.bas",831
	;[832] Spritex(0) = Spritex(0) + mermaid_speed
	SRCFILE "mermaid008.bas",832
	MVI Q8,R0
	ADD V15,R0
	MVO R0,Q8
	;[833] Spritex(1) = Spritex(1) + mermaid_speed
	SRCFILE "mermaid008.bas",833
	MVI Q8+1,R0
	ADD V15,R0
	MVO R0,Q8+1
	;[834] Spritex(2) = Spritex(2) + mermaid_speed
	SRCFILE "mermaid008.bas",834
	MVI Q8+2,R0
	ADD V15,R0
	MVO R0,Q8+2
	;[835] if mermaidFacing=0 then mermaidFacing=1
	SRCFILE "mermaid008.bas",835
	MVI V11,R0
	TSTR R0
	BNE T196
	MVII #1,R0
	MVO R0,V11
T196:
	;[836] 
	SRCFILE "mermaid008.bas",836
	;[837] finish_mermaid_right:
	SRCFILE "mermaid008.bas",837
	; FINISH_MERMAID_RIGHT
Q139:	;[838] nextScreen = 0
	SRCFILE "mermaid008.bas",838
	CLRR R0
	MVO R0,V19
	;[839] 
	SRCFILE "mermaid008.bas",839
	;[840] END
	SRCFILE "mermaid008.bas",840
	RETURN
	ENDP
	;[841] 
	SRCFILE "mermaid008.bas",841
	;[842] mermaid_moveUp:    Procedure
	SRCFILE "mermaid008.bas",842
	; MERMAID_MOVEUP
Q41:	PROC
	BEGIN
	;[843] IF mermaidLocation = 0 THEN GOTO all_up 
	SRCFILE "mermaid008.bas",843
	MVI V18,R0
	TSTR R0
	BEQ Q143
	;[844] 
	SRCFILE "mermaid008.bas",844
	;[845] 'castle_up:
	SRCFILE "mermaid008.bas",845
	;[846] 'determine if castle room permits movement to the north 
	SRCFILE "mermaid008.bas",846
	;[847] ON castleLayout(mermaid_CastleLocation) GOTO ,room_north,room_north,,room_north,room_north,,,room_north,,,,room_north,room_north,room_north,,
	SRCFILE "mermaid008.bas",847
	MVII #Q11,R3
	ADD V52,R3
	MVI@ R3,R0
	CMPI #17,R0
	BC T199
	ADDI #T198,R0
	MOVR R0,R1
	MVI@ R1,PC
T198:
	DECLE T199
	DECLE Q144
	DECLE Q144
	DECLE T199
	DECLE Q144
	DECLE Q144
	DECLE T199
	DECLE T199
	DECLE Q144
	DECLE T199
	DECLE T199
	DECLE T199
	DECLE Q144
	DECLE Q144
	DECLE Q144
	DECLE T199
	DECLE T199
T199:
	;[848] 'if north wall is blocked, skip ahead to all_up
	SRCFILE "mermaid008.bas",848
	;[849] dir = 0
	SRCFILE "mermaid008.bas",849
	CLRR R0
	MVO R0,V69
	;[850] GOTO all_up
	SRCFILE "mermaid008.bas",850
	B Q143
	;[851] 
	SRCFILE "mermaid008.bas",851
	;[852] room_north:
	SRCFILE "mermaid008.bas",852
	; ROOM_NORTH
Q144:	;[853] 'determine if mermaid is properly aligned with opening
	SRCFILE "mermaid008.bas",853
	;[854] 'IF Spritex(0) > 70 and Spritex(0) < 90 and nextScreen > 0 and spriteY(0)<=14 THEN 
	SRCFILE "mermaid008.bas",854
	;[855] IF Spritex(0) > 70 and Spritex(0) < 90 and nextScreen > 0 and spriteY(0)<=16 THEN 
	SRCFILE "mermaid008.bas",855
	MVI Q8,R0
	CMPI #70,R0
	MVII #-1,R0
	BGT $+3
	INCR R0
	MVI Q8,R1
	CMPI #90,R1
	MVII #-1,R1
	BLT $+3
	INCR R1
	ANDR R1,R0
	MVI V19,R1
	CMPI #0,R1
	MVII #-1,R1
	BGT $+3
	INCR R1
	ANDR R1,R0
	MVI Q9,R1
	CMPI #16,R1
	MVII #-1,R1
	BLE $+3
	INCR R1
	ANDR R1,R0
	BEQ T200
	;[856] 	IF mermaid_castleLocationY > 1 THEN 
	SRCFILE "mermaid008.bas",856
	MVI V64,R0
	CMPI #1,R0
	BLE T201
	;[857] 		mermaid_castleLocationY = mermaid_castleLocationY - 1: mermaid_CastleLocation = mermaid_CastleLocation - 10
	SRCFILE "mermaid008.bas",857
	DECR R0
	MVO R0,V64
	MVI V52,R0
	SUBI #10,R0
	MVO R0,V52
	;[858] 		Spritey(0) = 80: Spritey(1) = 80: Spritey(2) = 80 : dir = 1
	SRCFILE "mermaid008.bas",858
	MVII #80,R0
	MVO R0,Q9
	MVO R0,Q9+1
	NOP
	MVO R0,Q9+2
	MVII #1,R0
	MVO R0,V69
	;[859] 		'display new scene
	SRCFILE "mermaid008.bas",859
	;[860] 		SCREEN castle_level: GOSUB display_castle_walls : GOSUB treasure_placement : GOSUB creature_placement : GOTO finish_mermaid_up
	SRCFILE "mermaid008.bas",860
	MVII #Q73,R3
	MVII #512,R2
	MVII #20,R1
	MVII #12,R0
	CALL CPYBLK
	CALL Q74
	CALL Q123
	CALL Q124
	B Q146
	;[861] 	ELSE
	SRCFILE "mermaid008.bas",861
	B T202
T201:
	;[862] 		'bumped into castle wall, play bump sound
	SRCFILE "mermaid008.bas",862
	;[863] 		if spriteY(0)<14 THEN dir = 2 : GOSUB thump_sound : GOTO finish_mermaid_up
	SRCFILE "mermaid008.bas",863
	MVI Q9,R0
	CMPI #14,R0
	BGE T203
	MVII #2,R0
	MVO R0,V69
	CALL Q84
	B Q146
T203:
	;[864] 	END IF
	SRCFILE "mermaid008.bas",864
T202:
	;[865] ELSE
	SRCFILE "mermaid008.bas",865
	B T204
T200:
	;[866] 	GOTO all_up
	SRCFILE "mermaid008.bas",866
	B Q143
	;[867] END IF
	SRCFILE "mermaid008.bas",867
T204:
	;[868] 
	SRCFILE "mermaid008.bas",868
	;[869] all_up:
	SRCFILE "mermaid008.bas",869
	; ALL_UP
Q143:	;[870] 'add code to advance to the next screen here
	SRCFILE "mermaid008.bas",870
	;[871] Spritey(0) = Spritey(0) - mermaid_speed
	SRCFILE "mermaid008.bas",871
	MVI Q9,R0
	SUB V15,R0
	MVO R0,Q9
	;[872] Spritey(1) = Spritey(1) - mermaid_speed
	SRCFILE "mermaid008.bas",872
	MVI Q9+1,R0
	SUB V15,R0
	MVO R0,Q9+1
	;[873] Spritey(2) = Spritey(2) - mermaid_speed
	SRCFILE "mermaid008.bas",873
	MVI Q9+2,R0
	SUB V15,R0
	MVO R0,Q9+2
	;[874] 
	SRCFILE "mermaid008.bas",874
	;[875] finish_mermaid_up:
	SRCFILE "mermaid008.bas",875
	; FINISH_MERMAID_UP
Q146:	;[876] nextScreen = 0 
	SRCFILE "mermaid008.bas",876
	CLRR R0
	MVO R0,V19
	;[877] END
	SRCFILE "mermaid008.bas",877
	RETURN
	ENDP
	;[878] 
	SRCFILE "mermaid008.bas",878
	;[879] mermaid_moveDown:   Procedure
	SRCFILE "mermaid008.bas",879
	; MERMAID_MOVEDOWN
Q42:	PROC
	BEGIN
	;[880] IF mermaidLocation = 0 THEN GOTO all_down
	SRCFILE "mermaid008.bas",880
	MVI V18,R0
	TSTR R0
	BEQ Q150
	;[881] 
	SRCFILE "mermaid008.bas",881
	;[882] 'castle_down:
	SRCFILE "mermaid008.bas",882
	;[883] 'determine if castle room permits movement to the south 
	SRCFILE "mermaid008.bas",883
	;[884] ON castleLayout(mermaid_CastleLocation) GOTO ,room_south,room_south,,,,room_south,room_south,,room_south,,,room_south,room_south,,room_south
	SRCFILE "mermaid008.bas",884
	MVII #Q11,R3
	ADD V52,R3
	MVI@ R3,R0
	CMPI #16,R0
	BC T207
	ADDI #T206,R0
	MOVR R0,R1
	MVI@ R1,PC
T206:
	DECLE T207
	DECLE Q151
	DECLE Q151
	DECLE T207
	DECLE T207
	DECLE T207
	DECLE Q151
	DECLE Q151
	DECLE T207
	DECLE Q151
	DECLE T207
	DECLE T207
	DECLE Q151
	DECLE Q151
	DECLE T207
	DECLE Q151
T207:
	;[885] 'if south wall is blocked, skip ahead to all_down
	SRCFILE "mermaid008.bas",885
	;[886] dir = 0
	SRCFILE "mermaid008.bas",886
	CLRR R0
	MVO R0,V69
	;[887] GOTO all_down
	SRCFILE "mermaid008.bas",887
	B Q150
	;[888] 
	SRCFILE "mermaid008.bas",888
	;[889] room_south:
	SRCFILE "mermaid008.bas",889
	; ROOM_SOUTH
Q151:	;[890] 'determine if mermaid is properly aligned with opening
	SRCFILE "mermaid008.bas",890
	;[891] 
	SRCFILE "mermaid008.bas",891
	;[892] IF Spritex(0) > 70 and Spritex(0) < 90 and nextScreen > 0 and spriteY(0)>=88 THEN 
	SRCFILE "mermaid008.bas",892
	MVI Q8,R0
	CMPI #70,R0
	MVII #-1,R0
	BGT $+3
	INCR R0
	MVI Q8,R1
	CMPI #90,R1
	MVII #-1,R1
	BLT $+3
	INCR R1
	ANDR R1,R0
	MVI V19,R1
	CMPI #0,R1
	MVII #-1,R1
	BGT $+3
	INCR R1
	ANDR R1,R0
	MVI Q9,R1
	CMPI #88,R1
	MVII #-1,R1
	BGE $+3
	INCR R1
	ANDR R1,R0
	BEQ T208
	;[893] 	IF mermaid_castleLocationY < 10 THEN 
	SRCFILE "mermaid008.bas",893
	MVI V64,R0
	CMPI #10,R0
	BGE T209
	;[894] 		mermaid_castleLocationY = mermaid_castleLocationY + 1: mermaid_CastleLocation = mermaid_CastleLocation + 10
	SRCFILE "mermaid008.bas",894
	INCR R0
	MVO R0,V64
	MVI V52,R0
	ADDI #10,R0
	MVO R0,V52
	;[895] 		Spritey(0) = 16 : Spritey(1) = 16 : Spritey(2) = 16 : dir = 1
	SRCFILE "mermaid008.bas",895
	MVII #16,R0
	MVO R0,Q9
	MVO R0,Q9+1
	NOP
	MVO R0,Q9+2
	MVII #1,R0
	MVO R0,V69
	;[896] 		'display new scene
	SRCFILE "mermaid008.bas",896
	;[897] 		SCREEN castle_level: GOSUB display_castle_walls : GOSUB treasure_placement : GOSUB creature_placement : GOTO finish_mermaid_down
	SRCFILE "mermaid008.bas",897
	MVII #Q73,R3
	MVII #512,R2
	MVII #20,R1
	MVII #12,R0
	CALL CPYBLK
	CALL Q74
	CALL Q123
	CALL Q124
	B Q153
	;[898] 	ELSE
	SRCFILE "mermaid008.bas",898
	B T210
T209:
	;[899] 		'bumped into castle wall, play bump sound
	SRCFILE "mermaid008.bas",899
	;[900] 		if spriteY(0)>88 THEN dir = 2 : GOSUB thump_sound : GOTO finish_mermaid_down
	SRCFILE "mermaid008.bas",900
	MVI Q9,R0
	CMPI #88,R0
	BLE T211
	MVII #2,R0
	MVO R0,V69
	CALL Q84
	B Q153
T211:
	;[901] 	END IF
	SRCFILE "mermaid008.bas",901
T210:
	;[902] ELSE
	SRCFILE "mermaid008.bas",902
	B T212
T208:
	;[903] 	GOTO all_down
	SRCFILE "mermaid008.bas",903
	B Q150
	;[904] END IF
	SRCFILE "mermaid008.bas",904
T212:
	;[905] 
	SRCFILE "mermaid008.bas",905
	;[906] all_down:
	SRCFILE "mermaid008.bas",906
	; ALL_DOWN
Q150:	;[907] 'add code to advance to the next screen here
	SRCFILE "mermaid008.bas",907
	;[908] Spritey(0) = Spritey(0) + mermaid_speed
	SRCFILE "mermaid008.bas",908
	MVI Q9,R0
	ADD V15,R0
	MVO R0,Q9
	;[909] Spritey(1) = Spritey(1) + mermaid_speed
	SRCFILE "mermaid008.bas",909
	MVI Q9+1,R0
	ADD V15,R0
	MVO R0,Q9+1
	;[910] Spritey(2) = Spritey(2) + mermaid_speed
	SRCFILE "mermaid008.bas",910
	MVI Q9+2,R0
	ADD V15,R0
	MVO R0,Q9+2
	;[911] 
	SRCFILE "mermaid008.bas",911
	;[912] finish_mermaid_down:
	SRCFILE "mermaid008.bas",912
	; FINISH_MERMAID_DOWN
Q153:	;[913] nextScreen = 0
	SRCFILE "mermaid008.bas",913
	CLRR R0
	MVO R0,V19
	;[914] END
	SRCFILE "mermaid008.bas",914
	RETURN
	ENDP
	;[915] 
	SRCFILE "mermaid008.bas",915
	;[916] treasure_placement:   Procedure
	SRCFILE "mermaid008.bas",916
	; TREASURE_PLACEMENT
Q123:	PROC
	BEGIN
	;[917] 'determine if treasure exists on this screen, if so what type(s)?
	SRCFILE "mermaid008.bas",917
	;[918] 'if 1, place a gold bar and a silver coin
	SRCFILE "mermaid008.bas",918
	;[919] 'if 2 or 3, place a gold bar
	SRCFILE "mermaid008.bas",919
	;[920] 'if 10 through 12, place a silver coin
	SRCFILE "mermaid008.bas",920
	;[921] 'if 4 through 9, no treasure
	SRCFILE "mermaid008.bas",921
	;[922] inventory_gold = 0
	SRCFILE "mermaid008.bas",922
	CLRR R0
	MVO R0,V22
	;[923] inventory_silver = 0
	SRCFILE "mermaid008.bas",923
	MVO R0,V23
	;[924] gold_position = 0
	SRCFILE "mermaid008.bas",924
	NOP
	MVO R0,V26
	;[925] silver_position = 0
	SRCFILE "mermaid008.bas",925
	MVO R0,V27
	;[926] treasure = RANDOM(12)+1
	SRCFILE "mermaid008.bas",926
	MVII #12,R1
	CALL _next_random
	CALL qs_mpy8
	SWAP R0
	ANDI #255,R0
	INCR R0
	MVO R0,V28
	;[927] IF treasure = 1 THEN gold_position = RANDOM(18)+2:silver_position = RANDOM(18)+2
	SRCFILE "mermaid008.bas",927
	MVI V28,R0
	CMPI #1,R0
	BNE T213
	MVII #18,R1
	CALL _next_random
	CALL qs_mpy8
	SWAP R0
	ANDI #255,R0
	ADDI #2,R0
	MVO R0,V26
	MVII #18,R1
	CALL _next_random
	CALL qs_mpy8
	SWAP R0
	ANDI #255,R0
	ADDI #2,R0
	MVO R0,V27
T213:
	;[928] IF gold_position > 0 AND gold_position=silver_position THEN IF gold_position < 18 THEN silver_position = gold_position+1 ELSE silver_position = gold_position-1
	SRCFILE "mermaid008.bas",928
	MVI V26,R0
	CMPI #0,R0
	MVII #-1,R0
	BGT $+3
	INCR R0
	MVI V26,R1
	CMP V27,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	ANDR R1,R0
	BEQ T214
	MVI V26,R0
	CMPI #18,R0
	BGE T215
	INCR R0
	MVO R0,V27
	B T216
T215:
	MVI V26,R0
	DECR R0
	MVO R0,V27
T216:
T214:
	;[929] IF treasure > 1 AND treasure < 4 THEN gold_position = RANDOM(18)+2
	SRCFILE "mermaid008.bas",929
	MVI V28,R0
	CMPI #1,R0
	MVII #-1,R0
	BGT $+3
	INCR R0
	MVI V28,R1
	CMPI #4,R1
	MVII #-1,R1
	BLT $+3
	INCR R1
	ANDR R1,R0
	BEQ T217
	MVII #18,R1
	CALL _next_random
	CALL qs_mpy8
	SWAP R0
	ANDI #255,R0
	ADDI #2,R0
	MVO R0,V26
T217:
	;[930] IF treasure > 9 THEN silver_position = RANDOM(18)+2
	SRCFILE "mermaid008.bas",930
	MVI V28,R0
	CMPI #9,R0
	BLE T218
	MVII #18,R1
	CALL _next_random
	CALL qs_mpy8
	SWAP R0
	ANDI #255,R0
	ADDI #2,R0
	MVO R0,V27
T218:
	;[931] END
	SRCFILE "mermaid008.bas",931
	RETURN
	ENDP
	;[932] 
	SRCFILE "mermaid008.bas",932
	;[933] creature_placement:   Procedure
	SRCFILE "mermaid008.bas",933
	; CREATURE_PLACEMENT
Q124:	PROC
	BEGIN
	;[934] 'determine if creature(s) exist on this screen, if so what type(s)?
	SRCFILE "mermaid008.bas",934
	;[935] 'if 1, place the shark
	SRCFILE "mermaid008.bas",935
	;[936] 'if 2, place an octopus
	SRCFILE "mermaid008.bas",936
	;[937] 'if 3, place a squid
	SRCFILE "mermaid008.bas",937
	;[938] 'if 4 through 6, place fish
	SRCFILE "mermaid008.bas",938
	;[939] 'if 7 through 12, no creatures
	SRCFILE "mermaid008.bas",939
	;[940] 
	SRCFILE "mermaid008.bas",940
	;[941] spawnPoint = RANDOM(6)+1
	SRCFILE "mermaid008.bas",941
	MVII #6,R1
	CALL _next_random
	CALL qs_mpy8
	SWAP R0
	ANDI #255,R0
	INCR R0
	MVO R0,V66
	;[942] creature = RANDOM(12)+1
	SRCFILE "mermaid008.bas",942
	MVII #12,R1
	CALL _next_random
	CALL qs_mpy8
	SWAP R0
	ANDI #255,R0
	INCR R0
	MVO R0,V31
	;[943] 'hide sprites if creature random value between 7 and 12
	SRCFILE "mermaid008.bas",943
	;[944] IF creature>6 THEN resetsprite(3):resetsprite(4):GOTO finish_creature_placement
	SRCFILE "mermaid008.bas",944
	MVI V31,R0
	CMPI #6,R0
	BLE T219
	CLRR R0
	MVO R0,_mobs+3
	MVO R0,_mobs+11
	NOP
	MVO R0,_mobs+19
	MVO R0,_mobs+4
	NOP
	MVO R0,_mobs+12
	MVO R0,_mobs+20
	B Q158
T219:
	;[945] 'hide sprite 4 if creature is squid or fish
	SRCFILE "mermaid008.bas",945
	;[946] IF creature>1 THEN resetsprite(4)
	SRCFILE "mermaid008.bas",946
	MVI V31,R0
	CMPI #1,R0
	BLE T220
	CLRR R0
	MVO R0,_mobs+4
	MVO R0,_mobs+12
	NOP
	MVO R0,_mobs+20
T220:
	;[947] 'randomize creature speed from 2 to 4 pixels/frame
	SRCFILE "mermaid008.bas",947
	;[948] creature1_Speed = RANDOM(3)+2
	SRCFILE "mermaid008.bas",948
	MVII #3,R1
	CALL _next_random
	CALL qs_mpy8
	SWAP R0
	ANDI #255,R0
	ADDI #2,R0
	MVO R0,V35
	;[949] creature1_UpDown_Speed = RANDOM(2)+2
	SRCFILE "mermaid008.bas",949
	CALL _next_random
	ANDI #1,R0
	ADDI #2,R0
	MVO R0,V68
	;[950] creature1_UpDown = RANDOM(2)
	SRCFILE "mermaid008.bas",950
	CALL _next_random
	ANDI #1,R0
	MVO R0,V67
	;[951] IF spawnPoint = 1 THEN Spritex(3)=40:Spritey(3)=25:creature1_Facing=1:IF creature<3 THEN Spritex(4)=Spritex(3)+8
	SRCFILE "mermaid008.bas",951
	MVI V66,R0
	CMPI #1,R0
	BNE T221
	MVII #40,R0
	MVO R0,Q8+3
	MVII #25,R0
	MVO R0,Q9+3
	MVII #1,R0
	MVO R0,V32
	MVI V31,R0
	CMPI #3,R0
	BGE T222
	MVI Q8+3,R0
	ADDI #8,R0
	MVO R0,Q8+4
T222:
T221:
	;[952] IF spawnPoint = 2 THEN Spritex(3)=40:Spritey(3)=50:creature1_Facing=1:IF creature<3 THEN Spritex(4)=Spritex(3)+8
	SRCFILE "mermaid008.bas",952
	MVI V66,R0
	CMPI #2,R0
	BNE T223
	MVII #40,R0
	MVO R0,Q8+3
	MVII #50,R0
	MVO R0,Q9+3
	MVII #1,R0
	MVO R0,V32
	MVI V31,R0
	CMPI #3,R0
	BGE T224
	MVI Q8+3,R0
	ADDI #8,R0
	MVO R0,Q8+4
T224:
T223:
	;[953] IF spawnPoint = 3 THEN Spritex(3)=40:Spritey(3)=75:creature1_Facing=1:IF creature<3 THEN Spritex(4)=Spritex(3)+8
	SRCFILE "mermaid008.bas",953
	MVI V66,R0
	CMPI #3,R0
	BNE T225
	MVII #40,R0
	MVO R0,Q8+3
	MVII #75,R0
	MVO R0,Q9+3
	MVII #1,R0
	MVO R0,V32
	MVI V31,R0
	CMPI #3,R0
	BGE T226
	MVI Q8+3,R0
	ADDI #8,R0
	MVO R0,Q8+4
T226:
T225:
	;[954] IF spawnPoint = 4 THEN Spritex(3)=120:Spritey(3)=25:creature1_Facing=0:IF creature<3 THEN Spritex(4)=Spritex(3)-8
	SRCFILE "mermaid008.bas",954
	MVI V66,R0
	CMPI #4,R0
	BNE T227
	MVII #120,R0
	MVO R0,Q8+3
	MVII #25,R0
	MVO R0,Q9+3
	CLRR R0
	MVO R0,V32
	MVI V31,R0
	CMPI #3,R0
	BGE T228
	MVI Q8+3,R0
	SUBI #8,R0
	MVO R0,Q8+4
T228:
T227:
	;[955] IF spawnPoint = 5 THEN Spritex(3)=120:Spritey(3)=50:creature1_Facing=0:IF creature<3 THEN Spritex(4)=Spritex(3)-8
	SRCFILE "mermaid008.bas",955
	MVI V66,R0
	CMPI #5,R0
	BNE T229
	MVII #120,R0
	MVO R0,Q8+3
	MVII #50,R0
	MVO R0,Q9+3
	CLRR R0
	MVO R0,V32
	MVI V31,R0
	CMPI #3,R0
	BGE T230
	MVI Q8+3,R0
	SUBI #8,R0
	MVO R0,Q8+4
T230:
T229:
	;[956] IF spawnPoint = 6 THEN Spritex(3)=120:Spritey(3)=75:creature1_Facing=0:IF creature<3 THEN Spritex(4)=Spritex(3)-8
	SRCFILE "mermaid008.bas",956
	MVI V66,R0
	CMPI #6,R0
	BNE T231
	MVII #120,R0
	MVO R0,Q8+3
	MVII #75,R0
	MVO R0,Q9+3
	CLRR R0
	MVO R0,V32
	MVI V31,R0
	CMPI #3,R0
	BGE T232
	MVI Q8+3,R0
	SUBI #8,R0
	MVO R0,Q8+4
T232:
T231:
	;[957] Spritey(4)=Spritey(3)
	SRCFILE "mermaid008.bas",957
	MVI Q9+3,R0
	MVO R0,Q9+4
	;[958] 
	SRCFILE "mermaid008.bas",958
	;[959] IF creature = 1 THEN #SpriteC(3)=SPR_GREY:#SpriteC(4)=SPR_GREY:GOTO finish_creature_placement
	SRCFILE "mermaid008.bas",959
	MVI V31,R0
	CMPI #1,R0
	BNE T233
	MVII #4096,R0
	MVO R0,Q10+3
	MVO R0,Q10+4
	B Q158
T233:
	;[960] IF creature = 2 THEN #SpriteC(3)=SPR_PURPLE:GOTO finish_creature_placement
	SRCFILE "mermaid008.bas",960
	MVI V31,R0
	CMPI #2,R0
	BNE T234
	MVII #4103,R0
	MVO R0,Q10+3
	B Q158
T234:
	;[961] IF creature = 3 THEN #SpriteC(3)=SPR_WHITE:GOTO finish_creature_placement
	SRCFILE "mermaid008.bas",961
	MVI V31,R0
	CMPI #3,R0
	BNE T235
	MVII #7,R0
	MVO R0,Q10+3
	B Q158
T235:
	;[962] IF creature >= 4 AND creature <= 6 THEN 
	SRCFILE "mermaid008.bas",962
	MVI V31,R0
	CMPI #4,R0
	MVII #-1,R0
	BGE $+3
	INCR R0
	MVI V31,R1
	CMPI #6,R1
	MVII #-1,R1
	BLE $+3
	INCR R1
	ANDR R1,R0
	BEQ T236
	;[963] 	'random color for fish
	SRCFILE "mermaid008.bas",963
	;[964] 	IF spawnPoint = 1 THEN #SpriteC(3)=SPR_DARKGREEN
	SRCFILE "mermaid008.bas",964
	MVI V66,R0
	CMPI #1,R0
	BNE T237
	MVII #4,R0
	MVO R0,Q10+3
T237:
	;[965] 	IF spawnPoint = 2 THEN #SpriteC(3)=SPR_YELLOWGREEN
	SRCFILE "mermaid008.bas",965
	MVI V66,R0
	CMPI #2,R0
	BNE T238
	MVII #4102,R0
	MVO R0,Q10+3
T238:
	;[966] 	IF spawnPoint = 3 THEN #SpriteC(3)=SPR_LIGHTBLUE	
	SRCFILE "mermaid008.bas",966
	MVI V66,R0
	CMPI #3,R0
	BNE T239
	MVII #4101,R0
	MVO R0,Q10+3
T239:
	;[967] 	IF spawnPoint = 4 THEN #SpriteC(3)=SPR_PINK	
	SRCFILE "mermaid008.bas",967
	MVI V66,R0
	CMPI #4,R0
	BNE T240
	MVII #4100,R0
	MVO R0,Q10+3
T240:
	;[968] 	IF spawnPoint = 5 THEN #SpriteC(3)=SPR_ORANGE
	SRCFILE "mermaid008.bas",968
	MVI V66,R0
	CMPI #5,R0
	BNE T241
	MVII #4098,R0
	MVO R0,Q10+3
T241:
	;[969] 	IF spawnPoint = 6 THEN #SpriteC(3)=SPR_YELLOW
	SRCFILE "mermaid008.bas",969
	MVI V66,R0
	CMPI #6,R0
	BNE T242
	MVII #6,R0
	MVO R0,Q10+3
T242:
	;[970] END IF 	
	SRCFILE "mermaid008.bas",970
T236:
	;[971] finish_creature_placement:
	SRCFILE "mermaid008.bas",971
	; FINISH_CREATURE_PLACEMENT
Q158:	;[972] 
	SRCFILE "mermaid008.bas",972
	;[973] END
	SRCFILE "mermaid008.bas",973
	RETURN
	ENDP
	;[974] 
	SRCFILE "mermaid008.bas",974
	;[975] display_creature:   Procedure
	SRCFILE "mermaid008.bas",975
	; DISPLAY_CREATURE
Q35:	PROC
	BEGIN
	;[976] 
	SRCFILE "mermaid008.bas",976
	;[977] ON creature GOTO finish_display_creature,display_shark,display_octopus,display_squid,display_fish1,display_fish2,display_fish3,,,,,,
	SRCFILE "mermaid008.bas",977
	MVI V31,R0
	CMPI #13,R0
	BC T244
	ADDI #T243,R0
	MOVR R0,R1
	MVI@ R1,PC
T243:
	DECLE Q161
	DECLE Q162
	DECLE Q163
	DECLE Q164
	DECLE Q165
	DECLE Q166
	DECLE Q167
	DECLE T244
	DECLE T244
	DECLE T244
	DECLE T244
	DECLE T244
	DECLE T244
T244:
	;[978] 'skip display creature code if creature>6
	SRCFILE "mermaid008.bas",978
	;[979] GOTO finish_display_creature
	SRCFILE "mermaid008.bas",979
	B Q161
	;[980] 
	SRCFILE "mermaid008.bas",980
	;[981] display_shark:
	SRCFILE "mermaid008.bas",981
	; DISPLAY_SHARK
Q162:	;[982] IF creature1_Facing=0 THEN 
	SRCFILE "mermaid008.bas",982
	MVI V32,R0
	TSTR R0
	BNE T245
	;[983] 	''Sprite 3,Spritex(3)+VISIBLE+ZOOMX2,Spritey(3)+ZOOMY2, SPR45+ (8*creature1_frame) +#SpriteC(3)
	SRCFILE "mermaid008.bas",983
	;[984] 	Sprite 3,Spritex(3)+VISIBLE+HIT+ZOOMX2,Spritey(3)+ZOOMY2, SPR45+ (8*creature1_frame) +#SpriteC(3)
	SRCFILE "mermaid008.bas",984
	MVI Q8+3,R0
	ADDI #1792,R0
	MVO R0,_mobs+3
	MVI Q9+3,R0
	ADDI #256,R0
	MVO R0,_mobs+11
	MVI V33,R0
	SLL R0,2
	ADDR R0,R0
	ADDI #2408,R0
	MVI Q10+3,R1
	ADDR R1,R0
	MVO R0,_mobs+19
	;[985] 	Sprite 4,Spritex(4)+VISIBLE+ZOOMX2,Spritey(4)+ZOOMY2, SPR47+ (8*creature1_frame) +#SpriteC(4)
	SRCFILE "mermaid008.bas",985
	MVI Q8+4,R0
	ADDI #1536,R0
	MVO R0,_mobs+4
	MVI Q9+4,R0
	ADDI #256,R0
	MVO R0,_mobs+12
	MVI V33,R0
	SLL R0,2
	ADDR R0,R0
	ADDI #2424,R0
	MVI Q10+4,R1
	ADDR R1,R0
	MVO R0,_mobs+20
	;[986] ELSE	
	SRCFILE "mermaid008.bas",986
	B T246
T245:
	;[987] 	''Sprite 3,Spritex(3)+VISIBLE+ZOOMX2,Spritey(3)+ZOOMY2+FLIPX, SPR45+ (8*creature1_frame) +#SpriteC(3)
	SRCFILE "mermaid008.bas",987
	;[988] 	Sprite 3,Spritex(3)+VISIBLE+HIT+ZOOMX2,Spritey(3)+ZOOMY2+FLIPX, SPR45+ (8*creature1_frame) +#SpriteC(3)
	SRCFILE "mermaid008.bas",988
	MVI Q8+3,R0
	ADDI #1792,R0
	MVO R0,_mobs+3
	MVI Q9+3,R0
	ADDI #1280,R0
	MVO R0,_mobs+11
	MVI V33,R0
	SLL R0,2
	ADDR R0,R0
	ADDI #2408,R0
	MVI Q10+3,R1
	ADDR R1,R0
	MVO R0,_mobs+19
	;[989] 	Sprite 4,Spritex(4)+VISIBLE+ZOOMX2,Spritey(4)+ZOOMY2+FLIPX, SPR47+ (8*creature1_frame) +#SpriteC(4)
	SRCFILE "mermaid008.bas",989
	MVI Q8+4,R0
	ADDI #1536,R0
	MVO R0,_mobs+4
	MVI Q9+4,R0
	ADDI #1280,R0
	MVO R0,_mobs+12
	MVI V33,R0
	SLL R0,2
	ADDR R0,R0
	ADDI #2424,R0
	MVI Q10+4,R1
	ADDR R1,R0
	MVO R0,_mobs+20
	;[990] END IF
	SRCFILE "mermaid008.bas",990
T246:
	;[991] GOTO finish_display_creature
	SRCFILE "mermaid008.bas",991
	B Q161
	;[992] 
	SRCFILE "mermaid008.bas",992
	;[993] display_octopus:
	SRCFILE "mermaid008.bas",993
	; DISPLAY_OCTOPUS
Q163:	;[994] IF creature1_Facing=0 THEN 
	SRCFILE "mermaid008.bas",994
	MVI V32,R0
	TSTR R0
	BNE T247
	;[995] 	''Sprite 3,Spritex(3)+VISIBLE+ZOOMX2,Spritey(3)+ZOOMY2, SPR49+ (8*creature1_frame) +#SpriteC(3)
	SRCFILE "mermaid008.bas",995
	;[996] 	Sprite 3,Spritex(3)+VISIBLE+HIT+ZOOMX2,Spritey(3)+ZOOMY2, SPR49+ (8*creature1_frame) +#SpriteC(3)
	SRCFILE "mermaid008.bas",996
	MVI Q8+3,R0
	ADDI #1792,R0
	MVO R0,_mobs+3
	MVI Q9+3,R0
	ADDI #256,R0
	MVO R0,_mobs+11
	MVI V33,R0
	SLL R0,2
	ADDR R0,R0
	ADDI #2440,R0
	MVI Q10+3,R1
	ADDR R1,R0
	MVO R0,_mobs+19
	;[997] ELSE	
	SRCFILE "mermaid008.bas",997
	B T248
T247:
	;[998] 	''Sprite 3,Spritex(3)+VISIBLE+ZOOMX2,Spritey(3)+ZOOMY2+FLIPX, SPR49+ (8*creature1_frame) +#SpriteC(3)
	SRCFILE "mermaid008.bas",998
	;[999] 	Sprite 3,Spritex(3)+VISIBLE+HIT+ZOOMX2,Spritey(3)+ZOOMY2+FLIPX, SPR49+ (8*creature1_frame) +#SpriteC(3)
	SRCFILE "mermaid008.bas",999
	MVI Q8+3,R0
	ADDI #1792,R0
	MVO R0,_mobs+3
	MVI Q9+3,R0
	ADDI #1280,R0
	MVO R0,_mobs+11
	MVI V33,R0
	SLL R0,2
	ADDR R0,R0
	ADDI #2440,R0
	MVI Q10+3,R1
	ADDR R1,R0
	MVO R0,_mobs+19
	;[1000] END IF
	SRCFILE "mermaid008.bas",1000
T248:
	;[1001] GOTO finish_display_creature
	SRCFILE "mermaid008.bas",1001
	B Q161
	;[1002] 
	SRCFILE "mermaid008.bas",1002
	;[1003] display_squid:
	SRCFILE "mermaid008.bas",1003
	; DISPLAY_SQUID
Q164:	;[1004] IF creature1_Facing=0 THEN 
	SRCFILE "mermaid008.bas",1004
	MVI V32,R0
	TSTR R0
	BNE T249
	;[1005] 	''Sprite 3,Spritex(3)+VISIBLE+ZOOMX2,Spritey(3)+ZOOMY2, SPR41+ (8*creature1_frame) +#SpriteC(3)
	SRCFILE "mermaid008.bas",1005
	;[1006] 	Sprite 3,Spritex(3)+VISIBLE+HIT+ZOOMX2,Spritey(3)+ZOOMY2, SPR41+ (8*creature1_frame) +#SpriteC(3)
	SRCFILE "mermaid008.bas",1006
	MVI Q8+3,R0
	ADDI #1792,R0
	MVO R0,_mobs+3
	MVI Q9+3,R0
	ADDI #256,R0
	MVO R0,_mobs+11
	MVI V33,R0
	SLL R0,2
	ADDR R0,R0
	ADDI #2376,R0
	MVI Q10+3,R1
	ADDR R1,R0
	MVO R0,_mobs+19
	;[1007] ELSE	
	SRCFILE "mermaid008.bas",1007
	B T250
T249:
	;[1008] 	''Sprite 3,Spritex(3)+VISIBLE+ZOOMX2,Spritey(3)+ZOOMY2+FLIPX, SPR41+ (8*creature1_frame) +#SpriteC(3)
	SRCFILE "mermaid008.bas",1008
	;[1009] 	Sprite 3,Spritex(3)+VISIBLE+HIT+ZOOMX2,Spritey(3)+ZOOMY2+FLIPX, SPR41+ (8*creature1_frame) +#SpriteC(3)
	SRCFILE "mermaid008.bas",1009
	MVI Q8+3,R0
	ADDI #1792,R0
	MVO R0,_mobs+3
	MVI Q9+3,R0
	ADDI #1280,R0
	MVO R0,_mobs+11
	MVI V33,R0
	SLL R0,2
	ADDR R0,R0
	ADDI #2376,R0
	MVI Q10+3,R1
	ADDR R1,R0
	MVO R0,_mobs+19
	;[1010] END IF
	SRCFILE "mermaid008.bas",1010
T250:
	;[1011] GOTO finish_display_creature
	SRCFILE "mermaid008.bas",1011
	B Q161
	;[1012] 
	SRCFILE "mermaid008.bas",1012
	;[1013] display_fish1:
	SRCFILE "mermaid008.bas",1013
	; DISPLAY_FISH1
Q165:	;[1014] IF creature1_Facing=0 THEN 
	SRCFILE "mermaid008.bas",1014
	MVI V32,R0
	TSTR R0
	BNE T251
	;[1015] 	''Sprite 3,Spritex(3)+VISIBLE+ZOOMX2,Spritey(3)+ZOOMY2, SPR43+ (8*creature1_frame) +#SpriteC(3)
	SRCFILE "mermaid008.bas",1015
	;[1016] 	Sprite 3,Spritex(3)+VISIBLE+HIT+ZOOMX2,Spritey(3)+ZOOMY2, SPR43+ (8*creature1_frame) +#SpriteC(3)
	SRCFILE "mermaid008.bas",1016
	MVI Q8+3,R0
	ADDI #1792,R0
	MVO R0,_mobs+3
	MVI Q9+3,R0
	ADDI #256,R0
	MVO R0,_mobs+11
	MVI V33,R0
	SLL R0,2
	ADDR R0,R0
	ADDI #2392,R0
	MVI Q10+3,R1
	ADDR R1,R0
	MVO R0,_mobs+19
	;[1017] ELSE	
	SRCFILE "mermaid008.bas",1017
	B T252
T251:
	;[1018] 	''Sprite 3,Spritex(3)+VISIBLE+ZOOMX2,Spritey(3)+ZOOMY2+FLIPX, SPR43+ (8*creature1_frame) +#SpriteC(3)
	SRCFILE "mermaid008.bas",1018
	;[1019] 	Sprite 3,Spritex(3)+VISIBLE+HIT+ZOOMX2,Spritey(3)+ZOOMY2+FLIPX, SPR43+ (8*creature1_frame) +#SpriteC(3)
	SRCFILE "mermaid008.bas",1019
	MVI Q8+3,R0
	ADDI #1792,R0
	MVO R0,_mobs+3
	MVI Q9+3,R0
	ADDI #1280,R0
	MVO R0,_mobs+11
	MVI V33,R0
	SLL R0,2
	ADDR R0,R0
	ADDI #2392,R0
	MVI Q10+3,R1
	ADDR R1,R0
	MVO R0,_mobs+19
	;[1020] END IF
	SRCFILE "mermaid008.bas",1020
T252:
	;[1021] GOTO finish_display_creature
	SRCFILE "mermaid008.bas",1021
	B Q161
	;[1022] 
	SRCFILE "mermaid008.bas",1022
	;[1023] display_fish2:
	SRCFILE "mermaid008.bas",1023
	; DISPLAY_FISH2
Q166:	;[1024] IF creature1_Facing=0 THEN 
	SRCFILE "mermaid008.bas",1024
	MVI V32,R0
	TSTR R0
	BNE T253
	;[1025] 	''Sprite 3,Spritex(3)+VISIBLE+ZOOMX2,Spritey(3)+ZOOMY2, SPR53+ (8*creature1_frame) +#SpriteC(3)
	SRCFILE "mermaid008.bas",1025
	;[1026] 	Sprite 3,Spritex(3)+VISIBLE+HIT+ZOOMX2,Spritey(3)+ZOOMY2, SPR53+ (8*creature1_frame) +#SpriteC(3)
	SRCFILE "mermaid008.bas",1026
	MVI Q8+3,R0
	ADDI #1792,R0
	MVO R0,_mobs+3
	MVI Q9+3,R0
	ADDI #256,R0
	MVO R0,_mobs+11
	MVI V33,R0
	SLL R0,2
	ADDR R0,R0
	ADDI #2472,R0
	MVI Q10+3,R1
	ADDR R1,R0
	MVO R0,_mobs+19
	;[1027] ELSE	
	SRCFILE "mermaid008.bas",1027
	B T254
T253:
	;[1028] 	''Sprite 3,Spritex(3)+VISIBLE+ZOOMX2,Spritey(3)+ZOOMY2+FLIPX, SPR53+ (8*creature1_frame) +#SpriteC(3)
	SRCFILE "mermaid008.bas",1028
	;[1029] 	Sprite 3,Spritex(3)+VISIBLE+HIT+ZOOMX2,Spritey(3)+ZOOMY2+FLIPX, SPR53+ (8*creature1_frame) +#SpriteC(3)
	SRCFILE "mermaid008.bas",1029
	MVI Q8+3,R0
	ADDI #1792,R0
	MVO R0,_mobs+3
	MVI Q9+3,R0
	ADDI #1280,R0
	MVO R0,_mobs+11
	MVI V33,R0
	SLL R0,2
	ADDR R0,R0
	ADDI #2472,R0
	MVI Q10+3,R1
	ADDR R1,R0
	MVO R0,_mobs+19
	;[1030] END IF
	SRCFILE "mermaid008.bas",1030
T254:
	;[1031] GOTO finish_display_creature
	SRCFILE "mermaid008.bas",1031
	B Q161
	;[1032] 
	SRCFILE "mermaid008.bas",1032
	;[1033] display_fish3:
	SRCFILE "mermaid008.bas",1033
	; DISPLAY_FISH3
Q167:	;[1034] IF creature1_Facing=0 THEN 
	SRCFILE "mermaid008.bas",1034
	MVI V32,R0
	TSTR R0
	BNE T255
	;[1035] 	''Sprite 3,Spritex(3)+VISIBLE+ZOOMX2,Spritey(3)+ZOOMY2, SPR55+ (8*creature1_frame) +#SpriteC(3)
	SRCFILE "mermaid008.bas",1035
	;[1036] 	Sprite 3,Spritex(3)+VISIBLE+HIT+ZOOMX2,Spritey(3)+ZOOMY2, SPR55+ (8*creature1_frame) +#SpriteC(3)
	SRCFILE "mermaid008.bas",1036
	MVI Q8+3,R0
	ADDI #1792,R0
	MVO R0,_mobs+3
	MVI Q9+3,R0
	ADDI #256,R0
	MVO R0,_mobs+11
	MVI V33,R0
	SLL R0,2
	ADDR R0,R0
	ADDI #2488,R0
	MVI Q10+3,R1
	ADDR R1,R0
	MVO R0,_mobs+19
	;[1037] ELSE	
	SRCFILE "mermaid008.bas",1037
	B T256
T255:
	;[1038] 	''Sprite 3,Spritex(3)+VISIBLE+ZOOMX2,Spritey(3)+ZOOMY2+FLIPX, SPR55+ (8*creature1_frame) +#SpriteC(3)
	SRCFILE "mermaid008.bas",1038
	;[1039] 	Sprite 3,Spritex(3)+VISIBLE+HIT+ZOOMX2,Spritey(3)+ZOOMY2+FLIPX, SPR55+ (8*creature1_frame) +#SpriteC(3)
	SRCFILE "mermaid008.bas",1039
	MVI Q8+3,R0
	ADDI #1792,R0
	MVO R0,_mobs+3
	MVI Q9+3,R0
	ADDI #1280,R0
	MVO R0,_mobs+11
	MVI V33,R0
	SLL R0,2
	ADDR R0,R0
	ADDI #2488,R0
	MVI Q10+3,R1
	ADDR R1,R0
	MVO R0,_mobs+19
	;[1040] END IF
	SRCFILE "mermaid008.bas",1040
T256:
	;[1041] GOTO finish_display_creature
	SRCFILE "mermaid008.bas",1041
	B Q161
	;[1042] 
	SRCFILE "mermaid008.bas",1042
	;[1043] finish_display_creature:
	SRCFILE "mermaid008.bas",1043
	; FINISH_DISPLAY_CREATURE
Q161:	;[1044] 
	SRCFILE "mermaid008.bas",1044
	;[1045] wait
	SRCFILE "mermaid008.bas",1045
	CALL _wait
	;[1046] END
	SRCFILE "mermaid008.bas",1046
	RETURN
	ENDP
	;[1047] 
	SRCFILE "mermaid008.bas",1047
	;[1048] moveCreature:   Procedure
	SRCFILE "mermaid008.bas",1048
	; MOVECREATURE
Q34:	PROC
	BEGIN
	;[1049] REM redirect creature when they reach the screen border
	SRCFILE "mermaid008.bas",1049
	;[1050] IF creature1_Facing = 0 THEN 
	SRCFILE "mermaid008.bas",1050
	MVI V32,R0
	TSTR R0
	BNE T257
	;[1051] 	spriteX(3)=spriteX(3)-creature1_Speed
	SRCFILE "mermaid008.bas",1051
	MVI Q8+3,R0
	SUB V35,R0
	MVO R0,Q8+3
	;[1052] 	spriteX(4)=spriteX(3)+16
	SRCFILE "mermaid008.bas",1052
	MVI Q8+3,R0
	ADDI #16,R0
	MVO R0,Q8+4
	;[1053] 	''IF spriteX(3)<=0 THEN creature1_Facing=1:creature1_Speed = RANDOM(3)+2:GOTO finish_moveCreature
	SRCFILE "mermaid008.bas",1053
	;[1054] 	IF spriteX(3)<=4 THEN creature1_Facing=1:creature1_Speed = RANDOM(3)+2:GOTO finish_moveCreature
	SRCFILE "mermaid008.bas",1054
	MVI Q8+3,R0
	CMPI #4,R0
	BGT T258
	MVII #1,R0
	MVO R0,V32
	MVII #3,R1
	CALL _next_random
	CALL qs_mpy8
	SWAP R0
	ANDI #255,R0
	ADDI #2,R0
	MVO R0,V35
	B Q176
T258:
	;[1055] END IF
	SRCFILE "mermaid008.bas",1055
T257:
	;[1056] 
	SRCFILE "mermaid008.bas",1056
	;[1057] IF creature1_Facing = 1 THEN 
	SRCFILE "mermaid008.bas",1057
	MVI V32,R0
	CMPI #1,R0
	BNE T259
	;[1058] 	spriteX(3)=spriteX(3)+creature1_Speed
	SRCFILE "mermaid008.bas",1058
	MVI Q8+3,R0
	ADD V35,R0
	MVO R0,Q8+3
	;[1059] 	spriteX(4)=spriteX(3)-16
	SRCFILE "mermaid008.bas",1059
	MVI Q8+3,R0
	SUBI #16,R0
	MVO R0,Q8+4
	;[1060] 	''IF spriteX(3)>=160 THEN creature1_Facing=0:creature1_Speed = RANDOM(3)+2:GOTO finish_moveCreature
	SRCFILE "mermaid008.bas",1060
	;[1061] 	IF spriteX(3)>=156 THEN creature1_Facing=0:creature1_Speed = RANDOM(3)+2:GOTO finish_moveCreature
	SRCFILE "mermaid008.bas",1061
	MVI Q8+3,R0
	CMPI #156,R0
	BLT T260
	CLRR R0
	MVO R0,V32
	MVII #3,R1
	CALL _next_random
	CALL qs_mpy8
	SWAP R0
	ANDI #255,R0
	ADDI #2,R0
	MVO R0,V35
	B Q176
T260:
	;[1062] END IF
	SRCFILE "mermaid008.bas",1062
T259:
	;[1063] 
	SRCFILE "mermaid008.bas",1063
	;[1064] 'only adjust up/down movement if creature-speed > 2  otherwise lateral movement only
	SRCFILE "mermaid008.bas",1064
	;[1065] 
	SRCFILE "mermaid008.bas",1065
	;[1066] IF creature1_speed > 2 THEN 
	SRCFILE "mermaid008.bas",1066
	MVI V35,R0
	CMPI #2,R0
	BLE T261
	;[1067] 	IF creature1_UpDown = 0 THEN 
	SRCFILE "mermaid008.bas",1067
	MVI V67,R0
	TSTR R0
	BNE T262
	;[1068] 		spriteY(3)=spriteY(3)-creature1_UpDown_Speed
	SRCFILE "mermaid008.bas",1068
	MVI Q9+3,R0
	SUB V68,R0
	MVO R0,Q9+3
	;[1069] 		spriteY(4)=spriteY(3)
	SRCFILE "mermaid008.bas",1069
	MVI Q9+3,R0
	MVO R0,Q9+4
	;[1070] 		IF spriteY(3)<=4 THEN creature1_UpDown=1:creature1_UpDown_Speed = RANDOM(2)+2:GOTO finish_moveCreature
	SRCFILE "mermaid008.bas",1070
	MVI Q9+3,R0
	CMPI #4,R0
	BGT T263
	MVII #1,R0
	MVO R0,V67
	CALL _next_random
	ANDI #1,R0
	ADDI #2,R0
	MVO R0,V68
	B Q176
T263:
	;[1071] 	END IF
	SRCFILE "mermaid008.bas",1071
T262:
	;[1072] 
	SRCFILE "mermaid008.bas",1072
	;[1073] 	IF creature1_UpDown = 1 THEN 
	SRCFILE "mermaid008.bas",1073
	MVI V67,R0
	CMPI #1,R0
	BNE T264
	;[1074] 		spriteY(3)=spriteY(3)+creature1_UpDown_Speed
	SRCFILE "mermaid008.bas",1074
	MVI Q9+3,R0
	ADD V68,R0
	MVO R0,Q9+3
	;[1075] 		spriteY(4)=spriteY(3)
	SRCFILE "mermaid008.bas",1075
	MVI Q9+3,R0
	MVO R0,Q9+4
	;[1076] 		IF spriteY(3)>=84 THEN creature1_UpDown=0:creature1_UpDown_Speed = RANDOM(2)+2:GOTO finish_moveCreature
	SRCFILE "mermaid008.bas",1076
	MVI Q9+3,R0
	CMPI #84,R0
	BLT T265
	CLRR R0
	MVO R0,V67
	CALL _next_random
	ANDI #1,R0
	ADDI #2,R0
	MVO R0,V68
	B Q176
T265:
	;[1077] 	END IF
	SRCFILE "mermaid008.bas",1077
T264:
	;[1078] END IF
	SRCFILE "mermaid008.bas",1078
T261:
	;[1079] 
	SRCFILE "mermaid008.bas",1079
	;[1080] finish_moveCreature:
	SRCFILE "mermaid008.bas",1080
	; FINISH_MOVECREATURE
Q176:	;[1081] 
	SRCFILE "mermaid008.bas",1081
	;[1082] END
	SRCFILE "mermaid008.bas",1082
	RETURN
	ENDP
	;[1083] 
	SRCFILE "mermaid008.bas",1083
	;[1084] 
	SRCFILE "mermaid008.bas",1084
	;[1085] castle_walls:   Procedure
	SRCFILE "mermaid008.bas",1085
	; CASTLE_WALLS
Q87:	PROC
	BEGIN
	;[1086] 
	SRCFILE "mermaid008.bas",1086
	;[1087] PLAY Simple
	SRCFILE "mermaid008.bas",1087
	MVII #1,R3
	MVO R3,_music_mode
	;[1088] PLAY Castle_Tune
	SRCFILE "mermaid008.bas",1088
	MVII #Q179,R0
	CALL _play_music
	;[1089] 
	SRCFILE "mermaid008.bas",1089
	;[1090] REM add the entryway(s) to the castle screens based on the grid layout
	SRCFILE "mermaid008.bas",1090
	;[1091] REM (nsew, ns, ew, ne, nw, se, sw, n, s, e, w, nse, nsw, new, sew)
	SRCFILE "mermaid008.bas",1091
	;[1092] 
	SRCFILE "mermaid008.bas",1092
	;[1093] 'select a random castle grid
	SRCFILE "mermaid008.bas",1093
	;[1094] castleGrid = RANDOM(9)+1
	SRCFILE "mermaid008.bas",1094
	MVII #9,R1
	CALL _next_random
	CALL qs_mpy8
	SWAP R0
	ANDI #255,R0
	INCR R0
	MVO R0,V70
	;[1095] ON castleGrid GOTO grid1, grid2, grid3, grid4, grid5, grid6, grid7, grid8, grid9
	SRCFILE "mermaid008.bas",1095
	MVI V70,R0
	CMPI #9,R0
	BC T267
	ADDI #T266,R0
	MOVR R0,R1
	MVI@ R1,PC
T266:
	DECLE Q180
	DECLE Q181
	DECLE Q182
	DECLE Q183
	DECLE Q184
	DECLE Q185
	DECLE Q186
	DECLE Q187
	DECLE Q188
T267:
	;[1096] grid1:
	SRCFILE "mermaid008.bas",1096
	; GRID1
Q180:	;[1097] RESTORE castleGrid1
	SRCFILE "mermaid008.bas",1097
	MVII #Q190,R4
	MVO R4,_read
	;[1098] GOTO gridData
	SRCFILE "mermaid008.bas",1098
	B Q191
	;[1099] grid2: 
	SRCFILE "mermaid008.bas",1099
	; GRID2
Q181:	;[1100] RESTORE castleGrid2
	SRCFILE "mermaid008.bas",1100
	MVII #Q193,R4
	MVO R4,_read
	;[1101] GOTO gridData
	SRCFILE "mermaid008.bas",1101
	B Q191
	;[1102] grid3: 
	SRCFILE "mermaid008.bas",1102
	; GRID3
Q182:	;[1103] RESTORE castleGrid3
	SRCFILE "mermaid008.bas",1103
	MVII #Q195,R4
	MVO R4,_read
	;[1104] GOTO gridData
	SRCFILE "mermaid008.bas",1104
	B Q191
	;[1105] grid4: 
	SRCFILE "mermaid008.bas",1105
	; GRID4
Q183:	;[1106] RESTORE castleGrid4
	SRCFILE "mermaid008.bas",1106
	MVII #Q197,R4
	MVO R4,_read
	;[1107] GOTO gridData
	SRCFILE "mermaid008.bas",1107
	B Q191
	;[1108] grid5: 
	SRCFILE "mermaid008.bas",1108
	; GRID5
Q184:	;[1109] RESTORE castleGrid5
	SRCFILE "mermaid008.bas",1109
	MVII #Q199,R4
	MVO R4,_read
	;[1110] GOTO gridData
	SRCFILE "mermaid008.bas",1110
	B Q191
	;[1111] grid6: 
	SRCFILE "mermaid008.bas",1111
	; GRID6
Q185:	;[1112] RESTORE castleGrid6
	SRCFILE "mermaid008.bas",1112
	MVII #Q201,R4
	MVO R4,_read
	;[1113] GOTO gridData
	SRCFILE "mermaid008.bas",1113
	B Q191
	;[1114] grid7: 
	SRCFILE "mermaid008.bas",1114
	; GRID7
Q186:	;[1115] RESTORE castleGrid7
	SRCFILE "mermaid008.bas",1115
	MVII #Q203,R4
	MVO R4,_read
	;[1116] GOTO gridData
	SRCFILE "mermaid008.bas",1116
	B Q191
	;[1117] grid8: 
	SRCFILE "mermaid008.bas",1117
	; GRID8
Q187:	;[1118] RESTORE castleGrid8
	SRCFILE "mermaid008.bas",1118
	MVII #Q205,R4
	MVO R4,_read
	;[1119] GOTO gridData
	SRCFILE "mermaid008.bas",1119
	B Q191
	;[1120] grid9: 
	SRCFILE "mermaid008.bas",1120
	; GRID9
Q188:	;[1121] RESTORE castleGrid9
	SRCFILE "mermaid008.bas",1121
	MVII #Q207,R4
	MVO R4,_read
	;[1122] GOTO gridData
	SRCFILE "mermaid008.bas",1122
	B Q191
	;[1123] gridData:
	SRCFILE "mermaid008.bas",1123
	; GRIDDATA
Q191:	;[1124] cls
	SRCFILE "mermaid008.bas",1124
	CALL CLRSCR
	MVII #512,R0
	MVO R0,_screen
	;[1125] screen castle_level
	SRCFILE "mermaid008.bas",1125
	MVII #Q73,R3
	MOVR R0,R2
	MVII #20,R1
	MVII #12,R0
	CALL CPYBLK
	;[1126] FOR A=1 TO 100
	SRCFILE "mermaid008.bas",1126
	MVII #1,R0
	MVO R0,V58
T268:
	;[1127] READ castleLayout(A)
	SRCFILE "mermaid008.bas",1127
	MVI _read,R4
	MVI@ R4,R0
	MVO R4,_read
	MVII #Q11,R3
	ADD V58,R3
	MVO@ R0,R3
	;[1128] NEXT A
	SRCFILE "mermaid008.bas",1128
	MVI V58,R0
	INCR R0
	MVO R0,V58
	CMPI #100,R0
	BLE T268
	;[1129] 'mermaid always enters the castle in room #95 
	SRCFILE "mermaid008.bas",1129
	;[1130] mermaid_CastleLocation = 95
	SRCFILE "mermaid008.bas",1130
	MVII #95,R0
	MVO R0,V52
	;[1131] mermaid_castleLocationX = 100-mermaid_CastleLocation
	SRCFILE "mermaid008.bas",1131
	MVII #100,R0
	SUB V52,R0
	MVO R0,V63
	;[1132] mermaid_castleLocationY = 100-(mermaid_CastleLocation-mermaid_CastleLocationX)
	SRCFILE "mermaid008.bas",1132
	MVII #100,R0
	MVI V52,R1
	SUB V63,R1
	SUBR R1,R0
	MVO R0,V64
	;[1133] gosub display_castle_walls
	SRCFILE "mermaid008.bas",1133
	CALL Q74
	;[1134] END
	SRCFILE "mermaid008.bas",1134
	RETURN
	ENDP
	;[1135] 
	SRCFILE "mermaid008.bas",1135
	;[1136] REM (1=nsew, 2=ns, 3=ew, 4=ne, 5=nw, 6=se, 7=sw, 8=n, 9=s, 10=e, 11=w, 12=nse, 13=nsw, 14=new, 15=sew) 
	SRCFILE "mermaid008.bas",1136
	;[1137] REM (direction listed indicates opening to adjacent room)
	SRCFILE "mermaid008.bas",1137
	;[1138] 
	SRCFILE "mermaid008.bas",1138
	;[1139] display_castle_walls:   Procedure
	SRCFILE "mermaid008.bas",1139
	; DISPLAY_CASTLE_WALLS
Q74:	PROC
	BEGIN
	;[1140] on castleLayout(mermaid_CastleLocation) GOTO ,wall_nsew,wall_ns,wall_ew,wall_ne,wall_nw,wall_se,wall_sw,wall_n,wall_s,wall_e,wall_w,wall_nse,wall_nsw,wall_new,wall_sew,
	SRCFILE "mermaid008.bas",1140
	MVII #Q11,R3
	ADD V52,R3
	MVI@ R3,R0
	CMPI #17,R0
	BC T270
	ADDI #T269,R0
	MOVR R0,R1
	MVI@ R1,PC
T269:
	DECLE T270
	DECLE Q210
	DECLE Q211
	DECLE Q212
	DECLE Q213
	DECLE Q214
	DECLE Q215
	DECLE Q216
	DECLE Q217
	DECLE Q218
	DECLE Q219
	DECLE Q220
	DECLE Q221
	DECLE Q222
	DECLE Q223
	DECLE Q224
	DECLE T270
T270:
	;[1141] wall_nsew:
	SRCFILE "mermaid008.bas",1141
	; WALL_NSEW
Q210:	;[1142] 'do nothing, default castle level is built in the nsew configuration
	SRCFILE "mermaid008.bas",1142
	;[1143] GOTO finish_display_castle_walls
	SRCFILE "mermaid008.bas",1143
	B Q226
	;[1144] 
	SRCFILE "mermaid008.bas",1144
	;[1145] wall_ns:
	SRCFILE "mermaid008.bas",1145
	; WALL_NS
Q211:	;[1146] GOSUB close_east_wall
	SRCFILE "mermaid008.bas",1146
	CALL Q228
	;[1147] GOSUB close_west_wall
	SRCFILE "mermaid008.bas",1147
	CALL Q229
	;[1148] GOTO finish_display_castle_walls
	SRCFILE "mermaid008.bas",1148
	B Q226
	;[1149] 
	SRCFILE "mermaid008.bas",1149
	;[1150] wall_ew:
	SRCFILE "mermaid008.bas",1150
	; WALL_EW
Q212:	;[1151] GOSUB close_north_wall
	SRCFILE "mermaid008.bas",1151
	CALL Q231
	;[1152] GOSUB close_south_wall
	SRCFILE "mermaid008.bas",1152
	CALL Q232
	;[1153] GOTO finish_display_castle_walls
	SRCFILE "mermaid008.bas",1153
	B Q226
	;[1154] 
	SRCFILE "mermaid008.bas",1154
	;[1155] wall_ne:
	SRCFILE "mermaid008.bas",1155
	; WALL_NE
Q213:	;[1156] GOSUB close_south_wall
	SRCFILE "mermaid008.bas",1156
	CALL Q232
	;[1157] GOSUB close_west_wall
	SRCFILE "mermaid008.bas",1157
	CALL Q229
	;[1158] GOTO finish_display_castle_walls
	SRCFILE "mermaid008.bas",1158
	B Q226
	;[1159] 
	SRCFILE "mermaid008.bas",1159
	;[1160] wall_nw:
	SRCFILE "mermaid008.bas",1160
	; WALL_NW
Q214:	;[1161] GOSUB close_south_wall
	SRCFILE "mermaid008.bas",1161
	CALL Q232
	;[1162] GOSUB close_east_wall
	SRCFILE "mermaid008.bas",1162
	CALL Q228
	;[1163] GOTO finish_display_castle_walls
	SRCFILE "mermaid008.bas",1163
	B Q226
	;[1164] 
	SRCFILE "mermaid008.bas",1164
	;[1165] wall_se:
	SRCFILE "mermaid008.bas",1165
	; WALL_SE
Q215:	;[1166] GOSUB close_north_wall
	SRCFILE "mermaid008.bas",1166
	CALL Q231
	;[1167] GOSUB close_west_wall
	SRCFILE "mermaid008.bas",1167
	CALL Q229
	;[1168] GOTO finish_display_castle_walls
	SRCFILE "mermaid008.bas",1168
	B Q226
	;[1169] 
	SRCFILE "mermaid008.bas",1169
	;[1170] wall_sw:
	SRCFILE "mermaid008.bas",1170
	; WALL_SW
Q216:	;[1171] GOSUB close_north_wall
	SRCFILE "mermaid008.bas",1171
	CALL Q231
	;[1172] GOSUB close_east_wall
	SRCFILE "mermaid008.bas",1172
	CALL Q228
	;[1173] GOTO finish_display_castle_walls
	SRCFILE "mermaid008.bas",1173
	B Q226
	;[1174] 
	SRCFILE "mermaid008.bas",1174
	;[1175] wall_n:
	SRCFILE "mermaid008.bas",1175
	; WALL_N
Q217:	;[1176] GOSUB close_south_wall
	SRCFILE "mermaid008.bas",1176
	CALL Q232
	;[1177] GOSUB close_east_wall
	SRCFILE "mermaid008.bas",1177
	CALL Q228
	;[1178] GOSUB close_west_wall
	SRCFILE "mermaid008.bas",1178
	CALL Q229
	;[1179] GOTO finish_display_castle_walls
	SRCFILE "mermaid008.bas",1179
	B Q226
	;[1180] 
	SRCFILE "mermaid008.bas",1180
	;[1181] wall_s:
	SRCFILE "mermaid008.bas",1181
	; WALL_S
Q218:	;[1182] GOSUB close_north_wall
	SRCFILE "mermaid008.bas",1182
	CALL Q231
	;[1183] GOSUB close_east_wall
	SRCFILE "mermaid008.bas",1183
	CALL Q228
	;[1184] GOSUB close_west_wall
	SRCFILE "mermaid008.bas",1184
	CALL Q229
	;[1185] GOTO finish_display_castle_walls
	SRCFILE "mermaid008.bas",1185
	B Q226
	;[1186] 
	SRCFILE "mermaid008.bas",1186
	;[1187] wall_e:
	SRCFILE "mermaid008.bas",1187
	; WALL_E
Q219:	;[1188] GOSUB close_north_wall
	SRCFILE "mermaid008.bas",1188
	CALL Q231
	;[1189] GOSUB close_south_wall
	SRCFILE "mermaid008.bas",1189
	CALL Q232
	;[1190] GOSUB close_west_wall
	SRCFILE "mermaid008.bas",1190
	CALL Q229
	;[1191] GOTO finish_display_castle_walls
	SRCFILE "mermaid008.bas",1191
	B Q226
	;[1192] 
	SRCFILE "mermaid008.bas",1192
	;[1193] wall_w:
	SRCFILE "mermaid008.bas",1193
	; WALL_W
Q220:	;[1194] GOSUB close_north_wall
	SRCFILE "mermaid008.bas",1194
	CALL Q231
	;[1195] GOSUB close_south_wall
	SRCFILE "mermaid008.bas",1195
	CALL Q232
	;[1196] GOSUB close_east_wall
	SRCFILE "mermaid008.bas",1196
	CALL Q228
	;[1197] GOTO finish_display_castle_walls
	SRCFILE "mermaid008.bas",1197
	B Q226
	;[1198] 
	SRCFILE "mermaid008.bas",1198
	;[1199] wall_nse:
	SRCFILE "mermaid008.bas",1199
	; WALL_NSE
Q221:	;[1200] GOSUB close_west_wall
	SRCFILE "mermaid008.bas",1200
	CALL Q229
	;[1201] GOTO finish_display_castle_walls
	SRCFILE "mermaid008.bas",1201
	B Q226
	;[1202] 
	SRCFILE "mermaid008.bas",1202
	;[1203] wall_nsw:
	SRCFILE "mermaid008.bas",1203
	; WALL_NSW
Q222:	;[1204] GOSUB close_east_wall
	SRCFILE "mermaid008.bas",1204
	CALL Q228
	;[1205] GOTO finish_display_castle_walls
	SRCFILE "mermaid008.bas",1205
	B Q226
	;[1206] 
	SRCFILE "mermaid008.bas",1206
	;[1207] wall_new:
	SRCFILE "mermaid008.bas",1207
	; WALL_NEW
Q223:	;[1208] GOSUB close_south_wall
	SRCFILE "mermaid008.bas",1208
	CALL Q232
	;[1209] GOTO finish_display_castle_walls
	SRCFILE "mermaid008.bas",1209
	B Q226
	;[1210] 
	SRCFILE "mermaid008.bas",1210
	;[1211] wall_sew:
	SRCFILE "mermaid008.bas",1211
	; WALL_SEW
Q224:	;[1212] GOSUB close_north_wall
	SRCFILE "mermaid008.bas",1212
	CALL Q231
	;[1213] GOTO finish_display_castle_walls
	SRCFILE "mermaid008.bas",1213
	B Q226
	;[1214] 
	SRCFILE "mermaid008.bas",1214
	;[1215] finish_display_castle_walls:
	SRCFILE "mermaid008.bas",1215
	; FINISH_DISPLAY_CASTLE_WALLS
Q226:	;[1216] 
	SRCFILE "mermaid008.bas",1216
	;[1217] END
	SRCFILE "mermaid008.bas",1217
	RETURN
	ENDP
	;[1218] 
	SRCFILE "mermaid008.bas",1218
	;[1219] close_north_wall:   Procedure
	SRCFILE "mermaid008.bas",1219
	; CLOSE_NORTH_WALL
Q231:	PROC
	BEGIN
	;[1220] PRINT AT 9, $1858
	SRCFILE "mermaid008.bas",1220
	MVII #521,R0
	MVO R0,_screen
	MVII #6232,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	;[1221] PRINT AT 10, $1858
	SRCFILE "mermaid008.bas",1221
	MVII #522,R0
	MVO R0,_screen
	MVII #6232,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	;[1222] END
	SRCFILE "mermaid008.bas",1222
	RETURN
	ENDP
	;[1223] 
	SRCFILE "mermaid008.bas",1223
	;[1224] close_south_wall:   Procedure
	SRCFILE "mermaid008.bas",1224
	; CLOSE_SOUTH_WALL
Q232:	PROC
	BEGIN
	;[1225] PRINT AT 229, $1858
	SRCFILE "mermaid008.bas",1225
	MVII #741,R0
	MVO R0,_screen
	MVII #6232,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	;[1226] PRINT AT 230, $1858
	SRCFILE "mermaid008.bas",1226
	MVII #742,R0
	MVO R0,_screen
	MVII #6232,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	;[1227] END
	SRCFILE "mermaid008.bas",1227
	RETURN
	ENDP
	;[1228] 
	SRCFILE "mermaid008.bas",1228
	;[1229] close_east_wall:   Procedure
	SRCFILE "mermaid008.bas",1229
	; CLOSE_EAST_WALL
Q228:	PROC
	BEGIN
	;[1230] PRINT AT 119, $1860
	SRCFILE "mermaid008.bas",1230
	MVII #631,R0
	MVO R0,_screen
	MVII #6240,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	;[1231] PRINT AT 139, $1860
	SRCFILE "mermaid008.bas",1231
	MVII #651,R0
	MVO R0,_screen
	MVII #6240,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	;[1232] END
	SRCFILE "mermaid008.bas",1232
	RETURN
	ENDP
	;[1233] 
	SRCFILE "mermaid008.bas",1233
	;[1234] close_west_wall:   Procedure
	SRCFILE "mermaid008.bas",1234
	; CLOSE_WEST_WALL
Q229:	PROC
	BEGIN
	;[1235] PRINT AT 100, $1860
	SRCFILE "mermaid008.bas",1235
	MVII #612,R0
	MVO R0,_screen
	MVII #6240,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	;[1236] PRINT AT 120, $1860
	SRCFILE "mermaid008.bas",1236
	MVII #632,R0
	MVO R0,_screen
	MVII #6240,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	;[1237] END
	SRCFILE "mermaid008.bas",1237
	RETURN
	ENDP
	;[1238] 
	SRCFILE "mermaid008.bas",1238
	;[1239] 
	SRCFILE "mermaid008.bas",1239
	;[1240] REM (1=nsew, 2=ns, 3=ew, 4=ne, 5=nw, 6=se, 7=sw, 8=n, 9=s, 10=e, 11=w, 12=nse, 13=nsw, 14=new, 15=sew)
	SRCFILE "mermaid008.bas",1240
	;[1241] REM (direction listed indicates opening to adjacent room)
	SRCFILE "mermaid008.bas",1241
	;[1242] 
	SRCFILE "mermaid008.bas",1242
	;[1243] castleGrid1:
	SRCFILE "mermaid008.bas",1243
	; CASTLEGRID1
Q190:	;[1244] DATA 6,15,11,6,15,7,6,15,15,7
	SRCFILE "mermaid008.bas",1244
	DECLE 6
	DECLE 15
	DECLE 11
	DECLE 6
	DECLE 15
	DECLE 7
	DECLE 6
	DECLE 15
	DECLE 15
	DECLE 7
	;[1245] DATA 12,13,10,1,5,2,12,5,4,13
	SRCFILE "mermaid008.bas",1245
	DECLE 12
	DECLE 13
	DECLE 10
	DECLE 1
	DECLE 5
	DECLE 2
	DECLE 12
	DECLE 5
	DECLE 4
	DECLE 13
	;[1246] DATA 12,14,7,8,6,13,4,7,6,13
	SRCFILE "mermaid008.bas",1246
	DECLE 12
	DECLE 14
	DECLE 7
	DECLE 8
	DECLE 6
	DECLE 13
	DECLE 4
	DECLE 7
	DECLE 6
	DECLE 13
	;[1247] DATA 12,11,12,15,1,1,7,12,1,13
	SRCFILE "mermaid008.bas",1247
	DECLE 12
	DECLE 11
	DECLE 12
	DECLE 15
	DECLE 1
	DECLE 1
	DECLE 7
	DECLE 12
	DECLE 1
	DECLE 13
	;[1248] DATA 12,3,14,1,1,5,12,14,14,13
	SRCFILE "mermaid008.bas",1248
	DECLE 12
	DECLE 3
	DECLE 14
	DECLE 1
	DECLE 1
	DECLE 5
	DECLE 12
	DECLE 14
	DECLE 14
	DECLE 13
	;[1249] DATA 2,6,7,12,13,10,13,6,7,2
	SRCFILE "mermaid008.bas",1249
	DECLE 2
	DECLE 6
	DECLE 7
	DECLE 12
	DECLE 13
	DECLE 10
	DECLE 13
	DECLE 6
	DECLE 7
	DECLE 2
	;[1250] DATA 2,4,1,1,1,7,4,1,5,2
	SRCFILE "mermaid008.bas",1250
	DECLE 2
	DECLE 4
	DECLE 1
	DECLE 1
	DECLE 1
	DECLE 7
	DECLE 4
	DECLE 1
	DECLE 5
	DECLE 2
	;[1251] DATA 12,15,5,4,1,1,11,4,15,13
	SRCFILE "mermaid008.bas",1251
	DECLE 12
	DECLE 15
	DECLE 5
	DECLE 4
	DECLE 1
	DECLE 1
	DECLE 11
	DECLE 4
	DECLE 15
	DECLE 13
	;[1252] DATA 8,12,7,6,1,5,6,7,12,13
	SRCFILE "mermaid008.bas",1252
	DECLE 8
	DECLE 12
	DECLE 7
	DECLE 6
	DECLE 1
	DECLE 5
	DECLE 6
	DECLE 7
	DECLE 12
	DECLE 13
	;[1253] DATA 10,14,14,14,14,3,5,4,14,5
	SRCFILE "mermaid008.bas",1253
	DECLE 10
	DECLE 14
	DECLE 14
	DECLE 14
	DECLE 14
	DECLE 3
	DECLE 5
	DECLE 4
	DECLE 14
	DECLE 5
	;[1254] 
	SRCFILE "mermaid008.bas",1254
	;[1255] castleGrid2:
	SRCFILE "mermaid008.bas",1255
	; CASTLEGRID2
Q193:	;[1256] DATA 10,15,7,6,3,3,7,9,6,7
	SRCFILE "mermaid008.bas",1256
	DECLE 10
	DECLE 15
	DECLE 7
	DECLE 6
	DECLE 3
	DECLE 3
	DECLE 7
	DECLE 9
	DECLE 6
	DECLE 7
	;[1257] DATA 6,14,5,2,10,3,1,13,12,13
	SRCFILE "mermaid008.bas",1257
	DECLE 6
	DECLE 14
	DECLE 5
	DECLE 2
	DECLE 10
	DECLE 3
	DECLE 1
	DECLE 13
	DECLE 12
	DECLE 13
	;[1258] DATA 2,6,3,14,15,7,12,5,12,13
	SRCFILE "mermaid008.bas",1258
	DECLE 2
	DECLE 6
	DECLE 3
	DECLE 14
	DECLE 15
	DECLE 7
	DECLE 12
	DECLE 5
	DECLE 12
	DECLE 13
	;[1259] DATA 2,2,6,7,4,13,8,6,5,2
	SRCFILE "mermaid008.bas",1259
	DECLE 2
	DECLE 2
	DECLE 6
	DECLE 7
	DECLE 4
	DECLE 13
	DECLE 8
	DECLE 6
	DECLE 5
	DECLE 2
	;[1260] DATA 4,13,12,1,11,12,15,13,6,13
	SRCFILE "mermaid008.bas",1260
	DECLE 4
	DECLE 13
	DECLE 12
	DECLE 1
	DECLE 11
	DECLE 12
	DECLE 15
	DECLE 13
	DECLE 6
	DECLE 13
	;[1261] DATA 9,2,12,13,6,14,1,13,4,5
	SRCFILE "mermaid008.bas",1261
	DECLE 9
	DECLE 2
	DECLE 12
	DECLE 13
	DECLE 6
	DECLE 14
	DECLE 1
	DECLE 13
	DECLE 4
	DECLE 5
	;[1262] DATA 12,13,4,13,2,9,4,14,15,11
	SRCFILE "mermaid008.bas",1262
	DECLE 12
	DECLE 13
	DECLE 4
	DECLE 13
	DECLE 2
	DECLE 9
	DECLE 4
	DECLE 14
	DECLE 15
	DECLE 11
	;[1263] DATA 2,4,11,2,2,12,15,15,1,7
	SRCFILE "mermaid008.bas",1263
	DECLE 2
	DECLE 4
	DECLE 11
	DECLE 2
	DECLE 2
	DECLE 12
	DECLE 15
	DECLE 15
	DECLE 1
	DECLE 7
	;[1264] DATA 4,15,15,13,2,12,1,1,1,5 
	SRCFILE "mermaid008.bas",1264
	DECLE 4
	DECLE 15
	DECLE 15
	DECLE 13
	DECLE 2
	DECLE 12
	DECLE 1
	DECLE 1
	DECLE 1
	DECLE 5
	;[1265] DATA 10,14,14,5,8,4,14,14,14,11
	SRCFILE "mermaid008.bas",1265
	DECLE 10
	DECLE 14
	DECLE 14
	DECLE 5
	DECLE 8
	DECLE 4
	DECLE 14
	DECLE 14
	DECLE 14
	DECLE 11
	;[1266] 
	SRCFILE "mermaid008.bas",1266
	;[1267] castleGrid3:
	SRCFILE "mermaid008.bas",1267
	; CASTLEGRID3
Q195:	;[1268] DATA 6,15,15,3,15,15,15,15,15,7
	SRCFILE "mermaid008.bas",1268
	DECLE 6
	DECLE 15
	DECLE 15
	DECLE 3
	DECLE 15
	DECLE 15
	DECLE 15
	DECLE 15
	DECLE 15
	DECLE 7
	;[1269] DATA 12,1,5,9,12,1,14,1,1,13
	SRCFILE "mermaid008.bas",1269
	DECLE 12
	DECLE 1
	DECLE 5
	DECLE 9
	DECLE 12
	DECLE 1
	DECLE 14
	DECLE 1
	DECLE 1
	DECLE 13
	;[1270] DATA 12,5,6,13,12,1,7,4,1,5
	SRCFILE "mermaid008.bas",1270
	DECLE 12
	DECLE 5
	DECLE 6
	DECLE 13
	DECLE 12
	DECLE 1
	DECLE 7
	DECLE 4
	DECLE 1
	DECLE 5
	;[1271] DATA 8,6,1,13,12,13,12,7,8,9 
	SRCFILE "mermaid008.bas",1271
	DECLE 8
	DECLE 6
	DECLE 1
	DECLE 13
	DECLE 12
	DECLE 13
	DECLE 12
	DECLE 7
	DECLE 8
	DECLE 9
	;[1272] DATA 6,1,1,13,12,5,12,1,15,5 
	SRCFILE "mermaid008.bas",1272
	DECLE 6
	DECLE 1
	DECLE 1
	DECLE 13
	DECLE 12
	DECLE 5
	DECLE 12
	DECLE 1
	DECLE 15
	DECLE 5
	;[1273] DATA 12,1,1,13,8,6,1,1,13,9 
	SRCFILE "mermaid008.bas",1273
	DECLE 12
	DECLE 1
	DECLE 1
	DECLE 13
	DECLE 8
	DECLE 6
	DECLE 1
	DECLE 1
	DECLE 13
	DECLE 9
	;[1274] DATA 12,14,14,1,15,1,1,5,12,13
	SRCFILE "mermaid008.bas",1274
	DECLE 12
	DECLE 14
	DECLE 14
	DECLE 1
	DECLE 15
	DECLE 1
	DECLE 1
	DECLE 5
	DECLE 12
	DECLE 13
	;[1275] DATA 12,15,7,4,1,14,5,6,1,5 
	SRCFILE "mermaid008.bas",1275
	DECLE 12
	DECLE 15
	DECLE 7
	DECLE 4
	DECLE 1
	DECLE 14
	DECLE 5
	DECLE 6
	DECLE 1
	DECLE 5
	;[1276] DATA 8,4,1,11,2,10,15,1,1,7 
	SRCFILE "mermaid008.bas",1276
	DECLE 8
	DECLE 4
	DECLE 1
	DECLE 11
	DECLE 2
	DECLE 10
	DECLE 15
	DECLE 1
	DECLE 1
	DECLE 7
	;[1277] DATA 10,3,5,10,14,11,4,14,14,5 
	SRCFILE "mermaid008.bas",1277
	DECLE 10
	DECLE 3
	DECLE 5
	DECLE 10
	DECLE 14
	DECLE 11
	DECLE 4
	DECLE 14
	DECLE 14
	DECLE 5
	;[1278] 
	SRCFILE "mermaid008.bas",1278
	;[1279] castleGrid4:
	SRCFILE "mermaid008.bas",1279
	; CASTLEGRID4
Q197:	;[1280] DATA 9,9,10,3,15,15,15,3,3,11
	SRCFILE "mermaid008.bas",1280
	DECLE 9
	DECLE 9
	DECLE 10
	DECLE 3
	DECLE 15
	DECLE 15
	DECLE 15
	DECLE 3
	DECLE 3
	DECLE 11
	;[1281] DATA 4,14,15,7,12,1,13,6,2,11
	SRCFILE "mermaid008.bas",1281
	DECLE 4
	DECLE 14
	DECLE 15
	DECLE 7
	DECLE 12
	DECLE 1
	DECLE 13
	DECLE 6
	DECLE 2
	DECLE 11
	;[1282] DATA 6,7,12,13,12,1,1,13,6,7
	SRCFILE "mermaid008.bas",1282
	DECLE 6
	DECLE 7
	DECLE 12
	DECLE 13
	DECLE 12
	DECLE 1
	DECLE 1
	DECLE 13
	DECLE 6
	DECLE 7
	;[1283] DATA 12,13,12,13,12,14,5,2,12,13
	SRCFILE "mermaid008.bas",1283
	DECLE 12
	DECLE 13
	DECLE 12
	DECLE 13
	DECLE 12
	DECLE 14
	DECLE 5
	DECLE 2
	DECLE 12
	DECLE 13
	;[1284] DATA 12,13,12,13,2,6,15,5,12,13
	SRCFILE "mermaid008.bas",1284
	DECLE 12
	DECLE 13
	DECLE 12
	DECLE 13
	DECLE 2
	DECLE 6
	DECLE 15
	DECLE 5
	DECLE 12
	DECLE 13
	;[1285] DATA 4,13,12,13,8,12,13,6,1,13
	SRCFILE "mermaid008.bas",1285
	DECLE 4
	DECLE 13
	DECLE 12
	DECLE 13
	DECLE 8
	DECLE 12
	DECLE 13
	DECLE 6
	DECLE 1
	DECLE 13
	;[1286] DATA 6,1,1,1,15,1,13,4,14,13
	SRCFILE "mermaid008.bas",1286
	DECLE 6
	DECLE 1
	DECLE 1
	DECLE 1
	DECLE 15
	DECLE 1
	DECLE 13
	DECLE 4
	DECLE 14
	DECLE 13
	;[1287] DATA 4,1,14,1,1,1,14,3,15,5
	SRCFILE "mermaid008.bas",1287
	DECLE 4
	DECLE 1
	DECLE 14
	DECLE 1
	DECLE 1
	DECLE 1
	DECLE 14
	DECLE 3
	DECLE 15
	DECLE 5
	;[1288] DATA 6,1,7,4,1,5,6,7,2,9
	SRCFILE "mermaid008.bas",1288
	DECLE 6
	DECLE 1
	DECLE 7
	DECLE 4
	DECLE 1
	DECLE 5
	DECLE 6
	DECLE 7
	DECLE 2
	DECLE 9
	;[1289] DATA 4,14,14,11,8,10,14,14,14,5 
	SRCFILE "mermaid008.bas",1289
	DECLE 4
	DECLE 14
	DECLE 14
	DECLE 11
	DECLE 8
	DECLE 10
	DECLE 14
	DECLE 14
	DECLE 14
	DECLE 5
	;[1290] 
	SRCFILE "mermaid008.bas",1290
	;[1291] castleGrid5:
	SRCFILE "mermaid008.bas",1291
	; CASTLEGRID5
Q199:	;[1292] DATA 6,15,15,7,9,10,15,11,9,9
	SRCFILE "mermaid008.bas",1292
	DECLE 6
	DECLE 15
	DECLE 15
	DECLE 7
	DECLE 9
	DECLE 10
	DECLE 15
	DECLE 11
	DECLE 9
	DECLE 9
	;[1293] DATA 4,14,1,13,12,3,14,3,5,2 
	SRCFILE "mermaid008.bas",1293
	DECLE 4
	DECLE 14
	DECLE 1
	DECLE 13
	DECLE 12
	DECLE 3
	DECLE 14
	DECLE 3
	DECLE 5
	DECLE 2
	;[1294] DATA 10,7,12,5,2,6,15,15,15,13 
	SRCFILE "mermaid008.bas",1294
	DECLE 10
	DECLE 7
	DECLE 12
	DECLE 5
	DECLE 2
	DECLE 6
	DECLE 15
	DECLE 15
	DECLE 15
	DECLE 13
	;[1295] DATA 9,2,2,6,5,12,1,1,1,13
	SRCFILE "mermaid008.bas",1295
	DECLE 9
	DECLE 2
	DECLE 2
	DECLE 6
	DECLE 5
	DECLE 12
	DECLE 1
	DECLE 1
	DECLE 1
	DECLE 13
	;[1296] DATA 2,2,2,2,10,14,14,14,1,13 
	SRCFILE "mermaid008.bas",1296
	DECLE 2
	DECLE 2
	DECLE 2
	DECLE 2
	DECLE 10
	DECLE 14
	DECLE 14
	DECLE 14
	DECLE 1
	DECLE 13
	;[1297] DATA 2,4,1,1,3,3,3,7,12,5 
	SRCFILE "mermaid008.bas",1297
	DECLE 2
	DECLE 4
	DECLE 1
	DECLE 1
	DECLE 3
	DECLE 3
	DECLE 3
	DECLE 7
	DECLE 12
	DECLE 5
	;[1298] DATA 4,3,5,2,10,3,7,4,1,11 
	SRCFILE "mermaid008.bas",1298
	DECLE 4
	DECLE 3
	DECLE 5
	DECLE 2
	DECLE 10
	DECLE 3
	DECLE 7
	DECLE 4
	DECLE 1
	DECLE 11
	;[1299] DATA 10,3,15,1,15,7,12,15,1,7
	SRCFILE "mermaid008.bas",1299
	DECLE 10
	DECLE 3
	DECLE 15
	DECLE 1
	DECLE 15
	DECLE 7
	DECLE 12
	DECLE 15
	DECLE 1
	DECLE 7
	;[1300] DATA 6,15,13,2,8,2,12,1,1,13 
	SRCFILE "mermaid008.bas",1300
	DECLE 6
	DECLE 15
	DECLE 13
	DECLE 2
	DECLE 8
	DECLE 2
	DECLE 12
	DECLE 1
	DECLE 1
	DECLE 13
	;[1301] DATA 4,14,5,4,3,5,4,14,14,5 
	SRCFILE "mermaid008.bas",1301
	DECLE 4
	DECLE 14
	DECLE 5
	DECLE 4
	DECLE 3
	DECLE 5
	DECLE 4
	DECLE 14
	DECLE 14
	DECLE 5
	;[1302] 
	SRCFILE "mermaid008.bas",1302
	;[1303] castleGrid6:
	SRCFILE "mermaid008.bas",1303
	; CASTLEGRID6
Q201:	;[1304] DATA 6,15,15,7,9,6,15,15,15,7
	SRCFILE "mermaid008.bas",1304
	DECLE 6
	DECLE 15
	DECLE 15
	DECLE 7
	DECLE 9
	DECLE 6
	DECLE 15
	DECLE 15
	DECLE 15
	DECLE 7
	;[1305] DATA 12,1,1,13,2,12,1,1,1,13
	SRCFILE "mermaid008.bas",1305
	DECLE 12
	DECLE 1
	DECLE 1
	DECLE 13
	DECLE 2
	DECLE 12
	DECLE 1
	DECLE 1
	DECLE 1
	DECLE 13
	;[1306] DATA 12,14,1,5,2,4,1,1,1,13 
	SRCFILE "mermaid008.bas",1306
	DECLE 12
	DECLE 14
	DECLE 1
	DECLE 5
	DECLE 2
	DECLE 4
	DECLE 1
	DECLE 1
	DECLE 1
	DECLE 13
	;[1307] DATA 8,6,5,6,1,7,4,1,14,5 
	SRCFILE "mermaid008.bas",1307
	DECLE 8
	DECLE 6
	DECLE 5
	DECLE 6
	DECLE 1
	DECLE 7
	DECLE 4
	DECLE 1
	DECLE 14
	DECLE 5
	;[1308] DATA 10,1,15,1,1,1,15,14,15,11 
	SRCFILE "mermaid008.bas",1308
	DECLE 10
	DECLE 1
	DECLE 15
	DECLE 1
	DECLE 1
	DECLE 1
	DECLE 15
	DECLE 14
	DECLE 15
	DECLE 11
	;[1309] DATA 9,4,1,1,1,1,5,6,1,7 
	SRCFILE "mermaid008.bas",1309
	DECLE 9
	DECLE 4
	DECLE 1
	DECLE 1
	DECLE 1
	DECLE 1
	DECLE 5
	DECLE 6
	DECLE 1
	DECLE 7
	;[1310] DATA 12,7,12,1,1,5,6,1,1,13 
	SRCFILE "mermaid008.bas",1310
	DECLE 12
	DECLE 7
	DECLE 12
	DECLE 1
	DECLE 1
	DECLE 5
	DECLE 6
	DECLE 1
	DECLE 1
	DECLE 13
	;[1311] DATA 12,1,13,4,13,6,1,1,1,13 
	SRCFILE "mermaid008.bas",1311
	DECLE 12
	DECLE 1
	DECLE 13
	DECLE 4
	DECLE 13
	DECLE 6
	DECLE 1
	DECLE 1
	DECLE 1
	DECLE 13
	;[1312] DATA 12,1,1,7,2,12,1,1,1,13 
	SRCFILE "mermaid008.bas",1312
	DECLE 12
	DECLE 1
	DECLE 1
	DECLE 7
	DECLE 2
	DECLE 12
	DECLE 1
	DECLE 1
	DECLE 1
	DECLE 13
	;[1313] DATA 4,14,14,5,8,4,14,14,14,5 
	SRCFILE "mermaid008.bas",1313
	DECLE 4
	DECLE 14
	DECLE 14
	DECLE 5
	DECLE 8
	DECLE 4
	DECLE 14
	DECLE 14
	DECLE 14
	DECLE 5
	;[1314] 
	SRCFILE "mermaid008.bas",1314
	;[1315] castleGrid7:
	SRCFILE "mermaid008.bas",1315
	; CASTLEGRID7
Q203:	;[1316] DATA 9,9,9,9,9,9,9,9,9,9
	SRCFILE "mermaid008.bas",1316
	DECLE 9
	DECLE 9
	DECLE 9
	DECLE 9
	DECLE 9
	DECLE 9
	DECLE 9
	DECLE 9
	DECLE 9
	DECLE 9
	;[1317] DATA 2,2,2,2,2,2,2,2,2,2
	SRCFILE "mermaid008.bas",1317
	DECLE 2
	DECLE 2
	DECLE 2
	DECLE 2
	DECLE 2
	DECLE 2
	DECLE 2
	DECLE 2
	DECLE 2
	DECLE 2
	;[1318] DATA 2,4,14,14,14,14,14,14,14,13
	SRCFILE "mermaid008.bas",1318
	DECLE 2
	DECLE 4
	DECLE 14
	DECLE 14
	DECLE 14
	DECLE 14
	DECLE 14
	DECLE 14
	DECLE 14
	DECLE 13
	;[1319] DATA 4,3,15,15,15,7,10,15,11,2
	SRCFILE "mermaid008.bas",1319
	DECLE 4
	DECLE 3
	DECLE 15
	DECLE 15
	DECLE 15
	DECLE 7
	DECLE 10
	DECLE 15
	DECLE 11
	DECLE 2
	;[1320] DATA 6,11,8,8,8,2,10,1,11,2 
	SRCFILE "mermaid008.bas",1320
	DECLE 6
	DECLE 11
	DECLE 8
	DECLE 8
	DECLE 8
	DECLE 2
	DECLE 10
	DECLE 1
	DECLE 11
	DECLE 2
	;[1321] DATA 2,9,9,9,6,1,3,14,11,2 
	SRCFILE "mermaid008.bas",1321
	DECLE 2
	DECLE 9
	DECLE 9
	DECLE 9
	DECLE 6
	DECLE 1
	DECLE 3
	DECLE 14
	DECLE 11
	DECLE 2
	;[1322] DATA 4,1,1,1,14,13,6,3,15,13
	SRCFILE "mermaid008.bas",1322
	DECLE 4
	DECLE 1
	DECLE 1
	DECLE 1
	DECLE 14
	DECLE 13
	DECLE 6
	DECLE 3
	DECLE 15
	DECLE 13
	;[1323] DATA 10,5,2,4,3,13,12,11,12,5 
	SRCFILE "mermaid008.bas",1323
	DECLE 10
	DECLE 5
	DECLE 2
	DECLE 4
	DECLE 3
	DECLE 13
	DECLE 12
	DECLE 11
	DECLE 12
	DECLE 5
	;[1324] DATA 6,7,2,6,7,2,4,3,14,7 
	SRCFILE "mermaid008.bas",1324
	DECLE 6
	DECLE 7
	DECLE 2
	DECLE 6
	DECLE 7
	DECLE 2
	DECLE 4
	DECLE 3
	DECLE 14
	DECLE 7
	;[1325] DATA 4,14,14,14,14,14,3,3,3,5 
	SRCFILE "mermaid008.bas",1325
	DECLE 4
	DECLE 14
	DECLE 14
	DECLE 14
	DECLE 14
	DECLE 14
	DECLE 3
	DECLE 3
	DECLE 3
	DECLE 5
	;[1326] 
	SRCFILE "mermaid008.bas",1326
	;[1327] castleGrid8:
	SRCFILE "mermaid008.bas",1327
	; CASTLEGRID8
Q205:	;[1328] DATA 6,3,3,15,15,15,15,3,3,7
	SRCFILE "mermaid008.bas",1328
	DECLE 6
	DECLE 3
	DECLE 3
	DECLE 15
	DECLE 15
	DECLE 15
	DECLE 15
	DECLE 3
	DECLE 3
	DECLE 7
	;[1329] DATA 2,9,9,2,12,1,13,6,11,2 
	SRCFILE "mermaid008.bas",1329
	DECLE 2
	DECLE 9
	DECLE 9
	DECLE 2
	DECLE 12
	DECLE 1
	DECLE 13
	DECLE 6
	DECLE 11
	DECLE 2
	;[1330] DATA 2,2,2,2,4,14,13,12,11,2 
	SRCFILE "mermaid008.bas",1330
	DECLE 2
	DECLE 2
	DECLE 2
	DECLE 2
	DECLE 4
	DECLE 14
	DECLE 13
	DECLE 12
	DECLE 11
	DECLE 2
	;[1331] DATA 12,14,14,1,15,3,1,14,3,13 
	SRCFILE "mermaid008.bas",1331
	DECLE 12
	DECLE 14
	DECLE 14
	DECLE 1
	DECLE 15
	DECLE 3
	DECLE 1
	DECLE 14
	DECLE 3
	DECLE 13
	;[1332] DATA 2,6,11,2,8,6,13,6,11,2 
	SRCFILE "mermaid008.bas",1332
	DECLE 2
	DECLE 6
	DECLE 11
	DECLE 2
	DECLE 8
	DECLE 6
	DECLE 13
	DECLE 6
	DECLE 11
	DECLE 2
	;[1333] DATA 2,12,11,2,9,4,13,12,11,2
	SRCFILE "mermaid008.bas",1333
	DECLE 2
	DECLE 12
	DECLE 11
	DECLE 2
	DECLE 9
	DECLE 4
	DECLE 13
	DECLE 12
	DECLE 11
	DECLE 2
	;[1334] DATA 12,14,3,1,14,3,1,14,3,13 
	SRCFILE "mermaid008.bas",1334
	DECLE 12
	DECLE 14
	DECLE 3
	DECLE 1
	DECLE 14
	DECLE 3
	DECLE 1
	DECLE 14
	DECLE 3
	DECLE 13
	;[1335] DATA 2,6,11,2,6,15,13,6,11,2 
	SRCFILE "mermaid008.bas",1335
	DECLE 2
	DECLE 6
	DECLE 11
	DECLE 2
	DECLE 6
	DECLE 15
	DECLE 13
	DECLE 6
	DECLE 11
	DECLE 2
	;[1336] DATA 2,2,10,13,4,14,13,12,11,2 
	SRCFILE "mermaid008.bas",1336
	DECLE 2
	DECLE 2
	DECLE 10
	DECLE 13
	DECLE 4
	DECLE 14
	DECLE 13
	DECLE 12
	DECLE 11
	DECLE 2
	;[1337] DATA 4,14,3,14,3,3,14,14,3,5 
	SRCFILE "mermaid008.bas",1337
	DECLE 4
	DECLE 14
	DECLE 3
	DECLE 14
	DECLE 3
	DECLE 3
	DECLE 14
	DECLE 14
	DECLE 3
	DECLE 5
	;[1338] 
	SRCFILE "mermaid008.bas",1338
	;[1339] castleGrid9:
	SRCFILE "mermaid008.bas",1339
	; CASTLEGRID9
Q207:	;[1340] DATA 6,15,15,15,11,10,15,15,15,7
	SRCFILE "mermaid008.bas",1340
	DECLE 6
	DECLE 15
	DECLE 15
	DECLE 15
	DECLE 11
	DECLE 10
	DECLE 15
	DECLE 15
	DECLE 15
	DECLE 7
	;[1341] DATA 12,14,1,1,3,3,1,14,14,13
	SRCFILE "mermaid008.bas",1341
	DECLE 12
	DECLE 14
	DECLE 1
	DECLE 1
	DECLE 3
	DECLE 3
	DECLE 1
	DECLE 14
	DECLE 14
	DECLE 13
	;[1342] DATA 2,9,4,1,7,6,13,6,11,2
	SRCFILE "mermaid008.bas",1342
	DECLE 2
	DECLE 9
	DECLE 4
	DECLE 1
	DECLE 7
	DECLE 6
	DECLE 13
	DECLE 6
	DECLE 11
	DECLE 2
	;[1343] DATA 12,1,11,12,13,12,13,12,7,2 
	SRCFILE "mermaid008.bas",1343
	DECLE 12
	DECLE 1
	DECLE 11
	DECLE 12
	DECLE 13
	DECLE 12
	DECLE 13
	DECLE 12
	DECLE 7
	DECLE 2
	;[1344] DATA 2,8,6,1,5,12,13,12,5,2 
	SRCFILE "mermaid008.bas",1344
	DECLE 2
	DECLE 8
	DECLE 6
	DECLE 1
	DECLE 5
	DECLE 12
	DECLE 13
	DECLE 12
	DECLE 5
	DECLE 2
	;[1345] DATA 12,3,14,1,3,14,1,14,3,13 
	SRCFILE "mermaid008.bas",1345
	DECLE 12
	DECLE 3
	DECLE 14
	DECLE 1
	DECLE 3
	DECLE 14
	DECLE 1
	DECLE 14
	DECLE 3
	DECLE 13
	;[1346] DATA 2,6,7,2,9,9,2,6,11,2 
	SRCFILE "mermaid008.bas",1346
	DECLE 2
	DECLE 6
	DECLE 7
	DECLE 2
	DECLE 9
	DECLE 9
	DECLE 2
	DECLE 6
	DECLE 11
	DECLE 2
	;[1347] DATA 2,4,13,2,2,2,2,12,7,2 
	SRCFILE "mermaid008.bas",1347
	DECLE 2
	DECLE 4
	DECLE 13
	DECLE 2
	DECLE 2
	DECLE 2
	DECLE 2
	DECLE 12
	DECLE 7
	DECLE 2
	;[1348] DATA 2,6,13,2,12,13,2,12,5,2 
	SRCFILE "mermaid008.bas",1348
	DECLE 2
	DECLE 6
	DECLE 13
	DECLE 2
	DECLE 12
	DECLE 13
	DECLE 2
	DECLE 12
	DECLE 5
	DECLE 2
	;[1349] DATA 4,14,14,14,14,14,14,14,3,5 
	SRCFILE "mermaid008.bas",1349
	DECLE 4
	DECLE 14
	DECLE 14
	DECLE 14
	DECLE 14
	DECLE 14
	DECLE 14
	DECLE 14
	DECLE 3
	DECLE 5
	;[1350] 
	SRCFILE "mermaid008.bas",1350
	;[1351] displayQueen:   Procedure
	SRCFILE "mermaid008.bas",1351
	; DISPLAYQUEEN
Q36:	PROC
	BEGIN
	;[1352] 'place the queen's throne in the center of the screen
	SRCFILE "mermaid008.bas",1352
	;[1353] PRINT AT 69, $3E6E
	SRCFILE "mermaid008.bas",1353
	MVII #581,R0
	MVO R0,_screen
	MVII #15982,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	;[1354] PRINT AT 89, $3E76
	SRCFILE "mermaid008.bas",1354
	MVII #601,R0
	MVO R0,_screen
	MVII #15990,R0
	MVI _screen,R4
	MVO@ R0,R4
	MVO R4,_screen
	;[1355] 
	SRCFILE "mermaid008.bas",1355
	;[1356] 'movement (0-ne,1-se,2-sw,3-nw)
	SRCFILE "mermaid008.bas",1356
	;[1357] IF spriteX(5) = 70 THEN queenMovement = 0
	SRCFILE "mermaid008.bas",1357
	MVI Q8+5,R0
	CMPI #70,R0
	BNE T271
	CLRR R0
	MVO R0,V71
T271:
	;[1358] IF spriteY(5) = 28 THEN queenMovement = 1
	SRCFILE "mermaid008.bas",1358
	MVI Q9+5,R0
	CMPI #28,R0
	BNE T272
	MVII #1,R0
	MVO R0,V71
T272:
	;[1359] IF spriteX(5) = 90 THEN queenMovement = 2
	SRCFILE "mermaid008.bas",1359
	MVI Q8+5,R0
	CMPI #90,R0
	BNE T273
	MVII #2,R0
	MVO R0,V71
T273:
	;[1360] IF spriteY(5) = 68 THEN queenMovement = 3
	SRCFILE "mermaid008.bas",1360
	MVI Q9+5,R0
	CMPI #68,R0
	BNE T274
	MVII #3,R0
	MVO R0,V71
T274:
	;[1361] 
	SRCFILE "mermaid008.bas",1361
	;[1362] ON queen_counter GOTO moveQueen,,moveQueen,
	SRCFILE "mermaid008.bas",1362
	MVI V41,R0
	CMPI #4,R0
	BC T276
	ADDI #T275,R0
	MOVR R0,R1
	MVI@ R1,PC
T275:
	DECLE Q260
	DECLE T276
	DECLE Q260
	DECLE T276
T276:
	;[1363] 'move queen when queen_counter = 0 or 2 otherwise just display the queen
	SRCFILE "mermaid008.bas",1363
	;[1364] GOTO finish_display_queen
	SRCFILE "mermaid008.bas",1364
	B Q261
	;[1365] 
	SRCFILE "mermaid008.bas",1365
	;[1366] moveQueen:
	SRCFILE "mermaid008.bas",1366
	; MOVEQUEEN
Q260:	;[1367] ON queenMovement GOTO moveQueen_NE,moveQueen_SE,moveQueen_SW,moveQueen_NW
	SRCFILE "mermaid008.bas",1367
	MVI V71,R0
	CMPI #4,R0
	BC T278
	ADDI #T277,R0
	MOVR R0,R1
	MVI@ R1,PC
T277:
	DECLE Q263
	DECLE Q264
	DECLE Q265
	DECLE Q266
T278:
	;[1368] 
	SRCFILE "mermaid008.bas",1368
	;[1369] moveQueen_NE:
	SRCFILE "mermaid008.bas",1369
	; MOVEQUEEN_NE
Q263:	;[1370] spriteX(5)=spriteX(5)+1:spriteY(5)=spriteY(5)-2
	SRCFILE "mermaid008.bas",1370
	MVI Q8+5,R0
	INCR R0
	MVO R0,Q8+5
	MVI Q9+5,R0
	SUBI #2,R0
	MVO R0,Q9+5
	;[1371] spriteX(6)=spriteX(5):spriteY(6)=spriteY(5)
	SRCFILE "mermaid008.bas",1371
	MVI Q8+5,R0
	MVO R0,Q8+6
	MVI Q9+5,R0
	MVO R0,Q9+6
	;[1372] spriteX(7)=spriteX(5)-16:spriteY(7)=spriteY(5)
	SRCFILE "mermaid008.bas",1372
	MVI Q8+5,R0
	SUBI #16,R0
	MVO R0,Q8+7
	MVI Q9+5,R0
	MVO R0,Q9+7
	;[1373] GOTO finish_display_queen
	SRCFILE "mermaid008.bas",1373
	B Q261
	;[1374] 
	SRCFILE "mermaid008.bas",1374
	;[1375] moveQueen_SE:
	SRCFILE "mermaid008.bas",1375
	; MOVEQUEEN_SE
Q264:	;[1376] spriteX(5)=spriteX(5)+1:spriteY(5)=spriteY(5)+2
	SRCFILE "mermaid008.bas",1376
	MVI Q8+5,R0
	INCR R0
	MVO R0,Q8+5
	MVI Q9+5,R0
	ADDI #2,R0
	MVO R0,Q9+5
	;[1377] spriteX(6)=spriteX(5):spriteY(6)=spriteY(5)
	SRCFILE "mermaid008.bas",1377
	MVI Q8+5,R0
	MVO R0,Q8+6
	MVI Q9+5,R0
	MVO R0,Q9+6
	;[1378] spriteX(7)=spriteX(5)-16:spriteY(7)=spriteY(5)
	SRCFILE "mermaid008.bas",1378
	MVI Q8+5,R0
	SUBI #16,R0
	MVO R0,Q8+7
	MVI Q9+5,R0
	MVO R0,Q9+7
	;[1379] GOTO finish_display_queen
	SRCFILE "mermaid008.bas",1379
	B Q261
	;[1380] 
	SRCFILE "mermaid008.bas",1380
	;[1381] moveQueen_SW:
	SRCFILE "mermaid008.bas",1381
	; MOVEQUEEN_SW
Q265:	;[1382] spriteX(5)=spriteX(5)-1:spriteY(5)=spriteY(5)+2
	SRCFILE "mermaid008.bas",1382
	MVI Q8+5,R0
	DECR R0
	MVO R0,Q8+5
	MVI Q9+5,R0
	ADDI #2,R0
	MVO R0,Q9+5
	;[1383] spriteX(6)=spriteX(5):spriteY(6)=spriteY(5)
	SRCFILE "mermaid008.bas",1383
	MVI Q8+5,R0
	MVO R0,Q8+6
	MVI Q9+5,R0
	MVO R0,Q9+6
	;[1384] spriteX(7)=spriteX(5)-16:spriteY(7)=spriteY(5)
	SRCFILE "mermaid008.bas",1384
	MVI Q8+5,R0
	SUBI #16,R0
	MVO R0,Q8+7
	MVI Q9+5,R0
	MVO R0,Q9+7
	;[1385] GOTO finish_display_queen
	SRCFILE "mermaid008.bas",1385
	B Q261
	;[1386] 
	SRCFILE "mermaid008.bas",1386
	;[1387] moveQueen_NW:
	SRCFILE "mermaid008.bas",1387
	; MOVEQUEEN_NW
Q266:	;[1388] spriteX(5)=spriteX(5)-1:spriteY(5)=spriteY(5)-2
	SRCFILE "mermaid008.bas",1388
	MVI Q8+5,R0
	DECR R0
	MVO R0,Q8+5
	MVI Q9+5,R0
	SUBI #2,R0
	MVO R0,Q9+5
	;[1389] spriteX(6)=spriteX(5):spriteY(6)=spriteY(5)
	SRCFILE "mermaid008.bas",1389
	MVI Q8+5,R0
	MVO R0,Q8+6
	MVI Q9+5,R0
	MVO R0,Q9+6
	;[1390] spriteX(7)=spriteX(5)-16:spriteY(7)=spriteY(5)
	SRCFILE "mermaid008.bas",1390
	MVI Q8+5,R0
	SUBI #16,R0
	MVO R0,Q8+7
	MVI Q9+5,R0
	MVO R0,Q9+7
	;[1391] GOTO finish_display_queen
	SRCFILE "mermaid008.bas",1391
	B Q261
	;[1392] 
	SRCFILE "mermaid008.bas",1392
	;[1393] finish_display_queen:
	SRCFILE "mermaid008.bas",1393
	; FINISH_DISPLAY_QUEEN
Q261:	;[1394] queen_counter=queen_counter+1:if queen_counter>3 THEN queen_counter=0
	SRCFILE "mermaid008.bas",1394
	MVI V41,R0
	INCR R0
	MVO R0,V41
	MVI V41,R0
	CMPI #3,R0
	BLE T279
	CLRR R0
	MVO R0,V41
T279:
	;[1395] if queen_counter=2 THEN queen_frame = queen_frame+1:IF queen_frame>1 THEN queen_frame = 0
	SRCFILE "mermaid008.bas",1395
	MVI V41,R0
	CMPI #2,R0
	BNE T280
	MVI V42,R0
	INCR R0
	MVO R0,V42
	MVI V42,R0
	CMPI #1,R0
	BLE T281
	CLRR R0
	MVO R0,V42
T281:
T280:
	;[1396] Sprite 5,Spritex(5)+VISIBLE+ZOOMX2,Spritey(5)+ZOOMY2, SPR57+ (8*queen_frame) +#SpriteC(5)
	SRCFILE "mermaid008.bas",1396
	MVI Q8+5,R0
	ADDI #1536,R0
	MVO R0,_mobs+5
	MVI Q9+5,R0
	ADDI #256,R0
	MVO R0,_mobs+13
	MVI V42,R0
	SLL R0,2
	ADDR R0,R0
	ADDI #2504,R0
	MVI Q10+5,R1
	ADDR R1,R0
	MVO R0,_mobs+21
	;[1397] Sprite 6,Spritex(6)+VISIBLE+ZOOMX2,Spritey(6)+ZOOMY2, SPR59+ (8*queen_frame) +#SpriteC(6)
	SRCFILE "mermaid008.bas",1397
	MVI Q8+6,R0
	ADDI #1536,R0
	MVO R0,_mobs+6
	MVI Q9+6,R0
	ADDI #256,R0
	MVO R0,_mobs+14
	MVI V42,R0
	SLL R0,2
	ADDR R0,R0
	ADDI #2520,R0
	MVI Q10+6,R1
	ADDR R1,R0
	MVO R0,_mobs+22
	;[1398] Sprite 7,Spritex(7)+VISIBLE+ZOOMX2,Spritey(7)+ZOOMY2, SPR51+ (8*queen_frame) +#SpriteC(7)
	SRCFILE "mermaid008.bas",1398
	MVI Q8+7,R0
	ADDI #1536,R0
	MVO R0,_mobs+7
	MVI Q9+7,R0
	ADDI #256,R0
	MVO R0,_mobs+15
	MVI V42,R0
	SLL R0,2
	ADDR R0,R0
	ADDI #2456,R0
	MVI Q10+7,R1
	ADDR R1,R0
	MVO R0,_mobs+23
	;[1399] END
	SRCFILE "mermaid008.bas",1399
	RETURN
	ENDP
	;[1400] 
	SRCFILE "mermaid008.bas",1400
	;[1401] creatureCollisionOcean:   Procedure
	SRCFILE "mermaid008.bas",1401
	; CREATURECOLLISIONOCEAN
Q46:	PROC
	BEGIN
	;[1402] mermaid_oceanLocation = starting_point 
	SRCFILE "mermaid008.bas",1402
	MVI V17,R0
	MVO R0,V46
	;[1403] SCREEN screen_level : GOSUB treasure_placement : GOSUB creature_placement
	SRCFILE "mermaid008.bas",1403
	MVII #Q30,R3
	MVII #512,R2
	MVII #20,R1
	MVII #12,R0
	CALL CPYBLK
	CALL Q123
	CALL Q124
	;[1404] END
	SRCFILE "mermaid008.bas",1404
	RETURN
	ENDP
	;[1405] 
	SRCFILE "mermaid008.bas",1405
	;[1406] creatureCollisionCastle:   Procedure
	SRCFILE "mermaid008.bas",1406
	; CREATURECOLLISIONCASTLE
Q47:	PROC
	BEGIN
	;[1407] mermaid_CastleLocation = 95
	SRCFILE "mermaid008.bas",1407
	MVII #95,R0
	MVO R0,V52
	;[1408] mermaid_castleLocationX = 100-mermaid_CastleLocation
	SRCFILE "mermaid008.bas",1408
	MVII #100,R0
	SUB V52,R0
	MVO R0,V63
	;[1409] mermaid_castleLocationY = 100-(mermaid_CastleLocation-mermaid_CastleLocationX)
	SRCFILE "mermaid008.bas",1409
	MVII #100,R0
	MVI V52,R1
	SUB V63,R1
	SUBR R1,R0
	MVO R0,V64
	;[1410] SCREEN castle_level : GOSUB display_castle_walls : GOSUB treasure_placement : GOSUB creature_placement
	SRCFILE "mermaid008.bas",1410
	MVII #Q73,R3
	MVII #512,R2
	MVII #20,R1
	MVII #12,R0
	CALL CPYBLK
	CALL Q74
	CALL Q123
	CALL Q124
	;[1411] END
	SRCFILE "mermaid008.bas",1411
	RETURN
	ENDP
	;[1412] 
	SRCFILE "mermaid008.bas",1412
	;[1413] merColor:   Procedure
	SRCFILE "mermaid008.bas",1413
	; MERCOLOR
Q25:	PROC
	BEGIN
	;[1414] if mermaid = 1 then #mermaid_Color = SPR_GREEN
	SRCFILE "mermaid008.bas",1414
	MVI V8,R0
	CMPI #1,R0
	BNE T282
	MVII #5,R0
	MVO R0,V12
T282:
	;[1415] if mermaid = 2 then #mermaid_Color = SPR_PINK
	SRCFILE "mermaid008.bas",1415
	MVI V8,R0
	CMPI #2,R0
	BNE T283
	MVII #4100,R0
	MVO R0,V12
T283:
	;[1416] if mermaid = 3 then #mermaid_Color = SPR_RED
	SRCFILE "mermaid008.bas",1416
	MVI V8,R0
	CMPI #3,R0
	BNE T284
	MVII #2,R0
	MVO R0,V12
T284:
	;[1417] if mermaid = 4 then #mermaid_Color = SPR_PURPLE
	SRCFILE "mermaid008.bas",1417
	MVI V8,R0
	CMPI #4,R0
	BNE T285
	MVII #4103,R0
	MVO R0,V12
T285:
	;[1418] if mermaid = 5 then #mermaid_Color = SPR_BROWN
	SRCFILE "mermaid008.bas",1418
	MVI V8,R0
	CMPI #5,R0
	BNE T286
	MVII #4099,R0
	MVO R0,V12
T286:
	;[1419] END
	SRCFILE "mermaid008.bas",1419
	RETURN
	ENDP
	;[1420] 
	SRCFILE "mermaid008.bas",1420
	;[1421] 'check for 1UP
	SRCFILE "mermaid008.bas",1421
	;[1422] check1up:   Procedure
	SRCFILE "mermaid008.bas",1422
	; CHECK1UP
Q52:	PROC
	BEGIN
	;[1423] IF #score >= 2000 AND lives1UPFlag = 0 GOTO grant_extra_life
	SRCFILE "mermaid008.bas",1423
	MVI V1,R0
	CMPI #2000,R0
	MVII #-1,R0
	BGE $+3
	INCR R0
	MVI V37,R1
	TSTR R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	ANDR R1,R0
	BNE Q276
	;[1424] IF #score >= 4000 AND lives1UPFlag = 1 GOTO grant_extra_life
	SRCFILE "mermaid008.bas",1424
	MVI V1,R0
	CMPI #4000,R0
	MVII #-1,R0
	BGE $+3
	INCR R0
	MVI V37,R1
	CMPI #1,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	ANDR R1,R0
	BNE Q276
	;[1425] IF #score >= 6000 AND lives1UPFlag = 2 GOTO grant_extra_life
	SRCFILE "mermaid008.bas",1425
	MVI V1,R0
	CMPI #6000,R0
	MVII #-1,R0
	BGE $+3
	INCR R0
	MVI V37,R1
	CMPI #2,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	ANDR R1,R0
	BNE Q276
	;[1426] IF #score >= 8000 AND lives1UPFlag = 3 GOTO grant_extra_life
	SRCFILE "mermaid008.bas",1426
	MVI V1,R0
	CMPI #8000,R0
	MVII #-1,R0
	BGE $+3
	INCR R0
	MVI V37,R1
	CMPI #3,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	ANDR R1,R0
	BNE Q276
	;[1427] IF #score >= 10000 AND lives1UPFlag = 4 GOTO grant_extra_life
	SRCFILE "mermaid008.bas",1427
	MVI V1,R0
	CMPI #10000,R0
	MVII #-1,R0
	BGE $+3
	INCR R0
	MVI V37,R1
	CMPI #4,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	ANDR R1,R0
	BNE Q276
	;[1428] IF #score >= 20000 AND lives1UPFlag = 5 GOTO grant_extra_life ELSE goto finish_check1up
	SRCFILE "mermaid008.bas",1428
	MVI V1,R0
	CMPI #20000,R0
	MVII #-1,R0
	BGE $+3
	INCR R0
	MVI V37,R1
	CMPI #5,R1
	MVII #-1,R1
	BEQ $+3
	INCR R1
	ANDR R1,R0
	BEQ T292
	B Q276
	B T293
T292:
	B Q277
T293:
	;[1429] 
	SRCFILE "mermaid008.bas",1429
	;[1430] grant_extra_life: 
	SRCFILE "mermaid008.bas",1430
	; GRANT_EXTRA_LIFE
Q276:	;[1431] lives=lives+1:lives1UPFlag=lives1UPFlag+1:soundFlag=9:GOSUB loadSound
	SRCFILE "mermaid008.bas",1431
	MVI V13,R0
	INCR R0
	MVO R0,V13
	MVI V37,R0
	INCR R0
	MVO R0,V37
	MVII #9,R0
	MVO R0,V29
	CALL Q43
	;[1432] 
	SRCFILE "mermaid008.bas",1432
	;[1433] finish_check1up:
	SRCFILE "mermaid008.bas",1433
	; FINISH_CHECK1UP
Q277:	;[1434] 
	SRCFILE "mermaid008.bas",1434
	;[1435] END
	SRCFILE "mermaid008.bas",1435
	RETURN
	ENDP
	;[1436] 
	SRCFILE "mermaid008.bas",1436
	;[1437] lose_life:   Procedure
	SRCFILE "mermaid008.bas",1437
	; LOSE_LIFE
Q72:	PROC
	BEGIN
	;[1438] lives=lives-1
	SRCFILE "mermaid008.bas",1438
	MVI V13,R0
	DECR R0
	MVO R0,V13
	;[1439] if lives=0 GOTO game_over
	SRCFILE "mermaid008.bas",1439
	MVI V13,R0
	TSTR R0
	BEQ Q281
	;[1440] 'play music to indicate the countdown timer ran out
	SRCFILE "mermaid008.bas",1440
	;[1441] ''PLAY Time_Expired_Tune
	SRCFILE "mermaid008.bas",1441
	;[1442] ''gosub waitalittle
	SRCFILE "mermaid008.bas",1442
	;[1443] GOTO main
	SRCFILE "mermaid008.bas",1443
	B Q26
	;[1444] END
	SRCFILE "mermaid008.bas",1444
	RETURN
	ENDP
	;[1445] 
	SRCFILE "mermaid008.bas",1445
	;[1446] level_complete:   
	SRCFILE "mermaid008.bas",1446
	; LEVEL_COMPLETE
Q69:	;[1447] #score=#score+1000 : GOSUB check1up
	SRCFILE "mermaid008.bas",1447
	MVI V1,R0
	ADDI #1000,R0
	MVO R0,V1
	CALL Q52
	;[1448] ''PLAY Level_Complete_Tune
	SRCFILE "mermaid008.bas",1448
	;[1449] ''GOSUB waitalittle
	SRCFILE "mermaid008.bas",1449
	;[1450] GOTO nextLevel
	SRCFILE "mermaid008.bas",1450
	B Q23
	;[1451] 
	SRCFILE "mermaid008.bas",1451
	;[1452] game_over:  
	SRCFILE "mermaid008.bas",1452
	; GAME_OVER
Q281:	;[1453] ''PLAY Game_Over_Tune
	SRCFILE "mermaid008.bas",1453
	;[1454] ''GOSUB waitalittle
	SRCFILE "mermaid008.bas",1454
	;[1455] 'play music to indicate game over, keep final score, level detail on screen for five seconds before allowing player to restart
	SRCFILE "mermaid008.bas",1455
	;[1456] 
	SRCFILE "mermaid008.bas",1456
	;[1457] GOTO reset
	SRCFILE "mermaid008.bas",1457
	B Q13
	;[1458] 
	SRCFILE "mermaid008.bas",1458
	;[1459] 
	SRCFILE "mermaid008.bas",1459
	;[1460] Intro_Tune:	DATA 16
	SRCFILE "mermaid008.bas",1460
	; INTRO_TUNE
Q104:		DECLE 16
	;[1461] 
	SRCFILE "mermaid008.bas",1461
	;[1462] 	MUSIC C4,-
	SRCFILE "mermaid008.bas",1462
	DECLE 25,0
	;[1463] 	MUSIC G3,G4
	SRCFILE "mermaid008.bas",1463
	DECLE 8212,0
	;[1464] 	MUSIC F3,-
	SRCFILE "mermaid008.bas",1464
	DECLE 18,0
	;[1465] 	MUSIC E3,E4
	SRCFILE "mermaid008.bas",1465
	DECLE 7441,0
	;[1466] 
	SRCFILE "mermaid008.bas",1466
	;[1467] 	MUSIC D4#,E3
	SRCFILE "mermaid008.bas",1467
	DECLE 4380,0
	;[1468] 	MUSIC C4#,G3
	SRCFILE "mermaid008.bas",1468
	DECLE 5146,0
	;[1469] 	MUSIC F4,E3
	SRCFILE "mermaid008.bas",1469
	DECLE 4382,0
	;[1470] 	MUSIC G4#,G3
	SRCFILE "mermaid008.bas",1470
	DECLE 5153,0
	;[1471] 
	SRCFILE "mermaid008.bas",1471
	;[1472] 	MUSIC C4,-
	SRCFILE "mermaid008.bas",1472
	DECLE 25,0
	;[1473] 	MUSIC G3,G4
	SRCFILE "mermaid008.bas",1473
	DECLE 8212,0
	;[1474] 	MUSIC F3,-
	SRCFILE "mermaid008.bas",1474
	DECLE 18,0
	;[1475] 	MUSIC E3,E4
	SRCFILE "mermaid008.bas",1475
	DECLE 7441,0
	;[1476] 
	SRCFILE "mermaid008.bas",1476
	;[1477] 	MUSIC D4#,E3
	SRCFILE "mermaid008.bas",1477
	DECLE 4380,0
	;[1478] 	MUSIC C4#,G3
	SRCFILE "mermaid008.bas",1478
	DECLE 5146,0
	;[1479] 	MUSIC F4,E3
	SRCFILE "mermaid008.bas",1479
	DECLE 4382,0
	;[1480] 	MUSIC G4#,G3
	SRCFILE "mermaid008.bas",1480
	DECLE 5153,0
	;[1481] 
	SRCFILE "mermaid008.bas",1481
	;[1482] 	MUSIC D4,-
	SRCFILE "mermaid008.bas",1482
	DECLE 27,0
	;[1483] 	MUSIC B3,B5
	SRCFILE "mermaid008.bas",1483
	DECLE 12312,0
	;[1484] 	MUSIC B3,A5
	SRCFILE "mermaid008.bas",1484
	DECLE 11800,0
	;[1485] 	MUSIC A3,D5
	SRCFILE "mermaid008.bas",1485
	DECLE 10006,0
	;[1486] 
	SRCFILE "mermaid008.bas",1486
	;[1487] 	MUSIC D5#,-
	SRCFILE "mermaid008.bas",1487
	DECLE 40,0
	;[1488] 	MUSIC C5#,B2
	SRCFILE "mermaid008.bas",1488
	DECLE 3110,0
	;[1489] 	MUSIC G4#,A2
	SRCFILE "mermaid008.bas",1489
	DECLE 2593,0
	;[1490] 	MUSIC F4#,D2
	SRCFILE "mermaid008.bas",1490
	DECLE 799,0
	;[1491] 
	SRCFILE "mermaid008.bas",1491
	;[1492] 	MUSIC D4,-
	SRCFILE "mermaid008.bas",1492
	DECLE 27,0
	;[1493] 	MUSIC B3,B5
	SRCFILE "mermaid008.bas",1493
	DECLE 12312,0
	;[1494] 	MUSIC B3,A5
	SRCFILE "mermaid008.bas",1494
	DECLE 11800,0
	;[1495] 	MUSIC A3,D5
	SRCFILE "mermaid008.bas",1495
	DECLE 10006,0
	;[1496] 
	SRCFILE "mermaid008.bas",1496
	;[1497] 	MUSIC D5#,-
	SRCFILE "mermaid008.bas",1497
	DECLE 40,0
	;[1498] 	MUSIC C5#,B2
	SRCFILE "mermaid008.bas",1498
	DECLE 3110,0
	;[1499] 	MUSIC G4#,A2
	SRCFILE "mermaid008.bas",1499
	DECLE 2593,0
	;[1500] 	MUSIC F4#,D2
	SRCFILE "mermaid008.bas",1500
	DECLE 799,0
	;[1501] 
	SRCFILE "mermaid008.bas",1501
	;[1502] 	MUSIC REPEAT
	SRCFILE "mermaid008.bas",1502
	DECLE 253,0
	;[1503] 	
	SRCFILE "mermaid008.bas",1503
	;[1504] 	'MUSIC STOP
	SRCFILE "mermaid008.bas",1504
	;[1505] 
	SRCFILE "mermaid008.bas",1505
	;[1506] Game_Tune:	DATA 16
	SRCFILE "mermaid008.bas",1506
	; GAME_TUNE
Q32:		DECLE 16
	;[1507] 
	SRCFILE "mermaid008.bas",1507
	;[1508] 	MUSIC A5,-
	SRCFILE "mermaid008.bas",1508
	DECLE 46,0
	;[1509] 	MUSIC G5,A4
	SRCFILE "mermaid008.bas",1509
	DECLE 8748,0
	;[1510] 	MUSIC D5,-
	SRCFILE "mermaid008.bas",1510
	DECLE 39,0
	;[1511] 	MUSIC E5,B4	
	SRCFILE "mermaid008.bas",1511
	DECLE 9257,0
	;[1512] 
	SRCFILE "mermaid008.bas",1512
	;[1513] 	MUSIC A6,-
	SRCFILE "mermaid008.bas",1513
	DECLE 58,0
	;[1514] 	MUSIC G6,A3
	SRCFILE "mermaid008.bas",1514
	DECLE 5688,0
	;[1515] 	MUSIC D6,-
	SRCFILE "mermaid008.bas",1515
	DECLE 51,0
	;[1516] 	MUSIC E6,B3		
	SRCFILE "mermaid008.bas",1516
	DECLE 6197,0
	;[1517] 	
	SRCFILE "mermaid008.bas",1517
	;[1518] 	MUSIC REPEAT
	SRCFILE "mermaid008.bas",1518
	DECLE 253,0
	;[1519] 	
	SRCFILE "mermaid008.bas",1519
	;[1520] 	'MUSIC STOP	
	SRCFILE "mermaid008.bas",1520
	;[1521] 
	SRCFILE "mermaid008.bas",1521
	;[1522] Castle_Tune:  DATA 16
	SRCFILE "mermaid008.bas",1522
	; CASTLE_TUNE
Q179:		DECLE 16
	;[1523] 	
	SRCFILE "mermaid008.bas",1523
	;[1524] 	MUSIC C3Z,-
	SRCFILE "mermaid008.bas",1524
	DECLE 205,0
	;[1525] 	MUSIC C3Z,-
	SRCFILE "mermaid008.bas",1525
	DECLE 205,0
	;[1526] 	MUSIC D3Z,-
	SRCFILE "mermaid008.bas",1526
	DECLE 207,0
	;[1527] 	MUSIC E3Z,-
	SRCFILE "mermaid008.bas",1527
	DECLE 209,0
	;[1528] 	MUSIC -,-
	SRCFILE "mermaid008.bas",1528
	DECLE 0,0
	;[1529] 	MUSIC -,-
	SRCFILE "mermaid008.bas",1529
	DECLE 0,0
	;[1530] 	MUSIC -,-
	SRCFILE "mermaid008.bas",1530
	DECLE 0,0
	;[1531] 	MUSIC -,-
	SRCFILE "mermaid008.bas",1531
	DECLE 0,0
	;[1532] 	
	SRCFILE "mermaid008.bas",1532
	;[1533] 	MUSIC C3Z,-
	SRCFILE "mermaid008.bas",1533
	DECLE 205,0
	;[1534] 	MUSIC C3Z,-
	SRCFILE "mermaid008.bas",1534
	DECLE 205,0
	;[1535] 	MUSIC D3Z,-
	SRCFILE "mermaid008.bas",1535
	DECLE 207,0
	;[1536] 	MUSIC E3Z,-
	SRCFILE "mermaid008.bas",1536
	DECLE 209,0
	;[1537] 	MUSIC -,-
	SRCFILE "mermaid008.bas",1537
	DECLE 0,0
	;[1538] 	MUSIC -,-
	SRCFILE "mermaid008.bas",1538
	DECLE 0,0
	;[1539] 	MUSIC -,-
	SRCFILE "mermaid008.bas",1539
	DECLE 0,0
	;[1540] 	MUSIC -,-
	SRCFILE "mermaid008.bas",1540
	DECLE 0,0
	;[1541] 
	SRCFILE "mermaid008.bas",1541
	;[1542] 	MUSIC C2Z,-
	SRCFILE "mermaid008.bas",1542
	DECLE 193,0
	;[1543] 	MUSIC C2Z,-
	SRCFILE "mermaid008.bas",1543
	DECLE 193,0
	;[1544] 	MUSIC D2Z,-
	SRCFILE "mermaid008.bas",1544
	DECLE 195,0
	;[1545] 	MUSIC E2Z,-
	SRCFILE "mermaid008.bas",1545
	DECLE 197,0
	;[1546] 	MUSIC -,-
	SRCFILE "mermaid008.bas",1546
	DECLE 0,0
	;[1547] 	MUSIC -,-
	SRCFILE "mermaid008.bas",1547
	DECLE 0,0
	;[1548] 	MUSIC -,-
	SRCFILE "mermaid008.bas",1548
	DECLE 0,0
	;[1549] 	MUSIC -,-
	SRCFILE "mermaid008.bas",1549
	DECLE 0,0
	;[1550] 
	SRCFILE "mermaid008.bas",1550
	;[1551] 	MUSIC A2Z,-
	SRCFILE "mermaid008.bas",1551
	DECLE 202,0
	;[1552] 	MUSIC A2Z,-
	SRCFILE "mermaid008.bas",1552
	DECLE 202,0
	;[1553] 	MUSIC -,-
	SRCFILE "mermaid008.bas",1553
	DECLE 0,0
	;[1554] 	MUSIC -,-
	SRCFILE "mermaid008.bas",1554
	DECLE 0,0
	;[1555] 	MUSIC B2Z,-
	SRCFILE "mermaid008.bas",1555
	DECLE 204,0
	;[1556] 	MUSIC B2Z,-
	SRCFILE "mermaid008.bas",1556
	DECLE 204,0
	;[1557] 	MUSIC -,-
	SRCFILE "mermaid008.bas",1557
	DECLE 0,0
	;[1558] 	MUSIC -,-
	SRCFILE "mermaid008.bas",1558
	DECLE 0,0
	;[1559] 
	SRCFILE "mermaid008.bas",1559
	;[1560] 	MUSIC C3Z,-
	SRCFILE "mermaid008.bas",1560
	DECLE 205,0
	;[1561] 	MUSIC C3Z,-
	SRCFILE "mermaid008.bas",1561
	DECLE 205,0
	;[1562] 	MUSIC D3Z,-
	SRCFILE "mermaid008.bas",1562
	DECLE 207,0
	;[1563] 	MUSIC E3Z,-
	SRCFILE "mermaid008.bas",1563
	DECLE 209,0
	;[1564] 	MUSIC -,A4Y
	SRCFILE "mermaid008.bas",1564
	DECLE 41472,0
	;[1565] 	MUSIC -,G4Y
	SRCFILE "mermaid008.bas",1565
	DECLE 40960,0
	;[1566] 	MUSIC -,D4Y
	SRCFILE "mermaid008.bas",1566
	DECLE 39680,0
	;[1567] 	MUSIC -,E4Y
	SRCFILE "mermaid008.bas",1567
	DECLE 40192,0
	;[1568] 	
	SRCFILE "mermaid008.bas",1568
	;[1569] 	MUSIC C3Z,-
	SRCFILE "mermaid008.bas",1569
	DECLE 205,0
	;[1570] 	MUSIC C3Z,-
	SRCFILE "mermaid008.bas",1570
	DECLE 205,0
	;[1571] 	MUSIC D3Z,-
	SRCFILE "mermaid008.bas",1571
	DECLE 207,0
	;[1572] 	MUSIC E3Z,-
	SRCFILE "mermaid008.bas",1572
	DECLE 209,0
	;[1573] 	MUSIC -,A5Y
	SRCFILE "mermaid008.bas",1573
	DECLE 44544,0
	;[1574] 	MUSIC -,G5Y
	SRCFILE "mermaid008.bas",1574
	DECLE 44032,0
	;[1575] 	MUSIC -,D5Y
	SRCFILE "mermaid008.bas",1575
	DECLE 42752,0
	;[1576] 	MUSIC -,E5Y
	SRCFILE "mermaid008.bas",1576
	DECLE 43264,0
	;[1577] 
	SRCFILE "mermaid008.bas",1577
	;[1578] 	MUSIC C2Z,-
	SRCFILE "mermaid008.bas",1578
	DECLE 193,0
	;[1579] 	MUSIC C2Z,-
	SRCFILE "mermaid008.bas",1579
	DECLE 193,0
	;[1580] 	MUSIC D2Z,-
	SRCFILE "mermaid008.bas",1580
	DECLE 195,0
	;[1581] 	MUSIC E2Z,-
	SRCFILE "mermaid008.bas",1581
	DECLE 197,0
	;[1582] 	MUSIC -,A4Y
	SRCFILE "mermaid008.bas",1582
	DECLE 41472,0
	;[1583] 	MUSIC -,G4Y
	SRCFILE "mermaid008.bas",1583
	DECLE 40960,0
	;[1584] 	MUSIC -,D4Y
	SRCFILE "mermaid008.bas",1584
	DECLE 39680,0
	;[1585] 	MUSIC -,E4Y
	SRCFILE "mermaid008.bas",1585
	DECLE 40192,0
	;[1586] 
	SRCFILE "mermaid008.bas",1586
	;[1587] 	MUSIC A2Z,-
	SRCFILE "mermaid008.bas",1587
	DECLE 202,0
	;[1588] 	MUSIC A2Z,-
	SRCFILE "mermaid008.bas",1588
	DECLE 202,0
	;[1589] 	MUSIC -,A5Y
	SRCFILE "mermaid008.bas",1589
	DECLE 44544,0
	;[1590] 	MUSIC -,G5Y
	SRCFILE "mermaid008.bas",1590
	DECLE 44032,0
	;[1591] 	MUSIC B2Z,-
	SRCFILE "mermaid008.bas",1591
	DECLE 204,0
	;[1592] 	MUSIC B2Z,-
	SRCFILE "mermaid008.bas",1592
	DECLE 204,0
	;[1593] 	MUSIC -,D5Y
	SRCFILE "mermaid008.bas",1593
	DECLE 42752,0
	;[1594] 	MUSIC -,E5Y
	SRCFILE "mermaid008.bas",1594
	DECLE 43264,0
	;[1595] 	
	SRCFILE "mermaid008.bas",1595
	;[1596] 	MUSIC REPEAT
	SRCFILE "mermaid008.bas",1596
	DECLE 253,0
	;[1597] 	
	SRCFILE "mermaid008.bas",1597
	;[1598] 	'MUSIC STOP	
	SRCFILE "mermaid008.bas",1598
	;[1599] 
	SRCFILE "mermaid008.bas",1599
	;[1600] Level_Complete_Tune:  DATA 16
	SRCFILE "mermaid008.bas",1600
	; LEVEL_COMPLETE_TUNE
Q287:		DECLE 16
	;[1601] 
	SRCFILE "mermaid008.bas",1601
	;[1602] 	MUSIC A2Z,-
	SRCFILE "mermaid008.bas",1602
	DECLE 202,0
	;[1603] 	MUSIC A2Z,-
	SRCFILE "mermaid008.bas",1603
	DECLE 202,0
	;[1604] 	MUSIC -,A5Y
	SRCFILE "mermaid008.bas",1604
	DECLE 44544,0
	;[1605] 	MUSIC -,G5Y
	SRCFILE "mermaid008.bas",1605
	DECLE 44032,0
	;[1606] 	MUSIC B2Z,-
	SRCFILE "mermaid008.bas",1606
	DECLE 204,0
	;[1607] 	MUSIC B2Z,-
	SRCFILE "mermaid008.bas",1607
	DECLE 204,0
	;[1608] 	MUSIC -,D5Y
	SRCFILE "mermaid008.bas",1608
	DECLE 42752,0
	;[1609] 	MUSIC -,E5Y
	SRCFILE "mermaid008.bas",1609
	DECLE 43264,0
	;[1610] 
	SRCFILE "mermaid008.bas",1610
	;[1611] 	MUSIC STOP
	SRCFILE "mermaid008.bas",1611
	DECLE 254,0
	;[1612] 
	SRCFILE "mermaid008.bas",1612
	;[1613] Time_Expired_Tune:  DATA 16
	SRCFILE "mermaid008.bas",1613
	; TIME_EXPIRED_TUNE
Q288:		DECLE 16
	;[1614] 
	SRCFILE "mermaid008.bas",1614
	;[1615] 	MUSIC A2Z,-
	SRCFILE "mermaid008.bas",1615
	DECLE 202,0
	;[1616] 	MUSIC A2Z,-
	SRCFILE "mermaid008.bas",1616
	DECLE 202,0
	;[1617] 	MUSIC -,A5Y
	SRCFILE "mermaid008.bas",1617
	DECLE 44544,0
	;[1618] 	MUSIC -,G5Y
	SRCFILE "mermaid008.bas",1618
	DECLE 44032,0
	;[1619] 	MUSIC B2Z,-
	SRCFILE "mermaid008.bas",1619
	DECLE 204,0
	;[1620] 	MUSIC B2Z,-
	SRCFILE "mermaid008.bas",1620
	DECLE 204,0
	;[1621] 	MUSIC -,D5Y
	SRCFILE "mermaid008.bas",1621
	DECLE 42752,0
	;[1622] 	MUSIC -,E5Y
	SRCFILE "mermaid008.bas",1622
	DECLE 43264,0
	;[1623] 
	SRCFILE "mermaid008.bas",1623
	;[1624] 	MUSIC STOP
	SRCFILE "mermaid008.bas",1624
	DECLE 254,0
	;[1625] 	
	SRCFILE "mermaid008.bas",1625
	;[1626] Game_Over_Tune:  DATA 16
	SRCFILE "mermaid008.bas",1626
	; GAME_OVER_TUNE
Q289:		DECLE 16
	;[1627] 
	SRCFILE "mermaid008.bas",1627
	;[1628] 	MUSIC A2Z,-
	SRCFILE "mermaid008.bas",1628
	DECLE 202,0
	;[1629] 	MUSIC A2Z,-
	SRCFILE "mermaid008.bas",1629
	DECLE 202,0
	;[1630] 	MUSIC -,A5Y
	SRCFILE "mermaid008.bas",1630
	DECLE 44544,0
	;[1631] 	MUSIC -,G5Y
	SRCFILE "mermaid008.bas",1631
	DECLE 44032,0
	;[1632] 	MUSIC B2Z,-
	SRCFILE "mermaid008.bas",1632
	DECLE 204,0
	;[1633] 	MUSIC B2Z,-
	SRCFILE "mermaid008.bas",1633
	DECLE 204,0
	;[1634] 	MUSIC -,D5Y
	SRCFILE "mermaid008.bas",1634
	DECLE 42752,0
	;[1635] 	MUSIC -,E5Y
	SRCFILE "mermaid008.bas",1635
	DECLE 43264,0
	;[1636] 
	SRCFILE "mermaid008.bas",1636
	;[1637] 	MUSIC STOP
	SRCFILE "mermaid008.bas",1637
	DECLE 254,0
	;[1638] 	
	SRCFILE "mermaid008.bas",1638
	;[1639] 	
	SRCFILE "mermaid008.bas",1639
	;[1640] sprites:
	SRCFILE "mermaid008.bas",1640
	; SPRITES
Q15:	;[1641] 'mermaid1   (32)
	SRCFILE "mermaid008.bas",1641
	;[1642] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1642
	;[1643] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1643
	DECLE 0
	;[1644] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1644
	;[1645] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1645
	DECLE 0
	;[1646] 	BITMAP "##......"
	SRCFILE "mermaid008.bas",1646
	;[1647] 	BITMAP "###.#..."
	SRCFILE "mermaid008.bas",1647
	DECLE 59584
	;[1648] 	BITMAP "..#....."
	SRCFILE "mermaid008.bas",1648
	;[1649] 	BITMAP "...#...."
	SRCFILE "mermaid008.bas",1649
	DECLE 4128
	;[1650] 
	SRCFILE "mermaid008.bas",1650
	;[1651]     BITMAP "........"
	SRCFILE "mermaid008.bas",1651
	;[1652] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1652
	DECLE 0
	;[1653] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1653
	;[1654] 	BITMAP "##......"
	SRCFILE "mermaid008.bas",1654
	DECLE 49152
	;[1655] 	BITMAP "##......"
	SRCFILE "mermaid008.bas",1655
	;[1656] 	BITMAP "..#.#..."
	SRCFILE "mermaid008.bas",1656
	DECLE 10432
	;[1657] 	BITMAP "...#...."
	SRCFILE "mermaid008.bas",1657
	;[1658] 	BITMAP "....#..."
	SRCFILE "mermaid008.bas",1658
	DECLE 2064
	;[1659] 
	SRCFILE "mermaid008.bas",1659
	;[1660]     BITMAP "........"
	SRCFILE "mermaid008.bas",1660
	;[1661] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1661
	DECLE 0
	;[1662] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1662
	;[1663] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1663
	DECLE 0
	;[1664] 	BITMAP "##......"
	SRCFILE "mermaid008.bas",1664
	;[1665] 	BITMAP "###.#..."
	SRCFILE "mermaid008.bas",1665
	DECLE 59584
	;[1666] 	BITMAP "...##..."
	SRCFILE "mermaid008.bas",1666
	;[1667] 	BITMAP "........"	
	SRCFILE "mermaid008.bas",1667
	DECLE 24
	;[1668] 
	SRCFILE "mermaid008.bas",1668
	;[1669]     BITMAP "........"
	SRCFILE "mermaid008.bas",1669
	;[1670] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1670
	DECLE 0
	;[1671] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1671
	;[1672] 	BITMAP "##......"
	SRCFILE "mermaid008.bas",1672
	DECLE 49152
	;[1673] 	BITMAP "##......"
	SRCFILE "mermaid008.bas",1673
	;[1674] 	BITMAP "..#.#..."
	SRCFILE "mermaid008.bas",1674
	DECLE 10432
	;[1675] 	BITMAP "...#...."
	SRCFILE "mermaid008.bas",1675
	;[1676] 	BITMAP "....#..."
	SRCFILE "mermaid008.bas",1676
	DECLE 2064
	;[1677] 
	SRCFILE "mermaid008.bas",1677
	;[1678] 'mermaid2   (36)
	SRCFILE "mermaid008.bas",1678
	;[1679] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1679
	;[1680] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1680
	DECLE 0
	;[1681] 	BITMAP ".XXX...."
	SRCFILE "mermaid008.bas",1681
	;[1682] 	BITMAP "XXX....X"
	SRCFILE "mermaid008.bas",1682
	DECLE 57712
	;[1683] 	BITMAP "...XXXXX"
	SRCFILE "mermaid008.bas",1683
	;[1684] 	BITMAP "...X.XX."
	SRCFILE "mermaid008.bas",1684
	DECLE 5663
	;[1685] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1685
	;[1686] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1686
	DECLE 0
	;[1687] 
	SRCFILE "mermaid008.bas",1687
	;[1688]     BITMAP "...X...."
	SRCFILE "mermaid008.bas",1688
	;[1689] 	BITMAP ".XXX...."
	SRCFILE "mermaid008.bas",1689
	DECLE 28688
	;[1690] 	BITMAP "XX......"
	SRCFILE "mermaid008.bas",1690
	;[1691] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1691
	DECLE 192
	;[1692] 	BITMAP "...XXXXX"
	SRCFILE "mermaid008.bas",1692
	;[1693] 	BITMAP "...X.XXX"
	SRCFILE "mermaid008.bas",1693
	DECLE 5919
	;[1694] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1694
	;[1695] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1695
	DECLE 0
	;[1696] 
	SRCFILE "mermaid008.bas",1696
	;[1697]     BITMAP "........"
	SRCFILE "mermaid008.bas",1697
	;[1698] 	BITMAP "...XX..."
	SRCFILE "mermaid008.bas",1698
	DECLE 6144
	;[1699] 	BITMAP "..XX...."
	SRCFILE "mermaid008.bas",1699
	;[1700] 	BITMAP "XX......"
	SRCFILE "mermaid008.bas",1700
	DECLE 49200
	;[1701] 	BITMAP "...XXXX."
	SRCFILE "mermaid008.bas",1701
	;[1702] 	BITMAP "...X.XXX"
	SRCFILE "mermaid008.bas",1702
	DECLE 5918
	;[1703] 	BITMAP ".......X"
	SRCFILE "mermaid008.bas",1703
	;[1704] 	BITMAP "........"	
	SRCFILE "mermaid008.bas",1704
	DECLE 1
	;[1705] 
	SRCFILE "mermaid008.bas",1705
	;[1706]     BITMAP "...X...."
	SRCFILE "mermaid008.bas",1706
	;[1707] 	BITMAP ".XXX...."
	SRCFILE "mermaid008.bas",1707
	DECLE 28688
	;[1708] 	BITMAP "XX......"
	SRCFILE "mermaid008.bas",1708
	;[1709] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1709
	DECLE 192
	;[1710] 	BITMAP "...XXXXX"
	SRCFILE "mermaid008.bas",1710
	;[1711] 	BITMAP "...X.XXX"
	SRCFILE "mermaid008.bas",1711
	DECLE 5919
	;[1712] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1712
	;[1713] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1713
	DECLE 0
	;[1714] 
	SRCFILE "mermaid008.bas",1714
	;[1715] 'bubble (40)
	SRCFILE "mermaid008.bas",1715
	;[1716]     BITMAP "..XXXX.."
	SRCFILE "mermaid008.bas",1716
	;[1717] 	BITMAP ".X....X."
	SRCFILE "mermaid008.bas",1717
	DECLE 16956
	;[1718] 	BITMAP "X......X"
	SRCFILE "mermaid008.bas",1718
	;[1719] 	BITMAP "X......X"
	SRCFILE "mermaid008.bas",1719
	DECLE 33153
	;[1720] 	BITMAP "X......X"
	SRCFILE "mermaid008.bas",1720
	;[1721] 	BITMAP "X......X"
	SRCFILE "mermaid008.bas",1721
	DECLE 33153
	;[1722] 	BITMAP ".X....X."
	SRCFILE "mermaid008.bas",1722
	;[1723]     BITMAP "..XXXX.."
	SRCFILE "mermaid008.bas",1723
	DECLE 15426
	;[1724] 
	SRCFILE "mermaid008.bas",1724
	;[1725] 'squid (41)
	SRCFILE "mermaid008.bas",1725
	;[1726] 	BITMAP "XXX....."
	SRCFILE "mermaid008.bas",1726
	;[1727] 	BITMAP "XXXX...."
	SRCFILE "mermaid008.bas",1727
	DECLE 61664
	;[1728] 	BITMAP "XXXX...."
	SRCFILE "mermaid008.bas",1728
	;[1729] 	BITMAP "..XXX..."
	SRCFILE "mermaid008.bas",1729
	DECLE 14576
	;[1730] 	BITMAP ".XXXXXX."
	SRCFILE "mermaid008.bas",1730
	;[1731] 	BITMAP "X.X..X.X"
	SRCFILE "mermaid008.bas",1731
	DECLE 42366
	;[1732] 	BITMAP ".X.X..X."
	SRCFILE "mermaid008.bas",1732
	;[1733] 	BITMAP "..X.X..X"
	SRCFILE "mermaid008.bas",1733
	DECLE 10578
	;[1734] 
	SRCFILE "mermaid008.bas",1734
	;[1735] 	BITMAP ".XXX...."
	SRCFILE "mermaid008.bas",1735
	;[1736] 	BITMAP ".XXXX..."
	SRCFILE "mermaid008.bas",1736
	DECLE 30832
	;[1737] 	BITMAP ".XXXX..."
	SRCFILE "mermaid008.bas",1737
	;[1738] 	BITMAP "...XXX.."
	SRCFILE "mermaid008.bas",1738
	DECLE 7288
	;[1739] 	BITMAP "..XXXXXX"
	SRCFILE "mermaid008.bas",1739
	;[1740] 	BITMAP ".X.X..X."
	SRCFILE "mermaid008.bas",1740
	DECLE 21055
	;[1741] 	BITMAP ".X.X..X."
	SRCFILE "mermaid008.bas",1741
	;[1742] 	BITMAP "..X.X..X"
	SRCFILE "mermaid008.bas",1742
	DECLE 10578
	;[1743] 
	SRCFILE "mermaid008.bas",1743
	;[1744] 'fish1 (43)
	SRCFILE "mermaid008.bas",1744
	;[1745] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1745
	;[1746] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1746
	DECLE 0
	;[1747] 	BITMAP ".XXX.XX."
	SRCFILE "mermaid008.bas",1747
	;[1748] 	BITMAP "XXXXXXX."
	SRCFILE "mermaid008.bas",1748
	DECLE 65142
	;[1749] 	BITMAP ".XXX.XX."
	SRCFILE "mermaid008.bas",1749
	;[1750] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1750
	DECLE 118
	;[1751] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1751
	;[1752] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1752
	DECLE 0
	;[1753] 
	SRCFILE "mermaid008.bas",1753
	;[1754] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1754
	;[1755] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1755
	DECLE 0
	;[1756] 	BITMAP ".XXX..X."
	SRCFILE "mermaid008.bas",1756
	;[1757] 	BITMAP "XXXXXX.."
	SRCFILE "mermaid008.bas",1757
	DECLE 64626
	;[1758] 	BITMAP ".XXX..X."
	SRCFILE "mermaid008.bas",1758
	;[1759] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1759
	DECLE 114
	;[1760] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1760
	;[1761] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1761
	DECLE 0
	;[1762] 
	SRCFILE "mermaid008.bas",1762
	;[1763] 'shark-left (45)
	SRCFILE "mermaid008.bas",1763
	;[1764] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1764
	;[1765] 	BITMAP ".......X"
	SRCFILE "mermaid008.bas",1765
	DECLE 256
	;[1766] 	BITMAP "....XXXX"
	SRCFILE "mermaid008.bas",1766
	;[1767] 	BITMAP ".XXXX.XX"
	SRCFILE "mermaid008.bas",1767
	DECLE 31503
	;[1768] 	BITMAP "XXXXXXXX"
	SRCFILE "mermaid008.bas",1768
	;[1769] 	BITMAP ".XXXXXXX"
	SRCFILE "mermaid008.bas",1769
	DECLE 32767
	;[1770] 	BITMAP "......XX"
	SRCFILE "mermaid008.bas",1770
	;[1771] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1771
	DECLE 3
	;[1772] 
	SRCFILE "mermaid008.bas",1772
	;[1773] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1773
	;[1774] 	BITMAP ".......X"
	SRCFILE "mermaid008.bas",1774
	DECLE 256
	;[1775] 	BITMAP "...XXXXX"
	SRCFILE "mermaid008.bas",1775
	;[1776] 	BITMAP "XXXX.XXX"
	SRCFILE "mermaid008.bas",1776
	DECLE 63263
	;[1777] 	BITMAP "..XXXXXX"
	SRCFILE "mermaid008.bas",1777
	;[1778] 	BITMAP "XXXXXXXX"
	SRCFILE "mermaid008.bas",1778
	DECLE 65343
	;[1779] 	BITMAP "......XX"
	SRCFILE "mermaid008.bas",1779
	;[1780] 	BITMAP ".......X"
	SRCFILE "mermaid008.bas",1780
	DECLE 259
	;[1781] 
	SRCFILE "mermaid008.bas",1781
	;[1782] 
	SRCFILE "mermaid008.bas",1782
	;[1783] 'shark-right (47)
	SRCFILE "mermaid008.bas",1783
	;[1784] 	BITMAP "X......."
	SRCFILE "mermaid008.bas",1784
	;[1785] 	BITMAP "X......."
	SRCFILE "mermaid008.bas",1785
	DECLE 32896
	;[1786] 	BITMAP "XXXXX.XX"
	SRCFILE "mermaid008.bas",1786
	;[1787] 	BITMAP "XXXXXX.."
	SRCFILE "mermaid008.bas",1787
	DECLE 64763
	;[1788] 	BITMAP "XXXXXX.."
	SRCFILE "mermaid008.bas",1788
	;[1789] 	BITMAP "XXXXX.XX"
	SRCFILE "mermaid008.bas",1789
	DECLE 64508
	;[1790] 	BITMAP "X..X...."
	SRCFILE "mermaid008.bas",1790
	;[1791] 	BITMAP "X......."
	SRCFILE "mermaid008.bas",1791
	DECLE 32912
	;[1792] 
	SRCFILE "mermaid008.bas",1792
	;[1793] 
	SRCFILE "mermaid008.bas",1793
	;[1794] moreSprites:
	SRCFILE "mermaid008.bas",1794
	; MORESPRITES
Q16:	;[1795] 	BITMAP "X......."
	SRCFILE "mermaid008.bas",1795
	;[1796] 	BITMAP "X......X"
	SRCFILE "mermaid008.bas",1796
	DECLE 33152
	;[1797] 	BITMAP "XXXXX.XX"
	SRCFILE "mermaid008.bas",1797
	;[1798] 	BITMAP "XXXXXXX."
	SRCFILE "mermaid008.bas",1798
	DECLE 65275
	;[1799] 	BITMAP "XXXXXXX."
	SRCFILE "mermaid008.bas",1799
	;[1800] 	BITMAP "XXXXX.XX"
	SRCFILE "mermaid008.bas",1800
	DECLE 64510
	;[1801] 	BITMAP "....X..X"
	SRCFILE "mermaid008.bas",1801
	;[1802] 	BITMAP "X......."
	SRCFILE "mermaid008.bas",1802
	DECLE 32777
	;[1803] 
	SRCFILE "mermaid008.bas",1803
	;[1804] 
	SRCFILE "mermaid008.bas",1804
	;[1805] 'octopus  (49)
	SRCFILE "mermaid008.bas",1805
	;[1806] 	BITMAP "..XXXXXX"
	SRCFILE "mermaid008.bas",1806
	;[1807] 	BITMAP ".XX.XX.X"
	SRCFILE "mermaid008.bas",1807
	DECLE 27967
	;[1808] 	BITMAP ".XXXXXXX"
	SRCFILE "mermaid008.bas",1808
	;[1809] 	BITMAP ".XXXXXXX"
	SRCFILE "mermaid008.bas",1809
	DECLE 32639
	;[1810] 	BITMAP ".XXXXXXX"
	SRCFILE "mermaid008.bas",1810
	;[1811] 	BITMAP "X.X.X.X."
	SRCFILE "mermaid008.bas",1811
	DECLE 43647
	;[1812] 	BITMAP "X.X.X.X."
	SRCFILE "mermaid008.bas",1812
	;[1813] 	BITMAP "X.X.X.X."
	SRCFILE "mermaid008.bas",1813
	DECLE 43690
	;[1814] 
	SRCFILE "mermaid008.bas",1814
	;[1815] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1815
	;[1816] 	BITMAP "..XXXXXX"
	SRCFILE "mermaid008.bas",1816
	DECLE 16128
	;[1817] 	BITMAP ".X.XX.XX"
	SRCFILE "mermaid008.bas",1817
	;[1818] 	BITMAP ".XXXXXXX"
	SRCFILE "mermaid008.bas",1818
	DECLE 32603
	;[1819] 	BITMAP ".XXXXXXX"
	SRCFILE "mermaid008.bas",1819
	;[1820] 	BITMAP "X.X.X.X."
	SRCFILE "mermaid008.bas",1820
	DECLE 43647
	;[1821] 	BITMAP "X.X.X.X."
	SRCFILE "mermaid008.bas",1821
	;[1822] 	BITMAP ".X.X.X.X"
	SRCFILE "mermaid008.bas",1822
	DECLE 21930
	;[1823] 	
	SRCFILE "mermaid008.bas",1823
	;[1824] 'queen's sceptre	(51)
	SRCFILE "mermaid008.bas",1824
	;[1825] 	BITMAP "XX......"
	SRCFILE "mermaid008.bas",1825
	;[1826] 	BITMAP "X.X....."
	SRCFILE "mermaid008.bas",1826
	DECLE 41152
	;[1827] 	BITMAP ".XX....."
	SRCFILE "mermaid008.bas",1827
	;[1828] 	BITMAP "...X...."
	SRCFILE "mermaid008.bas",1828
	DECLE 4192
	;[1829] 	BITMAP "....X..."
	SRCFILE "mermaid008.bas",1829
	;[1830] 	BITMAP ".....X.."
	SRCFILE "mermaid008.bas",1830
	DECLE 1032
	;[1831] 	BITMAP "......X."
	SRCFILE "mermaid008.bas",1831
	;[1832] 	BITMAP ".......X"
	SRCFILE "mermaid008.bas",1832
	DECLE 258
	;[1833] 
	SRCFILE "mermaid008.bas",1833
	;[1834] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1834
	;[1835] 	BITMAP ".XX....."
	SRCFILE "mermaid008.bas",1835
	DECLE 24576
	;[1836] 	BITMAP ".X.X...."
	SRCFILE "mermaid008.bas",1836
	;[1837] 	BITMAP "..XX...."
	SRCFILE "mermaid008.bas",1837
	DECLE 12368
	;[1838] 	BITMAP "....X..."
	SRCFILE "mermaid008.bas",1838
	;[1839] 	BITMAP ".....X.."
	SRCFILE "mermaid008.bas",1839
	DECLE 1032
	;[1840] 	BITMAP "......X."
	SRCFILE "mermaid008.bas",1840
	;[1841] 	BITMAP ".......X"
	SRCFILE "mermaid008.bas",1841
	DECLE 258
	;[1842] 
	SRCFILE "mermaid008.bas",1842
	;[1843] 
	SRCFILE "mermaid008.bas",1843
	;[1844] 'fish2 (53)
	SRCFILE "mermaid008.bas",1844
	;[1845] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1845
	;[1846] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1846
	DECLE 0
	;[1847] 	BITMAP "...XXX.X"
	SRCFILE "mermaid008.bas",1847
	;[1848] 	BITMAP "..XXXXX."
	SRCFILE "mermaid008.bas",1848
	DECLE 15901
	;[1849] 	BITMAP "...XXX.X"
	SRCFILE "mermaid008.bas",1849
	;[1850] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1850
	DECLE 29
	;[1851] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1851
	;[1852] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1852
	DECLE 0
	;[1853] 
	SRCFILE "mermaid008.bas",1853
	;[1854] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1854
	;[1855] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1855
	DECLE 0
	;[1856] 	BITMAP "...XXX.X"
	SRCFILE "mermaid008.bas",1856
	;[1857] 	BITMAP "..XXXXXX"
	SRCFILE "mermaid008.bas",1857
	DECLE 16157
	;[1858] 	BITMAP "...XX..."
	SRCFILE "mermaid008.bas",1858
	;[1859] 	BITMAP ".....X.."
	SRCFILE "mermaid008.bas",1859
	DECLE 1048
	;[1860] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1860
	;[1861] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1861
	DECLE 0
	;[1862] 	
	SRCFILE "mermaid008.bas",1862
	;[1863] 'fish3 (55)
	SRCFILE "mermaid008.bas",1863
	;[1864] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1864
	;[1865] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1865
	DECLE 0
	;[1866] 	BITMAP "...XXX.X"
	SRCFILE "mermaid008.bas",1866
	;[1867] 	BITMAP "..XXXXX."
	SRCFILE "mermaid008.bas",1867
	DECLE 15901
	;[1868] 	BITMAP "...XXX.X"
	SRCFILE "mermaid008.bas",1868
	;[1869] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1869
	DECLE 29
	;[1870] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1870
	;[1871] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1871
	DECLE 0
	;[1872] 
	SRCFILE "mermaid008.bas",1872
	;[1873] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1873
	;[1874] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1874
	DECLE 0
	;[1875] 	BITMAP "...XXX.X"
	SRCFILE "mermaid008.bas",1875
	;[1876] 	BITMAP "..XXXXXX"
	SRCFILE "mermaid008.bas",1876
	DECLE 16157
	;[1877] 	BITMAP "...XX..."
	SRCFILE "mermaid008.bas",1877
	;[1878] 	BITMAP ".....X.."
	SRCFILE "mermaid008.bas",1878
	DECLE 1048
	;[1879] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1879
	;[1880] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1880
	DECLE 0
	;[1881] 
	SRCFILE "mermaid008.bas",1881
	;[1882] 'queen (57)
	SRCFILE "mermaid008.bas",1882
	;[1883] 	BITMAP "...XXX.."
	SRCFILE "mermaid008.bas",1883
	;[1884] 	BITMAP "......XX"
	SRCFILE "mermaid008.bas",1884
	DECLE 796
	;[1885] 	BITMAP "..XXX..."
	SRCFILE "mermaid008.bas",1885
	;[1886] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1886
	DECLE 56
	;[1887] 	BITMAP "..XXX..."
	SRCFILE "mermaid008.bas",1887
	;[1888] 	BITMAP "...XXX.."
	SRCFILE "mermaid008.bas",1888
	DECLE 7224
	;[1889] 	BITMAP "..XXX..."
	SRCFILE "mermaid008.bas",1889
	;[1890] 	BITMAP ".XXX...."
	SRCFILE "mermaid008.bas",1890
	DECLE 28728
	;[1891] 
	SRCFILE "mermaid008.bas",1891
	;[1892] 	BITMAP "....XXX."
	SRCFILE "mermaid008.bas",1892
	;[1893] 	BITMAP ".......X"
	SRCFILE "mermaid008.bas",1893
	DECLE 270
	;[1894] 	BITMAP "...XXX.."
	SRCFILE "mermaid008.bas",1894
	;[1895] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1895
	DECLE 28
	;[1896] 	BITMAP "...XXX.."
	SRCFILE "mermaid008.bas",1896
	;[1897] 	BITMAP "..XXX..."
	SRCFILE "mermaid008.bas",1897
	DECLE 14364
	;[1898] 	BITMAP "...XXX.."
	SRCFILE "mermaid008.bas",1898
	;[1899] 	BITMAP "....XXX."
	SRCFILE "mermaid008.bas",1899
	DECLE 3612
	;[1900] 
	SRCFILE "mermaid008.bas",1900
	;[1901] 'queen2 (59)
	SRCFILE "mermaid008.bas",1901
	;[1902] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1902
	;[1903] 	BITMAP "...XXX.."
	SRCFILE "mermaid008.bas",1903
	DECLE 7168
	;[1904] 	BITMAP "..X...X."
	SRCFILE "mermaid008.bas",1904
	;[1905] 	BITMAP ".X.XXX.X"
	SRCFILE "mermaid008.bas",1905
	DECLE 23842
	;[1906] 	BITMAP "X......X"
	SRCFILE "mermaid008.bas",1906
	;[1907] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1907
	DECLE 129
	;[1908] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1908
	;[1909] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1909
	DECLE 0
	;[1910] 
	SRCFILE "mermaid008.bas",1910
	;[1911] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1911
	;[1912] 	BITMAP "...XXX.."
	SRCFILE "mermaid008.bas",1912
	DECLE 7168
	;[1913] 	BITMAP ".XX...XX"
	SRCFILE "mermaid008.bas",1913
	;[1914] 	BITMAP "X..XXX.X"
	SRCFILE "mermaid008.bas",1914
	DECLE 40291
	;[1915] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1915
	;[1916] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1916
	DECLE 0
	;[1917] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1917
	;[1918] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1918
	DECLE 0
	;[1919] 
	SRCFILE "mermaid008.bas",1919
	;[1920] 'fish6 (61)
	SRCFILE "mermaid008.bas",1920
	;[1921] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1921
	;[1922] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1922
	DECLE 0
	;[1923] 	BITMAP "...XXX.X"
	SRCFILE "mermaid008.bas",1923
	;[1924] 	BITMAP "..XXXXX."
	SRCFILE "mermaid008.bas",1924
	DECLE 15901
	;[1925] 	BITMAP "...XXX.X"
	SRCFILE "mermaid008.bas",1925
	;[1926] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1926
	DECLE 29
	;[1927] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1927
	;[1928] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1928
	DECLE 0
	;[1929] 
	SRCFILE "mermaid008.bas",1929
	;[1930] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1930
	;[1931] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1931
	DECLE 0
	;[1932] 	BITMAP "...XXX.X"
	SRCFILE "mermaid008.bas",1932
	;[1933] 	BITMAP "..XXXXXX"
	SRCFILE "mermaid008.bas",1933
	DECLE 16157
	;[1934] 	BITMAP "...XX..."
	SRCFILE "mermaid008.bas",1934
	;[1935] 	BITMAP ".....X.."
	SRCFILE "mermaid008.bas",1935
	DECLE 1048
	;[1936] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1936
	;[1937] 	BITMAP "........"	
	SRCFILE "mermaid008.bas",1937
	DECLE 0
	;[1938] 
	SRCFILE "mermaid008.bas",1938
	;[1939] 'fish7 (63)
	SRCFILE "mermaid008.bas",1939
	;[1940] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1940
	;[1941] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1941
	DECLE 0
	;[1942] 	BITMAP "...XXX.X"
	SRCFILE "mermaid008.bas",1942
	;[1943] 	BITMAP "..XXXXX."
	SRCFILE "mermaid008.bas",1943
	DECLE 15901
	;[1944] 	BITMAP "...XXX.X"
	SRCFILE "mermaid008.bas",1944
	;[1945] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1945
	DECLE 29
	;[1946] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1946
	;[1947] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1947
	DECLE 0
	;[1948] 
	SRCFILE "mermaid008.bas",1948
	;[1949] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1949
	;[1950] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1950
	DECLE 0
	;[1951] 	BITMAP "...XXX.X"
	SRCFILE "mermaid008.bas",1951
	;[1952] 	BITMAP "..XXXXXX"
	SRCFILE "mermaid008.bas",1952
	DECLE 16157
	;[1953] 	BITMAP "...XX..."
	SRCFILE "mermaid008.bas",1953
	;[1954] 	BITMAP ".....X.."
	SRCFILE "mermaid008.bas",1954
	DECLE 1048
	;[1955] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1955
	;[1956] 	BITMAP "........"
	SRCFILE "mermaid008.bas",1956
	DECLE 0
	;[1957] 
	SRCFILE "mermaid008.bas",1957
	;[1958] end:
	SRCFILE "mermaid008.bas",1958
	; END
Q292:	;[1959] goto end
	SRCFILE "mermaid008.bas",1959
	B Q292
	;ENDFILE
	SRCFILE "",0
	IF DEFINED __FEATURE.CFGVAR
		CFGVAR "voice" = 1
	ENDI
intybasic_keypad:	equ 1	; Forces to include keypad library
intybasic_music:	equ 1	; Forces to include music library
intybasic_numbers:	equ 1	; Forces to include numbers library
intybasic_voice:	equ 1	; Forces to include voice library
intybasic_fastmult:	equ 1	; Forces to include fast multiplication
        ;
        ; Epilogue for IntyBASIC programs
        ; by Oscar Toledo G.  http://nanochess.org/
        ;
        ; Revision: Jan/30/2014. Moved GRAM code below MOB updates.
        ;                        Added comments.
        ; Revision: Feb/26/2014. Optimized access to collision registers
        ;                        per DZ-Jay suggestion. Added scrolling
        ;                        routines with optimization per intvnut
        ;                        suggestion. Added border/mask support.
        ; Revision: Apr/02/2014. Added support to set MODE (color stack
        ;                        or foreground/background), added support
        ;                        for SCREEN statement.
        ; Revision: Aug/19/2014. Solved bug in bottom scroll, moved an
        ;                        extra unneeded line.
        ; Revision: Aug/26/2014. Integrated music player and NTSC/PAL
        ;                        detection.
        ; Revision: Oct/24/2014. Adjust in some comments.
        ; Revision: Nov/13/2014. Integrated Joseph Zbiciak's routines
        ;                        for printing numbers.
        ; Revision: Nov/17/2014. Redesigned MODE support to use a single
        ;                        variable.
        ; Revision: Nov/21/2014. Added Intellivoice support routines made
        ;                        by Joseph Zbiciak.
	; Revision: Dec/11/2014. Optimized keypad decode routines.
	; Revision: Jan/25/2015. Added marker for insertion of ON FRAME GOSUB
	; Revision: Feb/17/2015. Allows to deactivate music player (PLAY NONE)
	; Revision: Apr/21/2015. Accelerates common case of keypad not pressed.
	;                        Added ECS ROM disable code.
	; Revision: Apr/22/2015. Added Joseph Zbiciak accelerated multiplication
	;                        routines.
	; Revision: Jun/04/2015. Optimized play_music (per GroovyBee suggestion)
	; Revision: Jul/25/2015. Added infinite loop at start to avoid crashing
	;                        with empty programs. Solved bug where _color
	;                        didn't started with white.
	; Revision: Aug/20/2015. Moved ECS mapper disable code so nothing gets
	;                        after it (GroovyBee 42K sample code)
	; Revision: Aug/21/2015. Added Joseph Zbiciak routines for JLP Flash
	;                        handling.
	; Revision: Aug/31/2015. Added CPYBLK2 for SCREEN fifth argument.
	; Revision: Sep/01/2015. Defined labels Q1 and Q2 as alias.

	;
	; Avoids empty programs to crash
	; 
stuck:	B stuck

	;
	; Copy screen helper for SCREEN wide statement
	;

CPYBLK2:	PROC
	MOVR R0,R3		; Offset
	MOVR R5,R2
	PULR R0
	PULR R1
	PULR R5
	PULR R4
	PSHR R2
	SUBR R1,R3

@@1:    PSHR R3
	MOVR R1,R3              ; Init line copy
@@2:    MVI@ R4,R2              ; Copy line
        MVO@ R2,R5
        DECR R3
        BNE @@2
        PULR R3                 ; Add offset to start in next line
        ADDR R3,R4
	SUBR R1,R5
        ADDI #20,R5
        DECR R0                 ; Count lines
        BNE @@1

	RETURN
	ENDP

        ;
        ; Copy screen helper for SCREEN statement
        ;
CPYBLK: PROC
        BEGIN
        MOVR R3,R4
        MOVR R2,R5

@@1:    MOVR R1,R3              ; Init line copy
@@2:    MVI@ R4,R2              ; Copy line
        MVO@ R2,R5
        DECR R3
        BNE @@2
        MVII #20,R3             ; Add offset to start in next line
        SUBR R1,R3
        ADDR R3,R4
        ADDR R3,R5
        DECR R0                 ; Count lines
        BNE @@1
	RETURN
        ENDP

        ;
        ; Wait for interruption
        ;
_wait:  PROC

    IF DEFINED intybasic_keypad
        MVI $01FF,R0
        COMR R0
        ANDI #$FF,R0
        CMP _cnt1_p0,R0
        BNE @@2
        CMP _cnt1_p1,R0
        BNE @@2
	TSTR R0		; Accelerates common case of key not pressed
	MVII #_keypad_table+13,R4
	BEQ @@4
        MVII #_keypad_table,R4
    REPEAT 6
        CMP@ R4,R0
        BEQ @@4
	CMP@ R4,R0
        BEQ @@4
    ENDR
	INCR R4
@@4:    SUBI #_keypad_table+1,R4
	MVO R4,_cnt1_key

@@2:    MVI _cnt1_p1,R1
        MVO R1,_cnt1_p0
        MVO R0,_cnt1_p1

        MVI $01FE,R0
        COMR R0
        ANDI #$FF,R0
        CMP _cnt2_p0,R0
        BNE @@5
        CMP _cnt2_p1,R0
        BNE @@5
	TSTR R0		; Accelerates common case of key not pressed
	MVII #_keypad_table+13,R4
	BEQ @@7
        MVII #_keypad_table,R4
    REPEAT 6
        CMP@ R4,R0
        BEQ @@7
	CMP@ R4,R0
	BEQ @@7
    ENDR

	INCR R4
@@7:    SUBI #_keypad_table+1,R4
	MVO R4,_cnt2_key

@@5:    MVI _cnt2_p1,R1
        MVO R1,_cnt2_p0
        MVO R0,_cnt2_p1
    ENDI

        CLRR    R0
        MVO     R0,_int         ; Clears waiting flag
@@1:    CMP     _int,  R0       ; Waits for change
        BEQ     @@1
        JR      R5              ; Returns
        ENDP

        ;
        ; Keypad table
        ;
_keypad_table:          PROC
        DECLE $48,$81,$41,$21,$82,$42,$22,$84,$44,$24,$88,$28
        ENDP

_pal1_vector:    PROC
        MVII #_pal2_vector,R0
        MVO R0,ISRVEC
        SWAP R0
        MVO R0,ISRVEC+1
        MVII #3,R0
        MVO R0,_ntsc
        JR R5
        ENDP

_pal2_vector:    PROC
        MVII #_int_vector,R0     ; Point to "real" interruption handler
        MVO R0,ISRVEC
        SWAP R0
        MVO R0,ISRVEC+1
        MVII #4,R0
        MVO R0,_ntsc
	CLRR R0
	CLRR R4
	MVII #$18,R1
@@1:	MVO@ R0,R4
	DECR R1
	BNE @@1
        JR R5
        ENDP

        ;
        ; Interruption routine
        ;
_int_vector:     PROC
        BEGIN

        MVO     R0,     $20     ; Activates display

    IF DEFINED intybasic_stack
	CMPI #$308,R6
	BNC @@vs
	MVI $21,R0	; Activates Color Stack mode
	CLRR R0
	MVO R0,$28
	MVO R0,$29
	MVO R0,$2A
	MVO R0,$2B
	MVII #@@vs1,R4
	MVII #$200,R5
	MVII #20,R1
@@vs2:	MVI@ R4,R0
	MVO@ R0,R5
	DECR R1
	BNE @@vs2
	RETURN

	; Stack Overflow message
@@vs1:	DECLE 0,0,0,$33*8+7,$54*8+7,$41*8+7,$43*8+7,$4B*8+7,$00*8+7
	DECLE $4F*8+7,$56*8+7,$45*8+7,$52*8+7,$46*8+7,$4C*8+7
	DECLE $4F*8+7,$57*8+7,0,0,0

@@vs:
    ENDI
        MVII    #1,     R0
        MVO     R0,     _int    ; Indicates interrupt happened

        MVI _mode_select,R0
        TSTR R0
        BEQ @@vi0
        CLRR R1
        MVO R1,_mode_select
        DECR R0
        BEQ @@vi14
        MVO R0,$21  ; Activates Foreground/Background mode
        B @@vi15

@@vi14: MVI $21,R0  ; Activates Color Stack mode
        MVI _color,R0
        MVO R0,$28
        SWAP R0
        MVO R0,$29
        SLR R0,2
        SLR R0,2
        MVO R0,$2A
        SWAP R0
        MVO R0,$2B
@@vi15: MVII #7,R0
        MVO R0,_color           ; Default color for PRINT "string"
@@vi0:
        MVI _border_color,R0
        MVO     R0,     $2C     ; Border color
        MVI _border_mask,R0
        MVO     R0,     $32     ; Border mask
        ;
        ; Save collision registers for further use and clear them
        ;
        MVII #$18,R4
        MVII #_col0,R5
        MVI@ R4,R0
        MVO@ R0,R5  ; _col0
        MVI@ R4,R0
        MVO@ R0,R5  ; _col1
        MVI@ R4,R0
        MVO@ R0,R5  ; _col2
        MVI@ R4,R0
        MVO@ R0,R5  ; _col3
        MVI@ R4,R0
        MVO@ R0,R5  ; _col4
        MVI@ R4,R0
        MVO@ R0,R5  ; _col5
        MVI@ R4,R0
        MVO@ R0,R5  ; _col6
        MVI@ R4,R0
        MVO@ R0,R5  ; _col7
        MVII #$18,R5
        CLRR R0
        MVO@ R0,R5
        MVO@ R0,R5
        MVO@ R0,R5
        MVO@ R0,R5
        MVO@ R0,R5
        MVO@ R0,R5
        MVO@ R0,R5
        MVO@ R0,R5
        
    IF DEFINED intybasic_scroll

        ;
        ; Scrolling things
        ;
        MVI _scroll_x,R0
        MVO R0,$30
        MVI _scroll_y,R0
        MVO R0,$31
    ENDI

        ;
        ; Updates sprites (MOBs)
        ;
        MVII #_mobs,R4
        MVII #$0,R5     ; X-coordinates
        MVII #8,R1
@@vi2:  MVI@ R4,R0
        MVO@ R0,R5
        MVI@ R4,R0
        MVO@ R0,R5
        MVI@ R4,R0
        MVO@ R0,R5
        DECR R1
        BNE @@vi2

    IF DEFINED intybasic_music
     	MVI _ntsc,R0
        TSTR R0         ; PAL?
        BEQ @@vo97      ; Yes, always emit sound
	MVI _music_frame,R0
	INCR R0
	CMPI #6,R0
	BNE @@vo14
	CLRR R0
@@vo14:	MVO R0,_music_frame
	BEQ @@vo15
@@vo97:	CALL _emit_sound
@@vo15:
    ENDI

        ;
        ; Detect GRAM definition
        ;
        MVI _gram_bitmap,R4
        TSTR R4
        BEQ @@vi1
        MVI _gram_target,R1
        SLL R1,2
        SLL R1,1
        ADDI #$3800,R1
        MOVR R1,R5
        MVI _gram_total,R0
@@vi3:
        MVI@    R4,     R1
        MVO@    R1,     R5
        SWAP    R1
        MVO@    R1,     R5
        MVI@    R4,     R1
        MVO@    R1,     R5
        SWAP    R1
        MVO@    R1,     R5
        MVI@    R4,     R1
        MVO@    R1,     R5
        SWAP    R1
        MVO@    R1,     R5
        MVI@    R4,     R1
        MVO@    R1,     R5
        SWAP    R1
        MVO@    R1,     R5
        DECR R0
        BNE @@vi3
        MVO R0,_gram_bitmap
@@vi1:
        MVI _gram2_bitmap,R4
        TSTR R4
        BEQ @@vii1
        MVI _gram2_target,R1
        SLL R1,2
        SLL R1,1
        ADDI #$3800,R1
        MOVR R1,R5
        MVI _gram2_total,R0
@@vii3:
        MVI@    R4,     R1
        MVO@    R1,     R5
        SWAP    R1
        MVO@    R1,     R5
        MVI@    R4,     R1
        MVO@    R1,     R5
        SWAP    R1
        MVO@    R1,     R5
        MVI@    R4,     R1
        MVO@    R1,     R5
        SWAP    R1
        MVO@    R1,     R5
        MVI@    R4,     R1
        MVO@    R1,     R5
        SWAP    R1
        MVO@    R1,     R5
        DECR R0
        BNE @@vii3
        MVO R0,_gram2_bitmap
@@vii1:

    IF DEFINED intybasic_scroll
        ;
        ; Frame scroll support
        ;
        MVI _scroll_d,R0
        TSTR R0
        BEQ @@vi4
        CLRR R1
        MVO R1,_scroll_d
        DECR R0     ; Left
        BEQ @@vi5
        DECR R0     ; Right
        BEQ @@vi6
        DECR R0     ; Top
        BEQ @@vi7
        DECR R0     ; Bottom
        BEQ @@vi8
        B @@vi4

@@vi5:  MVII #$0200,R4
        MOVR R4,R5
        INCR R5
        MVII #12,R1
@@vi12: MVI@ R4,R2
        MVI@ R4,R3
        REPEAT 8
        MVO@ R2,R5
        MVI@ R4,R2
        MVO@ R3,R5
        MVI@ R4,R3
        ENDR
        MVO@ R2,R5
        MVI@ R4,R2
        MVO@ R3,R5
        MVO@ R2,R5
        INCR R4
        INCR R5
        DECR R1
        BNE @@vi12
        B @@vi4

@@vi6:  MVII #$0201,R4
        MVII #$0200,R5
        MVII #12,R1
@@vi11:
        REPEAT 19
        MVI@ R4,R0
        MVO@ R0,R5
        ENDR
        INCR R4
        INCR R5
        DECR R1
        BNE @@vi11
        B @@vi4
    
        ;
        ; Complex routine to be ahead of STIC display
        ; Moves first the top 6 lines, saves intermediate line
        ; Then moves the bottom 6 lines and restores intermediate line
        ;
@@vi7:  MVII #$0264,R4
        MVII #5,R1
        MVII #_scroll_buffer,R5
        REPEAT 20
        MVI@ R4,R0
        MVO@ R0,R5
        ENDR
        SUBI #40,R4
        MOVR R4,R5
        ADDI #20,R5
@@vi10:
        REPEAT 20
        MVI@ R4,R0
        MVO@ R0,R5
        ENDR
        SUBI #40,R4
        SUBI #40,R5
        DECR R1
        BNE @@vi10
        MVII #$02C8,R4
        MVII #$02DC,R5
        MVII #5,R1
@@vi13:
        REPEAT 20
        MVI@ R4,R0
        MVO@ R0,R5
        ENDR
        SUBI #40,R4
        SUBI #40,R5
        DECR R1
        BNE @@vi13
        MVII #_scroll_buffer,R4
        REPEAT 20
        MVI@ R4,R0
        MVO@ R0,R5
        ENDR
        B @@vi4

@@vi8:  MVII #$0214,R4
        MVII #$0200,R5
        MVII #$DC/4,R1
@@vi9:  
        REPEAT 4
        MVI@ R4,R0
        MVO@ R0,R5
        ENDR
        DECR R1
        BNE @@vi9
        B @@vi4

@@vi4:
    ENDI

    IF DEFINED intybasic_voice
        ;
        ; Intellivoice support
        ;
        CALL IV_ISR
    ENDI

        ;
        ; Random number generator
        ;
	CALL _next_random

    IF DEFINED intybasic_music
	; Generate sound for next frame
       	MVI _ntsc,R0
        TSTR R0         ; PAL?
        BEQ @@vo98      ; Yes, always generate sound
	MVI _music_frame,R0
	TSTR R0
	BEQ @@vo16
@@vo98: CALL _generate_music
@@vo16:
    ENDI

        ; Increase frame number
        MVI _frame,R0
        INCR R0
        MVO R0,_frame

	; This mark is for ON FRAME GOSUB support

        RETURN
        ENDP

	;
	; Generates the next random number
	;
_next_random:	PROC

MACRO _ROR
	RRC R0,1
	MOVR R0,R2
	SLR R2,2
	SLR R2,2
	ANDI #$0800,R2
	SLR R2,2
	SLR R2,2
	ANDI #$007F,R0
	XORR R2,R0
ENDM
        MVI _rand,R0
        SETC
        _ROR
        XOR _frame,R0
        _ROR
        XOR _rand,R0
        _ROR
        XORI #9,R0
        MVO R0,_rand
	JR R5
	ENDP

    IF DEFINED intybasic_music

        ;
        ; Music player, comes from my game Princess Quest for Intellivision
        ; so it's a practical tracker used in a real game ;) and with enough
        ; features.
        ;

        ; NTSC frequency for notes (based on 3.579545 mhz)
ntsc_note_table:    PROC
        ; Silence - 0
        DECLE 0
        ; Octave 2 - 1
        DECLE 1721,1621,1532,1434,1364,1286,1216,1141,1076,1017,956,909
        ; Octave 3 - 13
        DECLE 854,805,761,717,678,639,605,571,538,508,480,453
        ; Octave 4 - 25
        DECLE 427,404,380,360,339,321,302,285,270,254,240,226
        ; Octave 5 - 37
        DECLE 214,202,191,180,170,160,151,143,135,127,120,113
        ; Octave 6 - 49
        DECLE 107,101,95,90,85,80,76,71,67,64,60,57
        ; Octave 7 - 61
        ; Space for two notes more
	ENDP

        ; PAL frequency for notes (based on 4 mhz)
pal_note_table:    PROC
        ; Silence - 0
        DECLE 0
        ; Octava 2 - 1
        DECLE 1923,1812,1712,1603,1524,1437,1359,1276,1202,1136,1068,1016
        ; Octava 3 - 13
        DECLE 954,899,850,801,758,714,676,638,601,568,536,506
        ; Octava 4 - 25
        DECLE 477,451,425,402,379,358,338,319,301,284,268,253
        ; Octava 5 - 37
        DECLE 239,226,213,201,190,179,169,159,150,142,134,127
        ; Octava 6 - 49
        DECLE 120,113,106,100,95,89,84,80,75,71,67,63
        ; Octava 7 - 61
        ; Space for two notes more
	ENDP
    ENDI

        ;
        ; Music tracker init
        ;
_init_music:	PROC
    IF DEFINED intybasic_music
        MVI _ntsc,R0
        CMPI #1,R0
        MVII #ntsc_note_table,R0
        BEQ @@0
        MVII #pal_note_table,R0
@@0:    MVO R0,_music_table
        MVII #$38,R0	; $B8 blocks controllers o.O!
	MVO R0,_music_mix
        CLRR R0
    ELSE
	JR R5
    ENDI
	ENDP

    IF DEFINED intybasic_music
        ;
        ; Start music
        ; R0 = Pointer to music
        ;
_play_music:	PROC
	MOVR R0,R2
        MVII #1,R0
	MOVR R0,R3
	TSTR R2
	BEQ @@1
	MVI@ R2,R3
	INCR R2
@@1:	MVO R2,_music_start
	MVO R2,_music_p
	MVO R3,_music_t
	MVO R0,_music_tc
        JR R5

	ENDP

        ;
        ; Generate music
        ;
_generate_music:	PROC
	BEGIN
	MVI _music_mix,R0
	ANDI #$C0,R0
	XORI #$38,R0
	MVO R0,_music_mix
	CLRR R1			; Turn off volume for the three sound channels
	MVO R1,_music_vol1
	MVO R1,_music_vol2
	NOP
	MVO R1,_music_vol3
	MVI _music_tc,R3
	DECR R3
	MVO R3,_music_tc
	BNE @@6
	; R3 is zero from here up to @@6
	MVI _music_p,R4
@@15:	TSTR R4		; Silence?
	BEQ @@000	; Keep quiet
	MVI@ R4,R0
	MVI@ R4,R1
	MVI _music_t,R2
        CMPI #$FE,R0	; The end?
	BEQ @@000       ; Keep quiet
	CMPI #$FD,R0	; Repeat?
	BNE @@00
	MVI _music_start,R4
	B @@15

@@000:  MVII #1,R0
        MVO R0,_music_tc
        B @@0
        
@@00: 	MVO R2,_music_tc    ; Restart note time
     	MVO R4,_music_p
     	
	MOVR R0,R2
	ANDI #$FF,R2
	CMPI #$3F,R2	; Sustain note?
	BEQ @@1
	MOVR R2,R4
	ANDI #$3F,R4
	MVO R4,_music_n1	; Note
	MVO R3,_music_s1	; Waveform
	ANDI #$C0,R2
	MVO R2,_music_i1	; Instrument
	
@@1:	MOVR R0,R2
	SWAP R2
	ANDI #$FF,R2
	CMPI #$3F,R2	; Sustain note?
	BEQ @@2
	MOVR R2,R4
	ANDI #$3F,R4
	MVO R4,_music_n2	; Note
	MVO R3,_music_s2	; Waveform
	ANDI #$C0,R2
	MVO R2,_music_i2	; Instrument
	
@@2:	MOVR R1,R2
	ANDI #$FF,R2
	CMPI #$3F,R2	; Sustain note?
	BEQ @@3
	MOVR R2,R4
	ANDI #$3F,R4
	MVO R4,_music_n3	; Note
	MVO R3,_music_s3	; Waveform
	ANDI #$C0,R2
	MVO R2,_music_i3	; Instrument
	
@@3:	MOVR R1,R2
	SWAP R2
	MVO R2,_music_n4
	MVO R3,_music_s4
	
        ;
        ; Construct main voice
        ;
@@6:	MVI _music_n1,R3	; Read note
	TSTR R3		; There is note?
	BEQ @@7		; No, jump
	MVI _music_s1,R1
	MVI _music_i1,R2
	MOVR R1,R0
	CALL _note2freq
	MVO R3,_music_freq10	; Note in voice A
	SWAP R3
	MVO R3,_music_freq11
	MVO R1,_music_vol1
        ; Increase time for instrument waveform
	INCR R0
	CMPI #$18,R0
	BNE @@20
	SUBI #$08,R0
@@20:	MVO R0,_music_s1

@@7:	MVI _music_n2,R3	; Read note
	TSTR R3		; There is note?
	BEQ @@8		; No, jump
	MVI _music_s2,R1
	MVI _music_i2,R2
	MOVR R1,R0
	CALL _note2freq
	MVO R3,_music_freq20	; Note in voice B
	SWAP R3
	MVO R3,_music_freq21
	MVO R1,_music_vol2
        ; Increase time for instrument waveform
	INCR R0
	CMPI #$18,R0
	BNE @@21
	SUBI #$08,R0
@@21:	MVO R0,_music_s2

@@8:	MVI _music_n3,R3	; Read note
	TSTR R3		; There is note?
	BEQ @@9		; No, jump
	MVI _music_s3,R1
	MVI _music_i3,R2
	MOVR R1,R0
	CALL _note2freq
	MVO R3,_music_freq30	; Note in voice C
	SWAP R3
	MVO R3,_music_freq31
	MVO R1,_music_vol3
        ; Increase time for instrument waveform
	INCR R0
	CMPI #$18,R0
	BNE @@22
	SUBI #$08,R0
@@22:	MVO R0,_music_s3

@@9:	MVI _music_n4,R0	; Read drum
	DECR R0		; There is drum?
	BMI @@4		; No, jump
	MVI _music_s4,R1
	       		; 1 - Strong
	BNE @@5
	CMPI #3,R1
	BGE @@12
@@10:	MVII #5,R0
	MVO R0,_music_noise
	CALL _activate_drum
	B @@12

@@5:	DECR R0		;2 - Short
	BNE @@11
	TSTR R1
	BNE @@12
	MVII #8,R0
	MVO R0,_music_noise
	CALL _activate_drum
	B @@12

@@11:	;DECR R0	; 3 - Rolling
	;BNE @@12
	CMPI #2,R1
	BLT @@10
	MVI _music_t,R0
	SLR R0,1
	CMPR R0,R1
	BLT @@12
        ADDI #2,R0
	CMPR R0,R1
	BLT @@10
        ; Increase time for drum waveform
@@12:   INCR R1
	MVO R1,_music_s4
@@4:
@@0:	RETURN
	ENDP

        ;
	; Translates note number to frequency
        ; R3 = Note
        ; R1 = Position in waveform for instrument
        ; R2 = Instrument
        ;
_note2freq:	PROC
        ADD _music_table,R3
	MVI@ R3,R3
        SWAP R2
	BEQ _piano_instrument
	RLC R2,1
	BNC _clarinet_instrument
	BPL _flute_instrument
;	BMI _bass_instrument
	ENDP

        ;
        ; Generates a bass
        ;
_bass_instrument:	PROC
	SLL R3,2	; Lower 2 octaves
	ADDI #_bass_volume,R1
	MVI@ R1,R1	; Bass effect
	JR R5
	ENDP

_bass_volume:	PROC
        DECLE 12,13,14,14,13,12,12,12
        DECLE 11,11,12,12,11,11,12,12
	DECLE 11,11,12,12,11,11,12,12
	ENDP

        ;
        ; Generates a piano
        ; R3 = Frequency
        ; R1 = Waveform position
        ;
        ; Output:
        ; R3 = Frequency.
        ; R1 = Volume.
        ;
_piano_instrument:	PROC
	ADDI #_piano_volume,R1
	MVI@ R1,R1
	JR R5
	ENDP

_piano_volume:	PROC
        DECLE 14,13,13,12,12,11,11,10
        DECLE 10,9,9,8,8,7,7,6
        DECLE 6,6,7,7,6,6,5,5
	ENDP

        ;
        ; Generate a clarinet
        ; R3 = Frequency
        ; R1 = Waveform position
        ;
        ; Output:
        ; R3 = Frequency
        ; R1 = Volume
        ;
_clarinet_instrument:	PROC
	ADDI #_clarinet_vibrato,R1
	ADD@ R1,R3
	CLRC
	RRC R3,1	; Duplicates frequency
	ADCR R3
        ADDI #_clarinet_volume-_clarinet_vibrato,R1
	MVI@ R1,R1
	JR R5
	ENDP

_clarinet_vibrato:	PROC
        DECLE 0,0,0,0
        DECLE -2,-4,-2,0
        DECLE 2,4,2,0
        DECLE -2,-4,-2,0
        DECLE 2,4,2,0
        DECLE -2,-4,-2,0
	ENDP

_clarinet_volume:	PROC
        DECLE 13,14,14,13,13,12,12,12
        DECLE 11,11,11,11,12,12,12,12
        DECLE 11,11,11,11,12,12,12,12
	ENDP

        ;
        ; Generates a flute
        ; R3 = Frequency
        ; R1 = Waveform position
        ;
        ; Output:
        ; R3 = Frequency
        ; R1 = Volume
        ;
_flute_instrument:	PROC
	ADDI #_flute_vibrato,R1
	ADD@ R1,R3
	ADDI #_flute_volume-_flute_vibrato,R1
	MVI@ R1,R1
	JR R5
	ENDP

_flute_vibrato:	PROC
        DECLE 0,0,0,0
        DECLE 0,1,2,1
        DECLE 0,1,2,1
        DECLE 0,1,2,1
        DECLE 0,1,2,1
        DECLE 0,1,2,1
	ENDP
                 
_flute_volume:	PROC
        DECLE 10,12,13,13,12,12,12,12
        DECLE 11,11,11,11,10,10,10,10
        DECLE 11,11,11,11,10,10,10,10
	ENDP

        ;
        ; Emits sound
        ;
_emit_sound:	PROC
        MOVR R5,R1
	MVI _music_mode,R2
	TSTR R2
	BEQ @@2
	MVII #_music_freq10,R4
	MVII #$01F0,R5
        MVI@ R4,R0
	MVO@ R0,R5
        MVI@ R4,R0
	MVO@ R0,R5
	CMPI #1,R2
	BEQ @@1
        MVI@ R4,R0
	MVO@ R0,R5
	INCR R5
        MVI@ R4,R0
	MVO@ R0,R5
        MVI@ R4,R0
	MVO@ R0,R5
        MVI@ R4,R0
	MVO@ R0,R5
	INCR R5
        MVI@ R4,R0
	MVO@ R0,R5
        MVI@ R4,R0
	MVO@ R0,R5
	INCR R5
        MVI@ R4,R0
	MVO@ R0,R5
        MVI@ R4,R0
	MVO@ R0,R5
        MVI@ R4,R0
	MVO@ R0,R5
        JR R1

@@1:	INCR R4
	ADDI #2,R5
        MVI@ R4,R0
	MVO@ R0,R5
        MVI@ R4,R0
	MVO@ R0,R5
	INCR R4
	ADDI #2,R5
        MVI@ R4,R0
	MVO@ R0,R5
        MVI@ R4,R0
	MVO@ R0,R5
	INCR R5
        MVI@ R4,R0
	MVO@ R0,R5
        MVI@ R4,R0
	MVO@ R0,R5
@@2:    JR R1
	ENDP

        ;
        ; Activates drum
        ;
_activate_drum:	PROC
	MVI _music_vol1,R0
	TSTR R0
	BNE @@1
        MVII #11,R0
	MVO R0,_music_vol1
	MVI _music_mix,R0
	ANDI #$F6,R0
	XORI #$01,R0
	MVO R0,_music_mix
	JR R5

@@1:    MVI _music_vol2,R0
	TSTR R0
	BNE @@2
        MVII #11,R0
	MVO R0,_music_vol2
	MVI _music_mix,R0
	ANDI #$ED,R0
	XORI #$02,R0
	MVO R0,_music_mix
	JR R5

@@2:    MVI _music_mode,R0
        CMPI #2,R0
        BNE @@3
        MVI _music_vol3,R0
	TSTR R0
	BNE @@3
        MVII #11,R0
	MVO R0,_music_vol3
	MVI _music_mix,R0
	ANDI #$DB,R0
	XORI #$04,R0
	MVO R0,_music_mix
	JR R5

@@3:    MVI _music_mix,R0
        ANDI #$EF,R0
	MVO R0,_music_mix
	JR R5

	ENDP

    ENDI
    
    IF DEFINED intybasic_numbers

	;
	; Following code from as1600 libraries, prnum16.asm
        ; Public domain by Joseph Zbiciak
	;

;* ======================================================================== *;
;*  These routines are placed into the public domain by their author.  All  *;
;*  copyright rights are hereby relinquished on the routines and data in    *;
;*  this file.  -- Joseph Zbiciak, 2008                                     *;
;* ======================================================================== *;

;; ======================================================================== ;;
;;  _PW10                                                                   ;;
;;      Lookup table holding the first 5 powers of 10 (1 thru 10000) as     ;;
;;      16-bit numbers.                                                     ;;
;; ======================================================================== ;;
_PW10   PROC    ; 0 thru 10000
        DECLE   10000, 1000, 100, 10, 1, 0
        ENDP

;; ======================================================================== ;;
;;  PRNUM16.l     -- Print an unsigned 16-bit number left-justified.        ;;
;;  PRNUM16.b     -- Print an unsigned 16-bit number with leading blanks.   ;;
;;  PRNUM16.z     -- Print an unsigned 16-bit number with leading zeros.    ;;
;;                                                                          ;;
;;  AUTHOR                                                                  ;;
;;      Joseph Zbiciak  <im14u2c AT globalcrossing DOT net>                 ;;
;;                                                                          ;;
;;  REVISION HISTORY                                                        ;;
;;      30-Mar-2003 Initial complete revision                               ;;
;;                                                                          ;;
;;  INPUTS for all variants                                                 ;;
;;      R0  Number to print.                                                ;;
;;      R2  Width of field.  Ignored by PRNUM16.l.                          ;;
;;      R3  Format word, added to digits to set the color.                  ;;
;;          Note:  Bit 15 MUST be cleared when building with PRNUM32.       ;;
;;      R4  Pointer to location on screen to print number                   ;;
;;                                                                          ;;
;;  OUTPUTS                                                                 ;;
;;      R0  Zeroed                                                          ;;
;;      R1  Unmodified                                                      ;;
;;      R2  Unmodified                                                      ;;
;;      R3  Unmodified                                                      ;;
;;      R4  Points to first character after field.                          ;;
;;                                                                          ;;
;;  DESCRIPTION                                                             ;;
;;      These routines print unsigned 16-bit numbers in a field up to 5     ;;
;;      positions wide.  The number is printed either in left-justified     ;;
;;      or right-justified format.  Right-justified numbers are padded      ;;
;;      with leading blanks or leading zeros.  Left-justified numbers       ;;
;;      are not padded on the right.                                        ;;
;;                                                                          ;;
;;      This code handles fields wider than 5 characters, padding with      ;;
;;      zeros or blanks as necessary.                                       ;;
;;                                                                          ;;
;;              Routine      Value(hex)     Field        Output             ;;
;;              ----------   ----------   ----------   ----------           ;;
;;              PRNUM16.l      $0045         n/a        "69"                ;;
;;              PRNUM16.b      $0045          4         "  69"              ;;
;;              PRNUM16.b      $0045          6         "    69"            ;;
;;              PRNUM16.z      $0045          4         "0069"              ;;
;;              PRNUM16.z      $0045          6         "000069"            ;;
;;                                                                          ;;
;;  TECHNIQUES                                                              ;;
;;      This routine uses repeated subtraction to divide the number         ;;
;;      to display by various powers of 10.  This is cheaper than a         ;;
;;      full divide, at least when the input number is large.  It's         ;;
;;      also easier to get right.  :-)                                      ;;
;;                                                                          ;;
;;      The printing routine first pads out fields wider than 5 spaces      ;;
;;      with zeros or blanks as requested.  It then scans the power-of-10   ;;
;;      table looking for the first power of 10 that is <= the number to    ;;
;;      display.  While scanning for this power of 10, it outputs leading   ;;
;;      blanks or zeros, if requested.  This eliminates "leading digit"     ;;
;;      logic from the main digit loop.                                     ;;
;;                                                                          ;;
;;      Once in the main digit loop, we discover the value of each digit    ;;
;;      by repeated subtraction.  We build up our digit value while         ;;
;;      subtracting the power-of-10 repeatedly.  We iterate until we go     ;;
;;      a step too far, and then we add back on power-of-10 to restore      ;;
;;      the remainder.                                                      ;;
;;                                                                          ;;
;;  NOTES                                                                   ;;
;;      The left-justified variant ignores field width.                     ;;
;;                                                                          ;;
;;      The code is fully reentrant.                                        ;;
;;                                                                          ;;
;;      This code does not handle numbers which are too large to be         ;;
;;      displayed in the provided field.  If the number is too large,       ;;
;;      non-digit characters will be displayed in the initial digit         ;;
;;      position.  Also, the run time of this routine may get excessively   ;;
;;      large, depending on the magnitude of the overflow.                  ;;
;;                                                                          ;;
;;      When using with PRNUM32, one must either include PRNUM32 before     ;;
;;      this function, or define the symbol _WITH_PRNUM32.  PRNUM32         ;;
;;      needs a tiny bit of support from PRNUM16 to handle numbers in       ;;
;;      the range 65536...99999 correctly.                                  ;;
;;                                                                          ;;
;;  CODESIZE                                                                ;;
;;      73 words, including power-of-10 table                               ;;
;;      80 words, if compiled with PRNUM32.                                 ;;
;;                                                                          ;;
;;      To save code size, you can define the following symbols to omit     ;;
;;      some variants:                                                      ;;
;;                                                                          ;;
;;          _NO_PRNUM16.l:   Disables PRNUM16.l.  Saves 10 words            ;;
;;          _NO_PRNUM16.b:   Disables PRNUM16.b.  Saves 3 words.            ;;
;;                                                                          ;;
;;      Defining both symbols saves 17 words total, because it omits        ;;
;;      some code shared by both routines.                                  ;;
;;                                                                          ;;
;;  STACK USAGE                                                             ;;
;;      This function uses up to 4 words of stack space.                    ;;
;; ======================================================================== ;;

PRNUM16 PROC

    
        ;; ---------------------------------------------------------------- ;;
        ;;  PRNUM16.l:  Print unsigned, left-justified.                     ;;
        ;; ---------------------------------------------------------------- ;;
@@l:    PSHR    R5              ; save return address
@@l1:   MVII    #$1,    R5      ; set R5 to 1 to counteract screen ptr update
                                ; in the 'find initial power of 10' loop
        PSHR    R2
        MVII    #5,     R2      ; force effective field width to 5.
        B       @@z2

        ;; ---------------------------------------------------------------- ;;
        ;;  PRNUM16.b:  Print unsigned with leading blanks.                 ;;
        ;; ---------------------------------------------------------------- ;;
@@b:    PSHR    R5
@@b1:   CLRR    R5              ; let the blank loop do its thing
        INCR    PC              ; skip the PSHR R5

        ;; ---------------------------------------------------------------- ;;
        ;;  PRNUM16.z:  Print unsigned with leading zeros.                  ;;
        ;; ---------------------------------------------------------------- ;;
@@z:    PSHR    R5
@@z1:   PSHR    R2
@@z2:   PSHR    R1

        ;; ---------------------------------------------------------------- ;;
        ;;  Find the initial power of 10 to use for display.                ;;
        ;;  Note:  For fields wider than 5, fill the extra spots above 5    ;;
        ;;  with blanks or zeros as needed.                                 ;;
        ;; ---------------------------------------------------------------- ;;
        MVII    #_PW10+5,R1     ; Point to end of power-of-10 table
        SUBR    R2,     R1      ; Subtract the field width to get right power
        PSHR    R3              ; save format word

        CMPI    #2,     R5      ; are we leading with zeros?
        BNC     @@lblnk         ; no:  then do the loop w/ blanks

        CLRR    R5              ; force R5==0
        ADDI    #$80,   R3      ; yes: do the loop with zeros
        B       @@lblnk
    

@@llp   MVO@    R3,     R4      ; print a blank/zero

        SUBR    R5,     R4      ; rewind pointer if needed.

        INCR    R1              ; get next power of 10
@@lblnk DECR    R2              ; decrement available digits
        BEQ     @@ldone
        CMPI    #5,     R2      ; field too wide?
        BGE     @@llp           ; just force blanks/zeros 'till we're narrower.
        CMP@    R1,     R0      ; Is this power of 10 too big?
        BNC     @@llp           ; Yes:  Put a blank and go to next

@@ldone PULR    R3              ; restore format word

        ;; ---------------------------------------------------------------- ;;
        ;;  The digit loop prints at least one digit.  It discovers digits  ;;
        ;;  by repeated subtraction.                                        ;;
        ;; ---------------------------------------------------------------- ;;
@@digit TSTR    R0              ; If the number is zero, print zero and leave
        BNEQ    @@dig1          ; no: print the number

        MOVR    R3,     R5      ;\    
        ADDI    #$80,   R5      ; |-- print a 0 there.
        MVO@    R5,     R4      ;/    
        B       @@done

@@dig1:
    
@@nxdig MOVR    R3,     R5      ; save display format word
@@cont: ADDI    #$80-8, R5      ; start our digit as one just before '0'
@@spcl:
 
        ;; ---------------------------------------------------------------- ;;
        ;;  Divide by repeated subtraction.  This divide is constructed     ;;
        ;;  to go "one step too far" and then back up.                      ;;
        ;; ---------------------------------------------------------------- ;;
@@div:  ADDI    #8,     R5      ; increment our digit
        SUB@    R1,     R0      ; subtract power of 10
        BC      @@div           ; loop until we go too far
        ADD@    R1,     R0      ; add back the extra power of 10.

        MVO@    R5,     R4      ; display the digit.

        INCR    R1              ; point to next power of 10
        DECR    R2              ; any room left in field?
        BPL     @@nxdig         ; keep going until R2 < 0.

@@done: PULR    R1              ; restore R1
        PULR    R2              ; restore R2
        PULR    PC              ; return

        ENDP
        
    ENDI

    IF DEFINED intybasic_voice
;;==========================================================================;;
;;  SP0256-AL2 Allophones                                                   ;;
;;                                                                          ;;
;;  This file contains the allophone set that was obtained from an          ;;
;;  SP0256-AL2.  It is being provided for your convenience.                 ;;
;;                                                                          ;;
;;  The directory "al2" contains a series of assembly files, each one       ;;
;;  containing a single allophone.  This series of files may be useful in   ;;
;;  situations where space is at a premium.                                 ;;
;;                                                                          ;;
;;  Consult the Archer SP0256-AL2 documentation (under doc/programming)     ;;
;;  for more information about SP0256-AL2's allophone library.              ;;
;;                                                                          ;;
;; ------------------------------------------------------------------------ ;;
;;                                                                          ;;
;;  Copyright information:                                                  ;;
;;                                                                          ;;
;;  The allophone data below was extracted from the SP0256-AL2 ROM image.   ;;
;;  The SP0256-AL2 allophones are NOT in the public domain, nor are they    ;;
;;  placed under the GNU General Public License.  This program is           ;;
;;  distributed in the hope that it will be useful, but WITHOUT ANY         ;;
;;  WARRANTY; without even the implied warranty of MERCHANTABILITY or       ;;
;;  FITNESS FOR A PARTICULAR PURPOSE.                                       ;;
;;                                                                          ;;
;;  Microchip, Inc. retains the copyright to the data and algorithms        ;;
;;  contained in the SP0256-AL2.  This speech data is distributed with      ;;
;;  explicit permission from Microchip, Inc.  All such redistributions      ;;
;;  must retain this notice of copyright.                                   ;;
;;                                                                          ;;
;;  No copyright claims are made on this data by the author(s) of SDK1600.  ;;
;;  Please see http://spatula-city.org/~im14u2c/sp0256-al2/ for details.    ;;
;;                                                                          ;;
;;==========================================================================;;

;; ------------------------------------------------------------------------ ;;
_AA:
    DECLE   _AA.end - _AA - 1
    DECLE   $0318, $014C, $016F, $02CE, $03AF, $015F, $01B1, $008E
    DECLE   $0088, $0392, $01EA, $024B, $03AA, $039B, $000F, $0000
_AA.end:  ; 16 decles
;; ------------------------------------------------------------------------ ;;
_AE1:
    DECLE   _AE1.end - _AE1 - 1
    DECLE   $0118, $038E, $016E, $01FC, $0149, $0043, $026F, $036E
    DECLE   $01CC, $0005, $0000
_AE1.end:  ; 11 decles
;; ------------------------------------------------------------------------ ;;
_AO:
    DECLE   _AO.end - _AO - 1
    DECLE   $0018, $010E, $016F, $0225, $00C6, $02C4, $030F, $0160
    DECLE   $024B, $0005, $0000
_AO.end:  ; 11 decles
;; ------------------------------------------------------------------------ ;;
_AR:
    DECLE   _AR.end - _AR - 1
    DECLE   $0218, $010C, $016E, $001E, $000B, $0091, $032F, $00DE
    DECLE   $018B, $0095, $0003, $0238, $0027, $01E0, $03E8, $0090
    DECLE   $0003, $01C7, $0020, $03DE, $0100, $0190, $01CA, $02AB
    DECLE   $00B7, $004A, $0386, $0100, $0144, $02B6, $0024, $0320
    DECLE   $0011, $0041, $01DF, $0316, $014C, $016E, $001E, $00C4
    DECLE   $02B2, $031E, $0264, $02AA, $019D, $01BE, $000B, $00F0
    DECLE   $006A, $01CE, $00D6, $015B, $03B5, $03E4, $0000, $0380
    DECLE   $0007, $0312, $03E8, $030C, $016D, $02EE, $0085, $03C2
    DECLE   $03EC, $0283, $024A, $0005, $0000
_AR.end:  ; 69 decles
;; ------------------------------------------------------------------------ ;;
_AW:
    DECLE   _AW.end - _AW - 1
    DECLE   $0010, $01CE, $016E, $02BE, $0375, $034F, $0220, $0290
    DECLE   $008A, $026D, $013F, $01D5, $0316, $029F, $02E2, $018A
    DECLE   $0170, $0035, $00BD, $0000, $0000
_AW.end:  ; 21 decles
;; ------------------------------------------------------------------------ ;;
_AX:
    DECLE   _AX.end - _AX - 1
    DECLE   $0218, $02CD, $016F, $02F5, $0386, $00C2, $00CD, $0094
    DECLE   $010C, $0005, $0000
_AX.end:  ; 11 decles
;; ------------------------------------------------------------------------ ;;
_AY:
    DECLE   _AY.end - _AY - 1
    DECLE   $0110, $038C, $016E, $03B7, $03B3, $02AF, $0221, $009E
    DECLE   $01AA, $01B3, $00BF, $02E7, $025B, $0354, $00DA, $017F
    DECLE   $018A, $03F3, $00AF, $02D5, $0356, $027F, $017A, $01FB
    DECLE   $011E, $01B9, $03E5, $029F, $025A, $0076, $0148, $0124
    DECLE   $003D, $0000
_AY.end:  ; 34 decles
;; ------------------------------------------------------------------------ ;;
_BB1:
    DECLE   _BB1.end - _BB1 - 1
    DECLE   $0318, $004C, $016C, $00FB, $00C7, $0144, $002E, $030C
    DECLE   $010E, $018C, $01DC, $00AB, $00C9, $0268, $01F7, $021D
    DECLE   $01B3, $0098, $0000
_BB1.end:  ; 19 decles
;; ------------------------------------------------------------------------ ;;
_BB2:
    DECLE   _BB2.end - _BB2 - 1
    DECLE   $00F4, $0046, $0062, $0200, $0221, $03E4, $0087, $016F
    DECLE   $02A6, $02B7, $0212, $0326, $0368, $01BF, $0338, $0196
    DECLE   $0002
_BB2.end:  ; 17 decles
;; ------------------------------------------------------------------------ ;;
_CH:
    DECLE   _CH.end - _CH - 1
    DECLE   $00F5, $0146, $0052, $0000, $032A, $0049, $0032, $02F2
    DECLE   $02A5, $0000, $026D, $0119, $0124, $00F6, $0000
_CH.end:  ; 15 decles
;; ------------------------------------------------------------------------ ;;
_DD1:
    DECLE   _DD1.end - _DD1 - 1
    DECLE   $0318, $034C, $016E, $0397, $01B9, $0020, $02B1, $008E
    DECLE   $0349, $0291, $01D8, $0072, $0000
_DD1.end:  ; 13 decles
;; ------------------------------------------------------------------------ ;;
_DD2:
    DECLE   _DD2.end - _DD2 - 1
    DECLE   $00F4, $00C6, $00F2, $0000, $0129, $00A6, $0246, $01F3
    DECLE   $02C6, $02B7, $028E, $0064, $0362, $01CF, $0379, $01D5
    DECLE   $0002
_DD2.end:  ; 17 decles
;; ------------------------------------------------------------------------ ;;
_DH1:
    DECLE   _DH1.end - _DH1 - 1
    DECLE   $0018, $034F, $016D, $030B, $0306, $0363, $017E, $006A
    DECLE   $0164, $019E, $01DA, $00CB, $00E8, $027A, $03E8, $01D7
    DECLE   $0173, $00A1, $0000
_DH1.end:  ; 19 decles
;; ------------------------------------------------------------------------ ;;
_DH2:
    DECLE   _DH2.end - _DH2 - 1
    DECLE   $0119, $034C, $016D, $030B, $0306, $0363, $017E, $006A
    DECLE   $0164, $019E, $01DA, $00CB, $00E8, $027A, $03E8, $01D7
    DECLE   $0173, $00A1, $0000
_DH2.end:  ; 19 decles
;; ------------------------------------------------------------------------ ;;
_EH:
    DECLE   _EH.end - _EH - 1
    DECLE   $0218, $02CD, $016F, $0105, $014B, $0224, $02CF, $0274
    DECLE   $014C, $0005, $0000
_EH.end:  ; 11 decles
;; ------------------------------------------------------------------------ ;;
_EL:
    DECLE   _EL.end - _EL - 1
    DECLE   $0118, $038D, $016E, $011C, $008B, $03D2, $030F, $0262
    DECLE   $006C, $019D, $01CC, $022B, $0170, $0078, $03FE, $0018
    DECLE   $0183, $03A3, $010D, $016E, $012E, $00C6, $00C3, $0300
    DECLE   $0060, $000D, $0005, $0000
_EL.end:  ; 28 decles
;; ------------------------------------------------------------------------ ;;
_ER1:
    DECLE   _ER1.end - _ER1 - 1
    DECLE   $0118, $034C, $016E, $001C, $0089, $01C3, $034E, $03E6
    DECLE   $00AB, $0095, $0001, $0000, $03FC, $0381, $0000, $0188
    DECLE   $01DA, $00CB, $00E7, $0048, $03A6, $0244, $016C, $01A8
    DECLE   $03E4, $0000, $0002, $0001, $00FC, $01DA, $02E4, $0000
    DECLE   $0002, $0008, $0200, $0217, $0164, $0000, $000E, $0038
    DECLE   $0014, $01EA, $0264, $0000, $0002, $0048, $01EC, $02F1
    DECLE   $03CC, $016D, $021E, $0048, $00C2, $034E, $036A, $000D
    DECLE   $008D, $000B, $0200, $0047, $0022, $03A8, $0000, $0000
_ER1.end:  ; 64 decles
;; ------------------------------------------------------------------------ ;;
_ER2:
    DECLE   _ER2.end - _ER2 - 1
    DECLE   $0218, $034C, $016E, $001C, $0089, $01C3, $034E, $03E6
    DECLE   $00AB, $0095, $0001, $0000, $03FC, $0381, $0000, $0190
    DECLE   $01D8, $00CB, $00E7, $0058, $01A6, $0244, $0164, $02A9
    DECLE   $0024, $0000, $0000, $0007, $0201, $02F8, $02E4, $0000
    DECLE   $0002, $0001, $00FC, $02DA, $0024, $0000, $0002, $0008
    DECLE   $0200, $0217, $0024, $0000, $000E, $0038, $0014, $03EA
    DECLE   $03A4, $0000, $0002, $0048, $01EC, $03F1, $038C, $016D
    DECLE   $021E, $0048, $00C2, $034E, $036A, $000D, $009D, $0003
    DECLE   $0200, $0047, $0022, $03A8, $0000, $0000
_ER2.end:  ; 70 decles
;; ------------------------------------------------------------------------ ;;
_EY:
    DECLE   _EY.end - _EY - 1
    DECLE   $0310, $038C, $016E, $02A7, $00BB, $0160, $0290, $0094
    DECLE   $01CA, $03A9, $00C1, $02D7, $015B, $01D4, $03CE, $02FF
    DECLE   $00EA, $03E7, $0041, $0277, $025B, $0355, $03C9, $0103
    DECLE   $02EA, $03E4, $003F, $0000
_EY.end:  ; 28 decles
;; ------------------------------------------------------------------------ ;;
_FF:
    DECLE   _FF.end - _FF - 1
    DECLE   $0119, $03C8, $0000, $00A7, $0094, $0138, $01C6, $0000
_FF.end:  ; 8 decles
;; ------------------------------------------------------------------------ ;;
_GG1:
    DECLE   _GG1.end - _GG1 - 1
    DECLE   $00F4, $00C6, $00C2, $0200, $0015, $03FE, $0283, $01FD
    DECLE   $01E6, $00B7, $030A, $0364, $0331, $017F, $033D, $0215
    DECLE   $0002
_GG1.end:  ; 17 decles
;; ------------------------------------------------------------------------ ;;
_GG2:
    DECLE   _GG2.end - _GG2 - 1
    DECLE   $00F4, $0106, $0072, $0300, $0021, $0308, $0039, $0173
    DECLE   $00C6, $00B7, $037E, $03A3, $0319, $0177, $0036, $0217
    DECLE   $0002
_GG2.end:  ; 17 decles
;; ------------------------------------------------------------------------ ;;
_GG3:
    DECLE   _GG3.end - _GG3 - 1
    DECLE   $00F8, $0146, $00F2, $0100, $0132, $03A8, $0055, $01F5
    DECLE   $00A6, $02B7, $0291, $0326, $0368, $0167, $023A, $01C6
    DECLE   $0002
_GG3.end:  ; 17 decles
;; ------------------------------------------------------------------------ ;;
_HH1:
    DECLE   _HH1.end - _HH1 - 1
    DECLE   $0218, $01C9, $0000, $0095, $0127, $0060, $01D6, $0213
    DECLE   $0002, $01AE, $033E, $01A0, $03C4, $0122, $0001, $0218
    DECLE   $01E4, $03FD, $0019, $0000
_HH1.end:  ; 20 decles
;; ------------------------------------------------------------------------ ;;
_HH2:
    DECLE   _HH2.end - _HH2 - 1
    DECLE   $0218, $00CB, $0000, $0086, $000F, $0240, $0182, $031A
    DECLE   $02DB, $0008, $0293, $0067, $00BD, $01E0, $0092, $000C
    DECLE   $0000
_HH2.end:  ; 17 decles
;; ------------------------------------------------------------------------ ;;
_IH:
    DECLE   _IH.end - _IH - 1
    DECLE   $0118, $02CD, $016F, $0205, $0144, $02C3, $00FE, $031A
    DECLE   $000D, $0005, $0000
_IH.end:  ; 11 decles
;; ------------------------------------------------------------------------ ;;
_IY:
    DECLE   _IY.end - _IY - 1
    DECLE   $0318, $02CC, $016F, $0008, $030B, $01C3, $0330, $0178
    DECLE   $002B, $019D, $01F6, $018B, $01E1, $0010, $020D, $0358
    DECLE   $015F, $02A4, $02CC, $016F, $0109, $030B, $0193, $0320
    DECLE   $017A, $034C, $009C, $0017, $0001, $0200, $03C1, $0020
    DECLE   $00A7, $001D, $0001, $0104, $003D, $0040, $01A7, $01CA
    DECLE   $018B, $0160, $0078, $01F6, $0343, $01C7, $0090, $0000
_IY.end:  ; 48 decles
;; ------------------------------------------------------------------------ ;;
_JH:
    DECLE   _JH.end - _JH - 1
    DECLE   $0018, $0149, $0001, $00A4, $0321, $0180, $01F4, $039A
    DECLE   $02DC, $023C, $011A, $0047, $0200, $0001, $018E, $034E
    DECLE   $0394, $0356, $02C1, $010C, $03FD, $0129, $00B7, $01BA
    DECLE   $0000
_JH.end:  ; 25 decles
;; ------------------------------------------------------------------------ ;;
_KK1:
    DECLE   _KK1.end - _KK1 - 1
    DECLE   $00F4, $00C6, $00D2, $0000, $023A, $03E0, $02D1, $02E5
    DECLE   $0184, $0200, $0041, $0210, $0188, $00C5, $0000
_KK1.end:  ; 15 decles
;; ------------------------------------------------------------------------ ;;
_KK2:
    DECLE   _KK2.end - _KK2 - 1
    DECLE   $021D, $023C, $0211, $003C, $0180, $024D, $0008, $032B
    DECLE   $025B, $002D, $01DC, $01E3, $007A, $0000
_KK2.end:  ; 14 decles
;; ------------------------------------------------------------------------ ;;
_KK3:
    DECLE   _KK3.end - _KK3 - 1
    DECLE   $00F7, $0046, $01D2, $0300, $0131, $006C, $006E, $00F1
    DECLE   $00E4, $0000, $025A, $010D, $0110, $01F9, $014A, $0001
    DECLE   $00B5, $01A2, $00D8, $01CE, $0000
_KK3.end:  ; 21 decles
;; ------------------------------------------------------------------------ ;;
_LL:
    DECLE   _LL.end - _LL - 1
    DECLE   $0318, $038C, $016D, $029E, $0333, $0260, $0221, $0294
    DECLE   $01C4, $0299, $025A, $00E6, $014C, $012C, $0031, $0000
_LL.end:  ; 16 decles
;; ------------------------------------------------------------------------ ;;
_MM:
    DECLE   _MM.end - _MM - 1
    DECLE   $0210, $034D, $016D, $03F5, $00B0, $002E, $0220, $0290
    DECLE   $03CE, $02B6, $03AA, $00F3, $00CF, $015D, $016E, $0000
_MM.end:  ; 16 decles
;; ------------------------------------------------------------------------ ;;
_NG1:
    DECLE   _NG1.end - _NG1 - 1
    DECLE   $0118, $03CD, $016E, $00DC, $032F, $01BF, $01E0, $0116
    DECLE   $02AB, $029A, $0358, $01DB, $015B, $01A7, $02FD, $02B1
    DECLE   $03D2, $0356, $0000
_NG1.end:  ; 19 decles
;; ------------------------------------------------------------------------ ;;
_NN1:
    DECLE   _NN1.end - _NN1 - 1
    DECLE   $0318, $03CD, $016C, $0203, $0306, $03C3, $015F, $0270
    DECLE   $002A, $009D, $000D, $0248, $01B4, $0120, $01E1, $00C8
    DECLE   $0003, $0040, $0000, $0080, $015F, $0006, $0000
_NN1.end:  ; 23 decles
;; ------------------------------------------------------------------------ ;;
_NN2:
    DECLE   _NN2.end - _NN2 - 1
    DECLE   $0018, $034D, $016D, $0203, $0306, $03C3, $015F, $0270
    DECLE   $002A, $0095, $0003, $0248, $01B4, $0120, $01E1, $0090
    DECLE   $000B, $0040, $0000, $0080, $015F, $019E, $01F6, $028B
    DECLE   $00E0, $0266, $03F6, $01D8, $0143, $01A8, $0024, $00C0
    DECLE   $0080, $0000, $01E6, $0321, $0024, $0260, $000A, $0008
    DECLE   $03FE, $0000, $0000
_NN2.end:  ; 43 decles
;; ------------------------------------------------------------------------ ;;
_OR2:
    DECLE   _OR2.end - _OR2 - 1
    DECLE   $0218, $018C, $016D, $02A6, $03AB, $004F, $0301, $0390
    DECLE   $02EA, $0289, $0228, $0356, $01CF, $02D5, $0135, $007D
    DECLE   $02B5, $02AF, $024A, $02E2, $0153, $0167, $0333, $02A9
    DECLE   $02B3, $039A, $0351, $0147, $03CD, $0339, $02DA, $0000
_OR2.end:  ; 32 decles
;; ------------------------------------------------------------------------ ;;
_OW:
    DECLE   _OW.end - _OW - 1
    DECLE   $0310, $034C, $016E, $02AE, $03B1, $00CF, $0304, $0192
    DECLE   $018A, $022B, $0041, $0277, $015B, $0395, $03D1, $0082
    DECLE   $03CE, $00B6, $03BB, $02DA, $0000
_OW.end:  ; 21 decles
;; ------------------------------------------------------------------------ ;;
_OY:
    DECLE   _OY.end - _OY - 1
    DECLE   $0310, $014C, $016E, $02A6, $03AF, $00CF, $0304, $0192
    DECLE   $03CA, $01A8, $007F, $0155, $02B4, $027F, $00E2, $036A
    DECLE   $031F, $035D, $0116, $01D5, $02F4, $025F, $033A, $038A
    DECLE   $014F, $01B5, $03D5, $0297, $02DA, $03F2, $0167, $0124
    DECLE   $03FB, $0001
_OY.end:  ; 34 decles
;; ------------------------------------------------------------------------ ;;
_PA1:
    DECLE   _PA1.end - _PA1 - 1
    DECLE   $00F1, $0000
_PA1.end:  ; 2 decles
;; ------------------------------------------------------------------------ ;;
_PA2:
    DECLE   _PA2.end - _PA2 - 1
    DECLE   $00F4, $0000
_PA2.end:  ; 2 decles
;; ------------------------------------------------------------------------ ;;
_PA3:
    DECLE   _PA3.end - _PA3 - 1
    DECLE   $00F7, $0000
_PA3.end:  ; 2 decles
;; ------------------------------------------------------------------------ ;;
_PA4:
    DECLE   _PA4.end - _PA4 - 1
    DECLE   $00FF, $0000
_PA4.end:  ; 2 decles
;; ------------------------------------------------------------------------ ;;
_PA5:
    DECLE   _PA5.end - _PA5 - 1
    DECLE   $031D, $003F, $0000
_PA5.end:  ; 3 decles
;; ------------------------------------------------------------------------ ;;
_PP:
    DECLE   _PP.end - _PP - 1
    DECLE   $00FD, $0106, $0052, $0000, $022A, $03A5, $0277, $035F
    DECLE   $0184, $0000, $0055, $0391, $00EB, $00CF, $0000
_PP.end:  ; 15 decles
;; ------------------------------------------------------------------------ ;;
_RR1:
    DECLE   _RR1.end - _RR1 - 1
    DECLE   $0118, $01CD, $016C, $029E, $0171, $038E, $01E0, $0190
    DECLE   $0245, $0299, $01AA, $02E2, $01C7, $02DE, $0125, $00B5
    DECLE   $02C5, $028F, $024E, $035E, $01CB, $02EC, $0005, $0000
_RR1.end:  ; 24 decles
;; ------------------------------------------------------------------------ ;;
_RR2:
    DECLE   _RR2.end - _RR2 - 1
    DECLE   $0218, $03CC, $016C, $030C, $02C8, $0393, $02CD, $025E
    DECLE   $008A, $019D, $01AC, $02CB, $00BE, $0046, $017E, $01C2
    DECLE   $0174, $00A1, $01E5, $00E0, $010E, $0007, $0313, $0017
    DECLE   $0000
_RR2.end:  ; 25 decles
;; ------------------------------------------------------------------------ ;;
_SH:
    DECLE   _SH.end - _SH - 1
    DECLE   $0218, $0109, $0000, $007A, $0187, $02E0, $03F6, $0311
    DECLE   $0002, $0126, $0242, $0161, $03E9, $0219, $016C, $0300
    DECLE   $0013, $0045, $0124, $0005, $024C, $005C, $0182, $03C2
    DECLE   $0001
_SH.end:  ; 25 decles
;; ------------------------------------------------------------------------ ;;
_SS:
    DECLE   _SS.end - _SS - 1
    DECLE   $0218, $01CA, $0001, $0128, $001C, $0149, $01C6, $0000
_SS.end:  ; 8 decles
;; ------------------------------------------------------------------------ ;;
_TH:
    DECLE   _TH.end - _TH - 1
    DECLE   $0019, $0349, $0000, $00C6, $0212, $01D8, $01CA, $0000
_TH.end:  ; 8 decles
;; ------------------------------------------------------------------------ ;;
_TT1:
    DECLE   _TT1.end - _TT1 - 1
    DECLE   $00F6, $0046, $0142, $0100, $0042, $0088, $027E, $02EF
    DECLE   $01A4, $0200, $0049, $0290, $00FC, $00E8, $0000
_TT1.end:  ; 15 decles
;; ------------------------------------------------------------------------ ;;
_TT2:
    DECLE   _TT2.end - _TT2 - 1
    DECLE   $00F5, $00C6, $01D2, $0100, $0335, $00E9, $0042, $027A
    DECLE   $02A4, $0000, $0062, $01D1, $014C, $03EA, $02EC, $01E0
    DECLE   $0007, $03A7, $0000
_TT2.end:  ; 19 decles
;; ------------------------------------------------------------------------ ;;
_UH:
    DECLE   _UH.end - _UH - 1
    DECLE   $0018, $034E, $016E, $01FF, $0349, $00D2, $003C, $030C
    DECLE   $008B, $0005, $0000
_UH.end:  ; 11 decles
;; ------------------------------------------------------------------------ ;;
_UW1:
    DECLE   _UW1.end - _UW1 - 1
    DECLE   $0318, $014C, $016F, $029E, $03BD, $03BD, $0271, $0212
    DECLE   $0325, $0291, $016A, $027B, $014A, $03B4, $0133, $0001
_UW1.end:  ; 16 decles
;; ------------------------------------------------------------------------ ;;
_UW2:
    DECLE   _UW2.end - _UW2 - 1
    DECLE   $0018, $034E, $016E, $02F6, $0107, $02C2, $006D, $0090
    DECLE   $03AC, $01A4, $01DC, $03AB, $0128, $0076, $03E6, $0119
    DECLE   $014F, $03A6, $03A5, $0020, $0090, $0001, $02EE, $00BB
    DECLE   $0000
_UW2.end:  ; 25 decles
;; ------------------------------------------------------------------------ ;;
_VV:
    DECLE   _VV.end - _VV - 1
    DECLE   $0218, $030D, $016C, $010B, $010B, $0095, $034F, $03E4
    DECLE   $0108, $01B5, $01BE, $028B, $0160, $00AA, $03E4, $0106
    DECLE   $00EB, $02DE, $014C, $016E, $00F6, $0107, $00D2, $00CD
    DECLE   $0296, $00E4, $0006, $0000
_VV.end:  ; 28 decles
;; ------------------------------------------------------------------------ ;;
_WH:
    DECLE   _WH.end - _WH - 1
    DECLE   $0218, $00C9, $0000, $0084, $038E, $0147, $03A4, $0195
    DECLE   $0000, $012E, $0118, $0150, $02D1, $0232, $01B7, $03F1
    DECLE   $0237, $01C8, $03B1, $0227, $01AE, $0254, $0329, $032D
    DECLE   $01BF, $0169, $019A, $0307, $0181, $028D, $0000
_WH.end:  ; 31 decles
;; ------------------------------------------------------------------------ ;;
_WW:
    DECLE   _WW.end - _WW - 1
    DECLE   $0118, $034D, $016C, $00FA, $02C7, $0072, $03CC, $0109
    DECLE   $000B, $01AD, $019E, $016B, $0130, $0278, $01F8, $0314
    DECLE   $017E, $029E, $014D, $016D, $0205, $0147, $02E2, $001A
    DECLE   $010A, $026E, $0004, $0000
_WW.end:  ; 28 decles
;; ------------------------------------------------------------------------ ;;
_XR2:
    DECLE   _XR2.end - _XR2 - 1
    DECLE   $0318, $034C, $016E, $02A6, $03BB, $002F, $0290, $008E
    DECLE   $004B, $0392, $01DA, $024B, $013A, $01DA, $012F, $00B5
    DECLE   $02E5, $0297, $02DC, $0372, $014B, $016D, $0377, $00E7
    DECLE   $0376, $038A, $01CE, $026B, $02FA, $01AA, $011E, $0071
    DECLE   $00D5, $0297, $02BC, $02EA, $01C7, $02D7, $0135, $0155
    DECLE   $01DD, $0007, $0000
_XR2.end:  ; 43 decles
;; ------------------------------------------------------------------------ ;;
_YR:
    DECLE   _YR.end - _YR - 1
    DECLE   $0318, $03CC, $016E, $0197, $00FD, $0130, $0270, $0094
    DECLE   $0328, $0291, $0168, $007E, $01CC, $02F5, $0125, $02B5
    DECLE   $00F4, $0298, $01DA, $03F6, $0153, $0126, $03B9, $00AB
    DECLE   $0293, $03DB, $0175, $01B9, $0001
_YR.end:  ; 29 decles
;; ------------------------------------------------------------------------ ;;
_YY1:
    DECLE   _YY1.end - _YY1 - 1
    DECLE   $0318, $01CC, $016E, $0015, $00CB, $0263, $0320, $0078
    DECLE   $01CE, $0094, $001F, $0040, $0320, $03BF, $0230, $00A7
    DECLE   $000F, $01FE, $03FC, $01E2, $00D0, $0089, $000F, $0248
    DECLE   $032B, $03FD, $01CF, $0001, $0000
_YY1.end:  ; 29 decles
;; ------------------------------------------------------------------------ ;;
_YY2:
    DECLE   _YY2.end - _YY2 - 1
    DECLE   $0318, $01CC, $016E, $0015, $00CB, $0263, $0320, $0078
    DECLE   $01CE, $0094, $001F, $0040, $0320, $03BF, $0230, $00A7
    DECLE   $000F, $01FE, $03FC, $01E2, $00D0, $0089, $000F, $0248
    DECLE   $032B, $03FD, $01CF, $0199, $01EE, $008B, $0161, $0232
    DECLE   $0004, $0318, $01A7, $0198, $0124, $03E0, $0001, $0001
    DECLE   $030F, $0027, $0000
_YY2.end:  ; 43 decles
;; ------------------------------------------------------------------------ ;;
_ZH:
    DECLE   _ZH.end - _ZH - 1
    DECLE   $0310, $014D, $016E, $00C3, $03B9, $01BF, $0241, $0012
    DECLE   $0163, $00E1, $0000, $0080, $0084, $023F, $003F, $0000
_ZH.end:  ; 16 decles
;; ------------------------------------------------------------------------ ;;
_ZZ:
    DECLE   _ZZ.end - _ZZ - 1
    DECLE   $0218, $010D, $016F, $0225, $0351, $00B5, $02A0, $02EE
    DECLE   $00E9, $014D, $002C, $0360, $0008, $00EC, $004C, $0342
    DECLE   $03D4, $0156, $0052, $0131, $0008, $03B0, $01BE, $0172
    DECLE   $0000
_ZZ.end:  ; 25 decles

;;==========================================================================;;
;;                                                                          ;;
;;  Copyright information:                                                  ;;
;;                                                                          ;;
;;  The above allophone data was extracted from the SP0256-AL2 ROM image.   ;;
;;  The SP0256-AL2 allophones are NOT in the public domain, nor are they    ;;
;;  placed under the GNU General Public License.  This program is           ;;
;;  distributed in the hope that it will be useful, but WITHOUT ANY         ;;
;;  WARRANTY; without even the implied warranty of MERCHANTABILITY or       ;;
;;  FITNESS FOR A PARTICULAR PURPOSE.                                       ;;
;;                                                                          ;;
;;  Microchip, Inc. retains the copyright to the data and algorithms        ;;
;;  contained in the SP0256-AL2.  This speech data is distributed with      ;;
;;  explicit permission from Microchip, Inc.  All such redistributions      ;;
;;  must retain this notice of copyright.                                   ;;
;;                                                                          ;;
;;  No copyright claims are made on this data by the author(s) of SDK1600.  ;;
;;  Please see http://spatula-city.org/~im14u2c/sp0256-al2/ for details.    ;;
;;                                                                          ;;
;;==========================================================================;;

;* ======================================================================== *;
;*  These routines are placed into the public domain by their author.  All  *;
;*  copyright rights are hereby relinquished on the routines and data in    *;
;*  this file.  -- Joseph Zbiciak, 2008                                     *;
;* ======================================================================== *;

;; ======================================================================== ;;
;;  INTELLIVOICE DRIVER ROUTINES                                            ;;
;;  Written in 2002 by Joe Zbiciak <intvnut AT gmail.com>                   ;;
;;  http://spatula-city.org/~im14u2c/intv/                                  ;;
;; ======================================================================== ;;

;; ======================================================================== ;;
;;  GLOBAL VARIABLES USED BY THESE ROUTINES                                 ;;
;;                                                                          ;;
;;  Note that some of these routines may use one or more global variables.  ;;
;;  If you use these routines, you will need to allocate the appropriate    ;;
;;  space in either 16-bit or 8-bit memory as appropriate.  Each global     ;;
;;  variable is listed with the routines which use it and the required      ;;
;;  memory width.                                                           ;;
;;                                                                          ;;
;;  Example declarations for these routines are shown below, commented out. ;;
;;  You should uncomment these and add them to your program to make use of  ;;
;;  the routine that needs them.  Make sure to assign these variables to    ;;
;;  locations that aren't used for anything else.                           ;;
;; ======================================================================== ;;

                        ; Used by       Req'd Width     Description
                        ;-----------------------------------------------------
;IV.QH      EQU $110    ; IV_xxx        8-bit           Voice queue head
;IV.QT      EQU $111    ; IV_xxx        8-bit           Voice queue tail
;IV.Q       EQU $112    ; IV_xxx        8-bit           Voice queue  (8 bytes)
;IV.FLEN    EQU $11A    ; IV_xxx        8-bit           Length of FIFO data
;IV.FPTR    EQU $320    ; IV_xxx        16-bit          Current FIFO ptr.
;IV.PPTR    EQU $321    ; IV_xxx        16-bit          Current Phrase ptr.

;; ======================================================================== ;;
;;  MEMORY USAGE                                                            ;;
;;                                                                          ;;
;;  These routines implement a queue of "pending phrases" that will be      ;;
;;  played by the Intellivoice.  The user calls IV_PLAY to enqueue a        ;;
;;  phrase number.  Phrase numbers indicate either a RESROM sample or       ;;
;;  a compiled in phrase to be spoken.                                      ;;
;;                                                                          ;;
;;  The user must compose an "IV_PHRASE_TBL", which is composed of          ;;
;;  pointers to phrases to be spoken.  Phrases are strings of pointers      ;;
;;  and RESROM triggers, terminated by a NUL.                               ;;
;;                                                                          ;;
;;  Phrase numbers 1 through 42 are RESROM samples.  Phrase numbers         ;;
;;  43 through 255 index into the IV_PHRASE_TBL.                            ;;
;;                                                                          ;;
;;  SPECIAL NOTES                                                           ;;
;;                                                                          ;;
;;  Bit 7 of IV.QH and IV.QT is used to denote whether the Intellivoice     ;;
;;  is present.  If Intellivoice is present, this bit is clear.             ;;
;;                                                                          ;;
;;  Bit 6 of IV.QT is used to denote that we still need to do an ALD $00    ;;
;;  for FIFO'd voice data.                                                  ;;
;; ======================================================================== ;;
            

;; ======================================================================== ;;
;;  NAME                                                                    ;;
;;      IV_INIT     Initialize the Intellivoice                             ;;
;;                                                                          ;;
;;  AUTHOR                                                                  ;;
;;      Joseph Zbiciak <intvnut AT gmail.com>                               ;;
;;                                                                          ;;
;;  REVISION HISTORY                                                        ;;
;;      15-Sep-2002 Initial revision . . . . . . . . . . .  J. Zbiciak      ;;
;;                                                                          ;;
;;  INPUTS for IV_INIT                                                      ;;
;;      R5      Return address                                              ;;
;;                                                                          ;;
;;  OUTPUTS                                                                 ;;
;;      R0      0 if Intellivoice found, -1 if not.                         ;;
;;                                                                          ;;
;;  DESCRIPTION                                                             ;;
;;      Resets Intellivoice, determines if it is actually there, and        ;;
;;      then initializes the IV structure.                                  ;;
;; ------------------------------------------------------------------------ ;;
;;                   Copyright (c) 2002, Joseph Zbiciak                     ;;
;; ======================================================================== ;;

IV_INIT     PROC
            MVII    #$0400, R0          ;
            MVO     R0,     $0081       ; Reset the Intellivoice

            MVI     $0081,  R0          ; \
            RLC     R0,     2           ;  |-- See if we detect Intellivoice
            BOV     @@no_ivoice         ; /    once we've reset it.

            CLRR    R0                  ; 
            MVO     R0,     IV.FPTR     ; No data for FIFO
            MVO     R0,     IV.PPTR     ; No phrase being spoken
            MVO     R0,     IV.QH       ; Clear our queue
            MVO     R0,     IV.QT       ; Clear our queue
            JR      R5                  ; Done!

@@no_ivoice:
            CLRR    R0
            MVO     R0,     IV.FPTR     ; No data for FIFO
            MVO     R0,     IV.PPTR     ; No phrase being spoken
            DECR    R0
            MVO     R0,     IV.QH       ; Set queue to -1 ("No Intellivoice")
            MVO     R0,     IV.QT       ; Set queue to -1 ("No Intellivoice")
            JR      R5                  ; Done!
            ENDP

;; ======================================================================== ;;
;;  NAME                                                                    ;;
;;      IV_ISR      Interrupt service routine to feed Intellivoice          ;;
;;                                                                          ;;
;;  AUTHOR                                                                  ;;
;;      Joseph Zbiciak <intvnut AT gmail.com>                               ;;
;;                                                                          ;;
;;  REVISION HISTORY                                                        ;;
;;      15-Sep-2002 Initial revision . . . . . . . . . . .  J. Zbiciak      ;;
;;                                                                          ;;
;;  INPUTS for IV_ISR                                                       ;;
;;      R5      Return address                                              ;;
;;                                                                          ;;
;;  OUTPUTS                                                                 ;;
;;      R0, R1, R4 trashed.                                                 ;;
;;                                                                          ;;
;;  NOTES                                                                   ;;
;;      Call this from your main interrupt service routine.                 ;;
;; ------------------------------------------------------------------------ ;;
;;                   Copyright (c) 2002, Joseph Zbiciak                     ;;
;; ======================================================================== ;;
IV_ISR      PROC
            ;; ------------------------------------------------------------ ;;
            ;;  Check for Intellivoice.  Leave if none present.             ;;
            ;; ------------------------------------------------------------ ;;
            MVI     IV.QT,  R1          ; Get queue tail
            SWAP    R1,     2
            BPL     @@ok                ; Bit 7 set? If yes: No Intellivoice
@@ald_busy:
@@leave     JR      R5                  ; Exit if no Intellivoice.

     
            ;; ------------------------------------------------------------ ;;
            ;;  Check to see if we pump samples into the FIFO.
            ;; ------------------------------------------------------------ ;;
@@ok:       MVI     IV.FPTR, R4         ; Get FIFO data pointer
            TSTR    R4                  ; is it zero?
            BEQ     @@no_fifodata       ; Yes:  No data for FIFO.
@@fifo_fill:
            MVI     $0081,  R0          ; Read speech FIFO ready bit
            SLLC    R0,     1           ; 
            BC      @@fifo_busy     

            MVI@    R4,     R0          ; Get next word
            MVO     R0,     $0081       ; write it to the FIFO

            MVI     IV.FLEN, R0         ;\
            DECR    R0                  ; |-- Decrement our FIFO'd data length
            MVO     R0,     IV.FLEN     ;/
            BEQ     @@last_fifo         ; If zero, we're done w/ FIFO
            MVO     R4,     IV.FPTR     ; Otherwise, save new pointer
            B       @@fifo_fill         ; ...and keep trying to load FIFO

@@last_fifo MVO     R0,     IV.FPTR     ; done with FIFO loading.
                                        ; fall into ALD processing.


            ;; ------------------------------------------------------------ ;;
            ;;  Try to do an Address Load.  We do this in two settings:     ;;
            ;;   -- We have no FIFO data to load.                           ;;
            ;;   -- We've loaded as much FIFO data as we can, but we        ;;
            ;;      might have an address load command to send for it.      ;;
            ;; ------------------------------------------------------------ ;;
@@fifo_busy:
@@no_fifodata:
            MVI     $0080,  R0          ; Read LRQ bit from ALD register
            SLLC    R0,     1
            BNC     @@ald_busy          ; LRQ is low, meaning we can't ALD.
                                        ; So, leave.

            ;; ------------------------------------------------------------ ;;
            ;;  We can do an address load (ALD) on the SP0256.  Give FIFO   ;;
            ;;  driven ALDs priority, since we already started the FIFO     ;;
            ;;  load.  The "need ALD" bit is stored in bit 6 of IV.QT.      ;;
            ;; ------------------------------------------------------------ ;;
            ANDI    #$40,   R1          ; Is "Need FIFO ALD" bit set?
            BEQ     @@no_fifo_ald
            XOR     IV.QT,  R1          ;\__ Clear the "Need FIFO ALD" bit.
            MVO     R1,     IV.QT       ;/
            CLRR    R1
            MVO     R1,     $80         ; Load a 0 into ALD (trigger FIFO rd.)
            JR      R5                  ; done!

            ;; ------------------------------------------------------------ ;;
            ;;  We don't need to ALD on behalf of the FIFO.  So, we grab    ;;
            ;;  the next thing off our phrase list.                         ;;
            ;; ------------------------------------------------------------ ;;
@@no_fifo_ald:
            MVI     IV.PPTR, R4         ; Get phrase pointer.
            TSTR    R4                  ; Is it zero?
            BEQ     @@next_phrase       ; Yes:  Get next phrase from queue.

            MVI@    R4,     R0
            TSTR    R0                  ; Is it end of phrase?
            BNEQ    @@process_phrase    ; !=0:  Go do it.

            MVO     R0,     IV.PPTR     ; 
@@next_phrase:
            MVI     IV.QT,  R1          ; reload queue tail (was trashed above)
            MOVR    R1,     R0          ; copy QT to R0 so we can increment it
            ANDI    #$7,    R1          ; Mask away flags in queue head
            CMP     IV.QH,  R1          ; Is it same as queue tail?
            BEQ     @@leave             ; Yes:  No more speech for now.

            INCR    R0
            ANDI    #$F7,   R0          ; mask away the possible 'carry'
            MVO     R0,     IV.QT       ; save updated queue tail

            ADDI    #IV.Q,  R1          ; Index into queue
            MVI@    R1,     R4          ; get next value from queue
            CMPI    #43,    R4          ; Is it a RESROM or Phrase?
            BNC     @@play_resrom_r4
@@new_phrase:
;            ADDI    #IV_PHRASE_TBL - 43, R4 ; Index into phrase table
;            MVI@    R4,     R4          ; Read from phrase table
            MVO     R4,     IV.PPTR
            JR      R5                  ; we'll get to this phrase next time.

@@play_resrom_r4:
            MVO     R4,     $0080       ; Just ALD it
            JR      R5                  ; and leave.

            ;; ------------------------------------------------------------ ;;
            ;;  We're in the middle of a phrase, so continue interpreting.  ;;
            ;; ------------------------------------------------------------ ;;
@@process_phrase:
            
            MVO     R4,     IV.PPTR     ; save new phrase pointer
            CMPI    #43,    R0          ; Is it a RESROM cue?
            BC      @@play_fifo         ; Just ALD it and leave.
@@play_resrom_r0
            MVO     R0,     $0080       ; Just ALD it
            JR      R5                  ; and leave.
@@play_fifo:
            MVI     IV.FPTR,R1          ; Make sure not to stomp existing FIFO
            TSTR    R1                  ; data.
            BEQ     @@new_fifo_ok
            DECR    R4                  ; Oops, FIFO data still playing,
            MVO     R4,     IV.PPTR     ; so rewind.
            JR      R5                  ; and leave.

@@new_fifo_ok:
            MOVR    R0,     R4          ;
            MVI@    R4,     R0          ; Get chunk length
            MVO     R0,     IV.FLEN     ; Init FIFO chunk length
            MVO     R4,     IV.FPTR     ; Init FIFO pointer
            MVI     IV.QT,  R0          ;\
            XORI    #$40,   R0          ; |- Set "Need ALD" bit in QT
            MVO     R0,     IV.QT       ;/

  IF 1      ; debug code                ;\
            ANDI    #$40,   R0          ; |   Debug code:  We should only
            BNEQ    @@qtok              ; |-- be here if "Need FIFO ALD" 
            HLT     ;BUG!!              ; |   was already clear.         
@@qtok                                  ;/    
  ENDI
            JR      R5                  ; leave.

            ENDP


;; ======================================================================== ;;
;;  NAME                                                                    ;;
;;      IV_PLAY     Play a voice sample sequence.                           ;;
;;                                                                          ;;
;;  AUTHOR                                                                  ;;
;;      Joseph Zbiciak <intvnut AT gmail.com>                               ;;
;;                                                                          ;;
;;  REVISION HISTORY                                                        ;;
;;      15-Sep-2002 Initial revision . . . . . . . . . . .  J. Zbiciak      ;;
;;                                                                          ;;
;;  INPUTS for IV_PLAY                                                      ;;
;;      R5      Invocation record, followed by return address.              ;;
;;                  1 DECLE    Phrase number to play.                       ;;
;;                                                                          ;;
;;  INPUTS for IV_PLAY.1                                                    ;;
;;      R0      Address of phrase to play.                                  ;;
;;      R5      Return address                                              ;;
;;                                                                          ;;
;;  OUTPUTS                                                                 ;;
;;      R0, R1  trashed                                                     ;;
;;      Z==0    if item not successfully queued.                            ;;
;;      Z==1    if successfully queued.                                     ;;
;;                                                                          ;;
;;  NOTES                                                                   ;;
;;      This code will drop phrases if the queue is full.                   ;;
;;      Phrase numbers 1..42 are RESROM samples.  43..255 will index        ;;
;;      into the user-supplied IV_PHRASE_TBL.  43 will refer to the         ;;
;;      first entry, 44 to the second, and so on.  Phrase 0 is undefined.   ;;
;;                                                                          ;;
;; ------------------------------------------------------------------------ ;;
;;                   Copyright (c) 2002, Joseph Zbiciak                     ;;
;; ======================================================================== ;;
IV_PLAY     PROC
            MVI@    R5,     R0

@@1:        ; alternate entry point
            MVI     IV.QT,  R1          ; Get queue tail
            SWAP    R1,     2           ;\___ Leave if "no Intellivoice"
            BMI     @@leave             ;/    bit it set.
@@ok:       
            DECR    R1                  ;\
            ANDI    #$7,    R1          ; |-- See if we still have room
            CMP     IV.QH,  R1          ;/
            BEQ     @@leave             ; Leave if we're full

@@2:        MVI     IV.QH,  R1          ; Get our queue head pointer
            PSHR    R1                  ;\
            INCR    R1                  ; |
            ANDI    #$F7,   R1          ; |-- Increment it, removing
            MVO     R1,     IV.QH       ; |   carry but preserving flags.
            PULR    R1                  ;/

            ADDI    #IV.Q,  R1          ;\__ Store phrase to queue
            MVO@    R0,     R1          ;/

@@leave:    JR      R5                  ; Leave.
            ENDP

;; ======================================================================== ;;
;;  NAME                                                                    ;;
;;      IV_PLAYW    Play a voice sample sequence.  Wait for queue room.     ;;
;;                                                                          ;;
;;  AUTHOR                                                                  ;;
;;      Joseph Zbiciak <intvnut AT gmail.com>                               ;;
;;                                                                          ;;
;;  REVISION HISTORY                                                        ;;
;;      15-Sep-2002 Initial revision . . . . . . . . . . .  J. Zbiciak      ;;
;;                                                                          ;;
;;  INPUTS for IV_PLAY                                                      ;;
;;      R5      Invocation record, followed by return address.              ;;
;;                  1 DECLE    Phrase number to play.                       ;;
;;                                                                          ;;
;;  INPUTS for IV_PLAY.1                                                    ;;
;;      R0      Address of phrase to play.                                  ;;
;;      R5      Return address                                              ;;
;;                                                                          ;;
;;  OUTPUTS                                                                 ;;
;;      R0, R1  trashed                                                     ;;
;;                                                                          ;;
;;  NOTES                                                                   ;;
;;      This code will wait for a queue slot to open if queue is full.      ;;
;;      Phrase numbers 1..42 are RESROM samples.  43..255 will index        ;;
;;      into the user-supplied IV_PHRASE_TBL.  43 will refer to the         ;;
;;      first entry, 44 to the second, and so on.  Phrase 0 is undefined.   ;;
;;                                                                          ;;
;; ------------------------------------------------------------------------ ;;
;;                   Copyright (c) 2002, Joseph Zbiciak                     ;;
;; ======================================================================== ;;
IV_PLAYW    PROC
            MVI@    R5,     R0

@@1:        ; alternate entry point
            MVI     IV.QT,  R1          ; Get queue tail
            SWAP    R1,     2           ;\___ Leave if "no Intellivoice"
            BMI     IV_PLAY.leave       ;/    bit it set.
@@ok:       
            DECR    R1                  ;\
            ANDI    #$7,    R1          ; |-- See if we still have room
            CMP     IV.QH,  R1          ;/
            BEQ     @@1                 ; wait for room
            B       IV_PLAY.2

            ENDP

;; ======================================================================== ;;
;;  NAME                                                                    ;;
;;      IV_WAIT     Wait for voice queue to empty.                          ;;
;;                                                                          ;;
;;  AUTHOR                                                                  ;;
;;      Joseph Zbiciak <intvnut AT gmail.com>                               ;;
;;                                                                          ;;
;;  REVISION HISTORY                                                        ;;
;;      15-Sep-2002 Initial revision . . . . . . . . . . .  J. Zbiciak      ;;
;;                                                                          ;;
;;  INPUTS for IV_WAIT                                                      ;;
;;      R5      Return address                                              ;;
;;                                                                          ;;
;;  OUTPUTS                                                                 ;;
;;      R0      trashed.                                                    ;;
;;                                                                          ;;
;;  NOTES                                                                   ;;
;;      This waits until the Intellivoice is nearly completely quiescent.   ;;
;;      Some voice data may still be spoken from the last triggered         ;;
;;      phrase.  To truly wait for *that* to be spoken, speak a 'pause'     ;;
;;      (eg. RESROM.pa1) and then call IV_WAIT.                             ;;
;; ------------------------------------------------------------------------ ;;
;;                   Copyright (c) 2002, Joseph Zbiciak                     ;;
;; ======================================================================== ;;
IV_WAIT     PROC
            MVI     IV.QH,  R0
            SWAP    R0                  ;\___ test bit 7, leave if set.
            SWAP    R0                  ;/    (SWAP2 corrupts upper byte.)
            BMI     @@leave

            ; Wait for queue to drain.
@@q_loop:   CMP     IV.QT,  R0
            BNEQ    @@q_loop

            ; Wait for FIFO and LRQ to say ready.
@@s_loop:   MVI     $81,    R0          ; Read FIFO status.  0 == ready.
            COMR    R0
            AND     $80,    R0          ; Merge w/ ALD status.  1 == ready
            TSTR    R0
            BPL     @@s_loop            ; if bit 15 == 0, not ready.
            
@@leave:    JR      R5
            ENDP

;; ======================================================================== ;;
;;  End of File:  ivoice.asm                                                ;;
;; ======================================================================== ;;

;* ======================================================================== *;
;*  These routines are placed into the public domain by their author.  All  *;
;*  copyright rights are hereby relinquished on the routines and data in    *;
;*  this file.  -- Joseph Zbiciak, 2008                                     *;
;* ======================================================================== *;

;; ======================================================================== ;;
;;  NAME                                                                    ;;
;;      IV_SAYNUM16 Say a 16-bit unsigned number using RESROM digits        ;;
;;                                                                          ;;
;;  AUTHOR                                                                  ;;
;;      Joseph Zbiciak <intvnut AT gmail.com>                               ;;
;;                                                                          ;;
;;  REVISION HISTORY                                                        ;;
;;      16-Sep-2002 Initial revision . . . . . . . . . . .  J. Zbiciak      ;;
;;                                                                          ;;
;;  INPUTS for IV_INIT                                                      ;;
;;      R0      Number to "speak"                                           ;;
;;      R5      Return address                                              ;;
;;                                                                          ;;
;;  OUTPUTS                                                                 ;;
;;                                                                          ;;
;;  DESCRIPTION                                                             ;;
;;      "Says" a 16-bit number using IV_PLAYW to queue up the phrase.       ;;
;;      Because the number may be built from several segments, it could     ;;
;;      easily eat up the queue.  I believe the longest number will take    ;;
;;      7 queue entries -- that is, fill the queue.  Thus, this code        ;;
;;      could block, waiting for slots in the queue.                        ;;
;; ======================================================================== ;;

IV_SAYNUM16 PROC
            PSHR    R5

            TSTR    R0
            BEQ     @@zero          ; Special case:  Just say "zero"

            ;; ------------------------------------------------------------ ;;
            ;;  First, try to pull off 'thousands'.  We call ourselves      ;;
            ;;  recursively to play the the number of thousands.            ;;
            ;; ------------------------------------------------------------ ;;
            CLRR    R1
@@thloop:   INCR    R1
            SUBI    #1000,  R0
            BC      @@thloop

            ADDI    #1000,  R0
            PSHR    R0
            DECR    R1
            BEQ     @@no_thousand

            CALL    IV_SAYNUM16.recurse

            CALL    IV_PLAYW
            DECLE   36  ; THOUSAND
            
@@no_thousand
            PULR    R1

            ;; ------------------------------------------------------------ ;;
            ;;  Now try to play hundreds.                                   ;;
            ;; ------------------------------------------------------------ ;;
            MVII    #7-1, R0    ; ZERO
            CMPI    #100,   R1
            BNC     @@no_hundred

@@hloop:    INCR    R0
            SUBI    #100,   R1
            BC      @@hloop
            ADDI    #100,   R1

            PSHR    R1

            CALL    IV_PLAYW.1

            CALL    IV_PLAYW
            DECLE   35  ; HUNDRED

            PULR    R1
            B       @@notrecurse    ; skip "PSHR R5"
@@recurse:  PSHR    R5              ; recursive entry point for 'thousand'

@@no_hundred:
@@notrecurse:
            MOVR    R1,     R0
            BEQ     @@leave

            SUBI    #20,    R1
            BNC     @@teens

            MVII    #27-1, R0   ; TWENTY
@@tyloop    INCR    R0
            SUBI    #10,    R1
            BC      @@tyloop
            ADDI    #10,    R1

            PSHR    R1
            CALL    IV_PLAYW.1

            PULR    R0
            TSTR    R0
            BEQ     @@leave

@@teens:
@@zero:     ADDI    #7, R0  ; ZERO

            CALL    IV_PLAYW.1

@@leave     PULR    PC
            ENDP

;; ======================================================================== ;;
;;  End of File:  saynum16.asm                                              ;;
;; ======================================================================== ;;

    ENDI

        IF DEFINED intybasic_flash

;; ======================================================================== ;;
;;  JLP "Save Game" support                                                 ;;
;; ======================================================================== ;;
JF.first    EQU     $8023
JF.last     EQU     $8024
JF.addr     EQU     $8025
JF.row      EQU     $8026
                   
JF.wrcmd    EQU     $802D
JF.rdcmd    EQU     $802E
JF.ercmd    EQU     $802F
JF.wrkey    EQU     $C0DE
JF.rdkey    EQU     $DEC0
JF.erkey    EQU     $BEEF

JF.write:   DECLE   JF.wrcmd,   JF.wrkey    ; Copy JLP RAM to flash row  
JF.read:    DECLE   JF.rdcmd,   JF.rdkey    ; Copy flash row to JLP RAM  
JF.erase:   DECLE   JF.ercmd,   JF.erkey    ; Erase flash sector 

;; ======================================================================== ;;
;;  JF.INIT         Copy JLP save-game support routine to System RAM        ;;
;; ======================================================================== ;;
JF.INIT     PROC
            PSHR    R5            
            MVII    #@@__code,  R5
            MVII    #JF.SYSRAM, R4
            REPEAT  5       
            MVI@    R5,         R0      ; \_ Copy code fragment to System RAM
            MVO@    R0,         R4      ; /
            ENDR
            PULR    PC

            ;; === start of code that will run from RAM
@@__code:   MVO@    R0,         R1      ; JF.SYSRAM + 0: initiate command
            ADD@    R1,         PC      ; JF.SYSRAM + 1: Wait for JLP to return
            JR      R5                  ; JF.SYSRAM + 2:
            MVO@    R2,         R2      ; JF.SYSRAM + 3: \__ simple ISR
            JR      R5                  ; JF.SYSRAM + 4: /
            ;; === end of code that will run from RAM
            ENDP

;; ======================================================================== ;;
;;  JF.CMD          Issue a JLP Flash command                               ;;
;;                                                                          ;;
;;  INPUT                                                                   ;;
;;      R0  Slot number to operate on                                       ;;
;;      R1  Address to copy to/from in JLP RAM                              ;;
;;      @R5 Command to invoke:                                              ;;
;;                                                                          ;;
;;              JF.write -- Copy JLP RAM to Flash                           ;;
;;              JF.read  -- Copy Flash to JLP RAM                           ;;
;;              JF.erase -- Erase flash sector                              ;;
;;                                                                          ;;
;;  OUTPUT                                                                  ;;
;;      R0 - R4 not modified.  (Saved and restored across call)             ;;
;;      JLP command executed                                                ;;
;;                                                                          ;;
;;  NOTES                                                                   ;;
;;      This code requires two short routines in the console's System RAM.  ;;
;;      It also requires that the system stack reside in System RAM.        ;;
;;      Because an interrupt may occur during the code's execution, there   ;;
;;      must be sufficient stack space to service the interrupt (8 words).  ;;
;;                                                                          ;;
;;      The code also relies on the fact that the EXEC ISR dispatch does    ;;
;;      not modify R2.  This allows us to initialize R2 for the ISR ahead   ;;
;;      of time, rather than in the ISR.                                    ;;
;; ======================================================================== ;;
JF.CMD      PROC

            MVO     R4,         JF.SV.R4    ; \
            MVII    #JF.SV.R0,  R4          ;  |
            MVO@    R0,         R4          ;  |- Save registers, but not on
            MVO@    R1,         R4          ;  |  the stack.  (limit stack use)
            MVO@    R2,         R4          ; /

            MVI@    R5,         R4          ; Get command to invoke

            MVO     R5,         JF.SV.R5    ; save return address

            DIS
            MVO     R1,         JF.addr     ; \_ Save SG arguments in JLP
            MVO     R0,         JF.row      ; /
                                          
            MVI@    R4,         R1          ; Get command address
            MVI@    R4,         R0          ; Get unlock word
                                          
            MVII    #$100,      R4          ; \
            SDBD                            ;  |_ Save old ISR in save area
            MVI@    R4,         R2          ;  |
            MVO     R2,         JF.SV.ISR   ; /
                                          
            MVII    #JF.SYSRAM + 3, R2      ; \
            MVO     R2,         $100        ;  |_ Set up new ISR in RAM
            SWAP    R2                      ;  |
            MVO     R2,         $101        ; / 
                                          
            MVII    #$20,       R2          ; Address of STIC handshake
            JSRE    R5,  JF.SYSRAM          ; Invoke the command
                                          
            MVI     JF.SV.ISR,  R2          ; \
            MVO     R2,         $100        ;  |_ Restore old ISR 
            SWAP    R2                      ;  |
            MVO     R2,         $101        ; /
                                          
            MVII    #JF.SV.R0,  R5          ; \
            MVI@    R5,         R0          ;  |
            MVI@    R5,         R1          ;  |- Restore registers
            MVI@    R5,         R2          ;  |
            MVI@    R5,         R4          ; /
            MVI@    R5,         PC          ; Return

            ENDP


        ENDI

	IF DEFINED intybasic_fastmult

; Quarter Square Multiplication
; Assembly code by Joe Zbiciak, 2015
; Released to public domain.

QSQR8_TBL:  PROC
            DECLE   $3F80, $3F01, $3E82, $3E04, $3D86, $3D09, $3C8C, $3C10
            DECLE   $3B94, $3B19, $3A9E, $3A24, $39AA, $3931, $38B8, $3840
            DECLE   $37C8, $3751, $36DA, $3664, $35EE, $3579, $3504, $3490
            DECLE   $341C, $33A9, $3336, $32C4, $3252, $31E1, $3170, $3100
            DECLE   $3090, $3021, $2FB2, $2F44, $2ED6, $2E69, $2DFC, $2D90
            DECLE   $2D24, $2CB9, $2C4E, $2BE4, $2B7A, $2B11, $2AA8, $2A40
            DECLE   $29D8, $2971, $290A, $28A4, $283E, $27D9, $2774, $2710
            DECLE   $26AC, $2649, $25E6, $2584, $2522, $24C1, $2460, $2400
            DECLE   $23A0, $2341, $22E2, $2284, $2226, $21C9, $216C, $2110
            DECLE   $20B4, $2059, $1FFE, $1FA4, $1F4A, $1EF1, $1E98, $1E40
            DECLE   $1DE8, $1D91, $1D3A, $1CE4, $1C8E, $1C39, $1BE4, $1B90
            DECLE   $1B3C, $1AE9, $1A96, $1A44, $19F2, $19A1, $1950, $1900
            DECLE   $18B0, $1861, $1812, $17C4, $1776, $1729, $16DC, $1690
            DECLE   $1644, $15F9, $15AE, $1564, $151A, $14D1, $1488, $1440
            DECLE   $13F8, $13B1, $136A, $1324, $12DE, $1299, $1254, $1210
            DECLE   $11CC, $1189, $1146, $1104, $10C2, $1081, $1040, $1000
            DECLE   $0FC0, $0F81, $0F42, $0F04, $0EC6, $0E89, $0E4C, $0E10
            DECLE   $0DD4, $0D99, $0D5E, $0D24, $0CEA, $0CB1, $0C78, $0C40
            DECLE   $0C08, $0BD1, $0B9A, $0B64, $0B2E, $0AF9, $0AC4, $0A90
            DECLE   $0A5C, $0A29, $09F6, $09C4, $0992, $0961, $0930, $0900
            DECLE   $08D0, $08A1, $0872, $0844, $0816, $07E9, $07BC, $0790
            DECLE   $0764, $0739, $070E, $06E4, $06BA, $0691, $0668, $0640
            DECLE   $0618, $05F1, $05CA, $05A4, $057E, $0559, $0534, $0510
            DECLE   $04EC, $04C9, $04A6, $0484, $0462, $0441, $0420, $0400
            DECLE   $03E0, $03C1, $03A2, $0384, $0366, $0349, $032C, $0310
            DECLE   $02F4, $02D9, $02BE, $02A4, $028A, $0271, $0258, $0240
            DECLE   $0228, $0211, $01FA, $01E4, $01CE, $01B9, $01A4, $0190
            DECLE   $017C, $0169, $0156, $0144, $0132, $0121, $0110, $0100
            DECLE   $00F0, $00E1, $00D2, $00C4, $00B6, $00A9, $009C, $0090
            DECLE   $0084, $0079, $006E, $0064, $005A, $0051, $0048, $0040
            DECLE   $0038, $0031, $002A, $0024, $001E, $0019, $0014, $0010
            DECLE   $000C, $0009, $0006, $0004, $0002, $0001, $0000
@@mid:
            DECLE   $0000, $0000, $0001, $0002, $0004, $0006, $0009, $000C
            DECLE   $0010, $0014, $0019, $001E, $0024, $002A, $0031, $0038
            DECLE   $0040, $0048, $0051, $005A, $0064, $006E, $0079, $0084
            DECLE   $0090, $009C, $00A9, $00B6, $00C4, $00D2, $00E1, $00F0
            DECLE   $0100, $0110, $0121, $0132, $0144, $0156, $0169, $017C
            DECLE   $0190, $01A4, $01B9, $01CE, $01E4, $01FA, $0211, $0228
            DECLE   $0240, $0258, $0271, $028A, $02A4, $02BE, $02D9, $02F4
            DECLE   $0310, $032C, $0349, $0366, $0384, $03A2, $03C1, $03E0
            DECLE   $0400, $0420, $0441, $0462, $0484, $04A6, $04C9, $04EC
            DECLE   $0510, $0534, $0559, $057E, $05A4, $05CA, $05F1, $0618
            DECLE   $0640, $0668, $0691, $06BA, $06E4, $070E, $0739, $0764
            DECLE   $0790, $07BC, $07E9, $0816, $0844, $0872, $08A1, $08D0
            DECLE   $0900, $0930, $0961, $0992, $09C4, $09F6, $0A29, $0A5C
            DECLE   $0A90, $0AC4, $0AF9, $0B2E, $0B64, $0B9A, $0BD1, $0C08
            DECLE   $0C40, $0C78, $0CB1, $0CEA, $0D24, $0D5E, $0D99, $0DD4
            DECLE   $0E10, $0E4C, $0E89, $0EC6, $0F04, $0F42, $0F81, $0FC0
            DECLE   $1000, $1040, $1081, $10C2, $1104, $1146, $1189, $11CC
            DECLE   $1210, $1254, $1299, $12DE, $1324, $136A, $13B1, $13F8
            DECLE   $1440, $1488, $14D1, $151A, $1564, $15AE, $15F9, $1644
            DECLE   $1690, $16DC, $1729, $1776, $17C4, $1812, $1861, $18B0
            DECLE   $1900, $1950, $19A1, $19F2, $1A44, $1A96, $1AE9, $1B3C
            DECLE   $1B90, $1BE4, $1C39, $1C8E, $1CE4, $1D3A, $1D91, $1DE8
            DECLE   $1E40, $1E98, $1EF1, $1F4A, $1FA4, $1FFE, $2059, $20B4
            DECLE   $2110, $216C, $21C9, $2226, $2284, $22E2, $2341, $23A0
            DECLE   $2400, $2460, $24C1, $2522, $2584, $25E6, $2649, $26AC
            DECLE   $2710, $2774, $27D9, $283E, $28A4, $290A, $2971, $29D8
            DECLE   $2A40, $2AA8, $2B11, $2B7A, $2BE4, $2C4E, $2CB9, $2D24
            DECLE   $2D90, $2DFC, $2E69, $2ED6, $2F44, $2FB2, $3021, $3090
            DECLE   $3100, $3170, $31E1, $3252, $32C4, $3336, $33A9, $341C
            DECLE   $3490, $3504, $3579, $35EE, $3664, $36DA, $3751, $37C8
            DECLE   $3840, $38B8, $3931, $39AA, $3A24, $3A9E, $3B19, $3B94
            DECLE   $3C10, $3C8C, $3D09, $3D86, $3E04, $3E82, $3F01, $3F80
            DECLE   $4000, $4080, $4101, $4182, $4204, $4286, $4309, $438C
            DECLE   $4410, $4494, $4519, $459E, $4624, $46AA, $4731, $47B8
            DECLE   $4840, $48C8, $4951, $49DA, $4A64, $4AEE, $4B79, $4C04
            DECLE   $4C90, $4D1C, $4DA9, $4E36, $4EC4, $4F52, $4FE1, $5070
            DECLE   $5100, $5190, $5221, $52B2, $5344, $53D6, $5469, $54FC
            DECLE   $5590, $5624, $56B9, $574E, $57E4, $587A, $5911, $59A8
            DECLE   $5A40, $5AD8, $5B71, $5C0A, $5CA4, $5D3E, $5DD9, $5E74
            DECLE   $5F10, $5FAC, $6049, $60E6, $6184, $6222, $62C1, $6360
            DECLE   $6400, $64A0, $6541, $65E2, $6684, $6726, $67C9, $686C
            DECLE   $6910, $69B4, $6A59, $6AFE, $6BA4, $6C4A, $6CF1, $6D98
            DECLE   $6E40, $6EE8, $6F91, $703A, $70E4, $718E, $7239, $72E4
            DECLE   $7390, $743C, $74E9, $7596, $7644, $76F2, $77A1, $7850
            DECLE   $7900, $79B0, $7A61, $7B12, $7BC4, $7C76, $7D29, $7DDC
            DECLE   $7E90, $7F44, $7FF9, $80AE, $8164, $821A, $82D1, $8388
            DECLE   $8440, $84F8, $85B1, $866A, $8724, $87DE, $8899, $8954
            DECLE   $8A10, $8ACC, $8B89, $8C46, $8D04, $8DC2, $8E81, $8F40
            DECLE   $9000, $90C0, $9181, $9242, $9304, $93C6, $9489, $954C
            DECLE   $9610, $96D4, $9799, $985E, $9924, $99EA, $9AB1, $9B78
            DECLE   $9C40, $9D08, $9DD1, $9E9A, $9F64, $A02E, $A0F9, $A1C4
            DECLE   $A290, $A35C, $A429, $A4F6, $A5C4, $A692, $A761, $A830
            DECLE   $A900, $A9D0, $AAA1, $AB72, $AC44, $AD16, $ADE9, $AEBC
            DECLE   $AF90, $B064, $B139, $B20E, $B2E4, $B3BA, $B491, $B568
            DECLE   $B640, $B718, $B7F1, $B8CA, $B9A4, $BA7E, $BB59, $BC34
            DECLE   $BD10, $BDEC, $BEC9, $BFA6, $C084, $C162, $C241, $C320
            DECLE   $C400, $C4E0, $C5C1, $C6A2, $C784, $C866, $C949, $CA2C
            DECLE   $CB10, $CBF4, $CCD9, $CDBE, $CEA4, $CF8A, $D071, $D158
            DECLE   $D240, $D328, $D411, $D4FA, $D5E4, $D6CE, $D7B9, $D8A4
            DECLE   $D990, $DA7C, $DB69, $DC56, $DD44, $DE32, $DF21, $E010
            DECLE   $E100, $E1F0, $E2E1, $E3D2, $E4C4, $E5B6, $E6A9, $E79C
            DECLE   $E890, $E984, $EA79, $EB6E, $EC64, $ED5A, $EE51, $EF48
            DECLE   $F040, $F138, $F231, $F32A, $F424, $F51E, $F619, $F714
            DECLE   $F810, $F90C, $FA09, $FB06, $FC04, $FD02, $FE01
            ENDP

; R0 = R0 * R1, where R0 and R1 are unsigned 8-bit values
; Destroys R1, R4
qs_mpy8:    PROC
            MOVR    R0,             R4      ;   6
            ADDI    #QSQR8_TBL.mid, R1      ;   8
            ADDR    R1,             R4      ;   6   a + b
            SUBR    R0,             R1      ;   6   a - b
@@ok:       MVI@    R4,             R0      ;   8
            SUB@    R1,             R0      ;   8
            JR      R5                      ;   7
                                            ;----
                                            ;  49
            ENDP
            

; R1 = R0 * R1, where R0 and R1 are 16-bit values
; destroys R0, R2, R3, R4, R5
qs_mpy16:   PROC
            PSHR    R5                  ;   9
                                   
            ; Unpack lo/hi
            MOVR    R0,         R2      ;   6   
            ANDI    #$FF,       R0      ;   8   R0 is lo(a)
            XORR    R0,         R2      ;   6   
            SWAP    R2                  ;   6   R2 is hi(a)

            MOVR    R1,         R3      ;   6   R3 is orig 16-bit b
            ANDI    #$FF,       R1      ;   8   R1 is lo(b)
            MOVR    R1,         R5      ;   6   R5 is lo(b)
            XORR    R1,         R3      ;   6   
            SWAP    R3                  ;   6   R3 is hi(b)
                                        ;----
                                        ;  67
                                        
            ; lo * lo                   
            MOVR    R0,         R4      ;   6   R4 is lo(a)
            ADDI    #QSQR8_TBL.mid, R1  ;   8
            ADDR    R1,         R4      ;   6   R4 = lo(a) + lo(b)
            SUBR    R0,         R1      ;   6   R1 = lo(a) - lo(b)
                                        
@@pos_ll:   MVI@    R4,         R4      ;   8   R4 = qstbl[lo(a)+lo(b)]
            SUB@    R1,         R4      ;   8   R4 = lo(a)*lo(b)
                                        ;----
                                        ;  42
                                        ;  67 (carried forward)
                                        ;----
                                        ; 109
                                       
            ; lo * hi                  
            MOVR    R0,         R1      ;   6   R0 = R1 = lo(a)
            ADDI    #QSQR8_TBL.mid, R3  ;   8
            ADDR    R3,         R1      ;   6   R1 = hi(b) + lo(a)
            SUBR    R0,         R3      ;   6   R3 = hi(b) - lo(a)
                                       
@@pos_lh:   MVI@    R1,         R1      ;   8   R1 = qstbl[hi(b)-lo(a)]
            SUB@    R3,         R1      ;   8   R1 = lo(a)*hi(b)
                                        ;----
                                        ;  42
                                        ; 109 (carried forward)
                                        ;----
                                        ; 151
                                       
            ; hi * lo                  
            MOVR    R5,         R0      ;   6   R5 = R0 = lo(b)
            ADDI    #QSQR8_TBL.mid, R2  ;   8
            ADDR    R2,         R5      ;   6   R3 = hi(a) + lo(b)
            SUBR    R0,         R2      ;   6   R2 = hi(a) - lo(b)
                                       
@@pos_hl:   ADD@    R5,         R1      ;   8   \_ R1 = lo(a)*hi(b)+hi(a)*lo(b)
            SUB@    R2,         R1      ;   8   /
                                        ;----
                                        ;  42
                                        ; 151 (carried forward)
                                        ;----
                                        ; 193
                                       
            SWAP    R1                  ;   6   \_ shift upper product left 8
            ANDI    #$FF00,     R1      ;   8   /
            ADDR    R4,         R1      ;   6   final product
            PULR    PC                  ;  12
                                        ;----
                                        ;  32
                                        ; 193 (carried forward)
                                        ;----
                                        ; 225
            ENDP

	ENDI

	IF DEFINED intybasic_fastdiv

; Fast unsigned division/remainder
; Assembly code by Oscar Toledo G. Jul/10/2015
; Released to public domain.

	; Ultrafast unsigned division/remainder operation
	; Entry: R0 = Dividend
	;        R1 = Divisor
	; Output: R0 = Quotient
	;         R2 = Remainder
	; Worst case: 6 + 6 + 9 + 496 = 517 cycles
	; Best case: 6 + (6 + 7) * 16 = 214 cycles

uf_udiv16:	PROC
	CLRR R2		; 6
	SLLC R0,1	; 6
	BC @@1		; 7/9
	SLLC R0,1	; 6
	BC @@2		; 7/9
	SLLC R0,1	; 6
	BC @@3		; 7/9
	SLLC R0,1	; 6
	BC @@4		; 7/9
	SLLC R0,1	; 6
	BC @@5		; 7/9
	SLLC R0,1	; 6
	BC @@6		; 7/9
	SLLC R0,1	; 6
	BC @@7		; 7/9
	SLLC R0,1	; 6
	BC @@8		; 7/9
	SLLC R0,1	; 6
	BC @@9		; 7/9
	SLLC R0,1	; 6
	BC @@10		; 7/9
	SLLC R0,1	; 6
	BC @@11		; 7/9
	SLLC R0,1	; 6
	BC @@12		; 7/9
	SLLC R0,1	; 6
	BC @@13		; 7/9
	SLLC R0,1	; 6
	BC @@14		; 7/9
	SLLC R0,1	; 6
	BC @@15		; 7/9
	SLLC R0,1	; 6
	BC @@16		; 7/9
	JR R5

@@1:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@2:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@3:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@4:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@5:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@6:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@7:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@8:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@9:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@10:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@11:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@12:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@13:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@14:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@15:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
@@16:	RLC R2,1	; 6
	CMPR R1,R2	; 6
	BNC $+3		; 7/9
	SUBR R1,R2	; 6
	RLC R0,1	; 6
	JR R5
	
	ENDP

	ENDI

	IF DEFINED intybasic_ecs
	ORG $4800	; Available up to $4FFF

        ; Disable ECS ROMs so that they don't conflict with us
        MVII    #$2A5F, R0
        MVO     R0,     $2FFF
        MVII    #$7A5F, R0
        MVO     R0,     $7FFF
        MVII    #$EA5F, R0
        MVO     R0,     $EFFF

        B       $1041       ; resume boot

	ENDI

        ORG $200,$200,"-RWB"

Q2:	; Reserved label for #BACKTAB

	ORG $319,$319,"-RWB"
        ;
        ; 16-bits variables
	; Note IntyBASIC variables grow up starting in $308.
        ;
        IF DEFINED intybasic_voice
IV.Q:      RMB 8    ; IV_xxx        16-bit          Voice queue  (8 words)
IV.FPTR:   RMB 1    ; IV_xxx        16-bit          Current FIFO ptr.
IV.PPTR:   RMB 1    ; IV_xxx        16-bit          Current Phrase ptr.
        ENDI

        ORG $323,$323,"-RWB"

_scroll_buffer: RMB 20  ; Sometimes this is unused
_music_table:	RMB 1	; Note table
_music_start:	RMB 1	; Start of music
_music_p:	RMB 1	; Pointer to music
_frame:         RMB 1   ; Current frame
_read:          RMB 1   ; Pointer to DATA
_gram_bitmap:   RMB 1   ; Bitmap for definition
_gram2_bitmap:  RMB 1   ; Secondary bitmap for definition
_screen:    RMB 1       ; Pointer to current screen position
_color:     RMB 1       ; Current color

Q1:			; Reserved label for #MOBSHADOW
_mobs:      RMB 3*8     ; MOB buffer

_col0:      RMB 1       ; Collision status for MOB0
_col1:      RMB 1       ; Collision status for MOB1
_col2:      RMB 1       ; Collision status for MOB2
_col3:      RMB 1       ; Collision status for MOB3
_col4:      RMB 1       ; Collision status for MOB4
_col5:      RMB 1       ; Collision status for MOB5
_col6:      RMB 1       ; Collision status for MOB6
_col7:      RMB 1       ; Collision status for MOB7

SCRATCH:    ORG $100,$100,"-RWBN"
        ;
        ; 8-bits variables
        ;
ISRVEC:     RMB 2       ; Pointer to ISR vector (required by Intellivision ROM)
_int:       RMB 1       ; Signals interrupt received
_ntsc:      RMB 1       ; Signals NTSC Intellivision
_rand:      RMB 1       ; Pseudo-random value
_gram_target:   RMB 1   ; Contains GRAM card number
_gram_total:    RMB 1   ; Contains total GRAM cards for definition
_gram2_target:  RMB 1   ; Contains GRAM card number
_gram2_total:   RMB 1   ; Contains total GRAM cards for definition
_mode_select:   RMB 1   ; Graphics mode selection
_border_color:  RMB 1   ; Border color
_border_mask:   RMB 1   ; Border mask
    IF DEFINED intybasic_keypad
_cnt1_p0:   RMB 1       ; Debouncing 1
_cnt1_p1:   RMB 1       ; Debouncing 2
_cnt1_key:  RMB 1       ; Currently pressed key
_cnt2_p0:   RMB 1       ; Debouncing 1
_cnt2_p1:   RMB 1       ; Debouncing 2
_cnt2_key:  RMB 1       ; Currently pressed key
    ENDI
    IF DEFINED intybasic_scroll
_scroll_x:  RMB 1       ; Scroll X offset
_scroll_y:  RMB 1       ; Scroll Y offset
_scroll_d:  RMB 1       ; Scroll direction
    ENDI
    IF DEFINED intybasic_music
_music_mode: RMB 1      ; Music mode (0= Not using PSG, 1= Simple, 2= Full)
_music_frame: RMB 1     ; Music frame (for 50 hz fixed)
_music_tc:  RMB 1       ; Time counter
_music_t:   RMB 1       ; Time base
_music_i1:  RMB 1       ; Instrument 1 
_music_s1:  RMB 1       ; Sample pointer 1
_music_n1:  RMB 1       ; Note 1
_music_i2:  RMB 1       ; Instrument 2
_music_s2:  RMB 1       ; Sample pointer 2
_music_n2:  RMB 1       ; Note 2
_music_i3:  RMB 1       ; Instrument 3
_music_s3:  RMB 1       ; Sample pointer 3
_music_n3:  RMB 1       ; Note 3
_music_s4:  RMB 1       ; Sample pointer 4
_music_n4:  RMB 1       ; Note 4 (really it's drum)

_music_freq10:	RMB 1   ; Low byte frequency A
_music_freq20:	RMB 1   ; Low byte frequency B
_music_freq30:	RMB 1   ; Low byte frequency C
_music_freq11:	RMB 1   ; High byte frequency A
_music_freq21:	RMB 1   ; High byte frequency B
_music_freq31:	RMB 1   ; High byte frequency C
_music_mix:	RMB 1   ; Mixer
_music_noise:	RMB 1   ; Noise
_music_vol1:	RMB 1   ; Volume A
_music_vol2:	RMB 1   ; Volume B
_music_vol3:	RMB 1   ; Volume C
    ENDI
    IF DEFINED intybasic_voice
IV.QH:     RMB 1    ; IV_xxx        8-bit           Voice queue head
IV.QT:     RMB 1    ; IV_xxx        8-bit           Voice queue tail
IV.FLEN:   RMB 1    ; IV_xxx        8-bit           Length of FIFO data
    ENDI


V58:	RMB 1	; A
V59:	RMB 1	; B
V39:	RMB 1	; BOOST
V55:	RMB 1	; BOOST_ACTIVE
V38:	RMB 1	; BUBBLES
V54:	RMB 1	; BUBBLE_ACTIVE
V70:	RMB 1	; CASTLEGRID
V51:	RMB 1	; CASTLELOCATION
V60:	RMB 1	; CNT1
V31:	RMB 1	; CREATURE
V32:	RMB 1	; CREATURE1_FACING
V33:	RMB 1	; CREATURE1_FRAME
V35:	RMB 1	; CREATURE1_SPEED
V34:	RMB 1	; CREATURE1_TIMER
V67:	RMB 1	; CREATURE1_UPDOWN
V68:	RMB 1	; CREATURE1_UPDOWN_SPEED
V47:	RMB 1	; CROWNLOCATION
V48:	RMB 1	; CROWNPOSITION
V25:	RMB 1	; CROWN_VISIBLE
V7:	RMB 1	; DIFFLEVEL
V69:	RMB 1	; DIR
V26:	RMB 1	; GOLD_POSITION
V44:	RMB 1	; GOLD_VISIBLE
V21:	RMB 1	; INVENTORY_CROWN
V22:	RMB 1	; INVENTORY_GOLD
V20:	RMB 1	; INVENTORY_KEY
V23:	RMB 1	; INVENTORY_SILVER
V65:	RMB 1	; JUNK
V49:	RMB 1	; KEYLOCATION
V50:	RMB 1	; KEYPOSITION
V24:	RMB 1	; KEY_VISIBLE
V2:	RMB 1	; LEVEL
V9:	RMB 1	; LEVELSELECT
V13:	RMB 1	; LIVES
V37:	RMB 1	; LIVES1UPFLAG
V40:	RMB 1	; MERCHANGE
V56:	RMB 1	; MERCHANGE_ACTIVE
V8:	RMB 1	; MERMAID
V11:	RMB 1	; MERMAIDFACING
V18:	RMB 1	; MERMAIDLOCATION
V10:	RMB 1	; MERMAIDSELECT
V52:	RMB 1	; MERMAID_CASTLELOCATION
V63:	RMB 1	; MERMAID_CASTLELOCATIONX
V64:	RMB 1	; MERMAID_CASTLELOCATIONY
V46:	RMB 1	; MERMAID_OCEANLOCATION
V15:	RMB 1	; MERMAID_SPEED
V19:	RMB 1	; NEXTSCREEN
V62:	RMB 1	; OCEAN_LEVEL_WIDTH
V57:	RMB 1	; PLAYERHIT
V53:	RMB 1	; QUEENLOCATION
V71:	RMB 1	; QUEENMOVEMENT
V41:	RMB 1	; QUEEN_COUNTER
V42:	RMB 1	; QUEEN_FRAME
V36:	RMB 1	; QUEEN_VISIBLE
V27:	RMB 1	; SILVER_POSITION
V45:	RMB 1	; SILVER_VISIBLE
V29:	RMB 1	; SOUNDFLAG
V30:	RMB 1	; SOUND_DURATION
V66:	RMB 1	; SPAWNPOINT
V43:	RMB 1	; SPRITEFRAME
V17:	RMB 1	; STARTING_POINT
V61:	RMB 1	; STARTINTROMUSIC
V16:	RMB 1	; TRACE
V28:	RMB 1	; TREASURE
V14:	RMB 1	; WAITKEYPRESS
Q11:	RMB 100	; CASTLELAYOUT
Q12:	RMB 3	; NOTE
Q8:	RMB 8	; SPRITEX
Q9:	RMB 8	; SPRITEY
_SCRATCH:	EQU $

SYSTEM:	ORG $2F0, $2F0, "-RWBN"
STACK:	RMB 24
V4:	RMB 1	; #BOOST_COUNTER
V3:	RMB 1	; #BUBBLE_COUNTER
V6:	RMB 1	; #COUNTDOWNTIMER
V5:	RMB 1	; #MERCHANGE_COUNTER
V12:	RMB 1	; #MERMAID_COLOR
V1:	RMB 1	; #SCORE
Q10:	RMB 8	; #SPRITEC
_SYSTEM:	EQU $
